Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
actuator (alpha) |  |  |  | Generic simple description of a heating/current drive actuator, for a first simplified version of the Plasma Simulator component
actuator.channels (alpha) | [1...N] | STR_1D |  | ID of the multiple channels of the actuator: Beam boxes for NBI, EC or IC launcher, ...
actuator.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
actuator.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
actuator.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
actuator.code.output_flag (alpha) | [actuator.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
actuator.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
actuator.code.repository (alpha) |  | STR_0D |  | URL of software repository
actuator.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
actuator.generic_dynamic (alpha) | [actuator.channels, actuator.time] | FLT_2D (uncertain) | mixed | Generic 2D dynamic slot for storing an actuator control parameter (e.g. the angle of an ECRH mirror)
actuator.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
actuator.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
actuator.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
actuator.name (alpha) |  | STR_0D | - | Name of the actuator (IC, EC, NBI, LH)
actuator.power (alpha) | [actuator.channels, actuator.time] | FLT_2D (uncertain) | W | Power delivered at the output of the actuator, in the vessel (NB this is before the coupling / beam blocking / shine through / orbit losses calculations)
actuator.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
amns_data (alpha) |  |  |  | Atomic, molecular, nuclear and surface physics data. Each occurrence contains the data for a given element (nuclear charge), describing various physical processes. For each process, data tables are organized by charge states. The coordinate system used by the data tables is described under the coordinate_system node.
amns_data.a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
amns_data.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
amns_data.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
amns_data.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
amns_data.code.output_flag (alpha) | [amns_data.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
amns_data.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
amns_data.code.repository (alpha) |  | STR_0D |  | URL of software repository
amns_data.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
amns_data.coordinate_system (alpha) | [1...N] | STRUCT_ARRAY |  | Array of possible coordinate systems for process tables
amns_data.coordinate_system[:].coordinate (alpha) | [1...N] | STRUCT_ARRAY |  | Set of coordinates for that coordinate system. A coordinate an be either a range of real values or a set of discrete values (if interpolation_type=0)
amns_data.coordinate_system[:].coordinate[:].extrapolation_type (alpha) | [1...2] | INT_1D |  | Extrapolation strategy when leaving the domain. The first value of the vector describes the behaviour at lower bound, the second describes the at upper bound. Possible values: 0=none, report error; 1=boundary value; 2=linear extrapolation
amns_data.coordinate_system[:].coordinate[:].interpolation_type (alpha) |  | INT_0D |  | Interpolation strategy in this coordinate direction. Integer flag: 0=discrete (no interpolation); 1=linear; ...
amns_data.coordinate_system[:].coordinate[:].label (alpha) |  | STR_0D |  | Description of coordinate (e.g. "Electron temperature")
amns_data.coordinate_system[:].coordinate[:].spacing (alpha) |  | INT_0D |  | Flag for specific coordinate spacing (for optimization purposes). Integer flag: 0=undefined; 1=uniform; ...
amns_data.coordinate_system[:].coordinate[:].transformation (alpha) |  | INT_0D |  | Coordinate transformation applied to coordinate values stored in coord. Integer flag: 0=none; 1=log10; 2=ln
amns_data.coordinate_system[:].coordinate[:].units (alpha) |  | STR_0D |  | Units of coordinate (e.g. eV)
amns_data.coordinate_system[:].coordinate[:].value_labels (alpha) | [amns_data.coordinate_system[:].coordinate[:].values] | STR_1D |  | String description of discrete coordinate values (if interpolation_type=0). E.g., for spectroscopic lines, the spectroscopic description of the transition.
amns_data.coordinate_system[:].coordinate[:].values (alpha) | [1...N] | FLT_1D (uncertain) | units given by coordinate_system(:)/coordinate(:)/units | Coordinate values
amns_data.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
amns_data.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
amns_data.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
amns_data.ids_properties.occurrence |  | INT_0D |  |
amns_data.process (alpha) | [1...N] | STRUCT_ARRAY |  | Description and data for a set of physical processes.
amns_data.process[:].charge_state (alpha) | [1...N] | STRUCT_ARRAY |  | Process tables for a set of charge states. Only one table is used for that process, defined by process(:)/table_dimension
amns_data.process[:].charge_state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
amns_data.process[:].charge_state[:].table_0d (alpha) |  | FLT_0D (uncertain) | units given by process(:)/results_units | 0D table describing the process data
amns_data.process[:].charge_state[:].table_1d (alpha) | [amns_data.process[:].charge_state[:].table_1d.coordinate_system[:].coordinate] | FLT_1D (uncertain) | units given by process(:)/results_units | 1D table describing the process data
amns_data.process[:].charge_state[:].table_2d (alpha) | [amns_data.process[:].charge_state[:].table_2d.coordinate_system[:].coordinate, amns_data.process[:].charge_state[:].table_2d.coordinate_system[:].coordinate] | FLT_2D (uncertain) | units given by process(:)/results_units | 2D table describing the process data
amns_data.process[:].charge_state[:].table_3d (alpha) | [amns_data.process[:].charge_state[:].table_3d.coordinate_system[:].coordinate, amns_data.process[:].charge_state[:].table_3d.coordinate_system[:].coordinate, amns_data.process[:].charge_state[:].table_3d.coordinate_system[:].coordinate] | FLT_3D (uncertain) | units given by process(:)/results_units | 3D table describing the process data
amns_data.process[:].charge_state[:].table_4d (alpha) | [amns_data.process[:].charge_state[:].table_4d.coordinate_system[:].coordinate, amns_data.process[:].charge_state[:].table_4d.coordinate_system[:].coordinate, amns_data.process[:].charge_state[:].table_4d.coordinate_system[:].coordinate, amns_data.process[:].charge_state[:].table_4d.coordinate_system[:].coordinate] | FLT_4D (uncertain) | units given by process(:)/results_units | 4D table describing the process data
amns_data.process[:].charge_state[:].table_5d (alpha) | [amns_data.process[:].charge_state[:].table_5d.coordinate_system[:].coordinate, amns_data.process[:].charge_state[:].table_5d.coordinate_system[:].coordinate, amns_data.process[:].charge_state[:].table_5d.coordinate_system[:].coordinate, amns_data.process[:].charge_state[:].table_5d.coordinate_system[:].coordinate, amns_data.process[:].charge_state[:].table_5d.coordinate_system[:].coordinate] | FLT_5D (uncertain) | units given by process(:)/results_units | 5D table describing the process data
amns_data.process[:].charge_state[:].table_6d (alpha) | [amns_data.process[:].charge_state[:].table_6d.coordinate_system[:].coordinate, amns_data.process[:].charge_state[:].table_6d.coordinate_system[:].coordinate, amns_data.process[:].charge_state[:].table_6d.coordinate_system[:].coordinate, amns_data.process[:].charge_state[:].table_6d.coordinate_system[:].coordinate, amns_data.process[:].charge_state[:].table_6d.coordinate_system[:].coordinate, amns_data.process[:].charge_state[:].table_6d.coordinate_system[:].coordinate] | FLT_6D (uncertain) | units given by process(:)/results_units | 6D table describing the process data
amns_data.process[:].charge_state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
amns_data.process[:].charge_state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
amns_data.process[:].coordinate_index (alpha) |  | INT_0D |  | Index in tables_coord, specifying what coordinate systems to use for this process (valid for all tables)
amns_data.process[:].label (alpha) |  | STR_0D |  | String identifying the process (e.g. EI, RC, ...)
amns_data.process[:].products (alpha) | [1...N] | STRUCT_ARRAY |  | Set of products resulting of this process
amns_data.process[:].products[:].charge (alpha) |  | FLT_0D (uncertain) | - | Charge number of the participant
amns_data.process[:].products[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom (in such cas, this array should be of size 1) or molecule
amns_data.process[:].products[:].element[:].a (alpha) |  | INT_0D | Atomic Mass Unit | Number of nucleons in the nucleus (nuclear mass); 0 if none (e-, gamma); Not set if not important (e.g. for an atomic process that is not isotope dependent)
amns_data.process[:].products[:].element[:].label (alpha) |  | STR_0D |  | String identifier for reaction constituent (e.g. "D", "C")
amns_data.process[:].products[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom in the molecule
amns_data.process[:].products[:].element[:].z_n (alpha) |  | INT_0D | Elementary Charge Unit | Nuclear charge. 0 if none (e-, gamma)
amns_data.process[:].products[:].label (alpha) |  | STR_0D |  | String identifying reaction participant (e.g. "D", "e", "W", "CD4", "photon", "n")
amns_data.process[:].products[:].mass (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of the participant
amns_data.process[:].products[:].metastable (alpha) | [1...N] | INT_1D |  | An array identifying the metastable; if zero-length, then not a metastable; if of length 1, then the value indicates the electronic level for the metastable (mostly used for atoms/ions); if of length 2, then the 1st would indicate the electronic level and the second the vibrational level for the metastable (mostly used for molecules and molecular ions); if of length 3, then the 1st would indicate the electronic level, the second the vibrational level and the third the rotational level for the metastable (mostly used for molecules and molecular ions)
amns_data.process[:].products[:].metastable_label (alpha) |  | STR_0D |  | Label identifying in text form the metastable
amns_data.process[:].products[:].multiplicity (alpha) |  | FLT_0D (uncertain) | - | Multiplicity in the reaction
amns_data.process[:].products[:].relative_charge (alpha) |  | INT_0D |  | This is a flag indicating that charges are absolute (if set to 0), relative (if 1) or irrelevant (-1); relative would be used to categorize the ionization reactions from i to i+1 for all charge states; in the case of bundles, the +1 relative indicates the next bundle
amns_data.process[:].products[:].role (alpha) |  | STRUCTURE |  | Identifier for the role of this paricipant in the reaction. For surface reactions distinguish between projectile and wall.
amns_data.process[:].products[:].role.description (alpha) |  | STR_0D |  | Verbose description
amns_data.process[:].products[:].role.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
amns_data.process[:].products[:].role.name (alpha) |  | STR_0D |  | Short string identifier
amns_data.process[:].reactants (alpha) | [1...N] | STRUCT_ARRAY |  | Set of reactants involved in this process
amns_data.process[:].reactants[:].charge (alpha) |  | FLT_0D (uncertain) | - | Charge number of the participant
amns_data.process[:].reactants[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom (in such cas, this array should be of size 1) or molecule
amns_data.process[:].reactants[:].element[:].a (alpha) |  | INT_0D | Atomic Mass Unit | Number of nucleons in the nucleus (nuclear mass); 0 if none (e-, gamma); Not set if not important (e.g. for an atomic process that is not isotope dependent)
amns_data.process[:].reactants[:].element[:].label (alpha) |  | STR_0D |  | String identifier for reaction constituent (e.g. "D", "C")
amns_data.process[:].reactants[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom in the molecule
amns_data.process[:].reactants[:].element[:].z_n (alpha) |  | INT_0D | Elementary Charge Unit | Nuclear charge. 0 if none (e-, gamma)
amns_data.process[:].reactants[:].label (alpha) |  | STR_0D |  | String identifying reaction participant (e.g. "D", "e", "W", "CD4", "photon", "n")
amns_data.process[:].reactants[:].mass (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of the participant
amns_data.process[:].reactants[:].metastable (alpha) | [1...N] | INT_1D |  | An array identifying the metastable; if zero-length, then not a metastable; if of length 1, then the value indicates the electronic level for the metastable (mostly used for atoms/ions); if of length 2, then the 1st would indicate the electronic level and the second the vibrational level for the metastable (mostly used for molecules and molecular ions); if of length 3, then the 1st would indicate the electronic level, the second the vibrational level and the third the rotational level for the metastable (mostly used for molecules and molecular ions)
amns_data.process[:].reactants[:].metastable_label (alpha) |  | STR_0D |  | Label identifying in text form the metastable
amns_data.process[:].reactants[:].multiplicity (alpha) |  | FLT_0D (uncertain) | - | Multiplicity in the reaction
amns_data.process[:].reactants[:].relative_charge (alpha) |  | INT_0D |  | This is a flag indicating that charges are absolute (if set to 0), relative (if 1) or irrelevant (-1); relative would be used to categorize the ionization reactions from i to i+1 for all charge states; in the case of bundles, the +1 relative indicates the next bundle
amns_data.process[:].reactants[:].role (alpha) |  | STRUCTURE |  | Identifier for the role of this paricipant in the reaction. For surface reactions distinguish between projectile and wall.
amns_data.process[:].reactants[:].role.description (alpha) |  | STR_0D |  | Verbose description
amns_data.process[:].reactants[:].role.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
amns_data.process[:].reactants[:].role.name (alpha) |  | STR_0D |  | Short string identifier
amns_data.process[:].result_label (alpha) |  | STR_0D |  | Description of the process result (rate, cross section, sputtering yield, ...)
amns_data.process[:].result_transformation (alpha) |  | INT_0D |  | Transformation of the process result. Integer flag: 0=no transformation; 1=10^; 2=exp()
amns_data.process[:].result_units (alpha) |  | STR_0D |  | Units of the process result
amns_data.process[:].table_dimension (alpha) |  | INT_0D |  | Table dimensionality of the process (1 to 6), valid for all charge states. Indicates which of the tables is filled (below the charge_state node)
amns_data.release (alpha) | [1...N] | STRUCT_ARRAY |  | List of available releases of the AMNS data; each element contains information about the AMNS data that is included in the release. This part of the IDS is filled and stored only into shot/run=0/1, playing the role of a catalogue.
amns_data.release[:].data_entry (alpha) | [1...N] | STRUCT_ARRAY |  | For this release, list of each data item (i.e. shot/run pair containing the actual data) included in this release
amns_data.release[:].data_entry[:].description (alpha) |  | STR_0D |  | Description of this data entry
amns_data.release[:].data_entry[:].run (alpha) |  | INT_0D |  | Which run number is the active run number for this version
amns_data.release[:].data_entry[:].shot (alpha) |  | INT_0D |  | Shot number = Mass*100+Nuclear_charge
amns_data.release[:].date (alpha) |  | STR_0D |  | Date of this release
amns_data.release[:].description (alpha) |  | STR_0D |  | Description of this release
amns_data.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
amns_data.z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
bolometer (alpha) |  |  |  | Bolometer diagnostic
bolometer.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (detector or pixel of a camera)
bolometer.channel[:].aperture (alpha) | [1...N] | STRUCT_ARRAY |  | Description of a set of collimating apertures
bolometer.channel[:].aperture[:].centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the center of the circle. If geometry_type=1, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
bolometer.channel[:].aperture[:].centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
bolometer.channel[:].aperture[:].centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
bolometer.channel[:].aperture[:].centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
bolometer.channel[:].aperture[:].geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3.
bolometer.channel[:].aperture[:].outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system
bolometer.channel[:].aperture[:].outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
bolometer.channel[:].aperture[:].outline.x2 (alpha) | [bolometer.channel[:].aperture[:].outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
bolometer.channel[:].aperture[:].radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
bolometer.channel[:].aperture[:].x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented is the positive phi direction (counter-clockwise when seen from above).
bolometer.channel[:].aperture[:].x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
bolometer.channel[:].aperture[:].x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
bolometer.channel[:].aperture[:].x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
bolometer.channel[:].aperture[:].x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
bolometer.channel[:].aperture[:].x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
bolometer.channel[:].aperture[:].x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
bolometer.channel[:].aperture[:].x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
bolometer.channel[:].aperture[:].x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
bolometer.channel[:].aperture[:].x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
bolometer.channel[:].aperture[:].x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
bolometer.channel[:].aperture[:].x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
bolometer.channel[:].detector (alpha) |  | STRUCTURE |  | Detector description
bolometer.channel[:].detector.centre (alpha) |  | STRUCTURE |  | If geometry_type=2, coordinates of the center of the circle. If geometry_type=1, coordinates of the origin of the local coordinate system (X1,X2,X3) describing the plane detector/aperture. This origin is located within the detector/aperture area.
bolometer.channel[:].detector.centre.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
bolometer.channel[:].detector.centre.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
bolometer.channel[:].detector.centre.z (alpha) |  | FLT_0D (uncertain) | m | Height
bolometer.channel[:].detector.geometry_type (alpha) |  | INT_0D |  | Type of geometry used to describe the surface of the detector or aperture (1:'outline', 2:'circular'). In case of 'outline', the surface is described by an outline of point in a local coordinate system defined by a centre and three unit vectors X1, X2, X3. In case of 'circular', the surface is a circle defined by its centre, radius, and normal vector oriented towards the plasma X3.
bolometer.channel[:].detector.outline (alpha) |  | STRUCTURE |  | Irregular outline of the detector/aperture in the (X1, X2) coordinate system
bolometer.channel[:].detector.outline.x1 (alpha) | [1...N] | FLT_1D (uncertain) | m | Positions along x1 axis
bolometer.channel[:].detector.outline.x2 (alpha) | [bolometer.channel[:].detector.outline.x1] | FLT_1D (uncertain) | m | Positions along x2 axis
bolometer.channel[:].detector.radius (alpha) |  | FLT_0D (uncertain) | m | Radius of the circle, used only if geometry_type = 2
bolometer.channel[:].detector.x1_unit_vector (alpha) |  | STRUCTURE |  | Components of the X1 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X1 vector is horizontal and oriented is the positive phi direction (counter-clockwise when seen from above).
bolometer.channel[:].detector.x1_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
bolometer.channel[:].detector.x1_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
bolometer.channel[:].detector.x1_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
bolometer.channel[:].detector.x2_unit_vector (alpha) |  | STRUCTURE |  | Components of the X2 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X2 axis is orthonormal so that uX2 = uX3 x uX1.
bolometer.channel[:].detector.x2_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
bolometer.channel[:].detector.x2_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
bolometer.channel[:].detector.x2_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
bolometer.channel[:].detector.x3_unit_vector (alpha) |  | STRUCTURE |  | Components of the X3 direction unit vector in the (X,Y,Z) coordinate system, where X is the major radius axis for phi = 0, Y is the major radius axis for phi = pi/2, and Z is the height axis. The X3 axis is normal to the detector/aperture plane and oriented towards the plasma.
bolometer.channel[:].detector.x3_unit_vector.x (alpha) |  | FLT_0D (uncertain) | m | Component along X axis
bolometer.channel[:].detector.x3_unit_vector.y (alpha) |  | FLT_0D (uncertain) | m | Component along Y axis
bolometer.channel[:].detector.x3_unit_vector.z (alpha) |  | FLT_0D (uncertain) | m | Component along Z axis
bolometer.channel[:].identifier (alpha) |  | STR_0D |  | ID of the channel
bolometer.channel[:].line_of_sight (alpha) |  | STRUCTURE |  | Description of the reference line of sight of the channel, defined by two points when the beam is not reflected, a third point is added to define the reflected beam path
bolometer.channel[:].line_of_sight.first_point (alpha) |  | STRUCTURE |  | Position of the first point
bolometer.channel[:].line_of_sight.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
bolometer.channel[:].line_of_sight.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
bolometer.channel[:].line_of_sight.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
bolometer.channel[:].line_of_sight.second_point (alpha) |  | STRUCTURE |  | Position of the second point
bolometer.channel[:].line_of_sight.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
bolometer.channel[:].line_of_sight.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
bolometer.channel[:].line_of_sight.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
bolometer.channel[:].line_of_sight.third_point (alpha) |  | STRUCTURE |  | Position of the third point
bolometer.channel[:].line_of_sight.third_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
bolometer.channel[:].line_of_sight.third_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
bolometer.channel[:].line_of_sight.third_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
bolometer.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
bolometer.channel[:].power (alpha) |  | STRUCTURE |  | Power received on the detector
bolometer.channel[:].power.data (alpha) | [bolometer.channel[:].power.time] | FLT_1D (uncertain) | W | Power received on the detector
bolometer.channel[:].power.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
bolometer.channel[:].validity (alpha) |  | INT_0D |  | Indicator of the validity of the channel for the whole acquisition period (0 means valid, negative values mean non-valid)
bolometer.channel[:].validity_timed (alpha) |  | STRUCTURE |  | Indicator of the validity of the channel as a function of time (0 means valid, negative values mean non-valid)
bolometer.channel[:].validity_timed.data (alpha) | [bolometer.channel[:].validity_timed.time] | INT_1D |  | Indicator of the validity of the channel as a function of time (0 means valid, negative values mean non-valid)
bolometer.channel[:].validity_timed.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
bolometer.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
bolometer.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
bolometer.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
bolometer.code.output_flag (alpha) | [bolometer.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
bolometer.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
bolometer.code.repository (alpha) |  | STR_0D |  | URL of software repository
bolometer.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
bolometer.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
bolometer.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
bolometer.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
bolometer.ids_properties.occurrence |  | INT_0D |  |
bolometer.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
charge_exchange (alpha) |  |  |  | Charge exchange spectroscopy diagnostic
charge_exchange.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (lines-of-sight)
charge_exchange.channel[:].a (alpha) | [charge_exchange.channel[:].channel_names] | FLT_1D (uncertain) | Atomic Mass Unit | Mass of atom of the emmitting impurity. Varies according to channels since they are spanning different lines of sight
charge_exchange.channel[:].identifier (alpha) |  | STR_0D |  | ID of the channel
charge_exchange.channel[:].label (alpha) | [charge_exchange.channel[:].channel_names] | STR_1D |  | String identifying the emmitting impurity (e.g. H+, D+, T+, He+2, C+6, ...)
charge_exchange.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
charge_exchange.channel[:].position (alpha) |  | STRUCTURE |  | Position of the measurements
charge_exchange.channel[:].position.phi (alpha) |  | STRUCTURE |  | Toroidal angle
charge_exchange.channel[:].position.phi.data (alpha) | [charge_exchange.channel[:].position.phi.time] | FLT_1D (uncertain) | rad | Toroidal angle
charge_exchange.channel[:].position.phi.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
charge_exchange.channel[:].position.r (alpha) |  | STRUCTURE |  | Major radius
charge_exchange.channel[:].position.r.data (alpha) | [charge_exchange.channel[:].position.r.time] | FLT_1D (uncertain) | m | Major radius
charge_exchange.channel[:].position.r.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
charge_exchange.channel[:].position.z (alpha) |  | STRUCTURE |  | Height
charge_exchange.channel[:].position.z.data (alpha) | [charge_exchange.channel[:].position.z.time] | FLT_1D (uncertain) | m | Height
charge_exchange.channel[:].position.z.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
charge_exchange.channel[:].temperature (alpha) |  | STRUCTURE |  | Ion temperature (of the emmitting impurity)
charge_exchange.channel[:].temperature.data (alpha) | [charge_exchange.channel[:].temperature.time] | FLT_1D (uncertain) | eV | Ion temperature (of the emmitting impurity)
charge_exchange.channel[:].temperature.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
charge_exchange.channel[:].velocity_pol (alpha) |  | STRUCTURE |  | Poloidal velocity (of the emmitting impurity)
charge_exchange.channel[:].velocity_pol.data (alpha) | [charge_exchange.channel[:].velocity_pol.time] | FLT_1D (uncertain) | eV | Poloidal velocity (of the emmitting impurity)
charge_exchange.channel[:].velocity_pol.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
charge_exchange.channel[:].velocity_tor (alpha) |  | STRUCTURE |  | Toroidal velocity (of the emmitting impurity)
charge_exchange.channel[:].velocity_tor.data (alpha) | [charge_exchange.channel[:].velocity_tor.time] | FLT_1D (uncertain) | eV | Toroidal velocity (of the emmitting impurity)
charge_exchange.channel[:].velocity_tor.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
charge_exchange.channel[:].z_ion (alpha) | [charge_exchange.channel[:].channel_names] | FLT_1D (uncertain) | Elementary Charge Unit | Ion charge of the emmitting impurity. Varies according to channels since they are spanning different lines of sight
charge_exchange.channel[:].z_n (alpha) | [charge_exchange.channel[:].channel_names] | FLT_1D (uncertain) | Elementary Charge Unit | Nuclear charge of the emmitting impurity. Varies according to channels since they are spanning different lines of sight
charge_exchange.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
charge_exchange.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
charge_exchange.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
charge_exchange.code.output_flag (alpha) | [charge_exchange.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
charge_exchange.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
charge_exchange.code.repository (alpha) |  | STR_0D |  | URL of software repository
charge_exchange.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
charge_exchange.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
charge_exchange.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
charge_exchange.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
charge_exchange.ids_properties.occurrence |  | INT_0D |  |
charge_exchange.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
controllers (alpha) |  |  |  | Feedback and feedforward controllers
controllers.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
controllers.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
controllers.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
controllers.code.output_flag (alpha) | [controllers.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
controllers.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
controllers.code.repository (alpha) |  | STR_0D |  | URL of software repository
controllers.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
controllers.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
controllers.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
controllers.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
controllers.ids_properties.occurrence |  | INT_0D |  |
controllers.linear_controller (alpha) | [1...N] | STRUCT_ARRAY |  | A linear controller, this is rather conventional
controllers.linear_controller[:].controller_class (alpha) |  | STR_0D |  | One of a known class of controllers
controllers.linear_controller[:].description (alpha) |  | STR_0D |  | Description of this controller
controllers.linear_controller[:].input_names (alpha) | [1...N] | STR_1D |  | Names of the input signals, following the SDN convention
controllers.linear_controller[:].inputs (alpha) |  | STRUCTURE |  | Input signals; the timebase is common to inputs and outputs for any particular controller
controllers.linear_controller[:].inputs.data (alpha) | [controllers.linear_controller[:].input_names, controllers.linear_controller[:].inputs.time] | FLT_2D (uncertain) | mixed | Input signals; the timebase is common to inputs and outputs for any particular controller
controllers.linear_controller[:].inputs.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
controllers.linear_controller[:].name (alpha) |  | STR_0D |  | Name of this controller
controllers.linear_controller[:].output_names (alpha) | [1...N] | STR_1D |  | Names of the output signals following the SDN convention
controllers.linear_controller[:].outputs (alpha) |  | STRUCTURE |  | Output signals; the timebase is common to inputs and outputs for any particular controller
controllers.linear_controller[:].outputs.data (alpha) | [controllers.linear_controller[:].output_names, controllers.linear_controller[:].outputs.time] | FLT_2D (uncertain) | mixed | Output signals; the timebase is common to inputs and outputs for any particular controller
controllers.linear_controller[:].outputs.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
controllers.linear_controller[:].pid (alpha) |  | STRUCTURE |  | Filtered PID controller
controllers.linear_controller[:].pid.d (alpha) |  | STRUCTURE |  | Derivative term
controllers.linear_controller[:].pid.d.data (alpha) | [controllers.linear_controller[:].pid.output_names, controllers.linear_controller[:].pid.input_names, controllers.linear_controller[:].pid.d.time] | FLT_3D (uncertain) | mixed | Derivative term
controllers.linear_controller[:].pid.d.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
controllers.linear_controller[:].pid.i (alpha) |  | STRUCTURE |  | Integral term
controllers.linear_controller[:].pid.i.data (alpha) | [controllers.linear_controller[:].pid.output_names, controllers.linear_controller[:].pid.input_names, controllers.linear_controller[:].pid.i.time] | FLT_3D (uncertain) | mixed | Integral term
controllers.linear_controller[:].pid.i.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
controllers.linear_controller[:].pid.p (alpha) |  | STRUCTURE |  | Proportional term
controllers.linear_controller[:].pid.p.data (alpha) | [controllers.linear_controller[:].pid.output_names, controllers.linear_controller[:].pid.input_names, controllers.linear_controller[:].pid.p.time] | FLT_3D (uncertain) | mixed | Proportional term
controllers.linear_controller[:].pid.p.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
controllers.linear_controller[:].pid.tau (alpha) |  | STRUCTURE |  | Filter time-constant for the D-term
controllers.linear_controller[:].pid.tau.data (alpha) | [controllers.linear_controller[:].pid.tau.time] | FLT_1D (uncertain) | s | Filter time-constant for the D-term
controllers.linear_controller[:].pid.tau.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
controllers.linear_controller[:].statespace (alpha) |  | STRUCTURE |  | Statespace controller in discrete or continuous time
controllers.linear_controller[:].statespace.a (alpha) |  | STRUCTURE |  | A matrix
controllers.linear_controller[:].statespace.a.data (alpha) | [controllers.linear_controller[:].statespace.state_names, controllers.linear_controller[:].statespace.state_names, controllers.linear_controller[:].statespace.a.time] | FLT_3D (uncertain) | mixed | A matrix
controllers.linear_controller[:].statespace.a.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
controllers.linear_controller[:].statespace.b (alpha) |  | STRUCTURE |  | B matrix
controllers.linear_controller[:].statespace.b.data (alpha) | [controllers.linear_controller[:].statespace.state_names, controllers.linear_controller[:].input_names, controllers.linear_controller[:].statespace.b.time] | FLT_3D (uncertain) | mixed | B matrix
controllers.linear_controller[:].statespace.b.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
controllers.linear_controller[:].statespace.c (alpha) |  | STRUCTURE |  | C matrix
controllers.linear_controller[:].statespace.c.data (alpha) | [controllers.linear_controller[:].statespace.state_names, controllers.linear_controller[:].output_names, controllers.linear_controller[:].statespace.c.time] | FLT_3D (uncertain) | mixed | C matrix
controllers.linear_controller[:].statespace.c.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
controllers.linear_controller[:].statespace.d (alpha) |  | STRUCTURE |  | D matrix, normally proper and D=0
controllers.linear_controller[:].statespace.d.data (alpha) | [controllers.linear_controller[:].statespace.input_names, controllers.linear_controller[:].output_names, controllers.linear_controller[:].statespace.d.time] | FLT_3D (uncertain) | mixed | D matrix, normally proper and D=0
controllers.linear_controller[:].statespace.d.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
controllers.linear_controller[:].statespace.deltat (alpha) |  | STRUCTURE |  | Discrete time sampling interval ; if less than 1e-10, the controller is considered to be expressed in continuous time
controllers.linear_controller[:].statespace.deltat.data (alpha) | [controllers.linear_controller[:].statespace.deltat.time] | FLT_1D (uncertain) | s | Discrete time sampling interval ; if less than 1e-10, the controller is considered to be expressed in continuous time
controllers.linear_controller[:].statespace.deltat.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
controllers.linear_controller[:].statespace.state_names (alpha) | [1...N] | STR_1D |  | Names of the states
controllers.nonlinear_controller (alpha) | [1...N] | STRUCT_ARRAY |  | A non-linear controller, this is less conventional and will have to be developed
controllers.nonlinear_controller[:].controller_class (alpha) |  | STR_0D |  | One of a known class of controllers
controllers.nonlinear_controller[:].description (alpha) |  | STR_0D |  | Description of this controller
controllers.nonlinear_controller[:].function (alpha) |  | STR_0D |  | Method to be defined
controllers.nonlinear_controller[:].input_names (alpha) | [1...N] | STR_1D |  | Names of the input signals, following the SDN convention
controllers.nonlinear_controller[:].inputs (alpha) |  | STRUCTURE |  | Input signals; the timebase is common to inputs and outputs for any particular controller
controllers.nonlinear_controller[:].inputs.data (alpha) | [controllers.nonlinear_controller[:].input_names, controllers.nonlinear_controller[:].inputs.time] | FLT_2D (uncertain) | mixed | Input signals; the timebase is common to inputs and outputs for any particular controller
controllers.nonlinear_controller[:].inputs.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
controllers.nonlinear_controller[:].name (alpha) |  | STR_0D |  | Name of this controller
controllers.nonlinear_controller[:].output_names (alpha) | [1...N] | STR_1D |  | Output signal names following the SDN convention
controllers.nonlinear_controller[:].outputs (alpha) |  | STRUCTURE |  | Output signals; the timebase is common to inputs and outputs for any particular controller
controllers.nonlinear_controller[:].outputs.data (alpha) | [controllers.nonlinear_controller[:].output_names, controllers.nonlinear_controller[:].outputs.time] | FLT_2D (uncertain) | mixed | Output signals; the timebase is common to inputs and outputs for any particular controller
controllers.nonlinear_controller[:].outputs.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
controllers.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
core_instant_changes |  |  |  | Instant changes of the radial core plasma profiles due to pellet, MHD, ...
core_instant_changes.change | [1...N] | STRUCT_ARRAY |  | Set of instant change terms (each being due to a different phenomenon)
core_instant_changes.change[:].identifier |  | STRUCTURE |  | Instant change term identifier
core_instant_changes.change[:].identifier.description |  | STR_0D |  | Verbose description
core_instant_changes.change[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list)
core_instant_changes.change[:].identifier.name |  | STR_0D |  | Short string identifier
core_instant_changes.change[:].profiles_1d | [core_instant_changes.change[:].profiles_1d[:].time] | STRUCT_ARRAY |  | Changes in 1D core profiles for various time slices. This structure mirrors core_profiles/profiles_1d and describes instant changes to each of these physical quantities (i.e. a signed difference quantity after change - quantity before change)
core_instant_changes.change[:].profiles_1d[:].conductivity_parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | ohm^-1.m^-1 | Parallel conductivity
core_instant_changes.change[:].profiles_1d[:].e_field |  | STRUCTURE | V.m^-1 | Electric field, averaged on the magnetic surface. E.g for the parellel component, average(E.B) / B0, using core_profiles/vacuum_toroidal_field/b0
core_instant_changes.change[:].profiles_1d[:].e_field.diamagnetic | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Diamagnetic component
core_instant_changes.change[:].profiles_1d[:].e_field.parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Parallel component
core_instant_changes.change[:].profiles_1d[:].e_field.poloidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Poloidal component
core_instant_changes.change[:].profiles_1d[:].e_field.radial | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Radial component
core_instant_changes.change[:].profiles_1d[:].e_field.toroidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Toroidal component
core_instant_changes.change[:].profiles_1d[:].e_field_parallel (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Parallel electric field = average(E.B) / B0, where Core_Profiles/Vacuum_Toroidal_Field/ B0
core_instant_changes.change[:].profiles_1d[:].electrons |  | STRUCTURE |  | Quantities related to the electrons
core_instant_changes.change[:].profiles_1d[:].electrons.density | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].electrons.density_fast | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
core_instant_changes.change[:].profiles_1d[:].electrons.pressure | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].electrons.pressure_fast_parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
core_instant_changes.change[:].profiles_1d[:].electrons.pressure_fast_perpendicular | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
core_instant_changes.change[:].profiles_1d[:].electrons.temperature | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
core_instant_changes.change[:].profiles_1d[:].electrons.velocity |  | STRUCTURE | m.s^-1 | Velocity
core_instant_changes.change[:].profiles_1d[:].electrons.velocity.diamagnetic | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_instant_changes.change[:].profiles_1d[:].electrons.velocity.parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_instant_changes.change[:].profiles_1d[:].electrons.velocity.poloidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_instant_changes.change[:].profiles_1d[:].electrons.velocity.radial | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_instant_changes.change[:].profiles_1d[:].electrons.velocity.toroidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_instant_changes.change[:].profiles_1d[:].electrons.velocity_pol (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
core_instant_changes.change[:].profiles_1d[:].electrons.velocity_tor (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
core_instant_changes.change[:].profiles_1d[:].grid |  | STRUCTURE |  | Radial grid
core_instant_changes.change[:].profiles_1d[:].grid.area | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
core_instant_changes.change[:].profiles_1d[:].grid.psi | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
core_instant_changes.change[:].profiles_1d[:].grid.rho_tor | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
core_instant_changes.change[:].profiles_1d[:].grid.volume | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
core_instant_changes.change[:].profiles_1d[:].ion | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
core_instant_changes.change[:].profiles_1d[:].ion[:].density | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].density_fast | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_instant_changes.change[:].profiles_1d[:].ion[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_instant_changes.change[:].profiles_1d[:].ion[:].element[:].multiplicity |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_instant_changes.change[:].profiles_1d[:].ion[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_instant_changes.change[:].profiles_1d[:].ion[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
core_instant_changes.change[:].profiles_1d[:].ion[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_instant_changes.change[:].profiles_1d[:].ion[:].neutral_index |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
core_instant_changes.change[:].profiles_1d[:].ion[:].pressure | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].pressure_fast_parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].pressure_fast_perpendicular | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].state | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].density_fast | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].ionisation_potential |  | FLT_0D (uncertain) | Elementary Charge Unit | Cumulative and average ionisation potential to reach a given bundle. Defined as sum (x_z* (sum of Epot from z'=0 to z-1)), where Epot is the ionisation potential of ion Xz’+, and x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].label |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].pressure | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].pressure_fast_parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].pressure_fast_perpendicular | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].temperature | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].velocity |  | STRUCTURE | m.s^-1 | Velocity
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].velocity.diamagnetic | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].velocity.parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].velocity.poloidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].velocity.radial | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].velocity.toroidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].z_average |  | FLT_0D (uncertain) | Elementary Charge Unit | Average Z of the charge state bundle (equal to z_min if no bundle), = sum (Z*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].z_max |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].z_min |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
core_instant_changes.change[:].profiles_1d[:].ion[:].state[:].z_square_average |  | FLT_0D (uncertain) | Elementary Charge Unit | Average Z square of the charge state bundle (equal to z_min if no bundle), = sum (Z^2*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_instant_changes.change[:].profiles_1d[:].ion[:].temperature | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity |  | STRUCTURE | m.s^-1 | Velocity (average over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity.diamagnetic | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity.parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity.poloidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity.radial | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity.toroidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity_pol (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity (average over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].velocity_tor (obsolescent) | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity (average over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].ion[:].z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed), volume averaged over plasma radius
core_instant_changes.change[:].profiles_1d[:].ion[:].z_ion_1d | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Average charge of the ion species (sum of states charge weighted by state density and divided by ion density)
core_instant_changes.change[:].profiles_1d[:].ion[:].z_ion_square_1d | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Average sqare charge of the ion species (sum of states square charge weighted by state density and divided by ion density)
core_instant_changes.change[:].profiles_1d[:].j_bootstrap | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Bootstrap current density = average(J_Bootstrap.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_instant_changes.change[:].profiles_1d[:].j_non_inductive | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Non-inductive (includes bootstrap) parallel current density = average(jni.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_instant_changes.change[:].profiles_1d[:].j_ohmic | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Ohmic parallel current density = average(J_Ohmic.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_instant_changes.change[:].profiles_1d[:].j_tor | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Total toroidal current density = average(J_Tor/R) / average(1/R)
core_instant_changes.change[:].profiles_1d[:].j_total | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Total parallel current density = average(jtot.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_instant_changes.change[:].profiles_1d[:].magnetic_shear | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
core_instant_changes.change[:].profiles_1d[:].momentum_tor | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-1 | Total plasma toroidal momentum, summed over ion species and electrons weighted by their density and major radius, i.e. sum_over_species(n*R*m*Vphi)
core_instant_changes.change[:].profiles_1d[:].n_i_total_over_n_e | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Ratio of total ion density (sum over species and charge states) over electron density. (thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].neutral | [1...N] | STRUCT_ARRAY |  | Quantities related to the different neutral species
core_instant_changes.change[:].profiles_1d[:].neutral[:].density | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].density_fast | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_instant_changes.change[:].profiles_1d[:].neutral[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_instant_changes.change[:].profiles_1d[:].neutral[:].element[:].multiplicity |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_instant_changes.change[:].profiles_1d[:].neutral[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_instant_changes.change[:].profiles_1d[:].neutral[:].ion_index |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
core_instant_changes.change[:].profiles_1d[:].neutral[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
core_instant_changes.change[:].profiles_1d[:].neutral[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_instant_changes.change[:].profiles_1d[:].neutral[:].pressure | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].pressure_fast_parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].pressure_fast_perpendicular | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (sum over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].state | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (energy, excitation, ...)
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].density | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].density_fast | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].label |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].neutral_type |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].neutral_type.description |  | STR_0D |  | Verbose description
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].neutral_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list)
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].neutral_type.name |  | STR_0D |  | Short string identifier
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].pressure | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].pressure_fast_parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].pressure_fast_perpendicular | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].temperature | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].velocity |  | STRUCTURE | m.s^-1 | Velocity
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].velocity.diamagnetic | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].velocity.parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].velocity.poloidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].velocity.radial | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].velocity.toroidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_instant_changes.change[:].profiles_1d[:].neutral[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_instant_changes.change[:].profiles_1d[:].neutral[:].temperature | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].velocity |  | STRUCTURE | m.s^-1 | Velocity (average over charge states when multiple charge states are considered)
core_instant_changes.change[:].profiles_1d[:].neutral[:].velocity.diamagnetic | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_instant_changes.change[:].profiles_1d[:].neutral[:].velocity.parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_instant_changes.change[:].profiles_1d[:].neutral[:].velocity.poloidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_instant_changes.change[:].profiles_1d[:].neutral[:].velocity.radial | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_instant_changes.change[:].profiles_1d[:].neutral[:].velocity.toroidal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_instant_changes.change[:].profiles_1d[:].pressure_ion_total | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total (sum over ion species) thermal ion pressure
core_instant_changes.change[:].profiles_1d[:].pressure_parallel | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total parallel pressure (electrons+ions, thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].pressure_perpendicular | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total perpendicular pressure (electrons+ions, thermal+non-thermal)
core_instant_changes.change[:].profiles_1d[:].pressure_thermal | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Thermal pressure (electrons+ions)
core_instant_changes.change[:].profiles_1d[:].q | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Safety factor
core_instant_changes.change[:].profiles_1d[:].t_i_average | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Ion temperature (averaged on charge states and ion species)
core_instant_changes.change[:].profiles_1d[:].time |  | FLT_0D | s | Time
core_instant_changes.change[:].profiles_1d[:].zeff | [core_instant_changes.change[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Effective charge
core_instant_changes.code |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
core_instant_changes.code.commit |  | STR_0D |  | Unique commit reference of software
core_instant_changes.code.name |  | STR_0D |  | Name of software generating IDS
core_instant_changes.code.output_flag | [core_instant_changes.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
core_instant_changes.code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
core_instant_changes.code.repository |  | STR_0D |  | URL of software repository
core_instant_changes.code.version |  | STR_0D |  | Unique version (tag) of software
core_instant_changes.ids_properties |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
core_instant_changes.ids_properties.comment |  | STR_0D |  | Any comment describing the content of this IDS
core_instant_changes.ids_properties.homogeneous_time |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
core_instant_changes.ids_properties.occurrence |  | INT_0D |  |
core_instant_changes.time | [1...N] | FLT_1D_TYPE |  | Generic time [s]
core_instant_changes.vacuum_toroidal_field |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in Rho_Tor definition and in the normalization of current densities)
core_instant_changes.vacuum_toroidal_field.b0 | [core_instant_changes.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewed from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
core_instant_changes.vacuum_toroidal_field.r0 |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
core_profiles |  |  |  | Core plasma radial profiles
core_profiles.code |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
core_profiles.code.commit |  | STR_0D |  | Unique commit reference of software
core_profiles.code.name |  | STR_0D |  | Name of software generating IDS
core_profiles.code.output_flag | [core_profiles.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
core_profiles.code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
core_profiles.code.repository |  | STR_0D |  | URL of software repository
core_profiles.code.version |  | STR_0D |  | Unique version (tag) of software
core_profiles.global_quantities |  | STRUCTURE |  | Various global quantities derived from the profiles
core_profiles.global_quantities.beta_pol | [core_profiles.time] | FLT_1D (uncertain) | - | Poloidal beta. Defined as betap = 4 int(p dV) / [R_0 * mu_0 * Ip^2]
core_profiles.global_quantities.beta_tor | [core_profiles.time] | FLT_1D (uncertain) | - | Toroidal beta, defined as the volume-averaged total perpendicular pressure divided by (B0^2/(2*mu0)), i.e. beta_toroidal = 2 mu0 int(p dV) / V / B0^2
core_profiles.global_quantities.beta_tor_norm | [core_profiles.time] | FLT_1D (uncertain) | - | Normalised toroidal beta, defined as 100 * beta_tor * a[m] * B0 [T] / ip [MA]
core_profiles.global_quantities.current_bootstrap | [core_profiles.time] | FLT_1D (uncertain) | A | Bootstrap current
core_profiles.global_quantities.current_non_inductive | [core_profiles.time] | FLT_1D (uncertain) | A | Total non-inductive parallel current
core_profiles.global_quantities.energy_diamagnetic | [core_profiles.time] | FLT_1D (uncertain) | J | Plasma energy content = 3/2 * integral over the plasma volume of the total perpendicular pressure
core_profiles.global_quantities.ip | [core_profiles.time] | FLT_1D (uncertain) | A | Total plasma current
core_profiles.global_quantities.li (obsolescent) | [core_profiles.time] | FLT_1D (uncertain) | - | Internal inductance. The li_3 definition is used, i.e. li_3 = 2/R0/mu0^2/Ip^2 * int(Bp^2 dV).
core_profiles.global_quantities.li_3 | [core_profiles.time] | FLT_1D (uncertain) | - | Internal inductance. The li_3 definition is used, i.e. li_3 = 2/R0/mu0^2/Ip^2 * int(Bp^2 dV).
core_profiles.global_quantities.v_loop | [core_profiles.time] | FLT_1D (uncertain) | V | LCFS loop voltage
core_profiles.ids_properties |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
core_profiles.ids_properties.comment |  | STR_0D |  | Any comment describing the content of this IDS
core_profiles.ids_properties.homogeneous_time |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
core_profiles.ids_properties.occurrence |  | INT_0D |  |
core_profiles.profiles_1d | [core_profiles.profiles_1d[:].time] | STRUCT_ARRAY |  | Core plasma radial profiles for various time slices
core_profiles.profiles_1d[:].conductivity_parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | ohm^-1.m^-1 | Parallel conductivity
core_profiles.profiles_1d[:].e_field |  | STRUCTURE | V.m^-1 | Electric field, averaged on the magnetic surface. E.g for the parellel component, average(E.B) / B0, using core_profiles/vacuum_toroidal_field/b0
core_profiles.profiles_1d[:].e_field.diamagnetic | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Diamagnetic component
core_profiles.profiles_1d[:].e_field.parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Parallel component
core_profiles.profiles_1d[:].e_field.poloidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Poloidal component
core_profiles.profiles_1d[:].e_field.radial | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Radial component
core_profiles.profiles_1d[:].e_field.toroidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Toroidal component
core_profiles.profiles_1d[:].e_field_parallel (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Parallel electric field = average(E.B) / B0, where Core_Profiles/Vacuum_Toroidal_Field/ B0
core_profiles.profiles_1d[:].electrons |  | STRUCTURE |  | Quantities related to the electrons
core_profiles.profiles_1d[:].electrons.density | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
core_profiles.profiles_1d[:].electrons.density_fast | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
core_profiles.profiles_1d[:].electrons.pressure | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
core_profiles.profiles_1d[:].electrons.pressure_fast_parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
core_profiles.profiles_1d[:].electrons.pressure_fast_perpendicular | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
core_profiles.profiles_1d[:].electrons.temperature | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
core_profiles.profiles_1d[:].electrons.velocity |  | STRUCTURE | m.s^-1 | Velocity
core_profiles.profiles_1d[:].electrons.velocity.diamagnetic | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_profiles.profiles_1d[:].electrons.velocity.parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_profiles.profiles_1d[:].electrons.velocity.poloidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_profiles.profiles_1d[:].electrons.velocity.radial | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_profiles.profiles_1d[:].electrons.velocity.toroidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_profiles.profiles_1d[:].electrons.velocity_pol (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
core_profiles.profiles_1d[:].electrons.velocity_tor (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
core_profiles.profiles_1d[:].grid |  | STRUCTURE |  | Radial grid
core_profiles.profiles_1d[:].grid.area | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
core_profiles.profiles_1d[:].grid.psi | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
core_profiles.profiles_1d[:].grid.rho_tor | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
core_profiles.profiles_1d[:].grid.rho_tor_norm | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
core_profiles.profiles_1d[:].grid.volume | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
core_profiles.profiles_1d[:].ion | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
core_profiles.profiles_1d[:].ion[:].density | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].density_fast | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_profiles.profiles_1d[:].ion[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_profiles.profiles_1d[:].ion[:].element[:].multiplicity |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_profiles.profiles_1d[:].ion[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_profiles.profiles_1d[:].ion[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
core_profiles.profiles_1d[:].ion[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_profiles.profiles_1d[:].ion[:].neutral_index |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
core_profiles.profiles_1d[:].ion[:].pressure | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].pressure_fast_parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].pressure_fast_perpendicular | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].state | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
core_profiles.profiles_1d[:].ion[:].state[:].density | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
core_profiles.profiles_1d[:].ion[:].state[:].density_fast | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
core_profiles.profiles_1d[:].ion[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_profiles.profiles_1d[:].ion[:].state[:].ionisation_potential |  | FLT_0D (uncertain) | Elementary Charge Unit | Cumulative and average ionisation potential to reach a given bundle. Defined as sum (x_z* (sum of Epot from z'=0 to z-1)), where Epot is the ionisation potential of ion Xz’+, and x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_profiles.profiles_1d[:].ion[:].state[:].label |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
core_profiles.profiles_1d[:].ion[:].state[:].pressure | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
core_profiles.profiles_1d[:].ion[:].state[:].pressure_fast_parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
core_profiles.profiles_1d[:].ion[:].state[:].pressure_fast_perpendicular | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
core_profiles.profiles_1d[:].ion[:].state[:].temperature | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
core_profiles.profiles_1d[:].ion[:].state[:].velocity |  | STRUCTURE | m.s^-1 | Velocity
core_profiles.profiles_1d[:].ion[:].state[:].velocity.diamagnetic | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_profiles.profiles_1d[:].ion[:].state[:].velocity.parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_profiles.profiles_1d[:].ion[:].state[:].velocity.poloidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_profiles.profiles_1d[:].ion[:].state[:].velocity.radial | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_profiles.profiles_1d[:].ion[:].state[:].velocity.toroidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_profiles.profiles_1d[:].ion[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_profiles.profiles_1d[:].ion[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_profiles.profiles_1d[:].ion[:].state[:].z_average |  | FLT_0D (uncertain) | Elementary Charge Unit | Average Z of the charge state bundle (equal to z_min if no bundle), = sum (Z*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_profiles.profiles_1d[:].ion[:].state[:].z_max |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
core_profiles.profiles_1d[:].ion[:].state[:].z_min |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
core_profiles.profiles_1d[:].ion[:].state[:].z_square_average |  | FLT_0D (uncertain) | Elementary Charge Unit | Average Z square of the charge state bundle (equal to z_min if no bundle), = sum (Z^2*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
core_profiles.profiles_1d[:].ion[:].temperature | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].velocity |  | STRUCTURE | m.s^-1 | Velocity (average over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].velocity.diamagnetic | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_profiles.profiles_1d[:].ion[:].velocity.parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_profiles.profiles_1d[:].ion[:].velocity.poloidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_profiles.profiles_1d[:].ion[:].velocity.radial | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_profiles.profiles_1d[:].ion[:].velocity.toroidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_profiles.profiles_1d[:].ion[:].velocity_pol (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity (average over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].velocity_tor (obsolescent) | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity (average over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].ion[:].z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed), volume averaged over plasma radius
core_profiles.profiles_1d[:].ion[:].z_ion_1d | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Average charge of the ion species (sum of states charge weighted by state density and divided by ion density)
core_profiles.profiles_1d[:].ion[:].z_ion_square_1d | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Average sqare charge of the ion species (sum of states square charge weighted by state density and divided by ion density)
core_profiles.profiles_1d[:].j_bootstrap | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Bootstrap current density = average(J_Bootstrap.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_profiles.profiles_1d[:].j_non_inductive | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Non-inductive (includes bootstrap) parallel current density = average(jni.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_profiles.profiles_1d[:].j_ohmic | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Ohmic parallel current density = average(J_Ohmic.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_profiles.profiles_1d[:].j_tor | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Total toroidal current density = average(J_Tor/R) / average(1/R)
core_profiles.profiles_1d[:].j_total | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Total parallel current density = average(jtot.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
core_profiles.profiles_1d[:].magnetic_shear | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
core_profiles.profiles_1d[:].momentum_tor | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-1 | Total plasma toroidal momentum, summed over ion species and electrons weighted by their density and major radius, i.e. sum_over_species(n*R*m*Vphi)
core_profiles.profiles_1d[:].n_i_total_over_n_e | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Ratio of total ion density (sum over species and charge states) over electron density. (thermal+non-thermal)
core_profiles.profiles_1d[:].neutral | [1...N] | STRUCT_ARRAY |  | Quantities related to the different neutral species
core_profiles.profiles_1d[:].neutral[:].density | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].density_fast | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_profiles.profiles_1d[:].neutral[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_profiles.profiles_1d[:].neutral[:].element[:].multiplicity |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_profiles.profiles_1d[:].neutral[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_profiles.profiles_1d[:].neutral[:].ion_index |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
core_profiles.profiles_1d[:].neutral[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
core_profiles.profiles_1d[:].neutral[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_profiles.profiles_1d[:].neutral[:].pressure | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].pressure_fast_parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].pressure_fast_perpendicular | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (sum over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].state | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (energy, excitation, ...)
core_profiles.profiles_1d[:].neutral[:].state[:].density | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
core_profiles.profiles_1d[:].neutral[:].state[:].density_fast | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
core_profiles.profiles_1d[:].neutral[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_profiles.profiles_1d[:].neutral[:].state[:].label |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
core_profiles.profiles_1d[:].neutral[:].state[:].neutral_type |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
core_profiles.profiles_1d[:].neutral[:].state[:].neutral_type.description |  | STR_0D |  | Verbose description
core_profiles.profiles_1d[:].neutral[:].state[:].neutral_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list)
core_profiles.profiles_1d[:].neutral[:].state[:].neutral_type.name |  | STR_0D |  | Short string identifier
core_profiles.profiles_1d[:].neutral[:].state[:].pressure | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
core_profiles.profiles_1d[:].neutral[:].state[:].pressure_fast_parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
core_profiles.profiles_1d[:].neutral[:].state[:].pressure_fast_perpendicular | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
core_profiles.profiles_1d[:].neutral[:].state[:].temperature | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
core_profiles.profiles_1d[:].neutral[:].state[:].velocity |  | STRUCTURE | m.s^-1 | Velocity
core_profiles.profiles_1d[:].neutral[:].state[:].velocity.diamagnetic | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_profiles.profiles_1d[:].neutral[:].state[:].velocity.parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_profiles.profiles_1d[:].neutral[:].state[:].velocity.poloidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_profiles.profiles_1d[:].neutral[:].state[:].velocity.radial | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_profiles.profiles_1d[:].neutral[:].state[:].velocity.toroidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_profiles.profiles_1d[:].neutral[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_profiles.profiles_1d[:].neutral[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_profiles.profiles_1d[:].neutral[:].temperature | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].velocity |  | STRUCTURE | m.s^-1 | Velocity (average over charge states when multiple charge states are considered)
core_profiles.profiles_1d[:].neutral[:].velocity.diamagnetic | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
core_profiles.profiles_1d[:].neutral[:].velocity.parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
core_profiles.profiles_1d[:].neutral[:].velocity.poloidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
core_profiles.profiles_1d[:].neutral[:].velocity.radial | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
core_profiles.profiles_1d[:].neutral[:].velocity.toroidal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
core_profiles.profiles_1d[:].pressure_ion_total | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total (sum over ion species) thermal ion pressure
core_profiles.profiles_1d[:].pressure_parallel | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total parallel pressure (electrons+ions, thermal+non-thermal)
core_profiles.profiles_1d[:].pressure_perpendicular | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total perpendicular pressure (electrons+ions, thermal+non-thermal)
core_profiles.profiles_1d[:].pressure_thermal | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Thermal pressure (electrons+ions)
core_profiles.profiles_1d[:].q | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Safety factor
core_profiles.profiles_1d[:].t_i_average | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Ion temperature (averaged on charge states and ion species)
core_profiles.profiles_1d[:].time |  | FLT_0D | s | Time
core_profiles.profiles_1d[:].zeff | [core_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Effective charge
core_profiles.time | [1...N] | FLT_1D_TYPE |  | Generic time [s]
core_profiles.vacuum_toroidal_field |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition and in the normalization of current densities)
core_profiles.vacuum_toroidal_field.b0 | [core_profiles.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewed from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
core_profiles.vacuum_toroidal_field.r0 |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
core_sources |  |  |  | Core plasma source terms (for the transport equations). Energy terms correspond to the full kinetic energy equation (i.e. the energy flux takes into account the energy transported by the particle flux)
core_sources.code |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
core_sources.code.commit |  | STR_0D |  | Unique commit reference of software
core_sources.code.name |  | STR_0D |  | Name of software generating IDS
core_sources.code.output_flag | [core_sources.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
core_sources.code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
core_sources.code.repository |  | STR_0D |  | URL of software repository
core_sources.code.version |  | STR_0D |  | Unique version (tag) of software
core_sources.ids_properties |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
core_sources.ids_properties.comment |  | STR_0D |  | Any comment describing the content of this IDS
core_sources.ids_properties.homogeneous_time |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
core_sources.ids_properties.occurrence |  | INT_0D |  |
core_sources.source | [1...N] | STRUCT_ARRAY |  | Set of source terms
core_sources.source[:].global_quantities | [core_sources.source[:].global_quantities[:].time] | STRUCT_ARRAY |  | Total source quantities integrated over the plasma volume or surface
core_sources.source[:].global_quantities[:].current_parallel |  | FLT_0D (uncertain) | A.m | Parallel current driven
core_sources.source[:].global_quantities[:].electrons |  | STRUCTURE |  | Sources for electrons
core_sources.source[:].global_quantities[:].electrons.particles |  | FLT_0D (uncertain) | s^-1 | Electron particle source
core_sources.source[:].global_quantities[:].electrons.power |  | FLT_0D (uncertain) | W | Power coupled to electrons
core_sources.source[:].global_quantities[:].power |  | FLT_0D (uncertain) | W | Total power coupled to the plasma
core_sources.source[:].global_quantities[:].time |  | FLT_0D | s | Time
core_sources.source[:].global_quantities[:].torque_tor |  | FLT_0D (uncertain) | kg.m^2.s^-2 | Toroidal torque
core_sources.source[:].global_quantities[:].total_ion_power |  | FLT_0D (uncertain) | W | Total power coupled to ion species (summed over ion species)
core_sources.source[:].identifier |  | STRUCTURE |  | Source term identifier
core_sources.source[:].identifier.description |  | STR_0D |  | Verbose description
core_sources.source[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list)
core_sources.source[:].identifier.name |  | STR_0D |  | Short string identifier
core_sources.source[:].profiles_1d | [core_sources.source[:].profiles_1d[:].time] | STRUCT_ARRAY |  | Source profiles for various time slices. Source terms are positive (resp. negative) when there is a gain (resp. a loss) to the considered channel.
core_sources.source[:].profiles_1d[:].conductivity_parallel | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | ohm^-1.m^-1 | Parallel conductivity due to this source
core_sources.source[:].profiles_1d[:].current_parallel_inside | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A | Parallel current driven inside the flux surface. Cumulative surface integral of j_parallel
core_sources.source[:].profiles_1d[:].electrons |  | STRUCTURE |  | Sources for electrons
core_sources.source[:].profiles_1d[:].electrons.energy | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source term for the electron energy equation
core_sources.source[:].profiles_1d[:].electrons.particles | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3.s^-1 | Source term for electron density equation
core_sources.source[:].profiles_1d[:].electrons.particles_inside | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1 | Electron source inside the flux surface. Cumulative volume integral of the source term for the electron density equation.
core_sources.source[:].profiles_1d[:].electrons.power_inside | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Power coupled to electrons inside the flux surface. Cumulative volume integral of the source term for the electron energy equation
core_sources.source[:].profiles_1d[:].grid |  | STRUCTURE |  | Radial grid
core_sources.source[:].profiles_1d[:].grid.area | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
core_sources.source[:].profiles_1d[:].grid.psi | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
core_sources.source[:].profiles_1d[:].grid.rho_tor | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
core_sources.source[:].profiles_1d[:].grid.rho_tor_norm | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
core_sources.source[:].profiles_1d[:].grid.volume | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
core_sources.source[:].profiles_1d[:].ion | [1...N] | STRUCT_ARRAY |  | Source terms related to the different ions species
core_sources.source[:].profiles_1d[:].ion[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_sources.source[:].profiles_1d[:].ion[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_sources.source[:].profiles_1d[:].ion[:].element[:].multiplicity |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_sources.source[:].profiles_1d[:].ion[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_sources.source[:].profiles_1d[:].ion[:].energy | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source term for the ion energy transport equation.
core_sources.source[:].profiles_1d[:].ion[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
core_sources.source[:].profiles_1d[:].ion[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_sources.source[:].profiles_1d[:].ion[:].neutral_index |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
core_sources.source[:].profiles_1d[:].ion[:].particles | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source term for ion density equation
core_sources.source[:].profiles_1d[:].ion[:].state | [1...N] | STRUCT_ARRAY |  | Source terms related to the different charge states of the species (ionisation, energy, excitation, ...)
core_sources.source[:].profiles_1d[:].ion[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_sources.source[:].profiles_1d[:].ion[:].state[:].energy | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source terms for the charge state energy transport equation
core_sources.source[:].profiles_1d[:].ion[:].state[:].is_neutral (obsolescent) |  | INT_0D |  | Flag specifying if this state corresponds to a neutral (1) or not (0)
core_sources.source[:].profiles_1d[:].ion[:].state[:].label |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
core_sources.source[:].profiles_1d[:].ion[:].state[:].neutral_type (obsolescent) |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
core_sources.source[:].profiles_1d[:].ion[:].state[:].neutral_type.description (obsolescent) |  | STR_0D |  | Verbose description
core_sources.source[:].profiles_1d[:].ion[:].state[:].neutral_type.index (obsolescent) |  | INT_0D |  | Integer identifier (enumeration index within a list)
core_sources.source[:].profiles_1d[:].ion[:].state[:].neutral_type.name (obsolescent) |  | STR_0D |  | Short string identifier
core_sources.source[:].profiles_1d[:].ion[:].state[:].particles | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source term for the charge state density transport equation
core_sources.source[:].profiles_1d[:].ion[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_sources.source[:].profiles_1d[:].ion[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_sources.source[:].profiles_1d[:].ion[:].state[:].z_max |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
core_sources.source[:].profiles_1d[:].ion[:].state[:].z_min |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
core_sources.source[:].profiles_1d[:].ion[:].z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
core_sources.source[:].profiles_1d[:].j_parallel | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Parallel current density source, average(J.B) / B0, where B0 = core_sources/vacuum_toroidal_field/b0
core_sources.source[:].profiles_1d[:].momentum_tor | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Source term for total toroidal momentum equation
core_sources.source[:].profiles_1d[:].neutral | [1...N] | STRUCT_ARRAY |  | Source terms related to the different neutral species
core_sources.source[:].profiles_1d[:].neutral[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_sources.source[:].profiles_1d[:].neutral[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_sources.source[:].profiles_1d[:].neutral[:].element[:].multiplicity |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_sources.source[:].profiles_1d[:].neutral[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_sources.source[:].profiles_1d[:].neutral[:].energy | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source term for the ion energy transport equation.
core_sources.source[:].profiles_1d[:].neutral[:].ion_index |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
core_sources.source[:].profiles_1d[:].neutral[:].label |  | STR_0D |  | String identifying the neutral species (e.g. H, D, T, He, C, ...)
core_sources.source[:].profiles_1d[:].neutral[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_sources.source[:].profiles_1d[:].neutral[:].particles | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source term for ion density equation
core_sources.source[:].profiles_1d[:].neutral[:].state | [1...N] | STRUCT_ARRAY |  | Source terms related to the different charge states of the species (energy, excitation, ...)
core_sources.source[:].profiles_1d[:].neutral[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_sources.source[:].profiles_1d[:].neutral[:].state[:].energy | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source terms for the charge state energy transport equation
core_sources.source[:].profiles_1d[:].neutral[:].state[:].label |  | STR_0D |  | String identifying state
core_sources.source[:].profiles_1d[:].neutral[:].state[:].neutral_type |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
core_sources.source[:].profiles_1d[:].neutral[:].state[:].neutral_type.description |  | STR_0D |  | Verbose description
core_sources.source[:].profiles_1d[:].neutral[:].state[:].neutral_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list)
core_sources.source[:].profiles_1d[:].neutral[:].state[:].neutral_type.name |  | STR_0D |  | Short string identifier
core_sources.source[:].profiles_1d[:].neutral[:].state[:].particles | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source term for the charge state density transport equation
core_sources.source[:].profiles_1d[:].neutral[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_sources.source[:].profiles_1d[:].neutral[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_sources.source[:].profiles_1d[:].time |  | FLT_0D | s | Time
core_sources.source[:].profiles_1d[:].torque_tor_inside | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m^2.s^-2 | Toroidal torque inside the flux surface. Cumulative volume integral of the source term for the total toroidal momentum equation
core_sources.source[:].profiles_1d[:].total_ion_energy | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source term for the total (summed over ion species) energy equation
core_sources.source[:].profiles_1d[:].total_ion_power_inside | [core_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Total power coupled to ion species (summed over ion species) inside the flux surface. Cumulative volume integral of the source term for the total ion energy equation
core_sources.time | [1...N] | FLT_1D_TYPE |  | Generic time [s]
core_sources.vacuum_toroidal_field |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in Rho_Tor definition and in the normalization of current densities)
core_sources.vacuum_toroidal_field.b0 | [core_sources.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewed from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
core_sources.vacuum_toroidal_field.r0 |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
core_transport |  |  |  | Core plasma transport. Energy terms correspond to the full kinetic energy equation (i.e. the energy flux takes into account the energy transported by the particle flux)
core_transport.code |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
core_transport.code.commit |  | STR_0D |  | Unique commit reference of software
core_transport.code.name |  | STR_0D |  | Name of software generating IDS
core_transport.code.output_flag | [core_transport.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
core_transport.code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
core_transport.code.repository |  | STR_0D |  | URL of software repository
core_transport.code.version |  | STR_0D |  | Unique version (tag) of software
core_transport.ids_properties |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
core_transport.ids_properties.comment |  | STR_0D |  | Any comment describing the content of this IDS
core_transport.ids_properties.homogeneous_time |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
core_transport.ids_properties.occurrence |  | INT_0D |  |
core_transport.model | [1...N_Models] | STRUCT_ARRAY |  | Transport is described by a combination of various transport models
core_transport.model[:].flux_multiplier |  | FLT_0D (uncertain) | - | Multiplier applied to the particule flux when adding its contribution in the expression of the heat flux : can be 0, 3/2 or 5/2
core_transport.model[:].identifier |  | STRUCTURE |  | Transport model identifier
core_transport.model[:].identifier.description |  | STR_0D |  | Verbose description
core_transport.model[:].identifier.index |  | INT_0D |  | Integer identifier (enumeration index within a list)
core_transport.model[:].identifier.name |  | STR_0D |  | Short string identifier
core_transport.model[:].profiles_1d | [core_transport.model[:].profiles_1d[:].time] | STRUCT_ARRAY |  | Transport coefficient profiles for various time slices. Fluxes and convection are positive (resp. negative) when outwards i.e. towards the LCFS (resp. inwards i.e. towards the magnetic axes).
core_transport.model[:].profiles_1d[:].conductivity_parallel | [core_transport.model[:].profiles_1d[:].rho_tor_norm] | FLT_1D (uncertain) | ohm^-1.m^-1 | Parallel conductivity
core_transport.model[:].profiles_1d[:].electrons |  | STRUCTURE |  | Transport quantities related to the electrons
core_transport.model[:].profiles_1d[:].electrons.energy |  | STRUCTURE |  | Transport quantities for the electron energy equation
core_transport.model[:].profiles_1d[:].electrons.energy.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].electrons.energy.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | W.m^-2 | Flux
core_transport.model[:].profiles_1d[:].electrons.energy.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].electrons.particles |  | STRUCTURE |  | Transport quantities for the electron density equation
core_transport.model[:].profiles_1d[:].electrons.particles.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].electrons.particles.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m^-2.s^-1 | Flux
core_transport.model[:].profiles_1d[:].electrons.particles.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].grid_d |  | STRUCTURE |  | Grid for effective diffusivities and parallel conductivity
core_transport.model[:].profiles_1d[:].grid_d.area | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
core_transport.model[:].profiles_1d[:].grid_d.psi | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
core_transport.model[:].profiles_1d[:].grid_d.rho_tor | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
core_transport.model[:].profiles_1d[:].grid_d.volume | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
core_transport.model[:].profiles_1d[:].grid_flux |  | STRUCTURE |  | Grid for fluxes
core_transport.model[:].profiles_1d[:].grid_flux.area | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
core_transport.model[:].profiles_1d[:].grid_flux.psi | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
core_transport.model[:].profiles_1d[:].grid_flux.rho_tor | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
core_transport.model[:].profiles_1d[:].grid_flux.volume | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
core_transport.model[:].profiles_1d[:].grid_v |  | STRUCTURE |  | Grid for effective convections
core_transport.model[:].profiles_1d[:].grid_v.area | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
core_transport.model[:].profiles_1d[:].grid_v.psi | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
core_transport.model[:].profiles_1d[:].grid_v.rho_tor | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
core_transport.model[:].profiles_1d[:].grid_v.volume | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
core_transport.model[:].profiles_1d[:].ion | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the various ion species
core_transport.model[:].profiles_1d[:].ion[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_transport.model[:].profiles_1d[:].ion[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_transport.model[:].profiles_1d[:].ion[:].element[:].multiplicity |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_transport.model[:].profiles_1d[:].ion[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_transport.model[:].profiles_1d[:].ion[:].energy |  | STRUCTURE |  | Transport coefficients related to the ion energy equation
core_transport.model[:].profiles_1d[:].ion[:].energy.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].energy.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | W.m^-2 | Flux
core_transport.model[:].profiles_1d[:].ion[:].energy.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
core_transport.model[:].profiles_1d[:].ion[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_transport.model[:].profiles_1d[:].ion[:].neutral_index |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
core_transport.model[:].profiles_1d[:].ion[:].particles |  | STRUCTURE |  | Transport related to the ion density equation
core_transport.model[:].profiles_1d[:].ion[:].particles.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].particles.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m^-2.s^-1 | Flux
core_transport.model[:].profiles_1d[:].ion[:].particles.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].state | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the different states of the species
core_transport.model[:].profiles_1d[:].ion[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_transport.model[:].profiles_1d[:].ion[:].state[:].energy |  | STRUCTURE |  | Transport quantities related to the energy equation of the charge state considered
core_transport.model[:].profiles_1d[:].ion[:].state[:].energy.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].state[:].energy.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | W.m^-2 | Flux
core_transport.model[:].profiles_1d[:].ion[:].state[:].energy.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].state[:].is_neutral (obsolescent) |  | INT_0D |  | Flag specifying if this state corresponds to a neutral (1) or not (0)
core_transport.model[:].profiles_1d[:].ion[:].state[:].label |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
core_transport.model[:].profiles_1d[:].ion[:].state[:].neutral_type (obsolescent) |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
core_transport.model[:].profiles_1d[:].ion[:].state[:].neutral_type.description (obsolescent) |  | STR_0D |  | Verbose description
core_transport.model[:].profiles_1d[:].ion[:].state[:].neutral_type.index (obsolescent) |  | INT_0D |  | Integer identifier (enumeration index within a list)
core_transport.model[:].profiles_1d[:].ion[:].state[:].neutral_type.name (obsolescent) |  | STR_0D |  | Short string identifier
core_transport.model[:].profiles_1d[:].ion[:].state[:].particles |  | STRUCTURE |  | Transport quantities related to density equation of the charge state considered (thermal+non-thermal)
core_transport.model[:].profiles_1d[:].ion[:].state[:].particles.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].ion[:].state[:].particles.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m^-2.s^-1 | Flux
core_transport.model[:].profiles_1d[:].ion[:].state[:].particles.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].ion[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_transport.model[:].profiles_1d[:].ion[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_transport.model[:].profiles_1d[:].ion[:].state[:].z_max |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
core_transport.model[:].profiles_1d[:].ion[:].state[:].z_min |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
core_transport.model[:].profiles_1d[:].ion[:].z_ion |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
core_transport.model[:].profiles_1d[:].momentum_tor |  | STRUCTURE |  | Transport coefficients for total toroidal momentum equation
core_transport.model[:].profiles_1d[:].momentum_tor.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].momentum_tor.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Flux
core_transport.model[:].profiles_1d[:].momentum_tor.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].neutral | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the various neutral species
core_transport.model[:].profiles_1d[:].neutral[:].element | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
core_transport.model[:].profiles_1d[:].neutral[:].element[:].a |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
core_transport.model[:].profiles_1d[:].neutral[:].element[:].multiplicity |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
core_transport.model[:].profiles_1d[:].neutral[:].element[:].z_n |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
core_transport.model[:].profiles_1d[:].neutral[:].energy |  | STRUCTURE |  | Transport coefficients related to the neutral energy equation
core_transport.model[:].profiles_1d[:].neutral[:].energy.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].neutral[:].energy.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | W.m^-2 | Flux
core_transport.model[:].profiles_1d[:].neutral[:].energy.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].neutral[:].ion_index |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
core_transport.model[:].profiles_1d[:].neutral[:].label |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
core_transport.model[:].profiles_1d[:].neutral[:].multiple_states_flag |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
core_transport.model[:].profiles_1d[:].neutral[:].particles |  | STRUCTURE |  | Transport related to the neutral density equation
core_transport.model[:].profiles_1d[:].neutral[:].particles.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].neutral[:].particles.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m^-2.s^-1 | Flux
core_transport.model[:].profiles_1d[:].neutral[:].particles.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].neutral[:].state | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the different states of the species
core_transport.model[:].profiles_1d[:].neutral[:].state[:].electron_configuration |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
core_transport.model[:].profiles_1d[:].neutral[:].state[:].energy |  | STRUCTURE |  | Transport quantities related to the energy equation of the charge state considered
core_transport.model[:].profiles_1d[:].neutral[:].state[:].energy.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].neutral[:].state[:].energy.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | W.m^-2 | Flux
core_transport.model[:].profiles_1d[:].neutral[:].state[:].energy.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].neutral[:].state[:].label |  | STR_0D |  | String identifying state
core_transport.model[:].profiles_1d[:].neutral[:].state[:].particles |  | STRUCTURE |  | Transport quantities related to density equation of the charge state considered (thermal+non-thermal)
core_transport.model[:].profiles_1d[:].neutral[:].state[:].particles.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].neutral[:].state[:].particles.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | m^-2.s^-1 | Flux
core_transport.model[:].profiles_1d[:].neutral[:].state[:].particles.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.model[:].profiles_1d[:].neutral[:].state[:].vibrational_level |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
core_transport.model[:].profiles_1d[:].neutral[:].state[:].vibrational_mode |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
core_transport.model[:].profiles_1d[:].time |  | FLT_0D | s | Time
core_transport.model[:].profiles_1d[:].total_ion_energy |  | STRUCTURE |  | Transport coefficients for the total (summed over ion species) energy equation
core_transport.model[:].profiles_1d[:].total_ion_energy.d | [core_transport.model[:].profiles_1d[:].grid_d.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Effective diffusivity
core_transport.model[:].profiles_1d[:].total_ion_energy.flux | [core_transport.model[:].profiles_1d[:].grid_flux.rho_tor_norm] | FLT_1D (uncertain) | W.m^-2 | Flux
core_transport.model[:].profiles_1d[:].total_ion_energy.v | [core_transport.model[:].profiles_1d[:].grid_v.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Effective convection
core_transport.time | [1...N] | FLT_1D_TYPE |  | Generic time [s]
core_transport.vacuum_toroidal_field |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in Rho_Tor definition and in the normalization of current densities)
core_transport.vacuum_toroidal_field.b0 | [core_transport.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewed from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
core_transport.vacuum_toroidal_field.r0 |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
dataset_description (alpha) |  |  |  | General description of the dataset (collection of all IDSs within the given database entry). Main description text to be put in ids_properties/comment
dataset_description.data_entry (alpha) |  | STRUCTURE |  | Definition of this data entry
dataset_description.data_entry.machine (alpha) |  | STR_0D |  | Name of the experimental device to which this data is related
dataset_description.data_entry.pulse (alpha) |  | INT_0D |  | Pulse number
dataset_description.data_entry.pulse_type (alpha) |  | STR_0D |  | Type of the data entry, e.g. "pulse", "simulation", ...
dataset_description.data_entry.run (alpha) |  | INT_0D |  | Run number
dataset_description.data_entry.user (alpha) |  | STR_0D |  | Username
dataset_description.dd_version (alpha) |  | STR_0D |  | Version of the physics data dictionary of this dataset
dataset_description.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
dataset_description.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
dataset_description.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
dataset_description.ids_properties.occurrence |  | INT_0D |  |
dataset_description.imas_version (alpha) |  | STR_0D |  | Version of the IMAS infrastructure used to produce this data entry. Refers to the global IMAS repository which links to versions of every infrastructure tools
dataset_description.parent_entry (alpha) |  | STRUCTURE |  | Definition of the parent data entry, if the present data entry has been generated by applying a given workflow to a unique parent entry
dataset_description.parent_entry.machine (alpha) |  | STR_0D |  | Name of the experimental device to which this data is related
dataset_description.parent_entry.pulse (alpha) |  | INT_0D |  | Pulse number
dataset_description.parent_entry.pulse_type (alpha) |  | STR_0D |  | Type of the data entry, e.g. "pulse", "simulation", ...
dataset_description.parent_entry.run (alpha) |  | INT_0D |  | Run number
dataset_description.parent_entry.user (alpha) |  | STR_0D |  | Username
dataset_description.simulation (alpha) |  | STRUCTURE |  | Description of the general simulation characteristics, if this data entry has been produced by a simulation. Several nodes describe typical time-dependent simulation with a time evolution as the main loop
dataset_description.simulation.comment_after (alpha) |  | STR_0D |  | Comment made at the end of a simulation
dataset_description.simulation.comment_before (alpha) |  | STR_0D |  | Comment made when launching a simulation
dataset_description.simulation.time_begin (alpha) |  | FLT_0D (uncertain) | s | Start time
dataset_description.simulation.time_begun (alpha) |  | STR_0D | UTC | Actual wall-clock time simulation started
dataset_description.simulation.time_current (alpha) |  | FLT_0D (uncertain) | s | Current time of the simulation
dataset_description.simulation.time_end (alpha) |  | FLT_0D (uncertain) | s | Stop time
dataset_description.simulation.time_ended (alpha) |  | STR_0D | UTC | Actual wall-clock time simulation finished
dataset_description.simulation.time_restart (alpha) |  | FLT_0D (uncertain) | s | Time of the last restart done during the simulation
dataset_description.simulation.time_step (alpha) |  | FLT_0D (uncertain) | s | Time interval between main steps, e.g. storage step (if relevant and constant)
dataset_description.simulation.workflow (alpha) |  | STR_0D |  | Description of the workflow which has been used to produce this data entry (e.g. copy of the Kepler MOML if using Kepler)
dataset_description.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
distribution_sources (alpha) |  |  |  | Sources of particles for input to kinetic equations, e.g. Fokker-Planck calculation. The sources could originate from e.g. NBI or fusion reactions.
distribution_sources.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
distribution_sources.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
distribution_sources.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
distribution_sources.code.output_flag (alpha) | [distribution_sources.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
distribution_sources.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
distribution_sources.code.repository (alpha) |  | STR_0D |  | URL of software repository
distribution_sources.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
distribution_sources.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
distribution_sources.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
distribution_sources.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
distribution_sources.ids_properties.occurrence |  | INT_0D |  |
distribution_sources.magnetic_axis (alpha) |  | STRUCTURE |  | Magnetic axis position (used to define a poloidal angle for the 2D profiles)
distribution_sources.magnetic_axis.r (alpha) | [distribution_sources.time] | FLT_1D (uncertain) | m | Major radius
distribution_sources.magnetic_axis.z (alpha) | [distribution_sources.time] | FLT_1D (uncertain) | m | Height
distribution_sources.source (alpha) | [1...N] | STRUCT_ARRAY |  | Set of source/sink terms. A source/sink term corresponds to the particle source due to an NBI injection unit, a nuclear reaction or any combination of them (described in "identifier")
distribution_sources.source[:].ggd (alpha) | [distribution_sources.source[:].ggd[:].time] | STRUCT_ARRAY |  | Source terms in phase space (real space, velocity space, spin state), represented using the ggd, for various time slices
distribution_sources.source[:].ggd[:].discrete (alpha) | [1...N] | INT_1D |  | List of indices of grid spaces (refers to ../grid/space) for which the source is discretely distributed. For example consider a source of 3.5 MeV alpha particles provided on a grid with two coordinates (spaces); rho_tor and energy. To specify that the source is given at energies exactly equal to 3.5 MeV, let discret have length 1 and set discrete(1)=2 since energy is dimension number 2. The source is then proportional to delta( 1 - energy / 3.5MeV ), where delta is the direct delta distribution. Discrete dimensions can only be used when the grid is rectangular.
distribution_sources.source[:].ggd[:].grid (alpha) |  | STRUCTURE |  | Grid description
distribution_sources.source[:].ggd[:].grid.grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
distribution_sources.source[:].ggd[:].grid.grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
distribution_sources.source[:].ggd[:].grid.grid_subset[:].base[:].jacobian (alpha) | [distribution_sources.source[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
distribution_sources.source[:].ggd[:].grid.grid_subset[:].base[:].tensor_contravariant (alpha) | [distribution_sources.source[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
distribution_sources.source[:].ggd[:].grid.grid_subset[:].base[:].tensor_covariant (alpha) | [distribution_sources.source[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
distribution_sources.source[:].ggd[:].grid.grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
distribution_sources.source[:].ggd[:].grid.grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
distribution_sources.source[:].ggd[:].grid.grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
distribution_sources.source[:].ggd[:].grid.grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
distribution_sources.source[:].ggd[:].grid.grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
distribution_sources.source[:].ggd[:].grid.grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
distribution_sources.source[:].ggd[:].grid.grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier
distribution_sources.source[:].ggd[:].grid.grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].ggd[:].grid.grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distribution_sources.source[:].ggd[:].grid.grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].ggd[:].grid.grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
distribution_sources.source[:].ggd[:].grid.grid_subset[:].metric.jacobian (alpha) | [distribution_sources.source[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
distribution_sources.source[:].ggd[:].grid.grid_subset[:].metric.tensor_contravariant (alpha) | [distribution_sources.source[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
distribution_sources.source[:].ggd[:].grid.grid_subset[:].metric.tensor_covariant (alpha) | [distribution_sources.source[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
distribution_sources.source[:].ggd[:].grid.identifier (alpha) |  | STRUCTURE |  | Grid identifier
distribution_sources.source[:].ggd[:].grid.identifier.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].ggd[:].grid.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distribution_sources.source[:].ggd[:].grid.identifier.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].ggd[:].grid.space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
distribution_sources.source[:].ggd[:].grid.space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therfore defines the dimension of the space. The meaning of these predefined integer constants can be found in the documentation of the grid service library
distribution_sources.source[:].ggd[:].grid.space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
distribution_sources.source[:].ggd[:].grid.space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].ggd[:].grid.space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distribution_sources.source[:].ggd[:].grid.space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
distribution_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
distribution_sources.source[:].ggd[:].particles (alpha) | [1...N] | STRUCT_ARRAY | (m.s^-1)^-3.m^-3.s^-1 | Source density of particles in phase space, for various grid subsets
distribution_sources.source[:].ggd[:].particles[:].coefficients (alpha) | [distribution_sources.source[:].ggd[:].particles[:].values, 1...N] | FLT_2D (uncertain) | (m.s^-1)^-3.m^-3.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
distribution_sources.source[:].ggd[:].particles[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
distribution_sources.source[:].ggd[:].particles[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
distribution_sources.source[:].ggd[:].particles[:].values (alpha) | [1...N] | FLT_1D (uncertain) | (m.s^-1)^-3.m^-3.s^-1 | One scalar value is provided per element in the grid subset.
distribution_sources.source[:].ggd[:].time (alpha) |  | FLT_0D | s | Time
distribution_sources.source[:].global_quantities (alpha) | [distribution_sources.source[:].global_quantities[:].time] | STRUCT_ARRAY |  | Global quantities for various time slices
distribution_sources.source[:].global_quantities[:].particles (alpha) |  | FLT_0D (uncertain) | s^-1 | Particle source rate
distribution_sources.source[:].global_quantities[:].power (alpha) |  | FLT_0D (uncertain) | W | Total power of the source
distribution_sources.source[:].global_quantities[:].shinethrough (alpha) |  | STRUCTURE |  | Shinethrough losses
distribution_sources.source[:].global_quantities[:].shinethrough.particles (alpha) |  | FLT_0D (uncertain) | s^-1 | Particle losses due to shinethrough
distribution_sources.source[:].global_quantities[:].shinethrough.power (alpha) |  | FLT_0D (uncertain) | W | Power losses due to shinethrough
distribution_sources.source[:].global_quantities[:].shinethrough.torque_tor (alpha) |  | FLT_0D (uncertain) | N.m | Toroidal torque losses due to shinethrough
distribution_sources.source[:].global_quantities[:].time (alpha) |  | FLT_0D | s | Time
distribution_sources.source[:].global_quantities[:].torque_tor (alpha) |  | FLT_0D (uncertain) | N.m | Total toroidal torque of the source
distribution_sources.source[:].gyro_type (alpha) |  | INT_0D |  | Defines how to interpret the spatial coordinates: 1 = given at the actual particle birth point; 2 =given at the gyro centre of the birth point
distribution_sources.source[:].markers (alpha) | [distribution_sources.source[:].markers[:].time] | STRUCT_ARRAY |  | Source given as a group of markers (test particles) born per second, for various time slices
distribution_sources.source[:].markers[:].coordinate_identifier (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Set of coordinate identifiers, coordinates on which the markers are represented
distribution_sources.source[:].markers[:].coordinate_identifier[:].description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].markers[:].coordinate_identifier[:].index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distribution_sources.source[:].markers[:].coordinate_identifier[:].name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].markers[:].positions (alpha) | [distribution_sources.source[:].markers[:].weights, distribution_sources.source[:].markers[:].coordinate_identifier] | FLT_2D (uncertain) | mixed | Position of the markers in the set of coordinates. The first dimension corresponds to the number of markers, the second dimension to the set of coordinates
distribution_sources.source[:].markers[:].time (alpha) |  | FLT_0D | s | Time
distribution_sources.source[:].markers[:].weights (alpha) | [1...N] | FLT_1D (uncertain) | - | Weight of the markers, i.e. number of real particles represented by each marker. The dimension of the vector correspond to the number of markers
distribution_sources.source[:].process (alpha) | [1...N] | STRUCT_ARRAY |  | Set of processes (NBI units, fusion reactions, ...) that provide the source.
distribution_sources.source[:].process[:].nbi_beamlets_group (alpha) |  | INT_0D |  | Index of the NBI beamlets group considered. Refers to the "unit/beamlets_group" array of the NBI IDS. 0 means sum over all beamlets groups.
distribution_sources.source[:].process[:].nbi_energy (alpha) |  | STRUCTURE |  | For NBI source, energy of the accelerated species considered. index = 0 for a sum over all energies; index = 1 for full energiy; index = 2 for half energy; index = 3 for third energy
distribution_sources.source[:].process[:].nbi_energy.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].process[:].nbi_energy.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distribution_sources.source[:].process[:].nbi_energy.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].process[:].nbi_unit (alpha) |  | INT_0D |  | Index of the NBI unit considered. Refers to the "unit" array of the NBI IDS. 0 means sum over all NBI units.
distribution_sources.source[:].process[:].reactant_energy (alpha) |  | STRUCTURE |  | For nuclear reaction source, energy of the reactants. index = 0 for a sum over all energies; index = 1 for thermal-thermal; index = 2 for beam-beam; index = 3 for beam-thermal
distribution_sources.source[:].process[:].reactant_energy.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].process[:].reactant_energy.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distribution_sources.source[:].process[:].reactant_energy.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].process[:].type (alpha) |  | STRUCTURE |  | Process type. index=1 for NBI; index=2 for nuclear reaction (reaction unspecified); index=3 for nuclear reaction: T(d,n)4He [D+T->He4+n]; index=4 for nuclear reaction: He3(d,p)4He [He3+D->He4+p]; index=5 for nuclear reaction: D(d,p)T [D+D->T+p]; index=6 for nuclear reaction: D(d,n)3He [D+D->He3+n]; index=7 for runaway processes
distribution_sources.source[:].process[:].type.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].process[:].type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distribution_sources.source[:].process[:].type.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].profiles_1d (alpha) | [distribution_sources.source[:].profiles_1d[:].time] | STRUCT_ARRAY |  | Source radial profiles (flux surface averaged quantities) for various time slices
distribution_sources.source[:].profiles_1d[:].energy (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source term for the energy transport equation
distribution_sources.source[:].profiles_1d[:].grid (alpha) |  | STRUCTURE |  | Radial grid
distribution_sources.source[:].profiles_1d[:].grid.area (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
distribution_sources.source[:].profiles_1d[:].grid.psi (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
distribution_sources.source[:].profiles_1d[:].grid.rho_tor (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
distribution_sources.source[:].profiles_1d[:].grid.volume (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
distribution_sources.source[:].profiles_1d[:].momentum_tor (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Source term for the toroidal momentum equation
distribution_sources.source[:].profiles_1d[:].particles (alpha) | [distribution_sources.source[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source term for the density transport equation
distribution_sources.source[:].profiles_1d[:].time (alpha) |  | FLT_0D | s | Time
distribution_sources.source[:].species (alpha) |  | STRUCTURE |  | Species injected or consumed by this source/sink
distribution_sources.source[:].species.ion (alpha) |  | STRUCTURE |  | Description of the ion or neutral species, used if type/index = 2 or 3
distribution_sources.source[:].species.ion.element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distribution_sources.source[:].species.ion.element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distribution_sources.source[:].species.ion.element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distribution_sources.source[:].species.ion.element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distribution_sources.source[:].species.ion.label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
distribution_sources.source[:].species.ion.state (alpha) |  | STRUCTURE |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
distribution_sources.source[:].species.ion.state.electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distribution_sources.source[:].species.ion.state.label (alpha) |  | STR_0D |  | String identifying ion state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distribution_sources.source[:].species.ion.state.vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distribution_sources.source[:].species.ion.state.vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distribution_sources.source[:].species.ion.state.z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distribution_sources.source[:].species.ion.state.z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distribution_sources.source[:].species.ion.z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
distribution_sources.source[:].species.neutral (alpha) |  | STRUCTURE |  | Description of the neutral species, used if type/index = 4 or 5
distribution_sources.source[:].species.neutral.element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distribution_sources.source[:].species.neutral.element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distribution_sources.source[:].species.neutral.element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distribution_sources.source[:].species.neutral.element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distribution_sources.source[:].species.neutral.label (alpha) |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
distribution_sources.source[:].species.neutral.state (alpha) |  | STRUCTURE |  | State of the species (energy, excitation, ...)
distribution_sources.source[:].species.neutral.state.electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distribution_sources.source[:].species.neutral.state.label (alpha) |  | STR_0D |  | String identifying neutral state
distribution_sources.source[:].species.neutral.state.neutral_type (alpha) |  | STRUCTURE |  | Neutral type, in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
distribution_sources.source[:].species.neutral.state.neutral_type.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].species.neutral.state.neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distribution_sources.source[:].species.neutral.state.neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.source[:].species.neutral.state.vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distribution_sources.source[:].species.neutral.state.vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distribution_sources.source[:].species.type (alpha) |  | STRUCTURE |  | Species type. index=1 for electron; index=2 for ion species in a single/average state (refer to ion structure); index=3 for ion species in a particular state (refer to ion/state structure); index=4 for neutral species in a single/average state (refer to neutral structure); index=5 for neutral species in a particular state (refer to neutral/state structure); index=6 for neutron; index=7 for photon
distribution_sources.source[:].species.type.description (alpha) |  | STR_0D |  | Verbose description
distribution_sources.source[:].species.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distribution_sources.source[:].species.type.name (alpha) |  | STR_0D |  | Short string identifier
distribution_sources.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
distribution_sources.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition)
distribution_sources.vacuum_toroidal_field.b0 (alpha) | [distribution_sources.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewed from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
distribution_sources.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
distributions (alpha) |  |  |  | Distribution function(s) of one or many particle species. This structure is specifically designed to handle non-Maxwellian distribution function generated during heating and current drive, typically solved using a Fokker-Planck calculation perturbed by a heating scheme (e.g. IC, EC, LH, NBI, or alpha heating) and then relaxed by Coloumb collisions.
distributions.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
distributions.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
distributions.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
distributions.code.output_flag (alpha) | [distributions.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
distributions.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
distributions.code.repository (alpha) |  | STR_0D |  | URL of software repository
distributions.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
distributions.distribution (alpha) | [1...N] | STRUCT_ARRAY |  | Set of distribution functions. Every distribution function has to be associated with only one particle species, specified in distri_vec/species/, but there could be multiple distribution function for each species. In this case, the fast particle populations should be superposed
distributions.distribution[:].fast_filter (alpha) |  | STRUCTURE |  | Description of how the fast and the thermal particle populations are separated
distributions.distribution[:].fast_filter.energy (alpha) | [distributions.distribution[:].fast_filter.energy.TBD] | FLT_1D (uncertain) | eV | Energy at which the fast and thermal particle populations were separated, as a function of radius
distributions.distribution[:].fast_filter.method (alpha) |  | STRUCTURE |  | Method used to separate the fast and thermal particle population (indices TBD)
distributions.distribution[:].fast_filter.method.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].fast_filter.method.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].fast_filter.method.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].ggd (alpha) | [distributions.distribution[:].ggd[:].time] | STRUCT_ARRAY |  | Distribution represented using the ggd, for various time slices
distributions.distribution[:].ggd[:].expansion (alpha) | [1...N] | STRUCT_ARRAY | (m.s^-1)^-3.m^-3.s^-1 | Distribution function expanded into a vector of successive approximations. The first element in the vector (expansion(1)) is the zeroth order distribution function, while the K:th element in the vector (expansion(K)) is the K:th correction, such that the total distribution function is a sum over all elements in the expansion vector.
distributions.distribution[:].ggd[:].expansion[:].grid_subset (alpha) | [1...N] | STRUCT_ARRAY | mixed | Values of the distribution function expansion, for various grid subsets
distributions.distribution[:].ggd[:].expansion[:].grid_subset[:].coefficients (alpha) | [distributions.distribution[:].ggd[:].expansion[:].grid_subset[:].values, 1...N] | FLT_2D (uncertain) | mixed | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
distributions.distribution[:].ggd[:].expansion[:].grid_subset[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
distributions.distribution[:].ggd[:].expansion[:].grid_subset[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
distributions.distribution[:].ggd[:].expansion[:].grid_subset[:].values (alpha) | [1...N] | FLT_1D (uncertain) | mixed | One scalar value is provided per element in the grid subset.
distributions.distribution[:].ggd[:].grid (alpha) |  | STRUCTURE |  | Grid description
distributions.distribution[:].ggd[:].grid.grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
distributions.distribution[:].ggd[:].grid.grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
distributions.distribution[:].ggd[:].grid.grid_subset[:].base[:].jacobian (alpha) | [distributions.distribution[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
distributions.distribution[:].ggd[:].grid.grid_subset[:].base[:].tensor_contravariant (alpha) | [distributions.distribution[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
distributions.distribution[:].ggd[:].grid.grid_subset[:].base[:].tensor_covariant (alpha) | [distributions.distribution[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
distributions.distribution[:].ggd[:].grid.grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
distributions.distribution[:].ggd[:].grid.grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
distributions.distribution[:].ggd[:].grid.grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
distributions.distribution[:].ggd[:].grid.grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
distributions.distribution[:].ggd[:].grid.grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
distributions.distribution[:].ggd[:].grid.grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
distributions.distribution[:].ggd[:].grid.grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier
distributions.distribution[:].ggd[:].grid.grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].ggd[:].grid.grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].ggd[:].grid.grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].ggd[:].grid.grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
distributions.distribution[:].ggd[:].grid.grid_subset[:].metric.jacobian (alpha) | [distributions.distribution[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
distributions.distribution[:].ggd[:].grid.grid_subset[:].metric.tensor_contravariant (alpha) | [distributions.distribution[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
distributions.distribution[:].ggd[:].grid.grid_subset[:].metric.tensor_covariant (alpha) | [distributions.distribution[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
distributions.distribution[:].ggd[:].grid.identifier (alpha) |  | STRUCTURE |  | Grid identifier
distributions.distribution[:].ggd[:].grid.identifier.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].ggd[:].grid.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].ggd[:].grid.identifier.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].ggd[:].grid.space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
distributions.distribution[:].ggd[:].grid.space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therfore defines the dimension of the space. The meaning of these predefined integer constants can be found in the documentation of the grid service library
distributions.distribution[:].ggd[:].grid.space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
distributions.distribution[:].ggd[:].grid.space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].ggd[:].grid.space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].ggd[:].grid.space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
distributions.distribution[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
distributions.distribution[:].ggd[:].temperature (alpha) | [distributions.distribution[:].profiles_1d.grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Reference temperature profile used to define the local thermal energy and the thermal velocity (for normalisation of the grid coordinates)
distributions.distribution[:].ggd[:].time (alpha) |  | FLT_0D | s | Time
distributions.distribution[:].global_quantities (alpha) | [distributions.distribution[:].global_quantities[:].time] | STRUCT_ARRAY |  | Global quantities (integrated over plasma volume for moments of the distribution, collisional exchange and source terms), for various time slices
distributions.distribution[:].global_quantities[:].collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].global_quantities[:].collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].global_quantities[:].collisions.electrons.power_fast (alpha) |  | FLT_0D (uncertain) | W | Collisional power to the fast particle population
distributions.distribution[:].global_quantities[:].collisions.electrons.power_thermal (alpha) |  | FLT_0D (uncertain) | W | Collisional power to the thermal particle population
distributions.distribution[:].global_quantities[:].collisions.electrons.torque_fast_tor (alpha) |  | FLT_0D (uncertain) | N.m | Collisional toroidal torque to the fast particle population
distributions.distribution[:].global_quantities[:].collisions.electrons.torque_thermal_tor (alpha) |  | FLT_0D (uncertain) | N.m | Collisional toroidal torque to the thermal particle population
distributions.distribution[:].global_quantities[:].collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].global_quantities[:].collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].global_quantities[:].collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].global_quantities[:].collisions.ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].global_quantities[:].collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].global_quantities[:].collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].global_quantities[:].collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].global_quantities[:].collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].global_quantities[:].collisions.ion[:].power_fast (alpha) |  | FLT_0D (uncertain) | W | Collisional power to the fast particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].power_thermal (alpha) |  | FLT_0D (uncertain) | W | Collisional power to the thermal particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].power_fast (alpha) |  | FLT_0D (uncertain) | W | Collisional power to the fast particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].power_thermal (alpha) |  | FLT_0D (uncertain) | W | Collisional power to the thermal particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].torque_fast_tor (alpha) |  | FLT_0D (uncertain) | N.m | Collisional toroidal torque to the fast particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].torque_thermal_tor (alpha) |  | FLT_0D (uncertain) | N.m | Collisional toroidal torque to the thermal particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].global_quantities[:].collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].global_quantities[:].collisions.ion[:].torque_fast_tor (alpha) |  | FLT_0D (uncertain) | N.m | Collisional toroidal torque to the fast particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].torque_thermal_tor (alpha) |  | FLT_0D (uncertain) | N.m | Collisional toroidal torque to the thermal particle population
distributions.distribution[:].global_quantities[:].collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].global_quantities[:].current_tor (alpha) |  | FLT_0D (uncertain) | N.m | Toroidal current driven by the distribution
distributions.distribution[:].global_quantities[:].energy (alpha) |  | FLT_0D (uncertain) | J | Total energy in the distribution
distributions.distribution[:].global_quantities[:].energy_fast (alpha) |  | FLT_0D (uncertain) | J | Total energy of the fast particles in the distribution
distributions.distribution[:].global_quantities[:].energy_fast_parallel (alpha) |  | FLT_0D (uncertain) | J | Parallel energy of the fast particles in the distribution
distributions.distribution[:].global_quantities[:].particles_fast_n (alpha) |  | FLT_0D (uncertain) | - | Number of fast particles in the distribution, i.e. the volume integral of the density (note: this is the number of real particles and not markers)
distributions.distribution[:].global_quantities[:].particles_n (alpha) |  | FLT_0D (uncertain) | - | Number of particles in the distribution, i.e. the volume integral of the density (note: this is the number of real particles and not markers)
distributions.distribution[:].global_quantities[:].source (alpha) | [1...N] | STRUCT_ARRAY |  | Set of volume integrated sources and sinks of particles, momentum and energy included in the Fokker-Planck modelling, related to the various waves or particle source processes affecting the distribution
distributions.distribution[:].global_quantities[:].source[:].identifier (alpha) |  | STRUCTURE |  | Identifier of the wave or particle source process, defined respectively in distribution/wave or distribution/process
distributions.distribution[:].global_quantities[:].source[:].identifier.process_index (alpha) |  | INT_0D |  | Index into distribution/process
distributions.distribution[:].global_quantities[:].source[:].identifier.type (alpha) |  | STRUCTURE |  | Type of the source term. Index = 1 for a wave, index = 2 for a particle source process
distributions.distribution[:].global_quantities[:].source[:].identifier.type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].global_quantities[:].source[:].identifier.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].global_quantities[:].source[:].identifier.type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].global_quantities[:].source[:].identifier.wave_index (alpha) |  | INT_0D |  | Index into distribution/wave
distributions.distribution[:].global_quantities[:].source[:].particles (alpha) |  | FLT_0D (uncertain) | s^-1 | Particle source rate
distributions.distribution[:].global_quantities[:].source[:].power (alpha) |  | FLT_0D (uncertain) | W | Total power of the source
distributions.distribution[:].global_quantities[:].source[:].torque_tor (alpha) |  | FLT_0D (uncertain) | N.m | Total toroidal torque of the source
distributions.distribution[:].global_quantities[:].time (alpha) |  | FLT_0D | s | Time
distributions.distribution[:].global_quantities[:].torque_tor_j_radial (alpha) |  | FLT_0D (uncertain) | N.m | Toroidal torque due to radial currents
distributions.distribution[:].gyro_type (alpha) |  | INT_0D |  | Defines how to interpret the spatial coordinates: 1 = given at the actual particle birth point; 2 =given at the gyro centre of the birth point
distributions.distribution[:].is_delta_f (alpha) |  | INT_0D |  | If is_delta_f=1, then the distribution represents the deviation from a Maxwellian; is_delta_f=0, then the distribution represents all particles, i.e. the full-f solution
distributions.distribution[:].markers (alpha) | [distributions.distribution[:].markers[:].time] | STRUCT_ARRAY |  | Distribution represented by a set of markers (test particles)
distributions.distribution[:].markers[:].coordinate_identifier (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Set of coordinate identifiers, coordinates on which the markers are represented
distributions.distribution[:].markers[:].coordinate_identifier[:].description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].markers[:].coordinate_identifier[:].index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].markers[:].coordinate_identifier[:].name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].markers[:].positions (alpha) | [distributions.distribution[:].markers[:].weights, distributions.distribution[:].markers[:].coordinate_identifier] | FLT_2D (uncertain) | mixed | Position of the markers in the set of coordinates. The first dimension corresponds to the number of markers, the second dimension to the set of coordinates
distributions.distribution[:].markers[:].time (alpha) |  | FLT_0D | s | Time
distributions.distribution[:].markers[:].weights (alpha) | [1...N] | FLT_1D (uncertain) | - | Weight of the markers, i.e. number of real particles represented by each marker. The dimension of the vector correspond to the number of markers
distributions.distribution[:].process (alpha) | [1...N] | STRUCT_ARRAY |  | List all processes (NBI units, fusion reactions, ...) affecting the distribution, identified as in distribution_sources/source(i)/process in the DISTRIBUTION_SOURCES IDS
distributions.distribution[:].process[:].nbi_beamlets_group (alpha) |  | INT_0D |  | Index of the NBI beamlets group considered. Refers to the "unit/beamlets_group" array of the NBI IDS. 0 means sum over all beamlets groups.
distributions.distribution[:].process[:].nbi_energy (alpha) |  | STRUCTURE |  | For NBI source, energy of the accelerated species considered. index = 0 for a sum over all energies; index = 1 for full energiy; index = 2 for half energy; index = 3 for third energy
distributions.distribution[:].process[:].nbi_energy.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].process[:].nbi_energy.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].process[:].nbi_energy.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].process[:].nbi_unit (alpha) |  | INT_0D |  | Index of the NBI unit considered. Refers to the "unit" array of the NBI IDS. 0 means sum over all NBI units.
distributions.distribution[:].process[:].reactant_energy (alpha) |  | STRUCTURE |  | For nuclear reaction source, energy of the reactants. index = 0 for a sum over all energies; index = 1 for thermal-thermal; index = 2 for beam-beam; index = 3 for beam-thermal
distributions.distribution[:].process[:].reactant_energy.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].process[:].reactant_energy.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].process[:].reactant_energy.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].process[:].type (alpha) |  | STRUCTURE |  | Process type. index=1 for NBI; index=2 for nuclear reaction (reaction unspecified); index=3 for nuclear reaction: T(d,n)4He [D+T->He4+n]; index=4 for nuclear reaction: He3(d,p)4He [He3+D->He4+p]; index=5 for nuclear reaction: D(d,p)T [D+D->T+p]; index=6 for nuclear reaction: D(d,n)3He [D+D->He3+n]; index=7 for runaway processes
distributions.distribution[:].process[:].type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].process[:].type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].process[:].type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].profiles_1d (alpha) | [distributions.distribution[:].profiles_1d[:].time] | STRUCT_ARRAY |  | Radial profiles (flux surface averaged quantities) for various time slices
distributions.distribution[:].profiles_1d[:].co_passing (alpha) |  | STRUCTURE |  | Flux surface averaged profile evaluated using the co-passing particle part of the distribution.
distributions.distribution[:].profiles_1d[:].co_passing.collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_1d[:].co_passing.collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_1d[:].co_passing.collisions.electrons.power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].co_passing.collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_1d[:].co_passing.current_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].co_passing.current_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].co_passing.density (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].co_passing.density_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_1d[:].co_passing.pressure (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].co_passing.pressure_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_1d[:].co_passing.pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_1d[:].co_passing.source (alpha) | [1...N] | STRUCT_ARRAY |  | Set of flux averaged sources and sinks of particles, momentum and energy included in the Fokker-Planck modelling, related to the various waves or particle source processes affecting the distribution
distributions.distribution[:].profiles_1d[:].co_passing.source[:].energy (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source rate of energy density
distributions.distribution[:].profiles_1d[:].co_passing.source[:].identifier (alpha) |  | STRUCTURE |  | Identifier of the wave or particle source process, defined respectively in distribution/wave or distribution/process
distributions.distribution[:].profiles_1d[:].co_passing.source[:].identifier.process_index (alpha) |  | INT_0D |  | Index into distribution/process
distributions.distribution[:].profiles_1d[:].co_passing.source[:].identifier.type (alpha) |  | STRUCTURE |  | Type of the source term. Index = 1 for a wave, index = 2 for a particle source process
distributions.distribution[:].profiles_1d[:].co_passing.source[:].identifier.type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].profiles_1d[:].co_passing.source[:].identifier.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].profiles_1d[:].co_passing.source[:].identifier.type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].profiles_1d[:].co_passing.source[:].identifier.wave_index (alpha) |  | INT_0D |  | Index into distribution/wave
distributions.distribution[:].profiles_1d[:].co_passing.source[:].momentum_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Source rate of toroidal angular momentum density
distributions.distribution[:].profiles_1d[:].co_passing.source[:].particles (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source rate of thermal particle density
distributions.distribution[:].profiles_1d[:].co_passing.torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].profiles_1d[:].collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_1d[:].collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_1d[:].collisions.electrons.power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_1d[:].collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_1d[:].collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_1d[:].collisions.ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_1d[:].collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_1d[:].collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_1d[:].collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_1d[:].collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_1d[:].collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_1d[:].collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_1d[:].collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_1d[:].counter_passing (alpha) |  | STRUCTURE |  | Flux surface averaged profile evaluated using the counter-passing particle part of the distribution.
distributions.distribution[:].profiles_1d[:].counter_passing.collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.electrons.power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].counter_passing.collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_1d[:].counter_passing.current_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].counter_passing.current_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].counter_passing.density (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].counter_passing.density_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_1d[:].counter_passing.pressure (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].counter_passing.pressure_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_1d[:].counter_passing.pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_1d[:].counter_passing.source (alpha) | [1...N] | STRUCT_ARRAY |  | Set of flux averaged sources and sinks of particles, momentum and energy included in the Fokker-Planck modelling, related to the various waves or particle source processes affecting the distribution
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].energy (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source rate of energy density
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].identifier (alpha) |  | STRUCTURE |  | Identifier of the wave or particle source process, defined respectively in distribution/wave or distribution/process
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].identifier.process_index (alpha) |  | INT_0D |  | Index into distribution/process
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].identifier.type (alpha) |  | STRUCTURE |  | Type of the source term. Index = 1 for a wave, index = 2 for a particle source process
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].identifier.type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].identifier.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].identifier.type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].identifier.wave_index (alpha) |  | INT_0D |  | Index into distribution/wave
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].momentum_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Source rate of toroidal angular momentum density
distributions.distribution[:].profiles_1d[:].counter_passing.source[:].particles (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source rate of thermal particle density
distributions.distribution[:].profiles_1d[:].counter_passing.torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].profiles_1d[:].current_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].current_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].density (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].density_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_1d[:].grid (alpha) |  | STRUCTURE |  | Radial grid
distributions.distribution[:].profiles_1d[:].grid.area (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
distributions.distribution[:].profiles_1d[:].grid.psi (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
distributions.distribution[:].profiles_1d[:].grid.rho_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
distributions.distribution[:].profiles_1d[:].grid.volume (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
distributions.distribution[:].profiles_1d[:].pressure (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].pressure_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_1d[:].pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_1d[:].source (alpha) | [1...N] | STRUCT_ARRAY |  | Set of flux averaged sources and sinks of particles, momentum and energy included in the Fokker-Planck modelling, related to the various waves or particle source processes affecting the distribution
distributions.distribution[:].profiles_1d[:].source[:].energy (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source rate of energy density
distributions.distribution[:].profiles_1d[:].source[:].identifier (alpha) |  | STRUCTURE |  | Identifier of the wave or particle source process, defined respectively in distribution/wave or distribution/process
distributions.distribution[:].profiles_1d[:].source[:].identifier.process_index (alpha) |  | INT_0D |  | Index into distribution/process
distributions.distribution[:].profiles_1d[:].source[:].identifier.type (alpha) |  | STRUCTURE |  | Type of the source term. Index = 1 for a wave, index = 2 for a particle source process
distributions.distribution[:].profiles_1d[:].source[:].identifier.type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].profiles_1d[:].source[:].identifier.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].profiles_1d[:].source[:].identifier.type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].profiles_1d[:].source[:].identifier.wave_index (alpha) |  | INT_0D |  | Index into distribution/wave
distributions.distribution[:].profiles_1d[:].source[:].momentum_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Source rate of toroidal angular momentum density
distributions.distribution[:].profiles_1d[:].source[:].particles (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source rate of thermal particle density
distributions.distribution[:].profiles_1d[:].thermalisation (alpha) |  | STRUCTURE |  | Flux surface averaged source of thermal particles, momentum and energy due to thermalisation. Here thermalisation refers to non-thermal particles, sufficiently assimilated to the thermal background to be re-categorised as thermal particles. Note that this source may also be negative if thermal particles are being accelerated such that they form a distinct non-thermal contribution, e.g. due run-away of RF interactions.
distributions.distribution[:].profiles_1d[:].thermalisation.energy (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source rate of energy density within the thermal particle population due to the thermalisation of fast particles
distributions.distribution[:].profiles_1d[:].thermalisation.momentum_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Source rate of toroidal angular momentum density within the thermal particle population due to the thermalisation of fast particles
distributions.distribution[:].profiles_1d[:].thermalisation.particles (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source rate of thermal particle density due to the thermalisation of fast particles
distributions.distribution[:].profiles_1d[:].time (alpha) |  | FLT_0D | s | Time
distributions.distribution[:].profiles_1d[:].torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].profiles_1d[:].trapped (alpha) |  | STRUCTURE |  | Flux surface averaged profile evaluated using the trapped particle part of the distribution.
distributions.distribution[:].profiles_1d[:].trapped.collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_1d[:].trapped.collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_1d[:].trapped.collisions.electrons.power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].power_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].power_thermal (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_1d[:].trapped.collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_1d[:].trapped.current_fast_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].trapped.current_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_1d[:].trapped.density (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].trapped.density_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_1d[:].trapped.pressure (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_1d[:].trapped.pressure_fast (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_1d[:].trapped.pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_1d[:].trapped.source (alpha) | [1...N] | STRUCT_ARRAY |  | Set of flux averaged sources and sinks of particles, momentum and energy included in the Fokker-Planck modelling, related to the various waves or particle source processes affecting the distribution
distributions.distribution[:].profiles_1d[:].trapped.source[:].energy (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Source rate of energy density
distributions.distribution[:].profiles_1d[:].trapped.source[:].identifier (alpha) |  | STRUCTURE |  | Identifier of the wave or particle source process, defined respectively in distribution/wave or distribution/process
distributions.distribution[:].profiles_1d[:].trapped.source[:].identifier.process_index (alpha) |  | INT_0D |  | Index into distribution/process
distributions.distribution[:].profiles_1d[:].trapped.source[:].identifier.type (alpha) |  | STRUCTURE |  | Type of the source term. Index = 1 for a wave, index = 2 for a particle source process
distributions.distribution[:].profiles_1d[:].trapped.source[:].identifier.type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].profiles_1d[:].trapped.source[:].identifier.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].profiles_1d[:].trapped.source[:].identifier.type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].profiles_1d[:].trapped.source[:].identifier.wave_index (alpha) |  | INT_0D |  | Index into distribution/wave
distributions.distribution[:].profiles_1d[:].trapped.source[:].momentum_tor (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Source rate of toroidal angular momentum density
distributions.distribution[:].profiles_1d[:].trapped.source[:].particles (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | s^-1.m^-3 | Source rate of thermal particle density
distributions.distribution[:].profiles_1d[:].trapped.torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].profiles_2d (alpha) | [distributions.distribution[:].profiles_2d[:].time] | STRUCT_ARRAY |  | 2D profiles in the poloidal plane for various time slices
distributions.distribution[:].profiles_2d[:].co_passing (alpha) |  | STRUCTURE |  | Flux surface averaged profile evaluated using the co-passing particle part of the distribution.
distributions.distribution[:].profiles_2d[:].co_passing.collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_2d[:].co_passing.collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_2d[:].co_passing.collisions.electrons.power_fast (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].power_fast (alpha) | [distributions.grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].power_thermal (alpha) | [distributions.grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].co_passing.collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_2d[:].co_passing.current_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].co_passing.current_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].co_passing.density (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].co_passing.density_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_2d[:].co_passing.pressure (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].co_passing.pressure_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_2d[:].co_passing.pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_2d[:].co_passing.torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].profiles_2d[:].collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_2d[:].collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_2d[:].collisions.electrons.power_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_2d[:].collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_2d[:].collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_2d[:].collisions.ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_2d[:].collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_2d[:].collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_2d[:].collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_2d[:].collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_2d[:].collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].power_fast (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].power_thermal (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_2d[:].collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_2d[:].collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_2d[:].counter_passing (alpha) |  | STRUCTURE |  | Flux surface averaged profile evaluated using the counter-passing particle part of the distribution.
distributions.distribution[:].profiles_2d[:].counter_passing.collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.electrons.power_fast (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].power_fast (alpha) | [distributions.grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].power_thermal (alpha) | [distributions.grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].counter_passing.collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_2d[:].counter_passing.current_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].counter_passing.current_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].counter_passing.density (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].counter_passing.density_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_2d[:].counter_passing.pressure (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].counter_passing.pressure_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_2d[:].counter_passing.pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_2d[:].counter_passing.torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].profiles_2d[:].current_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].current_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].density (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].density_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_2d[:].grid (alpha) |  | STRUCTURE |  | Grid. The grid has to be rectangular in a pair of coordinates, as specified in type
distributions.distribution[:].profiles_2d[:].grid.area (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
distributions.distribution[:].profiles_2d[:].grid.psi (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
distributions.distribution[:].profiles_2d[:].grid.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
distributions.distribution[:].profiles_2d[:].grid.rho_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation)
distributions.distribution[:].profiles_2d[:].grid.theta_geometric (alpha) | [1...N] | FLT_1D (uncertain) | rad | Geometrical poloidal angle
distributions.distribution[:].profiles_2d[:].grid.theta_straight (alpha) | [1...N] | FLT_1D (uncertain) | rad | Straight field line poloidal angle
distributions.distribution[:].profiles_2d[:].grid.type (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm] | STRUCTURE | m^3 | Grid type: index=0: Rectangular grid in the (R,Z) coordinates; index=1: Rectangular grid in the (radial, theta_geometric) coordinates; index=2: Rectangular grid in the (radial, theta_straight) coordinates.
distributions.distribution[:].profiles_2d[:].grid.type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].profiles_2d[:].grid.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].profiles_2d[:].grid.type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].profiles_2d[:].grid.volume (alpha) | [distributions.distribution[:].profiles_2d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
distributions.distribution[:].profiles_2d[:].grid.z (alpha) | [1...N] | FLT_1D (uncertain) | m | Height
distributions.distribution[:].profiles_2d[:].pressure (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].pressure_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_2d[:].pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_2d[:].time (alpha) |  | FLT_0D | s | Time
distributions.distribution[:].profiles_2d[:].torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_2d[:].grid.r, distributions.distribution[:].profiles_2d[:].grid.z] | FLT_2D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].profiles_2d[:].trapped (alpha) |  | STRUCTURE |  | Flux surface averaged profile evaluated using the trapped particle part of the distribution.
distributions.distribution[:].profiles_2d[:].trapped.collisions (alpha) |  | STRUCTURE |  | Power and torque exchanged between the species described by the distribution and the different plasma species through collisions
distributions.distribution[:].profiles_2d[:].trapped.collisions.electrons (alpha) |  | STRUCTURE |  | Collisional exchange with electrons
distributions.distribution[:].profiles_2d[:].trapped.collisions.electrons.power_fast (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.electrons.power_thermal (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.electrons.torque_fast_tor (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.electrons.torque_thermal_tor (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion (alpha) | [1...N] | STRUCT_ARRAY |  | Collisional exchange with the various ion species
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].power_fast (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].power_thermal (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].power_fast (alpha) | [distributions.grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the fast particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].power_thermal (alpha) | [distributions.grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | W.m^-3 | Collisional power density to the thermal particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].torque_fast_tor (alpha) | [distributions.grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].torque_thermal_tor (alpha) | [distributions.grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].torque_fast_tor (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the fast particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].torque_thermal_tor (alpha) | [distributions.distribution[:].grid.rho_tor_norm, distributions.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Collisional toroidal torque density to the thermal particle population
distributions.distribution[:].profiles_2d[:].trapped.collisions.ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
distributions.distribution[:].profiles_2d[:].trapped.current_fast_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density of fast (non-thermal) particles (excluding electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].trapped.current_tor (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | A.m^-2 | Total toroidal driven current density (including electron and thermal ion back-current, or drag-current)
distributions.distribution[:].profiles_2d[:].trapped.density (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | m^-3 | Density (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].trapped.density_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | m^-3 | Density of fast particles
distributions.distribution[:].profiles_2d[:].trapped.pressure (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | J.m^-3 | Pressure (thermal+non-thermal)
distributions.distribution[:].profiles_2d[:].trapped.pressure_fast (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles
distributions.distribution[:].profiles_2d[:].trapped.pressure_fast_parallel (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | J.m^-3 | Pressure of fast particles in the parallel direction
distributions.distribution[:].profiles_2d[:].trapped.torque_tor_j_radial (alpha) | [distributions.distribution[:].profiles_2d[:].grid.grid.rho_tor_norm, distributions.distribution[:].profiles_2d[:].grid.grid.grid.theta_straight] | FLT_2D (uncertain) | N.m^-2 | Toroidal torque due to radial currents
distributions.distribution[:].species (alpha) |  | STRUCTURE |  | Species described by this distribution
distributions.distribution[:].species.ion (alpha) |  | STRUCTURE |  | Description of the ion or neutral species, used if type/index = 2 or 3
distributions.distribution[:].species.ion.element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].species.ion.element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].species.ion.element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].species.ion.element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].species.ion.label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
distributions.distribution[:].species.ion.state (alpha) |  | STRUCTURE |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
distributions.distribution[:].species.ion.state.electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].species.ion.state.label (alpha) |  | STR_0D |  | String identifying ion state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
distributions.distribution[:].species.ion.state.vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].species.ion.state.vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].species.ion.state.z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
distributions.distribution[:].species.ion.state.z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
distributions.distribution[:].species.ion.z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
distributions.distribution[:].species.neutral (alpha) |  | STRUCTURE |  | Description of the neutral species, used if type/index = 4 or 5
distributions.distribution[:].species.neutral.element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
distributions.distribution[:].species.neutral.element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
distributions.distribution[:].species.neutral.element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
distributions.distribution[:].species.neutral.element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
distributions.distribution[:].species.neutral.label (alpha) |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
distributions.distribution[:].species.neutral.state (alpha) |  | STRUCTURE |  | State of the species (energy, excitation, ...)
distributions.distribution[:].species.neutral.state.electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
distributions.distribution[:].species.neutral.state.label (alpha) |  | STR_0D |  | String identifying neutral state
distributions.distribution[:].species.neutral.state.neutral_type (alpha) |  | STRUCTURE |  | Neutral type, in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
distributions.distribution[:].species.neutral.state.neutral_type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].species.neutral.state.neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].species.neutral.state.neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].species.neutral.state.vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
distributions.distribution[:].species.neutral.state.vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
distributions.distribution[:].species.type (alpha) |  | STRUCTURE |  | Species type. index=1 for electron; index=2 for ion species in a single/average state (refer to ion structure); index=3 for ion species in a particular state (refer to ion/state structure); index=4 for neutral species in a single/average state (refer to neutral structure); index=5 for neutral species in a particular state (refer to neutral/state structure); index=6 for neutron; index=7 for photon
distributions.distribution[:].species.type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].species.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].species.type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.distribution[:].wave (alpha) | [1...N] | STRUCT_ARRAY |  | List all waves affecting the distribution, identified as in waves/coherent_wave(i)/identifier in the waves IDS
distributions.distribution[:].wave[:].antenna_name (alpha) |  | STR_0D |  | Name of the antenna that launches this wave. Corresponds to the name specified in antennas/ec(i)/name, or antennas/ic(i)/name or antennas/lh(i)/name (depends of antenna/wave type) in the ANTENNAS IDS.
distributions.distribution[:].wave[:].index_in_antenna (alpha) |  | INT_0D |  | Index of the wave (starts at 1), separating different waves generated from a single antenna.
distributions.distribution[:].wave[:].type (alpha) |  | STRUCTURE |  | Wave/antenna type. index=1 for name=EC; index=2 for name=IC; index=3 for name=LH
distributions.distribution[:].wave[:].type.description (alpha) |  | STR_0D |  | Verbose description
distributions.distribution[:].wave[:].type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
distributions.distribution[:].wave[:].type.name (alpha) |  | STR_0D |  | Short string identifier
distributions.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
distributions.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
distributions.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
distributions.ids_properties.occurrence |  | INT_0D |  |
distributions.magnetic_axis (alpha) |  | STRUCTURE |  | Magnetic axis position (used to define a poloidal angle for the 2D profiles)
distributions.magnetic_axis.r (alpha) | [distributions.time] | FLT_1D (uncertain) | m | Major radius
distributions.magnetic_axis.z (alpha) | [distributions.time] | FLT_1D (uncertain) | m | Height
distributions.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
distributions.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition and in the normalization of current densities)
distributions.vacuum_toroidal_field.b0 (alpha) | [distributions.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewed from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
distributions.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
ec_antennas (alpha) |  |  |  | Antenna systems for heating and current drive in the electron cyclotron (EC) frequencies.
ec_antennas.antenna (alpha) | [1...N] | STRUCT_ARRAY |  | Set of Electron Cyclotron antennas
ec_antennas.antenna[:].beam (alpha) |  | STRUCTURE |  | Beam characteristics
ec_antennas.antenna[:].beam.phase (alpha) |  | STRUCTURE |  | Phase ellipse characteristics
ec_antennas.antenna[:].beam.phase.angle (alpha) |  | STRUCTURE |  | Rotation angle for the phase ellipse
ec_antennas.antenna[:].beam.phase.angle.data (alpha) | [ec_antennas.antenna[:].beam.phase.angle.time] | FLT_1D (uncertain) | rad | Rotation angle for the phase ellipse
ec_antennas.antenna[:].beam.phase.angle.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ec_antennas.antenna[:].beam.phase.curvature (alpha) |  | STRUCTURE |  | Inverse curvature radii for the phase ellipse, positive/negative for divergent/convergent beams
ec_antennas.antenna[:].beam.phase.curvature.data (alpha) | [1...2, ec_antennas.antenna[:].beam.phase.curvature.time] | FLT_2D (uncertain) | m^-1 | Inverse curvature radii for the phase ellipse, positive/negative for divergent/convergent beams
ec_antennas.antenna[:].beam.phase.curvature.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ec_antennas.antenna[:].beam.spot (alpha) |  | STRUCTURE |  | Spot ellipse characteristics
ec_antennas.antenna[:].beam.spot.angle (alpha) |  | STRUCTURE |  | Rotation angle for the spot ellipse
ec_antennas.antenna[:].beam.spot.angle.data (alpha) | [ec_antennas.antenna[:].beam.spot.angle.time] | FLT_1D (uncertain) | rad | Rotation angle for the spot ellipse
ec_antennas.antenna[:].beam.spot.angle.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ec_antennas.antenna[:].beam.spot.size (alpha) |  | STRUCTURE |  | Size of the spot ellipse
ec_antennas.antenna[:].beam.spot.size.data (alpha) | [1...2, ec_antennas.antenna[:].beam.spot.size.time] | FLT_2D (uncertain) | m | Size of the spot ellipse
ec_antennas.antenna[:].beam.spot.size.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ec_antennas.antenna[:].frequency (alpha) |  | FLT_0D (uncertain) | Hz | Frequency
ec_antennas.antenna[:].launching_angle_pol (alpha) |  | STRUCTURE |  | Poloidal launching angle between the horizontal plane and the poloidal component of the nominal beam centerline. tan(angle_pol)=-k_z/k_R;
ec_antennas.antenna[:].launching_angle_pol.data (alpha) | [ec_antennas.antenna[:].launching_angle_pol.time] | FLT_1D (uncertain) | rad | Poloidal launching angle between the horizontal plane and the poloidal component of the nominal beam centerline. tan(angle_pol)=-k_z/k_R;
ec_antennas.antenna[:].launching_angle_pol.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ec_antennas.antenna[:].launching_angle_tor (alpha) |  | STRUCTURE |  | Toroidal launching angle between the poloidal plane and the nominal beam centerline. sin(angle_tor)=k_phi
ec_antennas.antenna[:].launching_angle_tor.data (alpha) | [ec_antennas.antenna[:].launching_angle_tor.time] | FLT_1D (uncertain) | rad | Toroidal launching angle between the poloidal plane and the nominal beam centerline. sin(angle_tor)=k_phi
ec_antennas.antenna[:].launching_angle_tor.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ec_antennas.antenna[:].launching_position (alpha) |  | STRUCTURE |  | Launching position of the beam
ec_antennas.antenna[:].launching_position.phi (alpha) |  | STRUCTURE |  | Toroidal angle
ec_antennas.antenna[:].launching_position.phi.data (alpha) | [ec_antennas.antenna[:].launching_position.phi.time] | FLT_1D (uncertain) | rad | Toroidal angle
ec_antennas.antenna[:].launching_position.phi.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ec_antennas.antenna[:].launching_position.r (alpha) |  | STRUCTURE |  | Major radius
ec_antennas.antenna[:].launching_position.r.data (alpha) | [ec_antennas.antenna[:].launching_position.r.time] | FLT_1D (uncertain) | m | Major radius
ec_antennas.antenna[:].launching_position.r.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ec_antennas.antenna[:].launching_position.z (alpha) |  | STRUCTURE |  | Height
ec_antennas.antenna[:].launching_position.z.data (alpha) | [ec_antennas.antenna[:].launching_position.z.time] | FLT_1D (uncertain) | m | Height
ec_antennas.antenna[:].launching_position.z.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ec_antennas.antenna[:].mode (alpha) |  | STRUCTURE |  | Incoming wave mode (+ or -1 for O/X mode)
ec_antennas.antenna[:].mode.data (alpha) | [ec_antennas.antenna[:].mode.time] | INT_1D |  | Incoming wave mode (+ or -1 for O/X mode)
ec_antennas.antenna[:].mode.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ec_antennas.antenna[:].name (alpha) |  | STR_0D |  | Name of the antenna
ec_antennas.antenna[:].power (alpha) |  | STRUCTURE |  | Power
ec_antennas.antenna[:].power.data (alpha) | [ec_antennas.antenna[:].power.time] | FLT_1D (uncertain) | W | Power
ec_antennas.antenna[:].power.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ec_antennas.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
ec_antennas.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
ec_antennas.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
ec_antennas.code.output_flag (alpha) | [ec_antennas.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
ec_antennas.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
ec_antennas.code.repository (alpha) |  | STR_0D |  | URL of software repository
ec_antennas.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
ec_antennas.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
ec_antennas.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
ec_antennas.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
ec_antennas.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
ece (alpha) |  |  |  | Electron cyclotron emission diagnostic
ece.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (frequency)
ece.channel[:].frequency (alpha) |  | STRUCTURE |  | Frequency of the channel
ece.channel[:].frequency.data (alpha) | [ece.channel[:].frequency.time] | FLT_1D (uncertain) | Hz | Frequency of the channel
ece.channel[:].frequency.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ece.channel[:].harmonic (alpha) |  | STRUCTURE |  | Harmonic detected by the channel. 1 corresponds to the "O1" mode, while 2 corresponds to the "X2" mode.
ece.channel[:].harmonic.data (alpha) | [ece.channel[:].harmonic.time] | INT_1D |  | Harmonic detected by the channel. 1 corresponds to the "O1" mode, while 2 corresponds to the "X2" mode.
ece.channel[:].harmonic.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ece.channel[:].identifier (alpha) |  | STR_0D |  | ID of the channel
ece.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
ece.channel[:].position (alpha) |  | STRUCTURE |  | Position of the measurements
ece.channel[:].position.phi (alpha) |  | STRUCTURE |  | Toroidal angle
ece.channel[:].position.phi.data (alpha) | [ece.channel[:].position.phi.time] | FLT_1D (uncertain) | rad | Toroidal angle
ece.channel[:].position.phi.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ece.channel[:].position.r (alpha) |  | STRUCTURE |  | Major radius
ece.channel[:].position.r.data (alpha) | [ece.channel[:].position.r.time] | FLT_1D (uncertain) | m | Major radius
ece.channel[:].position.r.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ece.channel[:].position.z (alpha) |  | STRUCTURE |  | Height
ece.channel[:].position.z.data (alpha) | [ece.channel[:].position.z.time] | FLT_1D (uncertain) | m | Height
ece.channel[:].position.z.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ece.channel[:].t_e (alpha) |  | STRUCTURE |  | Electron temperature
ece.channel[:].t_e.data (alpha) | [ece.channel[:].t_e.time] | FLT_1D (uncertain) | eV | Electron temperature
ece.channel[:].t_e.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ece.channel[:].t_e_voltage (alpha) |  | STRUCTURE |  | Raw voltage measured on each channel, from which the calibrated temperature data is then derived
ece.channel[:].t_e_voltage.data (alpha) | [ece.channel[:].t_e_voltage.time] | FLT_1D (uncertain) | V | Raw voltage measured on each channel, from which the calibrated temperature data is then derived
ece.channel[:].t_e_voltage.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ece.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
ece.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
ece.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
ece.code.output_flag (alpha) | [ece.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
ece.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
ece.code.repository (alpha) |  | STR_0D |  | URL of software repository
ece.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
ece.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
ece.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
ece.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
ece.ids_properties.occurrence |  | INT_0D |  |
ece.line_of_sight (alpha) |  | STRUCTURE |  | Description of the line of sight of the diagnostic (valid for all channels), defined by two points
ece.line_of_sight.first_point (alpha) |  | STRUCTURE |  | Position of the first point
ece.line_of_sight.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
ece.line_of_sight.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
ece.line_of_sight.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
ece.line_of_sight.second_point (alpha) |  | STRUCTURE |  | Position of the second point
ece.line_of_sight.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
ece.line_of_sight.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
ece.line_of_sight.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
ece.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
edge_profiles (alpha) |  |  |  | Edge plasma profiles (includes the scrape-off layer and possibly part of the confined plasma)
edge_profiles.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
edge_profiles.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
edge_profiles.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
edge_profiles.code.output_flag (alpha) | [edge_profiles.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
edge_profiles.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
edge_profiles.code.repository (alpha) |  | STR_0D |  | URL of software repository
edge_profiles.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
edge_profiles.ggd (alpha) | [edge_profiles.ggd[:].time] | STRUCT_ARRAY |  | Edge plasma quantities represented using the general grid description, for various time slices
edge_profiles.ggd[:].e_field (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Electric field, given on various grid subsets
edge_profiles.ggd[:].e_field[:].diamagnetic (alpha) | [edge_profiles.ggd[:].e_field[:].radial] | FLT_1D (uncertain) | V.m^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].e_field[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].e_field[:].radial, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].e_field[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].e_field[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].e_field[:].parallel (alpha) | [edge_profiles.ggd[:].e_field[:].radial] | FLT_1D (uncertain) | V.m^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].e_field[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].e_field[:].radial, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].e_field[:].poloidal (alpha) | [edge_profiles.ggd[:].e_field[:].radial] | FLT_1D (uncertain) | V.m^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].e_field[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].e_field[:].radial, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].e_field[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].e_field[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].e_field[:].radial, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].e_field[:].toroidal (alpha) | [edge_profiles.ggd[:].e_field[:].radial] | FLT_1D (uncertain) | V.m^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].e_field[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].e_field[:].radial, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
edge_profiles.ggd[:].electrons.density (alpha) | [1...N] | STRUCT_ARRAY | m^-3 | Density (thermal+non-thermal), given on various grid subsets
edge_profiles.ggd[:].electrons.density[:].coefficients (alpha) | [edge_profiles.ggd[:].electrons.density[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.density[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.density[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.density[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.density_fast (alpha) | [1...N] | STRUCT_ARRAY | m^-3 | Density of fast (non-thermal) particles, given on various grid subsets
edge_profiles.ggd[:].electrons.density_fast[:].coefficients (alpha) | [edge_profiles.ggd[:].electrons.density_fast[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.density_fast[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.density_fast[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.density_fast[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.distribution_function (alpha) | [1...N] | STRUCT_ARRAY | mixed | Distribution function, given on various grid subsets
edge_profiles.ggd[:].electrons.distribution_function[:].coefficients (alpha) | [edge_profiles.ggd[:].electrons.distribution_function[:].values, 1...N] | FLT_2D (uncertain) | mixed | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.distribution_function[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.distribution_function[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.distribution_function[:].values (alpha) | [1...N] | FLT_1D (uncertain) | mixed | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.pressure (alpha) | [1...N] | STRUCT_ARRAY | Pa | Pressure, given on various grid subsets
edge_profiles.ggd[:].electrons.pressure[:].coefficients (alpha) | [edge_profiles.ggd[:].electrons.pressure[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.pressure[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.pressure[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.pressure[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.pressure_fast_parallel (alpha) | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) parallel pressure, given on various grid subsets
edge_profiles.ggd[:].electrons.pressure_fast_parallel[:].coefficients (alpha) | [edge_profiles.ggd[:].electrons.pressure_fast_parallel[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.pressure_fast_parallel[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.pressure_fast_parallel[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.pressure_fast_parallel[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.pressure_fast_perpendicular (alpha) | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) perpendicular pressure, given on various grid subsets
edge_profiles.ggd[:].electrons.pressure_fast_perpendicular[:].coefficients (alpha) | [edge_profiles.ggd[:].electrons.pressure_fast_perpendicular[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.pressure_fast_perpendicular[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.pressure_fast_perpendicular[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.pressure_fast_perpendicular[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.temperature (alpha) | [1...N] | STRUCT_ARRAY | eV | Temperature, given on various grid subsets
edge_profiles.ggd[:].electrons.temperature[:].coefficients (alpha) | [edge_profiles.ggd[:].electrons.temperature[:].values, 1...N] | FLT_2D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.temperature[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.temperature[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.temperature[:].values (alpha) | [1...N] | FLT_1D (uncertain) | eV | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.velocity (alpha) | [1...N] | STRUCTURE | m.s^-1 | Velocity, given on various grid subsets
edge_profiles.ggd[:].electrons.velocity.diamagnetic (alpha) | [edge_profiles.ggd[:].electrons.velocity.radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.velocity.diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].electrons.velocity.radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.velocity.grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].electrons.velocity.grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].electrons.velocity.parallel (alpha) | [edge_profiles.ggd[:].electrons.velocity.radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.velocity.parallel_coefficients (alpha) | [edge_profiles.ggd[:].electrons.velocity.radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.velocity.poloidal (alpha) | [edge_profiles.ggd[:].electrons.velocity.radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.velocity.poloidal_coefficients (alpha) | [edge_profiles.ggd[:].electrons.velocity.radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.velocity.radial (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.velocity.radial_coefficients (alpha) | [edge_profiles.ggd[:].electrons.velocity.radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].electrons.velocity.toroidal (alpha) | [edge_profiles.ggd[:].electrons.velocity.radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].electrons.velocity.toroidal_coefficients (alpha) | [edge_profiles.ggd[:].electrons.velocity.radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].grid (alpha) |  | STRUCTURE |  | Grid description
edge_profiles.ggd[:].grid.grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
edge_profiles.ggd[:].grid.grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
edge_profiles.ggd[:].grid.grid_subset[:].base[:].jacobian (alpha) | [edge_profiles.ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
edge_profiles.ggd[:].grid.grid_subset[:].base[:].tensor_contravariant (alpha) | [edge_profiles.ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
edge_profiles.ggd[:].grid.grid_subset[:].base[:].tensor_covariant (alpha) | [edge_profiles.ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
edge_profiles.ggd[:].grid.grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
edge_profiles.ggd[:].grid.grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
edge_profiles.ggd[:].grid.grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
edge_profiles.ggd[:].grid.grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
edge_profiles.ggd[:].grid.grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
edge_profiles.ggd[:].grid.grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
edge_profiles.ggd[:].grid.grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier
edge_profiles.ggd[:].grid.grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
edge_profiles.ggd[:].grid.grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
edge_profiles.ggd[:].grid.grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
edge_profiles.ggd[:].grid.grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
edge_profiles.ggd[:].grid.grid_subset[:].metric.jacobian (alpha) | [edge_profiles.ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
edge_profiles.ggd[:].grid.grid_subset[:].metric.tensor_contravariant (alpha) | [edge_profiles.ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
edge_profiles.ggd[:].grid.grid_subset[:].metric.tensor_covariant (alpha) | [edge_profiles.ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
edge_profiles.ggd[:].grid.identifier (alpha) |  | STRUCTURE |  | Grid identifier
edge_profiles.ggd[:].grid.identifier.description (alpha) |  | STR_0D |  | Verbose description
edge_profiles.ggd[:].grid.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
edge_profiles.ggd[:].grid.identifier.name (alpha) |  | STR_0D |  | Short string identifier
edge_profiles.ggd[:].grid.space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
edge_profiles.ggd[:].grid.space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therfore defines the dimension of the space. The meaning of these predefined integer constants can be found in the documentation of the grid service library
edge_profiles.ggd[:].grid.space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
edge_profiles.ggd[:].grid.space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
edge_profiles.ggd[:].grid.space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
edge_profiles.ggd[:].grid.space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
edge_profiles.ggd[:].grid.space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
edge_profiles.ggd[:].grid.space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
edge_profiles.ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
edge_profiles.ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
edge_profiles.ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
edge_profiles.ggd[:].grid.space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
edge_profiles.ggd[:].grid.space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
edge_profiles.ggd[:].grid.space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
edge_profiles.ggd[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
edge_profiles.ggd[:].ion[:].density (alpha) | [1...N] | STRUCT_ARRAY | m^-3 | Density (thermal+non-thermal) (sum over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].density[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].density[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].density[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].density[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].density[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].density_fast (alpha) | [1...N] | STRUCT_ARRAY | m^-3 | Density of fast (non-thermal) particles (sum over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].density_fast[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].density_fast[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].density_fast[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].density_fast[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].density_fast[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_profiles.ggd[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_profiles.ggd[:].ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_profiles.ggd[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_profiles.ggd[:].ion[:].energy_density_kinetic (alpha) | [1...N] | STRUCT_ARRAY | J.m^-3 | Kinetic energy density (sum over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].energy_density_kinetic[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].energy_density_kinetic[:].values, 1...N] | FLT_2D (uncertain) | J.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].energy_density_kinetic[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].energy_density_kinetic[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].energy_density_kinetic[:].values (alpha) | [1...N] | FLT_1D (uncertain) | J.m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
edge_profiles.ggd[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_profiles.ggd[:].ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
edge_profiles.ggd[:].ion[:].pressure (alpha) | [1...N] | STRUCT_ARRAY | Pa | Pressure (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].pressure[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].pressure[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].pressure[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].pressure[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].pressure[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].pressure_fast_parallel (alpha) | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) parallel pressure (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].pressure_fast_parallel[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].pressure_fast_parallel[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].pressure_fast_parallel[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].pressure_fast_parallel[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].pressure_fast_parallel[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].pressure_fast_perpendicular (alpha) | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) perpendicular pressure (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].pressure_fast_perpendicular[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].pressure_fast_perpendicular[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].pressure_fast_perpendicular[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].pressure_fast_perpendicular[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].pressure_fast_perpendicular[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
edge_profiles.ggd[:].ion[:].state[:].density (alpha) | [1...N] | STRUCT_ARRAY | m^-3 | Density (thermal+non-thermal), given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].density[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].density[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].density[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].density[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].density[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].density_fast (alpha) | [1...N] | STRUCT_ARRAY | m^-3 | Density of fast (non-thermal) particles, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].density_fast[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].density_fast[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].density_fast[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].density_fast[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].density_fast[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].distribution_function (alpha) | [1...N] | STRUCT_ARRAY | mixed | Distribution function, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].distribution_function[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].distribution_function[:].values, 1...N] | FLT_2D (uncertain) | mixed | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].distribution_function[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].distribution_function[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].distribution_function[:].values (alpha) | [1...N] | FLT_1D (uncertain) | mixed | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_profiles.ggd[:].ion[:].state[:].energy_density_kinetic (alpha) | [1...N] | STRUCT_ARRAY | J.m^-3 | Kinetic energy density, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].energy_density_kinetic[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].energy_density_kinetic[:].values, 1...N] | FLT_2D (uncertain) | J.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].energy_density_kinetic[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].energy_density_kinetic[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].energy_density_kinetic[:].values (alpha) | [1...N] | FLT_1D (uncertain) | J.m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].ionisation_potential (alpha) | [1...N] | STRUCT_ARRAY | Elementary Charge Unit | Cumulative and average ionisation potential to reach a given bundle. Defined as sum (x_z* (sum of Epot from z'=0 to z-1)), where Epot is the ionisation potential of ion Xz_+, and x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].ionisation_potential[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].ionisation_potential[:].values, 1...N] | FLT_2D (uncertain) | Elementary Charge Unit | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].ionisation_potential[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].ionisation_potential[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].ionisation_potential[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Elementary Charge Unit | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
edge_profiles.ggd[:].ion[:].state[:].pressure (alpha) | [1...N] | STRUCT_ARRAY | Pa | Pressure, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].pressure[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].pressure[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].pressure[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].pressure[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].pressure[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_parallel (alpha) | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) parallel pressure, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_parallel[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].pressure_fast_parallel[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_parallel[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_parallel[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_parallel[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_perpendicular (alpha) | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) perpendicular pressure, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_perpendicular[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].pressure_fast_perpendicular[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_perpendicular[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_perpendicular[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].pressure_fast_perpendicular[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].temperature (alpha) | [1...N] | STRUCT_ARRAY | eV | Temperature, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].temperature[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].temperature[:].values, 1...N] | FLT_2D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].temperature[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].temperature[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].temperature[:].values (alpha) | [1...N] | FLT_1D (uncertain) | eV | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].velocity[:].diamagnetic (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].velocity[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].velocity[:].parallel (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity[:].poloidal (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity[:].toroidal (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity due to the diamagnetic drift, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].diamagnetic (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].parallel (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].poloidal (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].toroidal (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_exb (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity due to the ExB drift, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].diamagnetic (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].parallel (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].poloidal (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].toroidal (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_profiles.ggd[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_profiles.ggd[:].ion[:].state[:].z_average (alpha) | [1...N] | STRUCT_ARRAY | Elementary Charge Unit | Average Z of the charge state bundle (equal to z_min if no bundle), = sum (Z*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].z_average[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].z_average[:].values, 1...N] | FLT_2D (uncertain) | Elementary Charge Unit | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].z_average[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].z_average[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].z_average[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Elementary Charge Unit | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
edge_profiles.ggd[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
edge_profiles.ggd[:].ion[:].state[:].z_square_average (alpha) | [1...N] | STRUCT_ARRAY | Elementary Charge Unit | Average Z square of the charge state bundle (equal to z_min if no bundle), = sum (Z^2*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle, given on various grid subsets
edge_profiles.ggd[:].ion[:].state[:].z_square_average[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].state[:].z_square_average[:].values, 1...N] | FLT_2D (uncertain) | Elementary Charge Unit | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].state[:].z_square_average[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].state[:].z_square_average[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].state[:].z_square_average[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Elementary Charge Unit | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].temperature (alpha) | [1...N] | STRUCT_ARRAY | eV | Temperature (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].temperature[:].coefficients (alpha) | [edge_profiles.ggd[:].ion[:].temperature[:].values, 1...N] | FLT_2D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].temperature[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].temperature[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].temperature[:].values (alpha) | [1...N] | FLT_1D (uncertain) | eV | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].velocity (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].ion[:].velocity[:].diamagnetic (alpha) | [edge_profiles.ggd[:].ion[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].velocity[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].velocity[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].ion[:].velocity[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].ion[:].velocity[:].parallel (alpha) | [edge_profiles.ggd[:].ion[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].velocity[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].velocity[:].poloidal (alpha) | [edge_profiles.ggd[:].ion[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].velocity[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].velocity[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].velocity[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].velocity[:].toroidal (alpha) | [edge_profiles.ggd[:].ion[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].ion[:].velocity[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].ion[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
edge_profiles.ggd[:].j_anomalous (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | Anomalous current density, given on various grid subsets
edge_profiles.ggd[:].j_anomalous[:].diamagnetic (alpha) | [edge_profiles.ggd[:].j_anomalous[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_anomalous[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].j_anomalous[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_anomalous[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_anomalous[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_anomalous[:].parallel (alpha) | [edge_profiles.ggd[:].j_anomalous[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_anomalous[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].j_anomalous[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_anomalous[:].poloidal (alpha) | [edge_profiles.ggd[:].j_anomalous[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_anomalous[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].j_anomalous[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_anomalous[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_anomalous[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].j_anomalous[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_anomalous[:].toroidal (alpha) | [edge_profiles.ggd[:].j_anomalous[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_anomalous[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].j_anomalous[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_diamagnetic (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | Current density due to the diamgnetic drift, given on various grid subsets
edge_profiles.ggd[:].j_diamagnetic[:].diamagnetic (alpha) | [edge_profiles.ggd[:].j_diamagnetic[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_diamagnetic[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].j_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_diamagnetic[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_diamagnetic[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_diamagnetic[:].parallel (alpha) | [edge_profiles.ggd[:].j_diamagnetic[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_diamagnetic[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].j_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_diamagnetic[:].poloidal (alpha) | [edge_profiles.ggd[:].j_diamagnetic[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_diamagnetic[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].j_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_diamagnetic[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_diamagnetic[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].j_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_diamagnetic[:].toroidal (alpha) | [edge_profiles.ggd[:].j_diamagnetic[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_diamagnetic[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].j_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_heat_viscosity (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | Current density due to the heat viscosity, given on various grid subsets
edge_profiles.ggd[:].j_heat_viscosity[:].diamagnetic (alpha) | [edge_profiles.ggd[:].j_heat_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_heat_viscosity[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].j_heat_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_heat_viscosity[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_heat_viscosity[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_heat_viscosity[:].parallel (alpha) | [edge_profiles.ggd[:].j_heat_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_heat_viscosity[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].j_heat_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_heat_viscosity[:].poloidal (alpha) | [edge_profiles.ggd[:].j_heat_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_heat_viscosity[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].j_heat_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_heat_viscosity[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_heat_viscosity[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].j_heat_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_heat_viscosity[:].toroidal (alpha) | [edge_profiles.ggd[:].j_heat_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_heat_viscosity[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].j_heat_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_inertial (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | Inertial current density, given on various grid subsets
edge_profiles.ggd[:].j_inertial[:].diamagnetic (alpha) | [edge_profiles.ggd[:].j_inertial[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_inertial[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].j_inertial[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_inertial[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_inertial[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_inertial[:].parallel (alpha) | [edge_profiles.ggd[:].j_inertial[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_inertial[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].j_inertial[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_inertial[:].poloidal (alpha) | [edge_profiles.ggd[:].j_inertial[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_inertial[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].j_inertial[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_inertial[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_inertial[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].j_inertial[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_inertial[:].toroidal (alpha) | [edge_profiles.ggd[:].j_inertial[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_inertial[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].j_inertial[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_ion_neutral_friction (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | Current density due to ion neutral friction, given on various grid subsets
edge_profiles.ggd[:].j_ion_neutral_friction[:].diamagnetic (alpha) | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_ion_neutral_friction[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_ion_neutral_friction[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_ion_neutral_friction[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_ion_neutral_friction[:].parallel (alpha) | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_ion_neutral_friction[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_ion_neutral_friction[:].poloidal (alpha) | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_ion_neutral_friction[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_ion_neutral_friction[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_ion_neutral_friction[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_ion_neutral_friction[:].toroidal (alpha) | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_ion_neutral_friction[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].j_ion_neutral_friction[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_parallel_viscosity (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | Current density due to the parallel viscosity, given on various grid subsets
edge_profiles.ggd[:].j_parallel_viscosity[:].diamagnetic (alpha) | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_parallel_viscosity[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_parallel_viscosity[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_parallel_viscosity[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_parallel_viscosity[:].parallel (alpha) | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_parallel_viscosity[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_parallel_viscosity[:].poloidal (alpha) | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_parallel_viscosity[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_parallel_viscosity[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_parallel_viscosity[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_parallel_viscosity[:].toroidal (alpha) | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_parallel_viscosity[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].j_parallel_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_perpendicular_viscosity (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | Current density due to the perpendicular viscosity, given on various grid subsets
edge_profiles.ggd[:].j_perpendicular_viscosity[:].diamagnetic (alpha) | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_perpendicular_viscosity[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_perpendicular_viscosity[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_perpendicular_viscosity[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_perpendicular_viscosity[:].parallel (alpha) | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_perpendicular_viscosity[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_perpendicular_viscosity[:].poloidal (alpha) | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_perpendicular_viscosity[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_perpendicular_viscosity[:].toroidal (alpha) | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_perpendicular_viscosity[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].j_perpendicular_viscosity[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_pfirsch_schlueter (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | Current density due to Pfirsch-Schlüter effects, given on various grid subsets
edge_profiles.ggd[:].j_pfirsch_schlueter[:].diamagnetic (alpha) | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial] | FLT_1D (uncertain) | A.m^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_pfirsch_schlueter[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_pfirsch_schlueter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].j_pfirsch_schlueter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].j_pfirsch_schlueter[:].parallel (alpha) | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial] | FLT_1D (uncertain) | A.m^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_pfirsch_schlueter[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_pfirsch_schlueter[:].poloidal (alpha) | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial] | FLT_1D (uncertain) | A.m^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_pfirsch_schlueter[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].j_pfirsch_schlueter[:].toroidal (alpha) | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial] | FLT_1D (uncertain) | A.m^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].j_pfirsch_schlueter[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].j_pfirsch_schlueter[:].radial, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].n_i_total_over_n_e (alpha) | [1...N] | STRUCT_ARRAY | - | Ratio of total ion density (sum over ion species) over electron density. (thermal+non-thermal), given on various grid subsets
edge_profiles.ggd[:].n_i_total_over_n_e[:].coefficients (alpha) | [edge_profiles.ggd[:].n_i_total_over_n_e[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].n_i_total_over_n_e[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].n_i_total_over_n_e[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].n_i_total_over_n_e[:].values (alpha) | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different neutral species
edge_profiles.ggd[:].neutral[:].density (alpha) | [1...N] | STRUCT_ARRAY | m^-3 | Density (thermal+non-thermal) (sum over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].density[:].coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].density[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].density[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].density[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].density[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].density_fast (alpha) | [1...N] | STRUCT_ARRAY | m^-3 | Density of fast (non-thermal) particles (sum over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].density_fast[:].coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].density_fast[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].density_fast[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].density_fast[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].density_fast[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_profiles.ggd[:].neutral[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_profiles.ggd[:].neutral[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_profiles.ggd[:].neutral[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_profiles.ggd[:].neutral[:].energy_density_kinetic (alpha) | [1...N] | STRUCT_ARRAY | J.m^-3 | Kinetic energy density (sum over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].energy_density_kinetic[:].coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].energy_density_kinetic[:].values, 1...N] | FLT_2D (uncertain) | J.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].energy_density_kinetic[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].energy_density_kinetic[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].energy_density_kinetic[:].values (alpha) | [1...N] | FLT_1D (uncertain) | J.m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].ion_index (alpha) |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
edge_profiles.ggd[:].neutral[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H, D, T, He, C, D2, DT, CD4, ...)
edge_profiles.ggd[:].neutral[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_profiles.ggd[:].neutral[:].pressure (alpha) | [1...N] | STRUCT_ARRAY | Pa | Pressure (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].pressure[:].coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].pressure[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].pressure[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].pressure[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].pressure[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].pressure_fast_parallel (alpha) | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) parallel pressure (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].pressure_fast_parallel[:].coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].pressure_fast_parallel[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].pressure_fast_parallel[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].pressure_fast_parallel[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].pressure_fast_parallel[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].pressure_fast_perpendicular (alpha) | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) perpendicular pressure (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].pressure_fast_perpendicular[:].coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].pressure_fast_perpendicular[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].pressure_fast_perpendicular[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].pressure_fast_perpendicular[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].pressure_fast_perpendicular[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Quantities related to the different states of the species (energy, excitation, ...)
edge_profiles.ggd[:].neutral[:].state[:].density (alpha) | [1...N] | STRUCT_ARRAY | m^-3 | Density (thermal+non-thermal), given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].density[:].coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].density[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].density[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].density[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].density[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].density_fast (alpha) | [1...N] | STRUCT_ARRAY | m^-3 | Density of fast (non-thermal) particles, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].density_fast[:].coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].density_fast[:].values, 1...N] | FLT_2D (uncertain) | m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].density_fast[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].density_fast[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].density_fast[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].distribution_function (alpha) | [1...N] | STRUCT_ARRAY | mixed | Distribution function, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].distribution_function[:].coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].distribution_function[:].values, 1...N] | FLT_2D (uncertain) | mixed | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].distribution_function[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].distribution_function[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].distribution_function[:].values (alpha) | [1...N] | FLT_1D (uncertain) | mixed | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_profiles.ggd[:].neutral[:].state[:].energy_density_kinetic (alpha) | [1...N] | STRUCT_ARRAY | J.m^-3 | Kinetic energy density, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].energy_density_kinetic[:].coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].energy_density_kinetic[:].values, 1...N] | FLT_2D (uncertain) | J.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].energy_density_kinetic[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].energy_density_kinetic[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].energy_density_kinetic[:].values (alpha) | [1...N] | FLT_1D (uncertain) | J.m^-3 | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].label (alpha) |  | STR_0D |  | String identifying state
edge_profiles.ggd[:].neutral[:].state[:].neutral_type (alpha) |  | STRUCTURE |  | Neutral type, in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
edge_profiles.ggd[:].neutral[:].state[:].neutral_type.description (alpha) |  | STR_0D |  | Verbose description
edge_profiles.ggd[:].neutral[:].state[:].neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
edge_profiles.ggd[:].neutral[:].state[:].neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
edge_profiles.ggd[:].neutral[:].state[:].pressure (alpha) | [1...N] | STRUCT_ARRAY | Pa | Pressure, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].pressure[:].coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].pressure[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].pressure[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].pressure[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].pressure[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_parallel (alpha) | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) parallel pressure, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_parallel[:].coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_parallel[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_parallel[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_parallel[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_parallel[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_perpendicular (alpha) | [1...N] | STRUCT_ARRAY | Pa | Fast (non-thermal) perpendicular pressure, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_perpendicular[:].coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_perpendicular[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_perpendicular[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_perpendicular[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].pressure_fast_perpendicular[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].temperature (alpha) | [1...N] | STRUCT_ARRAY | eV | Temperature, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].temperature[:].coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].temperature[:].values, 1...N] | FLT_2D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].temperature[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].temperature[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].temperature[:].values (alpha) | [1...N] | FLT_1D (uncertain) | eV | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].diamagnetic (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].parallel (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].poloidal (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].toroidal (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity due to the diamagnetic drift, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].diamagnetic (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].parallel (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].poloidal (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].toroidal (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_diamagnetic[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity due to the ExB drift, given on various grid subsets
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].diamagnetic (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].parallel (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].poloidal (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].toroidal (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].state[:].velocity_exb[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_profiles.ggd[:].neutral[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_profiles.ggd[:].neutral[:].temperature (alpha) | [1...N] | STRUCT_ARRAY | eV | Temperature (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].temperature[:].coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].temperature[:].values, 1...N] | FLT_2D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].temperature[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].temperature[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].temperature[:].values (alpha) | [1...N] | FLT_1D (uncertain) | eV | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].velocity (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Velocity (average over states when multiple states are considered), given on various grid subsets
edge_profiles.ggd[:].neutral[:].velocity[:].diamagnetic (alpha) | [edge_profiles.ggd[:].neutral[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].velocity[:].diamagnetic_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].velocity[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].neutral[:].velocity[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].neutral[:].velocity[:].parallel (alpha) | [edge_profiles.ggd[:].neutral[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].velocity[:].parallel_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].velocity[:].poloidal (alpha) | [edge_profiles.ggd[:].neutral[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].velocity[:].poloidal_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].velocity[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].velocity[:].radial_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].neutral[:].velocity[:].toroidal (alpha) | [edge_profiles.ggd[:].neutral[:].velocity[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].neutral[:].velocity[:].toroidal_coefficients (alpha) | [edge_profiles.ggd[:].neutral[:].velocity[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].phi_potential (alpha) | [1...N] | STRUCT_ARRAY | V | Electric potential, given on various grid subsets
edge_profiles.ggd[:].phi_potential[:].coefficients (alpha) | [edge_profiles.ggd[:].phi_potential[:].values, 1...N] | FLT_2D (uncertain) | V | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].phi_potential[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].phi_potential[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].phi_potential[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].pressure_parallel (alpha) | [1...N] | STRUCT_ARRAY | Pa | Total parallel pressure (electrons+ions, thermal+non-thermal), given on various grid subsets
edge_profiles.ggd[:].pressure_parallel[:].coefficients (alpha) | [edge_profiles.ggd[:].pressure_parallel[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].pressure_parallel[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].pressure_parallel[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].pressure_parallel[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].pressure_perpendicular (alpha) | [1...N] | STRUCT_ARRAY | Pa | Total perpendicular pressure (electrons+ions, thermal+non-thermal), given on various grid subsets
edge_profiles.ggd[:].pressure_perpendicular[:].coefficients (alpha) | [edge_profiles.ggd[:].pressure_perpendicular[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].pressure_perpendicular[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].pressure_perpendicular[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].pressure_perpendicular[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].pressure_thermal (alpha) | [1...N] | STRUCT_ARRAY | Pa | Thermal pressure (electrons+ions), given on various grid subsets
edge_profiles.ggd[:].pressure_thermal[:].coefficients (alpha) | [edge_profiles.ggd[:].pressure_thermal[:].values, 1...N] | FLT_2D (uncertain) | Pa | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].pressure_thermal[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].pressure_thermal[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].pressure_thermal[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Pa | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].t_i_average (alpha) | [1...N] | STRUCT_ARRAY | eV | Ion temperature (averaged on ion species), given on various grid subsets
edge_profiles.ggd[:].t_i_average[:].coefficients (alpha) | [edge_profiles.ggd[:].t_i_average[:].values, 1...N] | FLT_2D (uncertain) | eV | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].t_i_average[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].t_i_average[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].t_i_average[:].values (alpha) | [1...N] | FLT_1D (uncertain) | eV | One scalar value is provided per element in the grid subset.
edge_profiles.ggd[:].time (alpha) |  | FLT_0D | s | Time
edge_profiles.ggd[:].zeff (alpha) | [1...N] | STRUCT_ARRAY | - | Effective charge, given on various grid subsets
edge_profiles.ggd[:].zeff[:].coefficients (alpha) | [edge_profiles.ggd[:].zeff[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_profiles.ggd[:].zeff[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_profiles.ggd[:].zeff[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_profiles.ggd[:].zeff[:].values (alpha) | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_profiles.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
edge_profiles.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
edge_profiles.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
edge_profiles.ids_properties.occurrence |  | INT_0D |  |
edge_profiles.profiles_1d (alpha) | [edge_profiles.profiles_1d[:].time] | STRUCT_ARRAY |  | SOL radial profiles for various time slices, taken on outboard equatorial mid-plane
edge_profiles.profiles_1d[:].conductivity_parallel (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | ohm^-1.m^-1 | Parallel conductivity
edge_profiles.profiles_1d[:].e_field (alpha) |  | STRUCTURE | V.m^-1 | Electric field, averaged on the magnetic surface. E.g for the parellel component, average(E.B) / B0, using core_profiles/vacuum_toroidal_field/b0
edge_profiles.profiles_1d[:].e_field.diamagnetic (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Diamagnetic component
edge_profiles.profiles_1d[:].e_field.parallel (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Parallel component
edge_profiles.profiles_1d[:].e_field.poloidal (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Poloidal component
edge_profiles.profiles_1d[:].e_field.radial (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Radial component
edge_profiles.profiles_1d[:].e_field.toroidal (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Toroidal component
edge_profiles.profiles_1d[:].e_field_parallel (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Parallel electric field = average(E.B) / B0, where Core_Profiles/Vacuum_Toroidal_Field/ B0
edge_profiles.profiles_1d[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
edge_profiles.profiles_1d[:].electrons.density (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
edge_profiles.profiles_1d[:].electrons.density_fast (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
edge_profiles.profiles_1d[:].electrons.pressure (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
edge_profiles.profiles_1d[:].electrons.pressure_fast_parallel (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
edge_profiles.profiles_1d[:].electrons.pressure_fast_perpendicular (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
edge_profiles.profiles_1d[:].electrons.temperature (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
edge_profiles.profiles_1d[:].electrons.velocity (alpha) |  | STRUCTURE | m.s^-1 | Velocity
edge_profiles.profiles_1d[:].electrons.velocity.diamagnetic (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
edge_profiles.profiles_1d[:].electrons.velocity.parallel (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
edge_profiles.profiles_1d[:].electrons.velocity.poloidal (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
edge_profiles.profiles_1d[:].electrons.velocity.radial (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
edge_profiles.profiles_1d[:].electrons.velocity.toroidal (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
edge_profiles.profiles_1d[:].electrons.velocity_pol (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
edge_profiles.profiles_1d[:].electrons.velocity_tor (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
edge_profiles.profiles_1d[:].grid (alpha) |  | STRUCTURE |  | Radial grid
edge_profiles.profiles_1d[:].grid.area (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
edge_profiles.profiles_1d[:].grid.psi (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
edge_profiles.profiles_1d[:].grid.rho_tor (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
edge_profiles.profiles_1d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
edge_profiles.profiles_1d[:].grid.volume (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
edge_profiles.profiles_1d[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
edge_profiles.profiles_1d[:].ion[:].density (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].density_fast (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_profiles.profiles_1d[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_profiles.profiles_1d[:].ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_profiles.profiles_1d[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_profiles.profiles_1d[:].ion[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
edge_profiles.profiles_1d[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_profiles.profiles_1d[:].ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
edge_profiles.profiles_1d[:].ion[:].pressure (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].pressure_fast_parallel (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].pressure_fast_perpendicular (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
edge_profiles.profiles_1d[:].ion[:].state[:].density (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
edge_profiles.profiles_1d[:].ion[:].state[:].density_fast (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
edge_profiles.profiles_1d[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_profiles.profiles_1d[:].ion[:].state[:].ionisation_potential (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Cumulative and average ionisation potential to reach a given bundle. Defined as sum (x_z* (sum of Epot from z'=0 to z-1)), where Epot is the ionisation potential of ion Xz’+, and x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
edge_profiles.profiles_1d[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
edge_profiles.profiles_1d[:].ion[:].state[:].pressure (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
edge_profiles.profiles_1d[:].ion[:].state[:].pressure_fast_parallel (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
edge_profiles.profiles_1d[:].ion[:].state[:].pressure_fast_perpendicular (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
edge_profiles.profiles_1d[:].ion[:].state[:].temperature (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
edge_profiles.profiles_1d[:].ion[:].state[:].velocity (alpha) |  | STRUCTURE | m.s^-1 | Velocity
edge_profiles.profiles_1d[:].ion[:].state[:].velocity.diamagnetic (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
edge_profiles.profiles_1d[:].ion[:].state[:].velocity.parallel (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
edge_profiles.profiles_1d[:].ion[:].state[:].velocity.poloidal (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
edge_profiles.profiles_1d[:].ion[:].state[:].velocity.radial (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
edge_profiles.profiles_1d[:].ion[:].state[:].velocity.toroidal (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
edge_profiles.profiles_1d[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_profiles.profiles_1d[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_profiles.profiles_1d[:].ion[:].state[:].z_average (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Average Z of the charge state bundle (equal to z_min if no bundle), = sum (Z*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
edge_profiles.profiles_1d[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
edge_profiles.profiles_1d[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
edge_profiles.profiles_1d[:].ion[:].state[:].z_square_average (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Average Z square of the charge state bundle (equal to z_min if no bundle), = sum (Z^2*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
edge_profiles.profiles_1d[:].ion[:].temperature (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].velocity (alpha) |  | STRUCTURE | m.s^-1 | Velocity (average over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].velocity.diamagnetic (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
edge_profiles.profiles_1d[:].ion[:].velocity.parallel (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
edge_profiles.profiles_1d[:].ion[:].velocity.poloidal (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
edge_profiles.profiles_1d[:].ion[:].velocity.radial (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
edge_profiles.profiles_1d[:].ion[:].velocity.toroidal (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
edge_profiles.profiles_1d[:].ion[:].velocity_pol (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity (average over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].velocity_tor (obsolescent) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity (average over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed), volume averaged over plasma radius
edge_profiles.profiles_1d[:].ion[:].z_ion_1d (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Average charge of the ion species (sum of states charge weighted by state density and divided by ion density)
edge_profiles.profiles_1d[:].ion[:].z_ion_square_1d (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Average sqare charge of the ion species (sum of states square charge weighted by state density and divided by ion density)
edge_profiles.profiles_1d[:].j_bootstrap (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Bootstrap current density = average(J_Bootstrap.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
edge_profiles.profiles_1d[:].j_non_inductive (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Non-inductive (includes bootstrap) parallel current density = average(jni.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
edge_profiles.profiles_1d[:].j_ohmic (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Ohmic parallel current density = average(J_Ohmic.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
edge_profiles.profiles_1d[:].j_tor (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Total toroidal current density = average(J_Tor/R) / average(1/R)
edge_profiles.profiles_1d[:].j_total (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Total parallel current density = average(jtot.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
edge_profiles.profiles_1d[:].magnetic_shear (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
edge_profiles.profiles_1d[:].momentum_tor (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m^-1.s^-1 | Total plasma toroidal momentum, summed over ion species and electrons weighted by their density and major radius, i.e. sum_over_species(n*R*m*Vphi)
edge_profiles.profiles_1d[:].n_i_total_over_n_e (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Ratio of total ion density (sum over species and charge states) over electron density. (thermal+non-thermal)
edge_profiles.profiles_1d[:].neutral (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different neutral species
edge_profiles.profiles_1d[:].neutral[:].density (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].density_fast (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_profiles.profiles_1d[:].neutral[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_profiles.profiles_1d[:].neutral[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_profiles.profiles_1d[:].neutral[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_profiles.profiles_1d[:].neutral[:].ion_index (alpha) |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
edge_profiles.profiles_1d[:].neutral[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
edge_profiles.profiles_1d[:].neutral[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_profiles.profiles_1d[:].neutral[:].pressure (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].pressure_fast_parallel (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].pressure_fast_perpendicular (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (sum over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (energy, excitation, ...)
edge_profiles.profiles_1d[:].neutral[:].state[:].density (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
edge_profiles.profiles_1d[:].neutral[:].state[:].density_fast (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
edge_profiles.profiles_1d[:].neutral[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_profiles.profiles_1d[:].neutral[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
edge_profiles.profiles_1d[:].neutral[:].state[:].neutral_type (alpha) |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
edge_profiles.profiles_1d[:].neutral[:].state[:].neutral_type.description (alpha) |  | STR_0D |  | Verbose description
edge_profiles.profiles_1d[:].neutral[:].state[:].neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
edge_profiles.profiles_1d[:].neutral[:].state[:].neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
edge_profiles.profiles_1d[:].neutral[:].state[:].pressure (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (thermal+non-thermal)
edge_profiles.profiles_1d[:].neutral[:].state[:].pressure_fast_parallel (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
edge_profiles.profiles_1d[:].neutral[:].state[:].pressure_fast_perpendicular (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
edge_profiles.profiles_1d[:].neutral[:].state[:].temperature (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
edge_profiles.profiles_1d[:].neutral[:].state[:].velocity (alpha) |  | STRUCTURE | m.s^-1 | Velocity
edge_profiles.profiles_1d[:].neutral[:].state[:].velocity.diamagnetic (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
edge_profiles.profiles_1d[:].neutral[:].state[:].velocity.parallel (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
edge_profiles.profiles_1d[:].neutral[:].state[:].velocity.poloidal (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
edge_profiles.profiles_1d[:].neutral[:].state[:].velocity.radial (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
edge_profiles.profiles_1d[:].neutral[:].state[:].velocity.toroidal (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
edge_profiles.profiles_1d[:].neutral[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_profiles.profiles_1d[:].neutral[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_profiles.profiles_1d[:].neutral[:].temperature (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].velocity (alpha) |  | STRUCTURE | m.s^-1 | Velocity (average over charge states when multiple charge states are considered)
edge_profiles.profiles_1d[:].neutral[:].velocity.diamagnetic (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component
edge_profiles.profiles_1d[:].neutral[:].velocity.parallel (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Parallel component
edge_profiles.profiles_1d[:].neutral[:].velocity.poloidal (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal component
edge_profiles.profiles_1d[:].neutral[:].velocity.radial (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Radial component
edge_profiles.profiles_1d[:].neutral[:].velocity.toroidal (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal component
edge_profiles.profiles_1d[:].pressure_ion_total (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total (sum over ion species) thermal ion pressure
edge_profiles.profiles_1d[:].pressure_parallel (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total parallel pressure (electrons+ions, thermal+non-thermal)
edge_profiles.profiles_1d[:].pressure_perpendicular (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total perpendicular pressure (electrons+ions, thermal+non-thermal)
edge_profiles.profiles_1d[:].pressure_thermal (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Thermal pressure (electrons+ions)
edge_profiles.profiles_1d[:].q (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Safety factor
edge_profiles.profiles_1d[:].t_i_average (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Ion temperature (averaged on charge states and ion species)
edge_profiles.profiles_1d[:].time (alpha) |  | FLT_0D | s | Time
edge_profiles.profiles_1d[:].zeff (alpha) | [edge_profiles.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Effective charge
edge_profiles.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
edge_sources (alpha) |  |  |  | Edge plasma sources. Energy terms correspond to the full kinetic energy equation (i.e. the energy flux takes into account the energy transported by the particle flux)
edge_sources.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
edge_sources.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
edge_sources.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
edge_sources.code.output_flag (alpha) | [edge_sources.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
edge_sources.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
edge_sources.code.repository (alpha) |  | STR_0D |  | URL of software repository
edge_sources.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
edge_sources.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
edge_sources.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
edge_sources.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
edge_sources.ids_properties.occurrence |  | INT_0D |  |
edge_sources.source (alpha) | [1...N] | STRUCT_ARRAY |  | Set of source terms
edge_sources.source[:].ggd (alpha) | [edge_sources.source[:].ggd[:].time] | STRUCT_ARRAY |  | Source terms represented using the general grid description, for various time slices
edge_sources.source[:].ggd[:].current (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | Current density source
edge_sources.source[:].ggd[:].current[:].coefficients (alpha) | [edge_sources.source[:].ggd[:].current[:].values, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].current[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].current[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].current[:].values (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].electrons (alpha) |  | STRUCTURE |  | Sources for electrons
edge_sources.source[:].ggd[:].electrons.energy (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Source term for the electron energy equation, given on various grid subsets
edge_sources.source[:].ggd[:].electrons.energy[:].coefficients (alpha) | [edge_sources.source[:].ggd[:].electrons.energy[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].electrons.energy[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].electrons.energy[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].electrons.energy[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].electrons.particles (alpha) | [1...N] | STRUCT_ARRAY | m^-3.s^-1 | Source term for electron density equation, given on various grid subsets
edge_sources.source[:].ggd[:].electrons.particles[:].coefficients (alpha) | [edge_sources.source[:].ggd[:].electrons.particles[:].values, 1...N] | FLT_2D (uncertain) | m^-3.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].electrons.particles[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].electrons.particles[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].electrons.particles[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-3.s^-1 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].grid (alpha) |  | STRUCTURE |  | Grid description
edge_sources.source[:].ggd[:].grid.grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
edge_sources.source[:].ggd[:].grid.grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
edge_sources.source[:].ggd[:].grid.grid_subset[:].base[:].jacobian (alpha) | [edge_sources.source[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
edge_sources.source[:].ggd[:].grid.grid_subset[:].base[:].tensor_contravariant (alpha) | [edge_sources.source[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
edge_sources.source[:].ggd[:].grid.grid_subset[:].base[:].tensor_covariant (alpha) | [edge_sources.source[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
edge_sources.source[:].ggd[:].grid.grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
edge_sources.source[:].ggd[:].grid.grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
edge_sources.source[:].ggd[:].grid.grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
edge_sources.source[:].ggd[:].grid.grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
edge_sources.source[:].ggd[:].grid.grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
edge_sources.source[:].ggd[:].grid.grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
edge_sources.source[:].ggd[:].grid.grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier
edge_sources.source[:].ggd[:].grid.grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
edge_sources.source[:].ggd[:].grid.grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
edge_sources.source[:].ggd[:].grid.grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
edge_sources.source[:].ggd[:].grid.grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
edge_sources.source[:].ggd[:].grid.grid_subset[:].metric.jacobian (alpha) | [edge_sources.source[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
edge_sources.source[:].ggd[:].grid.grid_subset[:].metric.tensor_contravariant (alpha) | [edge_sources.source[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
edge_sources.source[:].ggd[:].grid.grid_subset[:].metric.tensor_covariant (alpha) | [edge_sources.source[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
edge_sources.source[:].ggd[:].grid.identifier (alpha) |  | STRUCTURE |  | Grid identifier
edge_sources.source[:].ggd[:].grid.identifier.description (alpha) |  | STR_0D |  | Verbose description
edge_sources.source[:].ggd[:].grid.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
edge_sources.source[:].ggd[:].grid.identifier.name (alpha) |  | STR_0D |  | Short string identifier
edge_sources.source[:].ggd[:].grid.space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
edge_sources.source[:].ggd[:].grid.space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therfore defines the dimension of the space. The meaning of these predefined integer constants can be found in the documentation of the grid service library
edge_sources.source[:].ggd[:].grid.space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
edge_sources.source[:].ggd[:].grid.space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
edge_sources.source[:].ggd[:].grid.space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
edge_sources.source[:].ggd[:].grid.space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
edge_sources.source[:].ggd[:].grid.space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
edge_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
edge_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
edge_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
edge_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
edge_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
edge_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
edge_sources.source[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
edge_sources.source[:].ggd[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Source terms related to the different ion species
edge_sources.source[:].ggd[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_sources.source[:].ggd[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_sources.source[:].ggd[:].ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_sources.source[:].ggd[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_sources.source[:].ggd[:].ion[:].energy (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Source term for the ion energy transport equation, on various grid subsets
edge_sources.source[:].ggd[:].ion[:].energy[:].coefficients (alpha) | [edge_sources.source[:].ggd[:].ion[:].energy[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].energy[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].ion[:].energy[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].ion[:].energy[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
edge_sources.source[:].ggd[:].ion[:].momentum (alpha) | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Source term for momentum equations (sum over states when multiple states are considered), on various grid subsets
edge_sources.source[:].ggd[:].ion[:].momentum[:].diamagnetic (alpha) | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].momentum[:].diamagnetic_coefficients (alpha) | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].momentum[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].ion[:].momentum[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].ion[:].momentum[:].parallel (alpha) | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].momentum[:].parallel_coefficients (alpha) | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].momentum[:].poloidal (alpha) | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].momentum[:].poloidal_coefficients (alpha) | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].momentum[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].momentum[:].radial_coefficients (alpha) | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].momentum[:].toroidal (alpha) | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].momentum[:].toroidal_coefficients (alpha) | [edge_sources.source[:].ggd[:].ion[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_sources.source[:].ggd[:].ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
edge_sources.source[:].ggd[:].ion[:].particles (alpha) | [1...N] | STRUCT_ARRAY | s^-1.m^-3 | Source term for ion density equation, on various grid subsets
edge_sources.source[:].ggd[:].ion[:].particles[:].coefficients (alpha) | [edge_sources.source[:].ggd[:].ion[:].particles[:].values, 1...N] | FLT_2D (uncertain) | s^-1.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].particles[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].ion[:].particles[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].ion[:].particles[:].values (alpha) | [1...N] | FLT_1D (uncertain) | s^-1.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Source terms related to the different charge states of the species (ionisation, energy, excitation, ...)
edge_sources.source[:].ggd[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_sources.source[:].ggd[:].ion[:].state[:].energy (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Source terms for the charge state energy transport equation
edge_sources.source[:].ggd[:].ion[:].state[:].energy[:].coefficients (alpha) | [edge_sources.source[:].ggd[:].ion[:].state[:].energy[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].state[:].energy[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].ion[:].state[:].energy[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].ion[:].state[:].energy[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
edge_sources.source[:].ggd[:].ion[:].state[:].momentum (alpha) | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Source term for momentum equations, on various grid subsets
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].diamagnetic (alpha) | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].diamagnetic_coefficients (alpha) | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].parallel (alpha) | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].parallel_coefficients (alpha) | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].poloidal (alpha) | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].poloidal_coefficients (alpha) | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial_coefficients (alpha) | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].toroidal (alpha) | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].toroidal_coefficients (alpha) | [edge_sources.source[:].ggd[:].ion[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].state[:].particles (alpha) | [1...N] | STRUCT_ARRAY | s^-1.m^-3 | Source term for the charge state density transport equation
edge_sources.source[:].ggd[:].ion[:].state[:].particles[:].coefficients (alpha) | [edge_sources.source[:].ggd[:].ion[:].state[:].particles[:].values, 1...N] | FLT_2D (uncertain) | s^-1.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].ion[:].state[:].particles[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].ion[:].state[:].particles[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].ion[:].state[:].particles[:].values (alpha) | [1...N] | FLT_1D (uncertain) | s^-1.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_sources.source[:].ggd[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_sources.source[:].ggd[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
edge_sources.source[:].ggd[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
edge_sources.source[:].ggd[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
edge_sources.source[:].ggd[:].momentum (alpha) | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Source term for total momentum equations, on various grid subsets
edge_sources.source[:].ggd[:].momentum[:].diamagnetic (alpha) | [edge_sources.source[:].ggd[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].momentum[:].diamagnetic_coefficients (alpha) | [edge_sources.source[:].ggd[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].momentum[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].momentum[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].momentum[:].parallel (alpha) | [edge_sources.source[:].ggd[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].momentum[:].parallel_coefficients (alpha) | [edge_sources.source[:].ggd[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].momentum[:].poloidal (alpha) | [edge_sources.source[:].ggd[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].momentum[:].poloidal_coefficients (alpha) | [edge_sources.source[:].ggd[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].momentum[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].momentum[:].radial_coefficients (alpha) | [edge_sources.source[:].ggd[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].momentum[:].toroidal (alpha) | [edge_sources.source[:].ggd[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].momentum[:].toroidal_coefficients (alpha) | [edge_sources.source[:].ggd[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral (alpha) | [1...N] | STRUCT_ARRAY |  | Source terms related to the different neutral species
edge_sources.source[:].ggd[:].neutral[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_sources.source[:].ggd[:].neutral[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_sources.source[:].ggd[:].neutral[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_sources.source[:].ggd[:].neutral[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_sources.source[:].ggd[:].neutral[:].energy (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Source term for the ion energy transport equation, on various grid subsets
edge_sources.source[:].ggd[:].neutral[:].energy[:].coefficients (alpha) | [edge_sources.source[:].ggd[:].neutral[:].energy[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].energy[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].neutral[:].energy[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].neutral[:].energy[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].ion_index (alpha) |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
edge_sources.source[:].ggd[:].neutral[:].label (alpha) |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
edge_sources.source[:].ggd[:].neutral[:].momentum (alpha) | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Source term for momentum equations (sum over states when multiple states are considered), on various grid subsets
edge_sources.source[:].ggd[:].neutral[:].momentum[:].diamagnetic (alpha) | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].momentum[:].diamagnetic_coefficients (alpha) | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].momentum[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].neutral[:].momentum[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].neutral[:].momentum[:].parallel (alpha) | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].momentum[:].parallel_coefficients (alpha) | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].momentum[:].poloidal (alpha) | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].momentum[:].poloidal_coefficients (alpha) | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial_coefficients (alpha) | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].momentum[:].toroidal (alpha) | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].momentum[:].toroidal_coefficients (alpha) | [edge_sources.source[:].ggd[:].neutral[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_sources.source[:].ggd[:].neutral[:].particles (alpha) | [1...N] | STRUCT_ARRAY | s^-1.m^-3 | Source term for ion density equation, on various grid subsets
edge_sources.source[:].ggd[:].neutral[:].particles[:].coefficients (alpha) | [edge_sources.source[:].ggd[:].neutral[:].particles[:].values, 1...N] | FLT_2D (uncertain) | s^-1.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].particles[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].neutral[:].particles[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].neutral[:].particles[:].values (alpha) | [1...N] | FLT_1D (uncertain) | s^-1.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Source terms related to the different charge states of the species (energy, excitation, ...)
edge_sources.source[:].ggd[:].neutral[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_sources.source[:].ggd[:].neutral[:].state[:].energy (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Source terms for the charge state energy transport equation
edge_sources.source[:].ggd[:].neutral[:].state[:].energy[:].coefficients (alpha) | [edge_sources.source[:].ggd[:].neutral[:].state[:].energy[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].state[:].energy[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].neutral[:].state[:].energy[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].neutral[:].state[:].energy[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state[:].label (alpha) |  | STR_0D |  | String identifying state
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum (alpha) | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Source term for momentum equations, on various grid subsets
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].diamagnetic (alpha) | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].diamagnetic_coefficients (alpha) | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].parallel (alpha) | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].parallel_coefficients (alpha) | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].poloidal (alpha) | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].poloidal_coefficients (alpha) | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial_coefficients (alpha) | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].toroidal (alpha) | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].toroidal_coefficients (alpha) | [edge_sources.source[:].ggd[:].neutral[:].state[:].momentum[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].state[:].neutral_type (alpha) |  | STRUCTURE |  | Neutral type, in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
edge_sources.source[:].ggd[:].neutral[:].state[:].neutral_type.description (alpha) |  | STR_0D |  | Verbose description
edge_sources.source[:].ggd[:].neutral[:].state[:].neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
edge_sources.source[:].ggd[:].neutral[:].state[:].neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
edge_sources.source[:].ggd[:].neutral[:].state[:].particles (alpha) | [1...N] | STRUCT_ARRAY | s^-1.m^-3 | Source term for the charge state density transport equation
edge_sources.source[:].ggd[:].neutral[:].state[:].particles[:].coefficients (alpha) | [edge_sources.source[:].ggd[:].neutral[:].state[:].particles[:].values, 1...N] | FLT_2D (uncertain) | s^-1.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].neutral[:].state[:].particles[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].neutral[:].state[:].particles[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].neutral[:].state[:].particles[:].values (alpha) | [1...N] | FLT_1D (uncertain) | s^-1.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].ggd[:].neutral[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_sources.source[:].ggd[:].neutral[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_sources.source[:].ggd[:].time (alpha) |  | FLT_0D | s | Time
edge_sources.source[:].ggd[:].total_ion_energy (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Source term for the total (summed over ion species) energy equation, on various grid subsets
edge_sources.source[:].ggd[:].total_ion_energy[:].coefficients (alpha) | [edge_sources.source[:].ggd[:].total_ion_energy[:].values, 1...N] | FLT_2D (uncertain) | W.m^-3 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_sources.source[:].ggd[:].total_ion_energy[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_sources.source[:].ggd[:].total_ion_energy[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_sources.source[:].ggd[:].total_ion_energy[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-3 | One scalar value is provided per element in the grid subset.
edge_sources.source[:].identifier (alpha) |  | STRUCTURE |  | Source term identifier
edge_sources.source[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
edge_sources.source[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
edge_sources.source[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
edge_sources.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
edge_transport (alpha) |  |  |  | Edge plasma transport. Energy terms correspond to the full kinetic energy equation (i.e. the energy flux takes into account the energy transported by the particle flux)
edge_transport.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
edge_transport.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
edge_transport.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
edge_transport.code.output_flag (alpha) | [edge_transport.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
edge_transport.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
edge_transport.code.repository (alpha) |  | STR_0D |  | URL of software repository
edge_transport.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
edge_transport.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
edge_transport.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
edge_transport.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
edge_transport.ids_properties.occurrence |  | INT_0D |  |
edge_transport.model (alpha) | [1...N_Models] | STRUCT_ARRAY |  | Transport is described by a combination of various transport models
edge_transport.model[:].flux_multiplier (alpha) |  | FLT_0D (uncertain) | - | Multiplier applied to the particule flux when adding its contribution in the expression of the heat flux : can be 0, 3/2 or 5/2
edge_transport.model[:].ggd (alpha) | [edge_transport.model[:].ggd[:].time] | STRUCT_ARRAY |  | Transport coefficients represented using the general grid description, for various time slices
edge_transport.model[:].ggd[:].conductivity (alpha) | [1...N] | STRUCT_ARRAY | ohm^-1.m^-1 | Conductivity, on various grid subsets
edge_transport.model[:].ggd[:].conductivity[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].conductivity[:].radial] | FLT_1D (uncertain) | ohm^-1.m^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].conductivity[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].conductivity[:].radial, 1...N] | FLT_2D (uncertain) | ohm^-1.m^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].conductivity[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].conductivity[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].conductivity[:].parallel (alpha) | [edge_transport.model[:].ggd[:].conductivity[:].radial] | FLT_1D (uncertain) | ohm^-1.m^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].conductivity[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].conductivity[:].radial, 1...N] | FLT_2D (uncertain) | ohm^-1.m^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].conductivity[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].conductivity[:].radial] | FLT_1D (uncertain) | ohm^-1.m^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].conductivity[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].conductivity[:].radial, 1...N] | FLT_2D (uncertain) | ohm^-1.m^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].conductivity[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | ohm^-1.m^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].conductivity[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].conductivity[:].radial, 1...N] | FLT_2D (uncertain) | ohm^-1.m^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].conductivity[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].conductivity[:].radial] | FLT_1D (uncertain) | ohm^-1.m^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].conductivity[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].conductivity[:].radial, 1...N] | FLT_2D (uncertain) | ohm^-1.m^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons (alpha) |  | STRUCTURE |  | Transport quantities related to the electrons
edge_transport.model[:].ggd[:].electrons.energy (alpha) |  | STRUCTURE |  | Transport quantities for the electron energy equation
edge_transport.model[:].ggd[:].electrons.energy.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].electrons.energy.d[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].electrons.energy.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.energy.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.energy.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.energy.d[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].electrons.energy.flux (alpha) | [1...N] | STRUCT_ARRAY | W.m^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].electrons.energy.flux[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].electrons.energy.flux[:].values, 1...N] | FLT_2D (uncertain) | W.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.energy.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.energy.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.energy.flux[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-2 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].electrons.energy.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].electrons.energy.flux_limiter[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].electrons.energy.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.energy.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.energy.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.energy.flux_limiter[:].values (alpha) | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].electrons.energy.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].electrons.energy.v[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].electrons.energy.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.energy.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.energy.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.energy.v[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].electrons.particles (alpha) |  | STRUCTURE |  | Transport quantities for the electron density equation
edge_transport.model[:].ggd[:].electrons.particles.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].electrons.particles.d[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].electrons.particles.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.particles.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.particles.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.particles.d[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].electrons.particles.flux (alpha) | [1...N] | STRUCT_ARRAY | m^-2.s^-1 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].electrons.particles.flux[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].electrons.particles.flux[:].values, 1...N] | FLT_2D (uncertain) | m^-2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.particles.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.particles.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.particles.flux[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].electrons.particles.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].electrons.particles.flux_limiter[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].electrons.particles.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.particles.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.particles.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.particles.flux_limiter[:].values (alpha) | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].electrons.particles.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].electrons.particles.v[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].electrons.particles.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].electrons.particles.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].electrons.particles.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].electrons.particles.v[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].grid (alpha) |  | STRUCTURE |  | Grid description
edge_transport.model[:].ggd[:].grid.grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
edge_transport.model[:].ggd[:].grid.grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
edge_transport.model[:].ggd[:].grid.grid_subset[:].base[:].jacobian (alpha) | [edge_transport.model[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
edge_transport.model[:].ggd[:].grid.grid_subset[:].base[:].tensor_contravariant (alpha) | [edge_transport.model[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
edge_transport.model[:].ggd[:].grid.grid_subset[:].base[:].tensor_covariant (alpha) | [edge_transport.model[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
edge_transport.model[:].ggd[:].grid.grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
edge_transport.model[:].ggd[:].grid.grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
edge_transport.model[:].ggd[:].grid.grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
edge_transport.model[:].ggd[:].grid.grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
edge_transport.model[:].ggd[:].grid.grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
edge_transport.model[:].ggd[:].grid.grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
edge_transport.model[:].ggd[:].grid.grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier
edge_transport.model[:].ggd[:].grid.grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
edge_transport.model[:].ggd[:].grid.grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
edge_transport.model[:].ggd[:].grid.grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
edge_transport.model[:].ggd[:].grid.grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
edge_transport.model[:].ggd[:].grid.grid_subset[:].metric.jacobian (alpha) | [edge_transport.model[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
edge_transport.model[:].ggd[:].grid.grid_subset[:].metric.tensor_contravariant (alpha) | [edge_transport.model[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
edge_transport.model[:].ggd[:].grid.grid_subset[:].metric.tensor_covariant (alpha) | [edge_transport.model[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
edge_transport.model[:].ggd[:].grid.identifier (alpha) |  | STRUCTURE |  | Grid identifier
edge_transport.model[:].ggd[:].grid.identifier.description (alpha) |  | STR_0D |  | Verbose description
edge_transport.model[:].ggd[:].grid.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
edge_transport.model[:].ggd[:].grid.identifier.name (alpha) |  | STR_0D |  | Short string identifier
edge_transport.model[:].ggd[:].grid.space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
edge_transport.model[:].ggd[:].grid.space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therfore defines the dimension of the space. The meaning of these predefined integer constants can be found in the documentation of the grid service library
edge_transport.model[:].ggd[:].grid.space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
edge_transport.model[:].ggd[:].grid.space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
edge_transport.model[:].ggd[:].grid.space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
edge_transport.model[:].ggd[:].grid.space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
edge_transport.model[:].ggd[:].grid.space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
edge_transport.model[:].ggd[:].grid.space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
edge_transport.model[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
edge_transport.model[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
edge_transport.model[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
edge_transport.model[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
edge_transport.model[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
edge_transport.model[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
edge_transport.model[:].ggd[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the various ion and neutral species
edge_transport.model[:].ggd[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_transport.model[:].ggd[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_transport.model[:].ggd[:].ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_transport.model[:].ggd[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_transport.model[:].ggd[:].ion[:].energy (alpha) |  | STRUCTURE |  | Transport coefficients related to the ion energy equation
edge_transport.model[:].ggd[:].ion[:].energy.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].energy.d[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].energy.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].energy.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].energy.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].energy.d[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].energy.flux (alpha) | [1...N] | STRUCT_ARRAY | W.m^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].energy.flux[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].energy.flux[:].values, 1...N] | FLT_2D (uncertain) | W.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].energy.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].energy.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].energy.flux[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-2 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].energy.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].energy.flux_limiter[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].energy.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].energy.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].energy.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].energy.flux_limiter[:].values (alpha) | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].energy.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].energy.v[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].energy.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].energy.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].energy.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].energy.v[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
edge_transport.model[:].ggd[:].ion[:].momentum (alpha) |  | STRUCTURE |  | Transport coefficients for the ion momentum equations
edge_transport.model[:].ggd[:].ion[:].momentum.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].parallel (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.d[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux (alpha) | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].parallel (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].parallel (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | - | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].parallel (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].momentum.v[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_transport.model[:].ggd[:].ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
edge_transport.model[:].ggd[:].ion[:].particles (alpha) |  | STRUCTURE |  | Transport related to the ion density equation
edge_transport.model[:].ggd[:].ion[:].particles.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].particles.d[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].particles.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].particles.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].particles.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].particles.d[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].particles.flux (alpha) | [1...N] | STRUCT_ARRAY | m^-2.s^-1 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].particles.flux[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].particles.flux[:].values, 1...N] | FLT_2D (uncertain) | m^-2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].particles.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].particles.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].particles.flux[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].particles.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].particles.flux_limiter[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].particles.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].particles.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].particles.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].particles.flux_limiter[:].values (alpha) | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].particles.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].particles.v[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].particles.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].particles.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].particles.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].particles.v[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the different states of the species
edge_transport.model[:].ggd[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_transport.model[:].ggd[:].ion[:].state[:].energy (alpha) |  | STRUCTURE |  | Transport quantities related to the energy equation of the charge state considered
edge_transport.model[:].ggd[:].ion[:].state[:].energy.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].energy.d[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].energy.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].energy.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].energy.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].energy.d[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux (alpha) | [1...N] | STRUCT_ARRAY | W.m^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux[:].values, 1...N] | FLT_2D (uncertain) | W.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-2 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux_limiter[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].energy.flux_limiter[:].values (alpha) | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].energy.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].energy.v[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].energy.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].energy.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].energy.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].energy.v[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
edge_transport.model[:].ggd[:].ion[:].state[:].momentum (alpha) |  | STRUCTURE |  | Transport coefficients related to the momentum equations of the charge state considered
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].parallel (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux (alpha) | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].parallel (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].parallel (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | - | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].parallel (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].particles (alpha) |  | STRUCTURE |  | Transport quantities related to density equation of the charge state considered (thermal+non-thermal)
edge_transport.model[:].ggd[:].ion[:].state[:].particles.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].particles.d[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].particles.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].particles.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].particles.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].particles.d[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux (alpha) | [1...N] | STRUCT_ARRAY | m^-2.s^-1 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux[:].values, 1...N] | FLT_2D (uncertain) | m^-2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux_limiter[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].particles.flux_limiter[:].values (alpha) | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].particles.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].ion[:].state[:].particles.v[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].ion[:].state[:].particles.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].ion[:].state[:].particles.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].ion[:].state[:].particles.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].ion[:].state[:].particles.v[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_transport.model[:].ggd[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_transport.model[:].ggd[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
edge_transport.model[:].ggd[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
edge_transport.model[:].ggd[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
edge_transport.model[:].ggd[:].momentum (alpha) |  | STRUCTURE |  | Transport coefficients for total momentum equation
edge_transport.model[:].ggd[:].momentum.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].momentum.d[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.d[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].momentum.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].momentum.d[:].parallel (alpha) | [edge_transport.model[:].ggd[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.d[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.d[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.d[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.d[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.d[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.d[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.d[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux (alpha) | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].momentum.flux[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].momentum.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].momentum.flux[:].parallel (alpha) | [edge_transport.model[:].ggd[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].parallel (alpha) | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | - | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.flux_limiter[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].momentum.v[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.v[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].momentum.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].momentum.v[:].parallel (alpha) | [edge_transport.model[:].ggd[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.v[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.v[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.v[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.v[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.v[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].momentum.v[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].momentum.v[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral (alpha) | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the various ion and neutral species
edge_transport.model[:].ggd[:].neutral[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
edge_transport.model[:].ggd[:].neutral[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
edge_transport.model[:].ggd[:].neutral[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
edge_transport.model[:].ggd[:].neutral[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
edge_transport.model[:].ggd[:].neutral[:].energy (alpha) |  | STRUCTURE |  | Transport coefficients related to the ion energy equation
edge_transport.model[:].ggd[:].neutral[:].energy.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].energy.d[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].energy.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].energy.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].energy.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].energy.d[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].energy.flux (alpha) | [1...N] | STRUCT_ARRAY | W.m^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].energy.flux[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].energy.flux[:].values, 1...N] | FLT_2D (uncertain) | W.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].energy.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].energy.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].energy.flux[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-2 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].energy.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].energy.flux_limiter[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].energy.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].energy.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].energy.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].energy.flux_limiter[:].values (alpha) | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].energy.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].energy.v[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].energy.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].energy.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].energy.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].energy.v[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].ion_index (alpha) |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
edge_transport.model[:].ggd[:].neutral[:].label (alpha) |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
edge_transport.model[:].ggd[:].neutral[:].momentum (alpha) |  | STRUCTURE |  | Transport coefficients for the ion momentum equations
edge_transport.model[:].ggd[:].neutral[:].momentum.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].parallel (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux (alpha) | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].parallel (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].parallel (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | - | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].parallel (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
edge_transport.model[:].ggd[:].neutral[:].particles (alpha) |  | STRUCTURE |  | Transport related to the ion density equation
edge_transport.model[:].ggd[:].neutral[:].particles.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].particles.d[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].particles.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].particles.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].particles.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].particles.d[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].particles.flux (alpha) | [1...N] | STRUCT_ARRAY | m^-2.s^-1 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].particles.flux[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].particles.flux[:].values, 1...N] | FLT_2D (uncertain) | m^-2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].particles.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].particles.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].particles.flux[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].particles.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].particles.flux_limiter[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].particles.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].particles.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].particles.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].particles.flux_limiter[:].values (alpha) | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].particles.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].particles.v[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].particles.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].particles.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].particles.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].particles.v[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Transport coefficients related to the different states of the species
edge_transport.model[:].ggd[:].neutral[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
edge_transport.model[:].ggd[:].neutral[:].state[:].energy (alpha) |  | STRUCTURE |  | Transport quantities related to the energy equation of the charge state considered
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.d[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].energy.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.d[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux (alpha) | [1...N] | STRUCT_ARRAY | W.m^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux[:].values, 1...N] | FLT_2D (uncertain) | W.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-2 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux_limiter[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.flux_limiter[:].values (alpha) | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.v[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].energy.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].energy.v[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].label (alpha) |  | STR_0D |  | String identifying state
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum (alpha) |  | STRUCTURE |  | Transport coefficients related to the momentum equations of the charge state considered
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].parallel (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial] | FLT_1D (uncertain) | m^2.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.d[:].radial, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux (alpha) | [1...N] | STRUCT_ARRAY | kg.m^-1.s^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].parallel (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial] | FLT_1D (uncertain) | kg.m^-1.s^-2 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux[:].radial, 1...N] | FLT_2D (uncertain) | kg.m^-1.s^-2 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].parallel (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | - | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial] | FLT_1D (uncertain) | - | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.flux_limiter[:].radial, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].diamagnetic (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Diamagnetic component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].diamagnetic_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the diamagnetic component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].parallel (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Parallel component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].parallel_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the parallel component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].poloidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Poloidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].poloidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the poloidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | Radial component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the radial component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].toroidal (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial] | FLT_1D (uncertain) | m.s^-1 | Toroidal component, one scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].toroidal_coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].momentum.v[:].radial, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients for the toroidal component, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].neutral_type (alpha) |  | STRUCTURE |  | Neutral type, in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
edge_transport.model[:].ggd[:].neutral[:].state[:].neutral_type.description (alpha) |  | STR_0D |  | Verbose description
edge_transport.model[:].ggd[:].neutral[:].state[:].neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
edge_transport.model[:].ggd[:].neutral[:].state[:].neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
edge_transport.model[:].ggd[:].neutral[:].state[:].particles (alpha) |  | STRUCTURE |  | Transport quantities related to density equation of the charge state considered (thermal+non-thermal)
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.d[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].particles.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.d[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux (alpha) | [1...N] | STRUCT_ARRAY | m^-2.s^-1 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux[:].values, 1...N] | FLT_2D (uncertain) | m^-2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^-2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux_limiter[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.flux_limiter[:].values (alpha) | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.v[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].neutral[:].state[:].particles.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].neutral[:].state[:].particles.v[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].neutral[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
edge_transport.model[:].ggd[:].neutral[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
edge_transport.model[:].ggd[:].time (alpha) |  | FLT_0D | s | Time
edge_transport.model[:].ggd[:].total_ion_energy (alpha) |  | STRUCTURE |  | Transport coefficients for the total (summed over ion species) energy equation
edge_transport.model[:].ggd[:].total_ion_energy.d (alpha) | [1...N] | STRUCT_ARRAY | m^2.s^-1 | Effective diffusivity, on various grid subsets
edge_transport.model[:].ggd[:].total_ion_energy.d[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].total_ion_energy.d[:].values, 1...N] | FLT_2D (uncertain) | m^2.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].total_ion_energy.d[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].total_ion_energy.d[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].total_ion_energy.d[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m^2.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].total_ion_energy.flux (alpha) | [1...N] | STRUCT_ARRAY | W.m^-2 | Flux, on various grid subsets
edge_transport.model[:].ggd[:].total_ion_energy.flux[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].total_ion_energy.flux[:].values, 1...N] | FLT_2D (uncertain) | W.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].total_ion_energy.flux[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].total_ion_energy.flux[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].total_ion_energy.flux[:].values (alpha) | [1...N] | FLT_1D (uncertain) | W.m^-2 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].total_ion_energy.flux_limiter (alpha) | [1...N] | STRUCT_ARRAY | - | Flux limiter coefficient, on various grid subsets
edge_transport.model[:].ggd[:].total_ion_energy.flux_limiter[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].total_ion_energy.flux_limiter[:].values, 1...N] | FLT_2D (uncertain) | - | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].total_ion_energy.flux_limiter[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].total_ion_energy.flux_limiter[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].total_ion_energy.flux_limiter[:].values (alpha) | [1...N] | FLT_1D (uncertain) | - | One scalar value is provided per element in the grid subset.
edge_transport.model[:].ggd[:].total_ion_energy.v (alpha) | [1...N] | STRUCT_ARRAY | m.s^-1 | Effective convection, on various grid subsets
edge_transport.model[:].ggd[:].total_ion_energy.v[:].coefficients (alpha) | [edge_transport.model[:].ggd[:].total_ion_energy.v[:].values, 1...N] | FLT_2D (uncertain) | m.s^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
edge_transport.model[:].ggd[:].total_ion_energy.v[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
edge_transport.model[:].ggd[:].total_ion_energy.v[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
edge_transport.model[:].ggd[:].total_ion_energy.v[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m.s^-1 | One scalar value is provided per element in the grid subset.
edge_transport.model[:].identifier (alpha) |  | STRUCTURE |  | Transport model identifier
edge_transport.model[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
edge_transport.model[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
edge_transport.model[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
edge_transport.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
em_coupling (alpha) |  |  |  | Description of the axisymmetric mutual electromagnetics; does not include non-axisymmetric coil systems; the convention is Quantity_Sensor_Source
em_coupling.active_coils (alpha) | [pf_active.coil] | STR_1D |  | List of the names of the active PF+CS coils
em_coupling.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
em_coupling.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
em_coupling.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
em_coupling.code.output_flag (alpha) | [em_coupling.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
em_coupling.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
em_coupling.code.repository (alpha) |  | STR_0D |  | URL of software repository
em_coupling.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
em_coupling.field_probes_active (alpha) | [em_coupling.poloidal_probes, em_coupling.active_coils] | FLT_2D (uncertain) | T/A | Poloidal field coupling from active coils to poloidal field probes
em_coupling.field_probes_grid (alpha) | [em_coupling.poloidal_probes, em_coupling.grid_points] | FLT_2D (uncertain) | T/A | Poloidal field coupling from equilibrium grid to poloidal field probes
em_coupling.field_probes_passive (alpha) | [em_coupling.poloidal_probes, em_coupling.passive_loops] | FLT_2D (uncertain) | T/A | Poloidal field coupling from passive loops to poloidal field probes
em_coupling.flux_loops (alpha) | [magnetics.flux_loop] | STR_1D |  | List of the names of the axisymmetric flux loops
em_coupling.grid_points (alpha) | [1...N] | STR_1D |  | List of the names of the plasma region grid points
em_coupling.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
em_coupling.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
em_coupling.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
em_coupling.ids_properties.occurrence |  | INT_0D |  |
em_coupling.mutual_active_active (alpha) | [em_coupling.active_coils, em_coupling.active_coils] | FLT_2D (uncertain) | H | Mutual inductance coupling from active coils to active coils
em_coupling.mutual_grid_active (alpha) | [em_coupling.grid_points, em_coupling.active_coils] | FLT_2D (uncertain) | H | Mutual inductance coupling from active coils to equilibrium grid
em_coupling.mutual_grid_grid (alpha) | [em_coupling.grid_points, em_coupling.grid_points] | FLT_2D (uncertain) | H | Mutual inductance from equilibrium grid to itself
em_coupling.mutual_grid_passive (alpha) | [em_coupling.grid_points, em_coupling.passive_loops] | FLT_2D (uncertain) | H | Mutual inductance coupling from passive loops to equilibrium grid
em_coupling.mutual_loops_active (alpha) | [em_coupling.flux_loops, em_coupling.active_coils] | FLT_2D (uncertain) | H | Mutual inductance coupling from active coils to poloidal flux loops
em_coupling.mutual_loops_grid (alpha) | [em_coupling.flux_loops, em_coupling.grid_points] | FLT_2D (uncertain) | H | Mutual inductance from equilibrium grid to poloidal flux loops
em_coupling.mutual_loops_passive (alpha) | [em_coupling.flux_loops, em_coupling.passive_loops] | FLT_2D (uncertain) | H | Mutual inductance coupling from passive loops to poloidal flux loops
em_coupling.mutual_passive_active (alpha) | [em_coupling.passive_loops, em_coupling.active_coils] | FLT_2D (uncertain) | H | Mutual inductance coupling from active coils to passive loops
em_coupling.mutual_passive_passive (alpha) | [em_coupling.passive_loops, em_coupling.passive_loops] | FLT_2D (uncertain) | H | Mutual inductance coupling from passive loops to passive loops
em_coupling.passive_loops (alpha) | [pf_passive.loop] | STR_1D |  | List of the names of the passive loops
em_coupling.poloidal_probes (alpha) | [magnetics.bpol_probe] | STR_1D |  | List of the names of poloidal field probes
em_coupling.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
equilibrium |  |  |  | Description of a 2D, axi-symmetric, tokamak equilibrium; result of an equilibrium code.
equilibrium.code |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
equilibrium.code.commit |  | STR_0D |  | Unique commit reference of software
equilibrium.code.name |  | STR_0D |  | Name of software generating IDS
equilibrium.code.output_flag | [equilibrium.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
equilibrium.code.parameters |  | STR_0D |  | List of the code specific parameters in XML format
equilibrium.code.repository |  | STR_0D |  | URL of software repository
equilibrium.code.version |  | STR_0D |  | Unique version (tag) of software
equilibrium.ids_properties |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
equilibrium.ids_properties.comment |  | STR_0D |  | Any comment describing the content of this IDS
equilibrium.ids_properties.homogeneous_time |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
equilibrium.ids_properties.occurrence |  | INT_0D |  |
equilibrium.time | [1...N] | FLT_1D_TYPE |  | Generic time [s]
equilibrium.time_slice | [equilibrium.time_slice[:].time] | STRUCT_ARRAY |  | Set of equilibria at various time slices
equilibrium.time_slice[:].boundary |  | STRUCTURE |  | Description of the plasma boundary
equilibrium.time_slice[:].boundary.active_limiter_point |  | STRUCTURE |  | RZ position of the active limiter point (point of the plasma boundary in contact with the limiter)
equilibrium.time_slice[:].boundary.active_limiter_point.r |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary.active_limiter_point.z |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].boundary.b_flux_pol_norm |  | FLT_0D (uncertain) | - | Value of the normalised poloidal flux at which the boundary is taken
equilibrium.time_slice[:].boundary.elongation |  | FLT_0D (uncertain) | - | Elongation of the plasma boundary
equilibrium.time_slice[:].boundary.elongation_lower |  | FLT_0D (uncertain) | - | Elongation (lower half w.r.t. geometric axis) of the plasma boundary
equilibrium.time_slice[:].boundary.elongation_upper |  | FLT_0D (uncertain) | - | Elongation (upper half w.r.t. geometric axis) of the plasma boundary
equilibrium.time_slice[:].boundary.geometric_axis |  | STRUCTURE |  | RZ position of the geometric axis (defined as (Rmin+Rmax) / 2 and (Zmin+Zmax) / 2 of the boundary)
equilibrium.time_slice[:].boundary.geometric_axis.r |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary.geometric_axis.z |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].boundary.lcfs (obsolescent) |  | STRUCTURE |  | RZ description of the plasma boundary
equilibrium.time_slice[:].boundary.lcfs.r (obsolescent) | [1...N] | FLT_1D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary.lcfs.z (obsolescent) | [equilibrium.time_slice[:].boundary.lcfs.r] | FLT_1D (uncertain) | m | Height
equilibrium.time_slice[:].boundary.minor_radius |  | FLT_0D (uncertain) | m | Minor radius of the plasma boundary (defined as (Rmax-Rmin) / 2 of the boundary)
equilibrium.time_slice[:].boundary.outline |  | STRUCTURE |  | RZ outline of the plasma boundary
equilibrium.time_slice[:].boundary.outline.r | [1...N] | FLT_1D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary.outline.z | [equilibrium.time_slice[:].boundary.outline.r] | FLT_1D (uncertain) | m | Height
equilibrium.time_slice[:].boundary.strike_point | [1...N] | STRUCT_ARRAY |  | Array of strike points, for each of them the RZ position is given
equilibrium.time_slice[:].boundary.strike_point[:].r |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary.strike_point[:].z |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].boundary.triangularity |  | FLT_0D (uncertain) | - | Triangularity of the plasma boundary
equilibrium.time_slice[:].boundary.triangularity_lower |  | FLT_0D (uncertain) | - | Lower triangularity of the plasma boundary
equilibrium.time_slice[:].boundary.triangularity_upper |  | FLT_0D (uncertain) | - | Upper triangularity of the plasma boundary
equilibrium.time_slice[:].boundary.type |  | INT_0D |  | 0 (limiter) or 1 (diverted)
equilibrium.time_slice[:].boundary.x_point | [1...N] | STRUCT_ARRAY |  | Array of X-points, for each of them the RZ position is given
equilibrium.time_slice[:].boundary.x_point[:].r |  | FLT_0D (uncertain) | m | Major radius
equilibrium.time_slice[:].boundary.x_point[:].z |  | FLT_0D (uncertain) | m | Height
equilibrium.time_slice[:].coordinate_system |  | STRUCTURE |  | Flux surface coordinate system on a square grid of flux and poloidal angle
equilibrium.time_slice[:].coordinate_system.g11_contravariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g11, contravariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g11_covariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g11, covariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g12_contravariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g12, contravariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g12_covariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g12, covariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g13_contravariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g13, contravariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g13_covariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g13, covariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g22_contravariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g22, contravariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g22_covariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g22, covariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g23_contravariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g23, contravariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g23_covariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g23, covariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g33_contravariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g33, contravariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.g33_covariant (obsolescent) | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | metric coefficients g33, covariant metric tensor for the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.grid |  | STRUCTURE |  | Definition of the 2D grid
equilibrium.time_slice[:].coordinate_system.grid.dim1 | [1...N] | FLT_1D (uncertain) | mixed | First dimension values
equilibrium.time_slice[:].coordinate_system.grid.dim2 | [1...N] | FLT_1D (uncertain) | mixed | Second dimension values
equilibrium.time_slice[:].coordinate_system.grid.volume_element | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | m^3 | Elementary plasma volume of plasma enclosed in the cell formed by the nodes [dim1(i) dim2(j)], [dim1(i+1) dim2(j)], [dim1(i) dim2(j+1)] and [dim1(i+1) dim2(j+1)]
equilibrium.time_slice[:].coordinate_system.grid_type |  | STRUCTURE |  | Type of coordinate system
equilibrium.time_slice[:].coordinate_system.grid_type.description |  | STR_0D |  | Verbose description
equilibrium.time_slice[:].coordinate_system.grid_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list)
equilibrium.time_slice[:].coordinate_system.grid_type.name |  | STR_0D |  | Short string identifier
equilibrium.time_slice[:].coordinate_system.jacobian | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | mixed | Jacobian of the coordinate system
equilibrium.time_slice[:].coordinate_system.r | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | m | Values of the major radius on the grid
equilibrium.time_slice[:].coordinate_system.tensor_contravariant | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2, 1...3, 1...3] | FLT_4D (uncertain) | mixed | Contravariant metric tensor on every point of the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.tensor_covariant | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2, 1...3, 1...3] | FLT_4D (uncertain) | mixed | Covariant metric tensor on every point of the grid described by grid_type
equilibrium.time_slice[:].coordinate_system.z | [equilibrium.time_slice[:].coordinate_system.grid.dim1, equilibrium.time_slice[:].coordinate_system.grid.dim2] | FLT_2D (uncertain) | m | Values of the Height on the grid
equilibrium.time_slice[:].ggd (alpha) | [1...N] | STRUCT_ARRAY |  | Equilibrium representation using the generic grid description. Multiple GGD representations of the equilibrium can be stored here.
equilibrium.time_slice[:].ggd[:].b_field_r (alpha) | [1...N] | STRUCT_ARRAY | T | R component of the poloidal magnetic field, given on various grid subsets
equilibrium.time_slice[:].ggd[:].b_field_r[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].b_field_r[:].values, 1...N] | FLT_2D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].b_field_r[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].b_field_r[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].b_field_r[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].b_field_tor (alpha) | [1...N] | STRUCT_ARRAY | T | Toroidal component of the magnetic field, given on various grid subsets
equilibrium.time_slice[:].ggd[:].b_field_tor[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].b_field_tor[:].values, 1...N] | FLT_2D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].b_field_tor[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].b_field_tor[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].b_field_tor[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].b_field_z (alpha) | [1...N] | STRUCT_ARRAY | T | Z component of the poloidal magnetic field, given on various grid subsets
equilibrium.time_slice[:].ggd[:].b_field_z[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].b_field_z[:].values, 1...N] | FLT_2D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].b_field_z[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].b_field_z[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].b_field_z[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].grid (alpha) |  | STRUCTURE |  | Grid description
equilibrium.time_slice[:].ggd[:].grid.grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].base[:].jacobian (alpha) | [equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].base[:].tensor_contravariant (alpha) | [equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].base[:].tensor_covariant (alpha) | [equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].metric.jacobian (alpha) | [equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].metric.tensor_contravariant (alpha) | [equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].metric.tensor_covariant (alpha) | [equilibrium.time_slice[:].ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
equilibrium.time_slice[:].ggd[:].grid.identifier (alpha) |  | STRUCTURE |  | Grid identifier
equilibrium.time_slice[:].ggd[:].grid.identifier.description (alpha) |  | STR_0D |  | Verbose description
equilibrium.time_slice[:].ggd[:].grid.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
equilibrium.time_slice[:].ggd[:].grid.identifier.name (alpha) |  | STR_0D |  | Short string identifier
equilibrium.time_slice[:].ggd[:].grid.space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
equilibrium.time_slice[:].ggd[:].grid.space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therfore defines the dimension of the space. The meaning of these predefined integer constants can be found in the documentation of the grid service library
equilibrium.time_slice[:].ggd[:].grid.space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
equilibrium.time_slice[:].ggd[:].grid.space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
equilibrium.time_slice[:].ggd[:].grid.space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
equilibrium.time_slice[:].ggd[:].grid.space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
equilibrium.time_slice[:].ggd[:].grid.space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
equilibrium.time_slice[:].ggd[:].j_parallel (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | Parallel (to magnetic field) plasma current density, given on various grid subsets
equilibrium.time_slice[:].ggd[:].j_parallel[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].j_parallel[:].values, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].j_parallel[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].j_parallel[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].j_parallel[:].values (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].j_tor (alpha) | [1...N] | STRUCT_ARRAY | A.m^-2 | Toroidal plasma current density, given on various grid subsets
equilibrium.time_slice[:].ggd[:].j_tor[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].j_tor[:].values, 1...N] | FLT_2D (uncertain) | A.m^-2 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].j_tor[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].j_tor[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].j_tor[:].values (alpha) | [1...N] | FLT_1D (uncertain) | A.m^-2 | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].phi (alpha) | [1...N] | STRUCT_ARRAY | Wb | Values of the toroidal flux, given on various grid subsets
equilibrium.time_slice[:].ggd[:].phi[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].phi[:].values, 1...N] | FLT_2D (uncertain) | Wb | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].phi[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].phi[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].phi[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Wb | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].psi (alpha) | [1...N] | STRUCT_ARRAY | Wb | Values of the poloidal flux, given on various grid subsets
equilibrium.time_slice[:].ggd[:].psi[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].psi[:].values, 1...N] | FLT_2D (uncertain) | Wb | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].psi[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].psi[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].psi[:].values (alpha) | [1...N] | FLT_1D (uncertain) | Wb | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].r (alpha) | [1...N] | STRUCT_ARRAY | m | Values of the major radius on various grid subsets
equilibrium.time_slice[:].ggd[:].r[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].r[:].values, 1...N] | FLT_2D (uncertain) | m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].r[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].r[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].r[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].theta (alpha) | [1...N] | STRUCT_ARRAY | rad | Values of the poloidal angle, given on various grid subsets
equilibrium.time_slice[:].ggd[:].theta[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].theta[:].values, 1...N] | FLT_2D (uncertain) | rad | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].theta[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].theta[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].theta[:].values (alpha) | [1...N] | FLT_1D (uncertain) | rad | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].ggd[:].z (alpha) | [1...N] | STRUCT_ARRAY | m | Values of the Height on various grid subsets
equilibrium.time_slice[:].ggd[:].z[:].coefficients (alpha) | [equilibrium.time_slice[:].ggd[:].z[:].values, 1...N] | FLT_2D (uncertain) | m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
equilibrium.time_slice[:].ggd[:].z[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
equilibrium.time_slice[:].ggd[:].z[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
equilibrium.time_slice[:].ggd[:].z[:].values (alpha) | [1...N] | FLT_1D (uncertain) | m | One scalar value is provided per element in the grid subset.
equilibrium.time_slice[:].global_quantities |  | STRUCTURE |  | 0D parameters of the equilibrium
equilibrium.time_slice[:].global_quantities.area |  | FLT_0D (uncertain) | m^2 | Area of the LCFS poloidal cross section
equilibrium.time_slice[:].global_quantities.beta_normal |  | FLT_0D (uncertain) | - | Normalised toroidal beta, defined as 100 * beta_tor * a[m] * B0 [T] / ip [MA]
equilibrium.time_slice[:].global_quantities.beta_pol |  | FLT_0D (uncertain) | - | Poloidal beta. Defined as betap = 4 int(p dV) / [R_0 * mu_0 * Ip^2]
equilibrium.time_slice[:].global_quantities.beta_tor |  | FLT_0D (uncertain) | - | Toroidal beta, defined as the volume-averaged total perpendicular pressure divided by (B0^2/(2*mu0)), i.e. beta_toroidal = 2 mu0 int(p dV) / V / B0^2
equilibrium.time_slice[:].global_quantities.ip |  | FLT_0D (uncertain) | A | Plasma current. Positive sign means anti-clockwise when viewed from above.
equilibrium.time_slice[:].global_quantities.length_pol |  | FLT_0D (uncertain) | m | Poloidal length of the magnetic surface
equilibrium.time_slice[:].global_quantities.li_3 |  | FLT_0D (uncertain) | - | Internal inductance
equilibrium.time_slice[:].global_quantities.magnetic_axis |  | STRUCTURE |  | Magnetic axis position and toroidal field
equilibrium.time_slice[:].global_quantities.magnetic_axis.b_field_tor |  | FLT_0D (uncertain) | T | Total toroidal magnetic field at the magnetic axis
equilibrium.time_slice[:].global_quantities.magnetic_axis.b_tor (obsolescent) |  | FLT_0D (uncertain) | T | Total toroidal magnetic field at the magnetic axis
equilibrium.time_slice[:].global_quantities.magnetic_axis.r |  | FLT_0D (uncertain) | m | Major radius of the magnetic axis
equilibrium.time_slice[:].global_quantities.magnetic_axis.z |  | FLT_0D (uncertain) | m | Height of the magnetic axis
equilibrium.time_slice[:].global_quantities.psi_axis |  | FLT_0D (uncertain) | Wb | Poloidal flux at the magnetic axis
equilibrium.time_slice[:].global_quantities.psi_boundary |  | FLT_0D (uncertain) | Wb | Poloidal flux at the selected plasma boundary
equilibrium.time_slice[:].global_quantities.q_95 |  | FLT_0D (uncertain) | - | q at the 95% poloidal flux surface
equilibrium.time_slice[:].global_quantities.q_axis |  | FLT_0D (uncertain) | - | q at the magnetic axis
equilibrium.time_slice[:].global_quantities.q_min |  | STRUCTURE |  | Minimum q value and position
equilibrium.time_slice[:].global_quantities.q_min.rho_tor_norm |  | FLT_0D (uncertain) | - | Minimum q position in normalised toroidal flux coordinate
equilibrium.time_slice[:].global_quantities.q_min.value |  | FLT_0D (uncertain) | - | Minimum q value
equilibrium.time_slice[:].global_quantities.surface |  | FLT_0D (uncertain) | m^2 | Surface area of the toroidal flux surface
equilibrium.time_slice[:].global_quantities.volume |  | FLT_0D (uncertain) | m^3 | Total plasma volume
equilibrium.time_slice[:].global_quantities.w_mhd |  | FLT_0D (uncertain) | J | Plasma energy content = 3/2 * int(p,dV) with p being the total pressure (thermal + fast particles) [J]. Time-dependent; Scalar
equilibrium.time_slice[:].profiles_1d |  | STRUCTURE |  | Equilibrium profiles (1D radial grid) as a function of the poloidal flux
equilibrium.time_slice[:].profiles_1d.area | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
equilibrium.time_slice[:].profiles_1d.b_average (obsolescent) | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T | Flux surface averaged B
equilibrium.time_slice[:].profiles_1d.b_field_average | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T | Flux surface averaged B
equilibrium.time_slice[:].profiles_1d.b_field_max | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T | Maximum(B) on the flux surface
equilibrium.time_slice[:].profiles_1d.b_field_min | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T | Minimum(B) on the flux surface
equilibrium.time_slice[:].profiles_1d.b_max (obsolescent) | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T | Maximum(B) on the flux surface
equilibrium.time_slice[:].profiles_1d.b_min (obsolescent) | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T | Minimum(B) on the flux surface
equilibrium.time_slice[:].profiles_1d.beta_pol | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Poloidal beta profile. Defined as betap = 4 int(p dV) / [R_0 * mu_0 * Ip^2]
equilibrium.time_slice[:].profiles_1d.darea_dpsi | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^2.Wb^-1 | Radial derivative of the cross-sectional area of the flux surface with respect to psi
equilibrium.time_slice[:].profiles_1d.darea_drho_tor | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m | Radial derivative of the cross-sectional area of the flux surface with respect to rho_tor
equilibrium.time_slice[:].profiles_1d.dpressure_dpsi | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | Pa.Wb^-1 | Derivative of pressure w.r.t. psi
equilibrium.time_slice[:].profiles_1d.dpsi_drho_tor | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | Wb/m | Derivative of Psi with respect to Rho_Tor
equilibrium.time_slice[:].profiles_1d.dvolume_dpsi | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^3.Wb^-1 | Radial derivative of the volume enclosed in the flux surface with respect to Psi
equilibrium.time_slice[:].profiles_1d.dvolume_drho_tor | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^2 | Radial derivative of the volume enclosed in the flux surface with respect to Rho_Tor
equilibrium.time_slice[:].profiles_1d.elongation | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Elongation
equilibrium.time_slice[:].profiles_1d.f | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T.m | Diamagnetic function (F=R B_Phi)
equilibrium.time_slice[:].profiles_1d.f_df_dpsi | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T^2.m^2/Wb | Derivative of F w.r.t. Psi, multiplied with F
equilibrium.time_slice[:].profiles_1d.gm1 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^-2 | Flux surface averaged 1/R^2
equilibrium.time_slice[:].profiles_1d.gm2 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^-2 | Flux surface averaged grad_rho^2/R^2
equilibrium.time_slice[:].profiles_1d.gm3 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Flux surface averaged grad_rho^2
equilibrium.time_slice[:].profiles_1d.gm4 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T^-2 | Flux surface averaged 1/B^2
equilibrium.time_slice[:].profiles_1d.gm5 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T^2 | Flux surface averaged B^2
equilibrium.time_slice[:].profiles_1d.gm6 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | T^-2 | Flux surface averaged grad_rho^2/B^2
equilibrium.time_slice[:].profiles_1d.gm7 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Flux surface averaged grad_rho
equilibrium.time_slice[:].profiles_1d.gm8 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m | Flux surface averaged R
equilibrium.time_slice[:].profiles_1d.gm9 | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^-1 | Flux surface averaged 1/R
equilibrium.time_slice[:].profiles_1d.j_parallel | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | A/m^2 | Flux surface averaged parallel current density = average(j.B) / B0, where B0 = Equilibrium/Global/Toroidal_Field/B0
equilibrium.time_slice[:].profiles_1d.j_tor | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | A/m^2 | Flux surface averaged toroidal current density = average(j_tor/R) / average(1/R)
equilibrium.time_slice[:].profiles_1d.magnetic_shear | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
equilibrium.time_slice[:].profiles_1d.mass_density | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | kg.m^-3 | Mass density
equilibrium.time_slice[:].profiles_1d.phi | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | Wb | Toroidal flux
equilibrium.time_slice[:].profiles_1d.pressure | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | Pa | Pressure
equilibrium.time_slice[:].profiles_1d.psi | [1...N] | FLT_1D (uncertain) | Wb | Poloidal flux
equilibrium.time_slice[:].profiles_1d.q | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Safety factor
equilibrium.time_slice[:].profiles_1d.r_inboard | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m | Radial coordinate (major radius) on the inboard side of the magnetic axis
equilibrium.time_slice[:].profiles_1d.r_outboard | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m | Radial coordinate (major radius) on the outboard side of the magnetic axis
equilibrium.time_slice[:].profiles_1d.rho_tor | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m | Toroidal flux coordinate. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
equilibrium.time_slice[:].profiles_1d.rho_tor_norm | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation)
equilibrium.time_slice[:].profiles_1d.rho_volume_norm | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Normalised square root of enclosed volume (radial coordinate). The normalizing value is the enclosed volume at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation)
equilibrium.time_slice[:].profiles_1d.surface | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^2 | Surface area of the toroidal flux surface
equilibrium.time_slice[:].profiles_1d.trapped_fraction | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Trapped particle fraction
equilibrium.time_slice[:].profiles_1d.triangularity_lower | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Lower triangularity w.r.t. magnetic axis
equilibrium.time_slice[:].profiles_1d.triangularity_upper | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | - | Upper triangularity w.r.t. magnetic axis
equilibrium.time_slice[:].profiles_1d.volume | [equilibrium.time_slice[:].profiles_1d.psi] | FLT_1D (uncertain) | m^3 | Volume enclosed in the flux surface
equilibrium.time_slice[:].profiles_2d | [1...N] | STRUCT_ARRAY |  | Equilibrium 2D profiles in the poloidal plane. Multiple 2D representations of the equilibrium can be stored here.
equilibrium.time_slice[:].profiles_2d[:].b_field_r | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | T | R component of the poloidal magnetic field
equilibrium.time_slice[:].profiles_2d[:].b_field_tor | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | T | Toroidal component of the magnetic field
equilibrium.time_slice[:].profiles_2d[:].b_field_z | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | T | Z component of the poloidal magnetic field
equilibrium.time_slice[:].profiles_2d[:].b_r (obsolescent) | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | T | R component of the poloidal magnetic field
equilibrium.time_slice[:].profiles_2d[:].b_tor (obsolescent) | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | T | Toroidal component of the magnetic field
equilibrium.time_slice[:].profiles_2d[:].b_z (obsolescent) | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | T | Z component of the poloidal magnetic field
equilibrium.time_slice[:].profiles_2d[:].grid |  | STRUCTURE |  | Definition of the 2D grid
equilibrium.time_slice[:].profiles_2d[:].grid.dim1 | [1...N] | FLT_1D (uncertain) | mixed | First dimension values
equilibrium.time_slice[:].profiles_2d[:].grid.dim2 | [1...N] | FLT_1D (uncertain) | mixed | Second dimension values
equilibrium.time_slice[:].profiles_2d[:].grid.volume_element | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | m^3 | Elementary plasma volume of plasma enclosed in the cell formed by the nodes [dim1(i) dim2(j)], [dim1(i+1) dim2(j)], [dim1(i) dim2(j+1)] and [dim1(i+1) dim2(j+1)]
equilibrium.time_slice[:].profiles_2d[:].grid_type |  | STRUCTURE |  | Selection of one of a set of grid types 1) rectangular : Regular grid in (R,Z). In this case the position arrays should not be filled since they are redundant with grid/dim1 and dim2. 2) inverse : Regular grid in (psi, theta). 'flux surface grid'.
equilibrium.time_slice[:].profiles_2d[:].grid_type.description |  | STR_0D |  | Verbose description
equilibrium.time_slice[:].profiles_2d[:].grid_type.index |  | INT_0D |  | Integer identifier (enumeration index within a list)
equilibrium.time_slice[:].profiles_2d[:].grid_type.name |  | STR_0D |  | Short string identifier
equilibrium.time_slice[:].profiles_2d[:].j_parallel | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | A.m^-2 | Parallel (to magnetic field) plasma current density
equilibrium.time_slice[:].profiles_2d[:].j_tor | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | A.m^-2 | Toroidal plasma current density
equilibrium.time_slice[:].profiles_2d[:].phi | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | Wb | Toroidal flux
equilibrium.time_slice[:].profiles_2d[:].psi | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | Wb | Values of the poloidal flux at the grid in the poloidal plane
equilibrium.time_slice[:].profiles_2d[:].r | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | m | Values of the major radius on the grid
equilibrium.time_slice[:].profiles_2d[:].theta | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | rad | Values of the poloidal angle on the grid
equilibrium.time_slice[:].profiles_2d[:].z | [equilibrium.time_slice[:].profiles_2d[:].grid.dim1, equilibrium.time_slice[:].profiles_2d[:].grid.dim2] | FLT_2D (uncertain) | m | Values of the Height on the grid
equilibrium.time_slice[:].time |  | FLT_0D | s | Time
equilibrium.vacuum_toroidal_field |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition and in the normalization of current densities)
equilibrium.vacuum_toroidal_field.b0 | [equilibrium.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewed from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
equilibrium.vacuum_toroidal_field.r0 |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
ic_antennas (alpha) |  |  |  | Antenna systems for heating and current drive in the ion cylcotron (IC) frequencies.
ic_antennas.antenna (alpha) | [1...N] | STRUCT_ARRAY |  | Set of Ion Cyclotron antennas
ic_antennas.antenna[:].frequency (alpha) |  | STRUCTURE |  | Frequency
ic_antennas.antenna[:].frequency.data (alpha) | [ic_antennas.antenna[:].frequency.time] | FLT_1D (uncertain) | Hz | Frequency
ic_antennas.antenna[:].frequency.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ic_antennas.antenna[:].name (alpha) |  | STR_0D |  | Name of the antenna
ic_antennas.antenna[:].power (alpha) |  | STRUCTURE |  | Power
ic_antennas.antenna[:].power.data (alpha) | [ic_antennas.antenna[:].power.time] | FLT_1D (uncertain) | W | Power
ic_antennas.antenna[:].power.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ic_antennas.antenna[:].strap (alpha) | [1...N] | STRUCT_ARRAY |  | Properties of IC antenna straps
ic_antennas.antenna[:].strap[:].current (alpha) |  | STRUCTURE |  | Root mean square current flowing along the strap
ic_antennas.antenna[:].strap[:].current.data (alpha) | [ic_antennas.antenna[:].strap[:].current.time] | FLT_1D (uncertain) | A | Root mean square current flowing along the strap
ic_antennas.antenna[:].strap[:].current.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ic_antennas.antenna[:].strap[:].distance_to_conductor (alpha) |  | FLT_0D (uncertain) | m | Distance to conducting wall or other conductor behind the antenna strap
ic_antennas.antenna[:].strap[:].geometry (alpha) |  | STRUCTURE |  | Cross-sectional shape of the strap
ic_antennas.antenna[:].strap[:].geometry.geometry_type (alpha) |  | INT_0D |  | Type used to describe the element shape (1:'outline', 2:'rectangle', 3:'oblique')
ic_antennas.antenna[:].strap[:].geometry.oblique (alpha) |  | STRUCTURE |  | Trapezoidal description of the element
ic_antennas.antenna[:].strap[:].geometry.oblique.alpha (alpha) |  | FLT_0D (uncertain) | m | Inclination of first angle TBD
ic_antennas.antenna[:].strap[:].geometry.oblique.beta (alpha) |  | FLT_0D (uncertain) | m | Inclination of second angle TBD
ic_antennas.antenna[:].strap[:].geometry.oblique.length (alpha) |  | FLT_0D (uncertain) | m | Length
ic_antennas.antenna[:].strap[:].geometry.oblique.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
ic_antennas.antenna[:].strap[:].geometry.oblique.thickness (alpha) |  | FLT_0D (uncertain) | m | Thickness
ic_antennas.antenna[:].strap[:].geometry.oblique.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
ic_antennas.antenna[:].strap[:].geometry.outline (alpha) |  | STRUCTURE |  | Irregular outline of the element
ic_antennas.antenna[:].strap[:].geometry.outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
ic_antennas.antenna[:].strap[:].geometry.outline.z (alpha) | [ic_antennas.antenna[:].strap[:].geometry.outline.r] | FLT_1D (uncertain) | m | Height
ic_antennas.antenna[:].strap[:].geometry.rectangle (alpha) |  | STRUCTURE |  | Rectangular description of the element
ic_antennas.antenna[:].strap[:].geometry.rectangle.height (alpha) |  | FLT_0D (uncertain) | m | Vertical full height
ic_antennas.antenna[:].strap[:].geometry.rectangle.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
ic_antennas.antenna[:].strap[:].geometry.rectangle.width (alpha) |  | FLT_0D (uncertain) | m | Horizontal full width
ic_antennas.antenna[:].strap[:].geometry.rectangle.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
ic_antennas.antenna[:].strap[:].outline (alpha) |  | STRUCTURE |  | Strap outline
ic_antennas.antenna[:].strap[:].outline.phi (alpha) | [ic_antennas.antenna[:].strap[:].outline.r] | FLT_1D (uncertain) | rad | Toroidal angle
ic_antennas.antenna[:].strap[:].outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
ic_antennas.antenna[:].strap[:].outline.z (alpha) | [ic_antennas.antenna[:].strap[:].outline.r] | FLT_1D (uncertain) | m | Height
ic_antennas.antenna[:].strap[:].phase (alpha) |  | STRUCTURE |  | Phase of the strap current
ic_antennas.antenna[:].strap[:].phase.data (alpha) | [ic_antennas.antenna[:].strap[:].phase.time] | FLT_1D (uncertain) | rad | Phase of the strap current
ic_antennas.antenna[:].strap[:].phase.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ic_antennas.antenna[:].strap[:].width_tor (alpha) |  | FLT_0D (uncertain) | m | Width of strap in the toroidal direction
ic_antennas.antenna[:].surface_current (alpha) | [ic_antennas.antenna[:].surface_current[:].time] | STRUCT_ARRAY |  | Description of the IC surface current on the antenna straps and on passive components, for every time slice
ic_antennas.antenna[:].surface_current[:].m_pol (alpha) | [1...N] | INT_1D |  | Poloidal mode numbers, used to describe the spectrum of the antenna current. The poloidal angle is defined from the reference point; the angle at a point (R,Z) is given by atan((Z-Zref)/(R-Rref)), where Rref=reference_point/r and Zref=reference_point/z
ic_antennas.antenna[:].surface_current[:].n_tor (alpha) | [1...N] | INT_1D |  | Toroidal mode numbers, used to describe the spectrum of the antenna current
ic_antennas.antenna[:].surface_current[:].spectrum (alpha) | [ic_antennas.antenna[:].surface_current[:].m_pol, ic_antennas.antenna[:].surface_current[:].n_pol] | INT_1D | A | Spectrum of the total surface current on the antenna strap and passive components expressed in poloidal and toroidal modes
ic_antennas.antenna[:].surface_current[:].time (alpha) |  | FLT_0D | s | Time
ic_antennas.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
ic_antennas.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
ic_antennas.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
ic_antennas.code.output_flag (alpha) | [ic_antennas.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
ic_antennas.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
ic_antennas.code.repository (alpha) |  | STR_0D |  | URL of software repository
ic_antennas.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
ic_antennas.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
ic_antennas.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
ic_antennas.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
ic_antennas.ids_properties.occurrence |  | INT_0D |  |
ic_antennas.reference_point (alpha) |  | STRUCTURE |  | Reference point used to define the poloidal angle, e.g. the geometrical centre of the vacuum vessel. Used to define the poloidal mode numbers under antenna/surface_current
ic_antennas.reference_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
ic_antennas.reference_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
ic_antennas.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
interfero_polarimeter (alpha) |  |  |  | Interfero-polarimeter diagnostic
interfero_polarimeter.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (lines-of-sight)
interfero_polarimeter.channel[:].ellipticity (alpha) |  | STRUCTURE |  | Ellipticity
interfero_polarimeter.channel[:].ellipticity.data (alpha) | [interfero_polarimeter.channel[:].ellipticity.time] | FLT_1D (uncertain) | - | Ellipticity
interfero_polarimeter.channel[:].ellipticity.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
interfero_polarimeter.channel[:].ellipticity_initial (alpha) |  | FLT_0D (uncertain) | m | Initial ellipticity before entering the plasma
interfero_polarimeter.channel[:].faraday_angle (alpha) |  | STRUCTURE |  | Faraday angle (variation of the Faraday angle induced by crossing the plasma)
interfero_polarimeter.channel[:].faraday_angle.data (alpha) | [interfero_polarimeter.channel[:].faraday_angle.time] | FLT_1D (uncertain) | rad | Faraday angle (variation of the Faraday angle induced by crossing the plasma)
interfero_polarimeter.channel[:].faraday_angle.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
interfero_polarimeter.channel[:].identifier (alpha) |  | STR_0D |  | ID of the channel
interfero_polarimeter.channel[:].line_of_sight (alpha) |  | STRUCTURE |  | Description of the line of sight of the channel, defined by two points when the beam is not reflected, a third point is added to define the reflected beam path
interfero_polarimeter.channel[:].line_of_sight.first_point (alpha) |  | STRUCTURE |  | Position of the first point
interfero_polarimeter.channel[:].line_of_sight.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
interfero_polarimeter.channel[:].line_of_sight.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
interfero_polarimeter.channel[:].line_of_sight.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
interfero_polarimeter.channel[:].line_of_sight.second_point (alpha) |  | STRUCTURE |  | Position of the second point
interfero_polarimeter.channel[:].line_of_sight.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
interfero_polarimeter.channel[:].line_of_sight.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
interfero_polarimeter.channel[:].line_of_sight.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
interfero_polarimeter.channel[:].line_of_sight.third_point (alpha) |  | STRUCTURE |  | Position of the third point
interfero_polarimeter.channel[:].line_of_sight.third_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
interfero_polarimeter.channel[:].line_of_sight.third_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
interfero_polarimeter.channel[:].line_of_sight.third_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
interfero_polarimeter.channel[:].n_e_line (alpha) |  | STRUCTURE |  | Line integrated density, possibly obtained by a combination of multiple interferometry wavelengths
interfero_polarimeter.channel[:].n_e_line.data (alpha) | [interfero_polarimeter.channel[:].n_e_line.time] | FLT_1D (uncertain) | m^-2 | Line integrated density, possibly obtained by a combination of multiple interferometry wavelengths
interfero_polarimeter.channel[:].n_e_line.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
interfero_polarimeter.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
interfero_polarimeter.channel[:].polarisation_initial (alpha) |  | FLT_0D (uncertain) | m | Initial polarisation vector before entering the plasma
interfero_polarimeter.channel[:].validity (alpha) |  | INT_0D |  | Indicator of the validity of the channel for the whole acquisition period (0 means valid, negative values mean non-valid)
interfero_polarimeter.channel[:].validity_timed (alpha) |  | STRUCTURE |  | Indicator of the validity of the channel as a function of time (0 means valid, negative values mean non-valid)
interfero_polarimeter.channel[:].validity_timed.data (alpha) | [interfero_polarimeter.channel[:].validity_timed.time] | INT_1D |  | Indicator of the validity of the channel as a function of time (0 means valid, negative values mean non-valid)
interfero_polarimeter.channel[:].validity_timed.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
interfero_polarimeter.channel[:].wavelength_interferometry (alpha) | [1...N] | STRUCT_ARRAY |  | Set of wavelengths used for interferometry
interfero_polarimeter.channel[:].wavelength_interferometry[:].n_e_line (alpha) |  | STRUCTURE |  | Line integrated density estimated from this wavelength
interfero_polarimeter.channel[:].wavelength_interferometry[:].n_e_line.data (alpha) | [interfero_polarimeter.channel[:].wavelength_interferometry[:].n_e_line.time] | FLT_1D (uncertain) | m^-2 | Line integrated density estimated from this wavelength
interfero_polarimeter.channel[:].wavelength_interferometry[:].n_e_line.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
interfero_polarimeter.channel[:].wavelength_interferometry[:].phase (alpha) |  | STRUCTURE |  | Phase measured for this wavelength
interfero_polarimeter.channel[:].wavelength_interferometry[:].phase.data (alpha) | [interfero_polarimeter.channel[:].wavelength_interferometry[:].phase.time] | FLT_1D (uncertain) | rad | Phase measured for this wavelength
interfero_polarimeter.channel[:].wavelength_interferometry[:].phase.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
interfero_polarimeter.channel[:].wavelength_interferometry[:].value (alpha) |  | FLT_0D (uncertain) | m | Wavelength value
interfero_polarimeter.channel[:].wavelength_polarimetry (alpha) |  | FLT_0D (uncertain) | m | Wavelength used for polarimetry
interfero_polarimeter.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
interfero_polarimeter.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
interfero_polarimeter.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
interfero_polarimeter.code.output_flag (alpha) | [interfero_polarimeter.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
interfero_polarimeter.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
interfero_polarimeter.code.repository (alpha) |  | STR_0D |  | URL of software repository
interfero_polarimeter.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
interfero_polarimeter.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
interfero_polarimeter.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
interfero_polarimeter.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
interfero_polarimeter.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
iron_core (alpha) |  |  |  | Iron core description
iron_core.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
iron_core.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
iron_core.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
iron_core.code.output_flag (alpha) | [iron_core.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
iron_core.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
iron_core.code.repository (alpha) |  | STR_0D |  | URL of software repository
iron_core.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
iron_core.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
iron_core.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
iron_core.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
iron_core.ids_properties.occurrence |  | INT_0D |  |
iron_core.segment (alpha) | [1...N] | STRUCT_ARRAY |  | The iron core is describred as a set of segments
iron_core.segment[:].b_field (alpha) | [1...N] | FLT_1D (uncertain) | T | Array of magnetic field values, for each of which the relative permeability is given
iron_core.segment[:].geometry (alpha) |  | STRUCTURE |  | Cross-sectional shape of the segment
iron_core.segment[:].geometry.geometry_type (alpha) |  | INT_0D |  | Type used to describe the element shape (1:'outline', 2:'rectangle', 3:'oblique')
iron_core.segment[:].geometry.oblique (alpha) |  | STRUCTURE |  | Trapezoidal description of the element
iron_core.segment[:].geometry.oblique.alpha (alpha) |  | FLT_0D (uncertain) | m | Inclination of first angle TBD
iron_core.segment[:].geometry.oblique.beta (alpha) |  | FLT_0D (uncertain) | m | Inclination of second angle TBD
iron_core.segment[:].geometry.oblique.length (alpha) |  | FLT_0D (uncertain) | m | Length
iron_core.segment[:].geometry.oblique.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
iron_core.segment[:].geometry.oblique.thickness (alpha) |  | FLT_0D (uncertain) | m | Thickness
iron_core.segment[:].geometry.oblique.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
iron_core.segment[:].geometry.outline (alpha) |  | STRUCTURE |  | Irregular outline of the element
iron_core.segment[:].geometry.outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
iron_core.segment[:].geometry.outline.z (alpha) | [iron_core.segment[:].geometry.outline.r] | FLT_1D (uncertain) | m | Height
iron_core.segment[:].geometry.rectangle (alpha) |  | STRUCTURE |  | Rectangular description of the element
iron_core.segment[:].geometry.rectangle.height (alpha) |  | FLT_0D (uncertain) | m | Vertical full height
iron_core.segment[:].geometry.rectangle.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
iron_core.segment[:].geometry.rectangle.width (alpha) |  | FLT_0D (uncertain) | m | Horizontal full width
iron_core.segment[:].geometry.rectangle.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
iron_core.segment[:].identifier (alpha) |  | STR_0D |  | ID of the segment
iron_core.segment[:].magnetisation_r (alpha) |  | STRUCTURE |  | Magnetisation M of the iron segment along the major radius axis, assumed to be constant inside a given iron segment. Reminder : H = 1/mu0 * B - mur * M;
iron_core.segment[:].magnetisation_r.data (alpha) | [iron_core.segment[:].magnetisation_r.time] | FLT_1D (uncertain) | T | Magnetisation M of the iron segment along the major radius axis, assumed to be constant inside a given iron segment. Reminder : H = 1/mu0 * B - mur * M;
iron_core.segment[:].magnetisation_r.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
iron_core.segment[:].magnetisation_z (alpha) |  | STRUCTURE |  | Magnetisation M of the iron segment along the vertical axis, assumed to be constant inside a given iron segment. Reminder : H = 1/mu0 * B - mur * M;
iron_core.segment[:].magnetisation_z.data (alpha) | [iron_core.segment[:].magnetisation_z.time] | FLT_1D (uncertain) | T | Magnetisation M of the iron segment along the vertical axis, assumed to be constant inside a given iron segment. Reminder : H = 1/mu0 * B - mur * M;
iron_core.segment[:].magnetisation_z.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
iron_core.segment[:].name (alpha) |  | STR_0D |  | Name of the segment
iron_core.segment[:].permeability_relative (alpha) | [iron_core.segment[:].b_field] | FLT_1D (uncertain) | - | Relative permeability of the iron segment
iron_core.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
magnetics (alpha) |  |  |  | Magnetic diagnostics for equilibrium identification and plasma shape control.
magnetics.bpol_probe (alpha) | [1...N] | STRUCT_ARRAY |  | Poloidal field probes
magnetics.bpol_probe[:].area (alpha) |  | FLT_0D (uncertain) | m^2 | Area of each turn of the coil
magnetics.bpol_probe[:].field (alpha) |  | STRUCTURE |  | Measured magnetic field
magnetics.bpol_probe[:].field.data (alpha) | [magnetics.bpol_probe[:].field.time] | FLT_1D (uncertain) | T | Measured magnetic field
magnetics.bpol_probe[:].field.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
magnetics.bpol_probe[:].identifier (alpha) |  | STR_0D |  | ID of the probe
magnetics.bpol_probe[:].length (alpha) |  | FLT_0D (uncertain) | m | Length of the coil
magnetics.bpol_probe[:].name (alpha) |  | STR_0D |  | Name of the probe
magnetics.bpol_probe[:].poloidal_angle (alpha) |  | FLT_0D (uncertain) | rad | Poloidal angle of the coil orientation
magnetics.bpol_probe[:].position (alpha) |  | STRUCTURE |  | R, Z, Phi position of the coil centre
magnetics.bpol_probe[:].position.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
magnetics.bpol_probe[:].position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
magnetics.bpol_probe[:].position.z (alpha) |  | FLT_0D (uncertain) | m | Height
magnetics.bpol_probe[:].toroidal_angle (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle of coil orientation (0 if fully in the poloidal plane)
magnetics.bpol_probe[:].turns (alpha) |  | INT_0D |  | Turns in the coil, including sign
magnetics.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
magnetics.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
magnetics.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
magnetics.code.output_flag (alpha) | [magnetics.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
magnetics.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
magnetics.code.repository (alpha) |  | STR_0D |  | URL of software repository
magnetics.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
magnetics.flux_loop (alpha) | [1...N] | STRUCT_ARRAY |  | Flux loops; partial flux loops can be described
magnetics.flux_loop[:].flux (alpha) |  | STRUCTURE |  | Measured flux
magnetics.flux_loop[:].flux.data (alpha) | [magnetics.flux_loop[:].flux.time] | FLT_1D (uncertain) | Wb | Measured flux
magnetics.flux_loop[:].flux.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
magnetics.flux_loop[:].identifier (alpha) |  | STR_0D |  | ID of the flux loop
magnetics.flux_loop[:].name (alpha) |  | STR_0D |  | Name of the flux loop
magnetics.flux_loop[:].position (alpha) | [1...N] | STRUCT_ARRAY |  | List of (R,Z,phi) points defining the position of the loop (see data structure documentation FLUXLOOPposition.pdf)
magnetics.flux_loop[:].position[:].phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
magnetics.flux_loop[:].position[:].r (alpha) |  | FLT_0D (uncertain) | m | Major radius
magnetics.flux_loop[:].position[:].z (alpha) |  | FLT_0D (uncertain) | m | Height
magnetics.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
magnetics.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
magnetics.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
magnetics.ids_properties.occurrence |  | INT_0D |  |
magnetics.method (alpha) | [1...N] | STRUCT_ARRAY |  | A method generating processed quantities derived from the magnetic measurements
magnetics.method[:].diamagnetic_flux (alpha) |  | STRUCTURE |  | Diamagnetic flux
magnetics.method[:].diamagnetic_flux.data (alpha) | [magnetics.method[:].diamagnetic_flux.time] | FLT_1D (uncertain) | Wb | Diamagnetic flux
magnetics.method[:].diamagnetic_flux.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
magnetics.method[:].ip (alpha) |  | STRUCTURE |  | Plasma current. Positive sign means anti-clockwise when viewed from above.
magnetics.method[:].ip.data (alpha) | [magnetics.method[:].ip.time] | FLT_1D (uncertain) | A | Plasma current. Positive sign means anti-clockwise when viewed from above.
magnetics.method[:].ip.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
magnetics.method[:].name (alpha) |  | STR_0D |  | Name of the data processing method
magnetics.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
mhd_linear (alpha) |  |  |  | Magnetohydronamic linear stability
mhd_linear.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
mhd_linear.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
mhd_linear.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
mhd_linear.code.output_flag (alpha) | [mhd_linear.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
mhd_linear.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
mhd_linear.code.repository (alpha) |  | STR_0D |  | URL of software repository
mhd_linear.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
mhd_linear.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
mhd_linear.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
mhd_linear.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
mhd_linear.ids_properties.occurrence |  | INT_0D |  |
mhd_linear.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
mhd_linear.time_slice (alpha) | [mhd_linear.time_slice[:].time] | STRUCT_ARRAY |  | Core plasma radial profiles for various time slices
mhd_linear.time_slice[:].time (alpha) |  | FLT_0D | s | Time
mhd_linear.time_slice[:].toroidal_mode (alpha) | [1...N] | STRUCT_ARRAY |  | Vector of toroidal modes
mhd_linear.time_slice[:].toroidal_mode[:].frequency (alpha) |  | FLT_0D (uncertain) | Hz | Frequency of the mode
mhd_linear.time_slice[:].toroidal_mode[:].growthrate (alpha) |  | FLT_0D (uncertain) | Hz | Linear growthrate of the mode
mhd_linear.time_slice[:].toroidal_mode[:].n_tor (alpha) |  | INT_0D |  | Toroidal mode number of the MHD mode
mhd_linear.time_slice[:].toroidal_mode[:].plasma (alpha) |  | STRUCTURE |  | MHD modes in the confined plasma
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed (alpha) |  | STRUCTURE | T.m | Pertubed vector potential for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate1 (alpha) |  | STRUCTURE | T.m | First coordinate (radial)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate1.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T.m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate1.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T.m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate2 (alpha) |  | STRUCTURE | T.m | Second coordinate (poloidal)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate2.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T.m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate2.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T.m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate3 (alpha) |  | STRUCTURE | T.m | Third coordinate (toroidal)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate3.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T.m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.a_field_perturbed.coordinate3.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T.m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed (alpha) |  | STRUCTURE | T | Pertubed magnetic field for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate1 (alpha) |  | STRUCTURE | T | First coordinate (radial)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate1.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate1.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate2 (alpha) |  | STRUCTURE | T | Second coordinate (poloidal)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate2.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate2.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate3 (alpha) |  | STRUCTURE | T | Third coordinate (toroidal)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate3.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.b_field_perturbed.coordinate3.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | T | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_parallel (alpha) |  | STRUCTURE | m | Parallel displacement of the modes
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_parallel.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_parallel.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_perpendicular (alpha) |  | STRUCTURE | m | Perpendicular displacement of the modes
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_perpendicular.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.displacement_perpendicular.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid (alpha) |  | STRUCTURE |  | Definition of the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1 (alpha) | [1...N] | FLT_1D (uncertain) | mixed | First dimension values
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2 (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Second dimension values
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.volume_element (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m^3 | Elementary plasma volume of plasma enclosed in the cell formed by the nodes [dim1(i) dim2(j)], [dim1(i+1) dim2(j)], [dim1(i) dim2(j+1)] and [dim1(i+1) dim2(j+1)]
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid_type (alpha) |  | STRUCTURE |  | Selection of one of a set of grid types 1) rectangular : Cylindrical R,Z ala eqdsk. In this case the position arrays should not be filled since they are redundant with grid/dim1 and dim2. 2) inverse : Rhopolar_polar 2D polar coordinates (rho, theta) with magnetic axis as center of grid; theta and values following the COCOS convention, theta=atan2(z-zaxis,r-raxis)≡polar angle 11) inverse psi_straight field line : Flux surface type with psi as radial label, theta straight-field line (mod(index,10)=1), could be non-equidistant; magnetic axis as center of grid; following the COCOS convention 12) inverse psi_equal : Arc flux surface type with psi as radial label, theta to have equal arc (mod(index,10)=2) 13) inverse psi_polar : Flux surface type with psi as radial label, theta as polar angle, could be non-equidistant 14) inverse psi_m : Flux surface type with psi as radial label and poloidal mode number as dim2, could be non-equidistant 21) inverse rhopolnorm_straight field line : Flux surface type with radial label is sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] and theta straight-field line 22) inverse rhopolnorm_equal arc : Flux surface type with radial label is sqrt[(psi-psi_axis)/(psi_edge-psi_axis)], theta to have equal arc 23) inverse rhopolnorm_polar : Same as 13 but radial label is sqrt[(psi-psi_axis)/(psi_edge-psi_axis)], theta as polar angle, could be non-equidistant 23) inverse rhopolnorm_m : Same as 13 but radial label is sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] and poloidal mode number as dim2, could be non-equidistant 31) inverse rhotornorm_straight field line : Flux surface type with radial label is sqrt[Phi/Phi_edge], Phi being toroidal flux and theta straight-field line 32) inverse rhotornorm_equal arc : Flux surface type with radial label is sqrt[Phi/Phi_edge], Phi being toroidal flux, theta to have equal arc 33) inverse rhotornorm_polar : Flux surface type with radial label is sqrt[Phi/Phi_edge], Phi being toroidal flux, theta as polar angle, could be non-equidistant 34) inverse rhotornorm_m : Flux surface type with radial label is sqrt[Phi/Phi_edge], Phi being toroidal flux, poloidal mode number as dim2, could be non-equidistant 41) inverse rhopol_straight field line : Flux surface type with radial label is sqrt[psi-psi_axis] and theta straight-field line 42) inverse rhopol_equal arc : Flux surface type with radial label is sqrt[psi-psi_axis], theta to have equal arc 43) inverse rhopol_polar : Same as 13 but radial label is sqrt[psi-psi_axis], theta as polar angle, could be non-equidistant 44) inverse rhopol_m : Same as 13 but radial label is sqrt[psi-psi_axis], poloidal mode number as dim2, could be non-equidistant 51) inverse rhotor_straight field line : Flux surface type with radial label is sqrt[Phi/pi/B0], Phi being toroidal flux and theta straight-field line 52) inverse rhotor_equal arc : Flux surface type with radial label is sqrt[Phi/pi/B0], Phi being toroidal flux, theta to have equal arc 53) inverse rhotor_polar : Flux surface type with radial label is sqrt[Phi/pi/B0], Phi being toroidal flux, theta as polar angle, could be non-equidistant 54) inverse rhotor_m : Flux surface type with radial label is sqrt[Phi/pi/B0], Phi being toroidal flux, poloidal mode number as dim2, could be non-equidistant 91) irregular rz_na : Irregular grid, thus give list of vertices in dim1(1:ndim1), dim2(1:ndim1) and then all fields are on values(1:ndim1,1); needs to know if R,Z, psi,theta for dim1, dim2?Used with connect and only for rz
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid_type.description (alpha) |  | STR_0D |  | Verbose description
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid_type.name (alpha) |  | STR_0D |  | Short string identifier
mhd_linear.time_slice[:].toroidal_mode[:].plasma.mass_density_perturbed (alpha) |  | STRUCTURE | kg.m^-3 | Perturbed mass density for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].plasma.mass_density_perturbed.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | kg.m^-3 | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.mass_density_perturbed.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | kg.m^-3 | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.pressure_perturbed (alpha) |  | STRUCTURE | Pa | Perturbed pressure for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].plasma.pressure_perturbed.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | Pa | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.pressure_perturbed.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | Pa | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.tau_alfven (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1] | FLT_1D (uncertain) | s | Alven time=R/vA=R0 sqrt(mi ni(rho))/B0
mhd_linear.time_slice[:].toroidal_mode[:].plasma.tau_resistive (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1] | FLT_1D (uncertain) | s | Resistive time = mu_0 rho*rho/1.22/eta_neo
mhd_linear.time_slice[:].toroidal_mode[:].plasma.temperature_perturbed (alpha) |  | STRUCTURE | eV | Perturbed temperature for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].plasma.temperature_perturbed.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | eV | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.temperature_perturbed.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | eV | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed (alpha) |  | STRUCTURE | m/s | Pertubed velocity for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate1 (alpha) |  | STRUCTURE | m/s | First coordinate (radial)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate1.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m/s | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate1.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m/s | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate2 (alpha) |  | STRUCTURE | m/s | Second coordinate (poloidal)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate2.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m/s | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate2.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m/s | Real part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate3 (alpha) |  | STRUCTURE | m/s | Third coordinate (toroidal)
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate3.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m/s | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].plasma.velocity_perturbed.coordinate3.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].plasma.grid.dim2] | FLT_2D (uncertain) | m/s | Real part
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum (alpha) |  | STRUCTURE |  | MHD modes in the vaccum
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.a_field_perturbed (alpha) |  | STRUCTURE | T.m | Pertubed vector potential for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.a_field_perturbed.coordinate1 (alpha) |  | STRUCTURE | T.m | First coordinate (radial)
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.a_field_perturbed.coordinate1.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim2] | FLT_2D (uncertain) | T.m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.a_field_perturbed.coordinate1.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim2] | FLT_2D (uncertain) | T.m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.a_field_perturbed.coordinate2 (alpha) |  | STRUCTURE | T.m | Second coordinate (poloidal)
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.a_field_perturbed.coordinate2.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim2] | FLT_2D (uncertain) | T.m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.a_field_perturbed.coordinate2.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim2] | FLT_2D (uncertain) | T.m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.a_field_perturbed.coordinate3 (alpha) |  | STRUCTURE | T.m | Third coordinate (toroidal)
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.a_field_perturbed.coordinate3.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim2] | FLT_2D (uncertain) | T.m | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.a_field_perturbed.coordinate3.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim2] | FLT_2D (uncertain) | T.m | Real part
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.b_field_perturbed (alpha) |  | STRUCTURE | T | Pertubed magnetic field for given toroidal mode number
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.b_field_perturbed.coordinate1 (alpha) |  | STRUCTURE | T | First coordinate (radial)
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.b_field_perturbed.coordinate1.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim2] | FLT_2D (uncertain) | T | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.b_field_perturbed.coordinate1.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim2] | FLT_2D (uncertain) | T | Real part
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.b_field_perturbed.coordinate2 (alpha) |  | STRUCTURE | T | Second coordinate (poloidal)
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.b_field_perturbed.coordinate2.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim2] | FLT_2D (uncertain) | T | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.b_field_perturbed.coordinate2.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim2] | FLT_2D (uncertain) | T | Real part
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.b_field_perturbed.coordinate3 (alpha) |  | STRUCTURE | T | Third coordinate (toroidal)
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.b_field_perturbed.coordinate3.imaginary (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim2] | FLT_2D (uncertain) | T | Imaginary part
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.b_field_perturbed.coordinate3.real (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim2] | FLT_2D (uncertain) | T | Real part
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid (alpha) |  | STRUCTURE |  | Definition of the 2D grid
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim1 (alpha) | [1...N] | FLT_1D (uncertain) | mixed | First dimension values
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim2 (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Second dimension values
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.volume_element (alpha) | [mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim1, mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid.dim2] | FLT_2D (uncertain) | m^3 | Elementary plasma volume of plasma enclosed in the cell formed by the nodes [dim1(i) dim2(j)], [dim1(i+1) dim2(j)], [dim1(i) dim2(j+1)] and [dim1(i+1) dim2(j+1)]
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid_type (alpha) |  | STRUCTURE |  | Selection of one of a set of grid types 1) rectangular : Cylindrical R,Z ala eqdsk. In this case the position arrays should not be filled since they are redundant with grid/dim1 and dim2. 2) inverse : Rhopolar_polar 2D polar coordinates (rho, theta) with magnetic axis as center of grid; theta and values following the COCOS convention, theta=atan2(z-zaxis,r-raxis)≡polar angle 11) inverse psi_straight field line : Flux surface type with psi as radial label, theta straight-field line (mod(index,10)=1), could be non-equidistant; magnetic axis as center of grid; following the COCOS convention 12) inverse psi_equal : Arc flux surface type with psi as radial label, theta to have equal arc (mod(index,10)=2) 13) inverse psi_polar : Flux surface type with psi as radial label, theta as polar angle, could be non-equidistant 14) inverse psi_m : Flux surface type with psi as radial label and poloidal mode number as dim2, could be non-equidistant 21) inverse rhopolnorm_straight field line : Flux surface type with radial label is sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] and theta straight-field line 22) inverse rhopolnorm_equal arc : Flux surface type with radial label is sqrt[(psi-psi_axis)/(psi_edge-psi_axis)], theta to have equal arc 23) inverse rhopolnorm_polar : Same as 13 but radial label is sqrt[(psi-psi_axis)/(psi_edge-psi_axis)], theta as polar angle, could be non-equidistant 23) inverse rhopolnorm_m : Same as 13 but radial label is sqrt[(psi-psi_axis)/(psi_edge-psi_axis)] and poloidal mode number as dim2, could be non-equidistant 31) inverse rhotornorm_straight field line : Flux surface type with radial label is sqrt[Phi/Phi_edge], Phi being toroidal flux and theta straight-field line 32) inverse rhotornorm_equal arc : Flux surface type with radial label is sqrt[Phi/Phi_edge], Phi being toroidal flux, theta to have equal arc 33) inverse rhotornorm_polar : Flux surface type with radial label is sqrt[Phi/Phi_edge], Phi being toroidal flux, theta as polar angle, could be non-equidistant 34) inverse rhotornorm_m : Flux surface type with radial label is sqrt[Phi/Phi_edge], Phi being toroidal flux, poloidal mode number as dim2, could be non-equidistant 41) inverse rhopol_straight field line : Flux surface type with radial label is sqrt[psi-psi_axis] and theta straight-field line 42) inverse rhopol_equal arc : Flux surface type with radial label is sqrt[psi-psi_axis], theta to have equal arc 43) inverse rhopol_polar : Same as 13 but radial label is sqrt[psi-psi_axis], theta as polar angle, could be non-equidistant 44) inverse rhopol_m : Same as 13 but radial label is sqrt[psi-psi_axis], poloidal mode number as dim2, could be non-equidistant 51) inverse rhotor_straight field line : Flux surface type with radial label is sqrt[Phi/pi/B0], Phi being toroidal flux and theta straight-field line 52) inverse rhotor_equal arc : Flux surface type with radial label is sqrt[Phi/pi/B0], Phi being toroidal flux, theta to have equal arc 53) inverse rhotor_polar : Flux surface type with radial label is sqrt[Phi/pi/B0], Phi being toroidal flux, theta as polar angle, could be non-equidistant 54) inverse rhotor_m : Flux surface type with radial label is sqrt[Phi/pi/B0], Phi being toroidal flux, poloidal mode number as dim2, could be non-equidistant 91) irregular rz_na : Irregular grid, thus give list of vertices in dim1(1:ndim1), dim2(1:ndim1) and then all fields are on values(1:ndim1,1); needs to know if R,Z, psi,theta for dim1, dim2?Used with connect and only for rz
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid_type.description (alpha) |  | STR_0D |  | Verbose description
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
mhd_linear.time_slice[:].toroidal_mode[:].vaccuum.grid_type.name (alpha) |  | STR_0D |  | Short string identifier
mhd_linear.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition and in the normalization of current densities)
mhd_linear.vacuum_toroidal_field.b0 (alpha) | [mhd_linear.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewed from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
mhd_linear.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
nbi (alpha) |  |  |  | Neutral Beam Injection systems and description of the fast neutrals that arrive into the torus
nbi.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
nbi.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
nbi.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
nbi.code.output_flag (alpha) | [nbi.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
nbi.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
nbi.code.repository (alpha) |  | STR_0D |  | URL of software repository
nbi.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
nbi.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
nbi.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
nbi.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
nbi.ids_properties.occurrence |  | INT_0D |  |
nbi.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
nbi.unit (alpha) | [1...N] | STRUCT_ARRAY |  | The NBI system is described as a set of units of which the power can be controlled individually.
nbi.unit[:].beam_current_fraction (alpha) |  | STRUCTURE |  | Fractions of beam current distributed among the different energies, the first index corresponds to the fast neutrals energy (1:full, 2: half, 3: one third)
nbi.unit[:].beam_current_fraction.data (alpha) | [1...3, nbi.unit[:].beam_current_fraction.time] | FLT_2D (uncertain) | - | Fractions of beam current distributed among the different energies, the first index corresponds to the fast neutrals energy (1:full, 2: half, 3: one third)
nbi.unit[:].beam_current_fraction.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
nbi.unit[:].beam_power_fraction (alpha) |  | STRUCTURE |  | Fractions of beam power distributed among the different energies, the first index corresponds to the fast neutrals energy (1:full, 2: half, 3: one third)
nbi.unit[:].beam_power_fraction.data (alpha) | [1...3, nbi.unit[:].beam_power_fraction.time] | FLT_2D (uncertain) | - | Fractions of beam power distributed among the different energies, the first index corresponds to the fast neutrals energy (1:full, 2: half, 3: one third)
nbi.unit[:].beam_power_fraction.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
nbi.unit[:].beamlets_group (alpha) | [1...N] | STRUCT_ARRAY |  | Group of beamlets with common vertical and horizontal focal point. If there are no common focal points, then select small groups of beamlets such that a focal point description of the beamlets group provides a fair description
nbi.unit[:].beamlets_group[:].angle (alpha) |  | FLT_0D (uncertain) | rad | Angle of inclination between a beamlet at the centre of the injection unit surface and the horiontal plane
nbi.unit[:].beamlets_group[:].beamlets (alpha) |  | STRUCTURE |  | Detailed information on beamlets
nbi.unit[:].beamlets_group[:].beamlets.angles (alpha) | [nbi.unit[:].beamlets_group[:].beamlets.positions.R] | FLT_1D (uncertain) | rad | Angle of inclination between a line at the centre of a beamlet and the horiontal plane, for each beamlet
nbi.unit[:].beamlets_group[:].beamlets.positions (alpha) |  | STRUCTURE |  | Position of each beamlet
nbi.unit[:].beamlets_group[:].beamlets.positions.phi (alpha) | [nbi.unit[:].beamlets_group[:].beamlets.positions.r] | FLT_1D (uncertain) | rad | Toroidal angle
nbi.unit[:].beamlets_group[:].beamlets.positions.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
nbi.unit[:].beamlets_group[:].beamlets.positions.z (alpha) | [nbi.unit[:].beamlets_group[:].beamlets.positions.r] | FLT_1D (uncertain) | m | Height
nbi.unit[:].beamlets_group[:].beamlets.power_fractions (alpha) | [nbi.unit[:].beamlets_group[:].beamlets.positions.R] | FLT_1D (uncertain) | rad | Fraction of power of a unit injected by each beamlet
nbi.unit[:].beamlets_group[:].beamlets.tangency_radii (alpha) | [nbi.unit[:].beamlets_group[:].beamlets.positions.R] | FLT_1D (uncertain) | m | Tangency radius (major radius where the central line of a beamlet is tangent to a circle around the torus), for each beamlet
nbi.unit[:].beamlets_group[:].direction (alpha) |  | INT_0D |  | Direction of the beam seen from above the torus: -1 = clockwise; 1 = counter clockwise
nbi.unit[:].beamlets_group[:].divergence_component (alpha) | [1...N] | STRUCT_ARRAY |  | Detailed information on beamlet divergence. Divergence is described as a superposition of Gaussian components with amplitide "particles_fraction" and vertical/horizontal divergence. Note that for positive ion NBI the divergence is well described by a single Gaussian
nbi.unit[:].beamlets_group[:].divergence_component[:].horizontal (alpha) |  | FLT_0D (uncertain) | rad | The horiztonal beamlet divergence of the component. Here the divergence is defined for Gaussian beams as the angel where the beam density is reduced by a factor 1/e compared to the maximum density. For non-Gaussian beams the divergence is sqrt(2)*mean((x-mean(x))**2), where x is the angle and the mean should be performed over the beam density, P(x): mean(y)=int(y*P(x)*dx).
nbi.unit[:].beamlets_group[:].divergence_component[:].particles_fraction (alpha) |  | FLT_0D (uncertain) | - | Fraction of injected particles in the component
nbi.unit[:].beamlets_group[:].divergence_component[:].vertical (alpha) |  | FLT_0D (uncertain) | rad | The vertical beamlet divergence of the component. Here the divergence is defined for Gaussian beams as the angel where the beam density is reduced by a factor 1/e compared to the maximum density. For non-Gaussian beams the divergence is sqrt(2)*mean((x-mean(x))**2), where x is the angle and the mean should be performed over the beam density, P(x): mean(y)=int(y*P(x)*dx).
nbi.unit[:].beamlets_group[:].focus (alpha) |  | STRUCTURE |  | Describes how the beamlet group is focused
nbi.unit[:].beamlets_group[:].focus.focal_length_horizontal (alpha) |  | FLT_0D (uncertain) | m | Horizontal focal length along the beam line, i.e. the point along the centre of the beamlet-group where the beamlet-group has its minimum horizontal width
nbi.unit[:].beamlets_group[:].focus.focal_length_vertical (alpha) |  | FLT_0D (uncertain) | m | Vertical focal length along the beam line, i.e. the point along the centre of the beamlet-group where the beamlet-group has its minimum vertical width
nbi.unit[:].beamlets_group[:].focus.width_min_horizontal (alpha) |  | FLT_0D (uncertain) | m | The horizontal width of the beamlets group at the at the horizontal focal point
nbi.unit[:].beamlets_group[:].focus.width_min_vertical (alpha) |  | FLT_0D (uncertain) | m | The vertical width of the beamlets group at the at the vertical focal point
nbi.unit[:].beamlets_group[:].position (alpha) |  | STRUCTURE |  | R, Z, Phi position of the beamlet group centre
nbi.unit[:].beamlets_group[:].position.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
nbi.unit[:].beamlets_group[:].position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
nbi.unit[:].beamlets_group[:].position.z (alpha) |  | FLT_0D (uncertain) | m | Height
nbi.unit[:].beamlets_group[:].tangency_radius (alpha) |  | FLT_0D (uncertain) | m | Tangency radius (major radius where the central line of a NBI unit is tangent to a circle around the torus)
nbi.unit[:].beamlets_group[:].width_horizontal (alpha) |  | FLT_0D (uncertain) | m | Horizontal width of the beam group at the injection unit surface (or grounded grid)
nbi.unit[:].beamlets_group[:].width_vertical (alpha) |  | FLT_0D (uncertain) | m | Vertical width of the beam group at the injection unit surface (or grounded grid)
nbi.unit[:].energy (alpha) |  | STRUCTURE |  | Full energy of the injected species (acceleration of a single atom)
nbi.unit[:].energy.data (alpha) | [nbi.unit[:].energy.time] | FLT_1D (uncertain) | eV | Full energy of the injected species (acceleration of a single atom)
nbi.unit[:].energy.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
nbi.unit[:].identifier (alpha) |  | STR_0D |  | ID of the NBI unit
nbi.unit[:].name (alpha) |  | STR_0D |  | Name of the NBI unit
nbi.unit[:].power (alpha) |  | STRUCTURE |  | Power
nbi.unit[:].power.data (alpha) | [nbi.unit[:].power.time] | FLT_1D (uncertain) | W | Power
nbi.unit[:].power.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
nbi.unit[:].species (alpha) |  | STRUCTURE | Atomic Mass Unit | Injected species
nbi.unit[:].species.a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
nbi.unit[:].species.label (alpha) |  | STR_0D |  | String identifying the species (e.g. H, D, T, ...)
nbi.unit[:].species.z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
neutron_diagnostic (alpha) |  |  |  | Neutron diagnostic such as DNFM, NFM or MFC
neutron_diagnostic.characteristics (alpha) |  | STRUCTURE |  | Description of Diagnostic's module detection characteristics for differen plasma modes based on Design Description
neutron_diagnostic.characteristics.dead_time (alpha) |  | FLT_0D (uncertain) | s | Dead time of detectors
neutron_diagnostic.characteristics.pulse_length (alpha) |  | FLT_0D (uncertain) | s | Lower counting limit of recent Measuring Mode and plasma reaction
neutron_diagnostic.characteristics.reaction (alpha) | [neutron_diagnostic.characteristics.reaction[:].index] | STRUCT_ARRAY |  | Plasma reaction (1 -'DT'; 2 - 'DD')
neutron_diagnostic.characteristics.reaction[:].error (alpha) |  | FLT_0D (uncertain) | - | Diagnostic's relative uncertainty for recent plasma reaction
neutron_diagnostic.characteristics.reaction[:].index (alpha) |  | INT_0D |  | Index of plasma reaction type
neutron_diagnostic.characteristics.reaction[:].mode (alpha) | [neutron_diagnostic.characteristics.reaction[:].mode[:].index] | STRUCT_ARRAY |  | Characteristics of counting linear limits in recent Measuring modes for recent Plasma reaction type
neutron_diagnostic.characteristics.reaction[:].mode[:].count_limit_max (alpha) |  | FLT_0D (uncertain) | cps | Maximum count limit of recent Measuring Mode and plasma reaction
neutron_diagnostic.characteristics.reaction[:].mode[:].count_limit_min (alpha) |  | FLT_0D (uncertain) | cps | Minimum count limit of recent Measuring Mode and plasma reaction
neutron_diagnostic.characteristics.reaction[:].mode[:].index (alpha) |  | INT_0D |  | Index of Measuring Mode
neutron_diagnostic.characteristics.reaction[:].mode[:].name (alpha) |  | STR_0D |  | Name of Measuring Mode
neutron_diagnostic.characteristics.reaction[:].probability_overlap (alpha) |  | FLT_0D (uncertain) | - | Pulse probability overlap for recent plasma reaction
neutron_diagnostic.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
neutron_diagnostic.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
neutron_diagnostic.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
neutron_diagnostic.code.output_flag (alpha) | [neutron_diagnostic.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
neutron_diagnostic.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
neutron_diagnostic.code.repository (alpha) |  | STR_0D |  | URL of software repository
neutron_diagnostic.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
neutron_diagnostic.detectors (alpha) | [1...N] | STRUCT_ARRAY |  | Description of Detectors properties and Data in Neutron Diagnostic Module
neutron_diagnostic.detectors[:].index (alpha) |  | INT_0D |  | Number of Detector. TO BE REMOVED: the detector index is provided by the index of the detector array above.
neutron_diagnostic.detectors[:].mode (alpha) | [neutron_diagnostic.detectors[:].mode[:].index] | STRUCT_ARRAY |  | Measuring Mode Properties and Data
neutron_diagnostic.detectors[:].mode[:].counting (alpha) |  | STRUCTURE |  | Counting in Measuring Mode in Dynamic
neutron_diagnostic.detectors[:].mode[:].counting.data (alpha) | [neutron_diagnostic.time] | FLT_1D (uncertain) | cps | Counting in Measuring Mode in Dynamic
neutron_diagnostic.detectors[:].mode[:].counting.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
neutron_diagnostic.detectors[:].mode[:].index (alpha) |  | INT_0D |  | Index of Measuring Mode. TO BE REMOVED: the mode index is provided by the index of the mode array above.
neutron_diagnostic.detectors[:].mode[:].name (alpha) |  | STR_0D |  | Name of Measuring Mode
neutron_diagnostic.detectors[:].name (alpha) |  | STR_0D |  | Name of Detector
neutron_diagnostic.detectors[:].position (alpha) |  | STRUCTURE |  | Detector Position Data
neutron_diagnostic.detectors[:].position.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
neutron_diagnostic.detectors[:].position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
neutron_diagnostic.detectors[:].position.z (alpha) |  | FLT_0D (uncertain) | m | Height
neutron_diagnostic.detectors[:].radiation (alpha) | [neutron_diagnostic.detectors[:].radiation[:].index] | STRUCT_ARRAY |  | Radiation type on detector's converter (1 - 'neutrons'; 2 - 'gamma-rays')
neutron_diagnostic.detectors[:].radiation[:].converter_name (alpha) |  | STR_0D |  | Name of detector's converter for resent particle
neutron_diagnostic.detectors[:].radiation[:].converter_nuclear_density (alpha) |  | FLT_0D (uncertain) | m^-3 | Nuclear density of detector's converter for resent particle
neutron_diagnostic.detectors[:].radiation[:].converter_temperature (alpha) | [neutron_diagnostic.time] | FLT_1D (uncertain) | K | Temperature of detector's converter
neutron_diagnostic.detectors[:].radiation[:].converter_volume (alpha) |  | FLT_0D (uncertain) | m^3 | Volume of detector's converter for resent particle
neutron_diagnostic.detectors[:].radiation[:].index (alpha) |  | INT_0D |  | Index of radiation type
neutron_diagnostic.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
neutron_diagnostic.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
neutron_diagnostic.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
neutron_diagnostic.ids_properties.occurrence |  | INT_0D |  |
neutron_diagnostic.synthetic_signals (alpha) |  | STRUCTURE |  | Output Data from Neutron Diagnostic's Module
neutron_diagnostic.synthetic_signals.fusion_power (alpha) | [neutron_diagnostic.time] | FLT_1D (uncertain) | W | Fusion Power
neutron_diagnostic.synthetic_signals.total_neutron_flux (alpha) | [neutron_diagnostic.time] | FLT_1D (uncertain) | s^-1 | Total Neutron Flux in Dynamic
neutron_diagnostic.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
neutron_diagnostic.unit_source (alpha) | [1...N] | STRUCT_ARRAY |  | Unit ring sources description
neutron_diagnostic.unit_source[:].position (alpha) |  | STRUCTURE |  | Position of ring unit sources inside ITER vacuum vessel
neutron_diagnostic.unit_source[:].position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
neutron_diagnostic.unit_source[:].position.z (alpha) |  | FLT_0D (uncertain) | m | Height
neutron_diagnostic.unit_source[:].radiation (alpha) | [neutron_diagnostic.unit_source[:].radiation[:].index] | STRUCT_ARRAY |  | Radiation type on detector's converter (1 - 'neutrons'; 2 - 'gamma-rays')
neutron_diagnostic.unit_source[:].radiation[:].index (alpha) |  | INT_0D |  | Index of radiation type. TO BE REMOVED, since it is given by the index of the radiation array above.
neutron_diagnostic.unit_source[:].radiation[:].reaction (alpha) | [neutron_diagnostic.unit_source[:].radiation[:].reaction[:].index] | STRUCT_ARRAY |  | Plasma reaction (1 - 'DT'; 2 - 'DD')
neutron_diagnostic.unit_source[:].radiation[:].reaction[:].d2flux_drdz (alpha) | [1...N, neutron_diagnostic.unit_source[:].unit_source[:].energy] | FLT_2D (uncertain) | m^-4 | Second deriviation of Radiation flux from Unit Ring Source in recent detector's converter for "spline" reconstruction(1 - Number of Detector, 2 - Energy of particles)
neutron_diagnostic.unit_source[:].radiation[:].reaction[:].energy (alpha) | [1...N] | FLT_1D (uncertain) | eV | Energy boundaries for Detector Radiator Flux
neutron_diagnostic.unit_source[:].radiation[:].reaction[:].flux (alpha) | [1...N, neutron_diagnostic.unit_source[:].unit_source[:].energy] | FLT_2D (uncertain) | m^-2 | Radiation flux from Unit Ring Source in recent detector's converter (1 - Number of Detector, 2 - Energy of particles)
neutron_diagnostic.unit_source[:].radiation[:].reaction[:].index (alpha) |  | INT_0D |  | Index of plasma reaction type. To be removed, since it is given by the index of the reaction array above.
neutron_diagnostic.unit_source[:].radiation[:].reaction[:].reaction_rate (alpha) | [1...N, neutron_diagnostic.unit_source[:].unit_source[:].energy] | FLT_2D (uncertain) | m^-3 | Reaction Rate on converter's material from Unit Ring Source in recent detector's converter (1 - Number of Detector, 2 - Energy of particles)
neutron_diagnostic.unit_source[:].radiation[:].reaction[:].sensitivity (alpha) | [1...N, neutron_diagnostic.unit_source[:].unit_source[:].energy] | FLT_2D (uncertain) | cps.m^2.s | Sensitivity of converter's material in recent detector's converter (1 - Number of Detector, 2 - Energy of particles)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
ntms (alpha) |  |  |  | Description of neoclassical tearing modes
ntms.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
ntms.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
ntms.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
ntms.code.output_flag (alpha) | [ntms.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
ntms.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
ntms.code.repository (alpha) |  | STR_0D |  | URL of software repository
ntms.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
ntms.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
ntms.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
ntms.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
ntms.ids_properties.occurrence |  | INT_0D |  |
ntms.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
ntms.time_slice (alpha) | [ntms.time_slice[:].time] | STRUCT_ARRAY |  | Description of neoclassical tearing modes for various time slices
ntms.time_slice[:].mode (alpha) | [1...N] | STRUCT_ARRAY |  | List of the various NTM modes appearing during the simulation. If a mode appears several times, use several indices in this array of structure with the same m,n values.
ntms.time_slice[:].mode[:].calculation_method (alpha) |  | STR_0D |  | Description of how the mode evolution is calculated
ntms.time_slice[:].mode[:].delta_diff (alpha) | [1...3] | FLT_1D (uncertain) | m^2.s^-1 | Extra diffusion coefficient for the transport equations of Te, ne, Ti
ntms.time_slice[:].mode[:].deltaw (alpha) | [1...N] | STRUCT_ARRAY |  | deltaw contributions to the Rutherford equation
ntms.time_slice[:].mode[:].deltaw[:].name (alpha) |  | STR_0D |  | Name of the contribution
ntms.time_slice[:].mode[:].deltaw[:].value (alpha) |  | FLT_0D (uncertain) | m^-1 | Value of the contribution
ntms.time_slice[:].mode[:].detailed_evolution (alpha) |  | STRUCTURE |  | Detailed NTM evolution on a finer timebase than the time_slice array of structure
ntms.time_slice[:].mode[:].detailed_evolution.calculation_method (alpha) |  | STR_0D |  | Description of how the mode evolution is calculated
ntms.time_slice[:].mode[:].detailed_evolution.delta_diff (alpha) | [1...3, ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_2D (uncertain) | m^2.s^-1 | Extra diffusion coefficient for the transport equations of Te, ne, Ti
ntms.time_slice[:].mode[:].detailed_evolution.deltaw (alpha) | [1...N] | STRUCT_ARRAY |  | deltaw contributions to the Rutherford equation
ntms.time_slice[:].mode[:].detailed_evolution.deltaw[:].name (alpha) |  | STR_0D |  | Name of the contribution
ntms.time_slice[:].mode[:].detailed_evolution.deltaw[:].value (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | m^-1 | Value of the contribution
ntms.time_slice[:].mode[:].detailed_evolution.dfrequency_dt (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | s^-2 | Time derivative of the frequency of the mode
ntms.time_slice[:].mode[:].detailed_evolution.dphase_dt (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | rad/s | Time derivative of the phase of the mode
ntms.time_slice[:].mode[:].detailed_evolution.dwidth_dt (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | m/s | Time derivative of the full width of the mode
ntms.time_slice[:].mode[:].detailed_evolution.frequency (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | Hz | Frequency of the mode
ntms.time_slice[:].mode[:].detailed_evolution.m_pol (alpha) |  | INT_0D |  | Poloidal mode number
ntms.time_slice[:].mode[:].detailed_evolution.n_tor (alpha) |  | INT_0D |  | Toroidal mode number
ntms.time_slice[:].mode[:].detailed_evolution.phase (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | rad | Phase of the mode
ntms.time_slice[:].mode[:].detailed_evolution.rho_tor (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | m | Flux coordinate on which the mode is centred
ntms.time_slice[:].mode[:].detailed_evolution.rho_tor_norm (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | - | Normalised flux coordinate on which the mode is centred
ntms.time_slice[:].mode[:].detailed_evolution.time_detailed (alpha) | [1...N] | FLT_1D (uncertain) | s | Time array used to describe the detailed evolution of the NTM
ntms.time_slice[:].mode[:].detailed_evolution.torque (alpha) | [1...N] | STRUCT_ARRAY |  | torque contributions to the Rutherford equation
ntms.time_slice[:].mode[:].detailed_evolution.torque[:].name (alpha) |  | STR_0D |  | Name of the contribution
ntms.time_slice[:].mode[:].detailed_evolution.torque[:].value (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | kg.m^2.s^-2 | Value of the contribution
ntms.time_slice[:].mode[:].detailed_evolution.width (alpha) | [ntms.time_slice[:].mode[:].detailed_evolution.time_detailed] | FLT_1D (uncertain) | m | Full width of the mode
ntms.time_slice[:].mode[:].dfrequency_dt (alpha) |  | FLT_0D (uncertain) | s^-2 | Time derivative of the frequency of the mode
ntms.time_slice[:].mode[:].dphase_dt (alpha) |  | FLT_0D (uncertain) | rad/s | Time derivative of the phase of the mode
ntms.time_slice[:].mode[:].dwidth_dt (alpha) |  | FLT_0D (uncertain) | m/s | Time derivative of the full width of the mode
ntms.time_slice[:].mode[:].frequency (alpha) |  | FLT_0D (uncertain) | Hz | Frequency of the mode
ntms.time_slice[:].mode[:].m_pol (alpha) |  | INT_0D |  | Poloidal mode number
ntms.time_slice[:].mode[:].n_tor (alpha) |  | INT_0D |  | Toroidal mode number
ntms.time_slice[:].mode[:].onset (alpha) |  | STRUCTURE |  | NTM onset characteristics
ntms.time_slice[:].mode[:].onset.cause (alpha) |  | STR_0D |  | Cause of the mode onset
ntms.time_slice[:].mode[:].onset.m_pol (alpha) |  | INT_0D |  | Poloidal mode number
ntms.time_slice[:].mode[:].onset.n_tor (alpha) |  | INT_0D |  | Toroidal mode number
ntms.time_slice[:].mode[:].onset.phase (alpha) |  | FLT_0D (uncertain) | rad | Phase of the mode at onset
ntms.time_slice[:].mode[:].onset.time_offset (alpha) |  | FLT_0D (uncertain) | s | Offset time (when a mode disappears). If the mode reappears later in the simulation, use another index of the mode array of structure
ntms.time_slice[:].mode[:].onset.time_onset (alpha) |  | FLT_0D (uncertain) | s | Onset time
ntms.time_slice[:].mode[:].onset.width (alpha) |  | FLT_0D (uncertain) | m | Seed island full width at onset time
ntms.time_slice[:].mode[:].phase (alpha) |  | FLT_0D (uncertain) | rad | Phase of the mode
ntms.time_slice[:].mode[:].rho_tor (alpha) |  | FLT_0D (uncertain) | m | Flux coordinate on which the mode is centred
ntms.time_slice[:].mode[:].rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Normalised flux coordinate on which the mode is centred
ntms.time_slice[:].mode[:].torque (alpha) | [1...N] | STRUCT_ARRAY |  | torque contributions to the Rutherford equation
ntms.time_slice[:].mode[:].torque[:].name (alpha) |  | STR_0D |  | Name of the contribution
ntms.time_slice[:].mode[:].torque[:].value (alpha) |  | FLT_0D (uncertain) | kg.m^2.s^-2 | Value of the contribution
ntms.time_slice[:].mode[:].width (alpha) |  | FLT_0D (uncertain) | m | Full width of the mode
ntms.time_slice[:].time (alpha) |  | FLT_0D | s | Time
ntms.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition)
ntms.vacuum_toroidal_field.b0 (alpha) | [ntms.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewed from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
ntms.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
pellets (alpha) |  |  |  | Description of pellets launched into the plasma
pellets.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
pellets.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
pellets.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
pellets.code.output_flag (alpha) | [pellets.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
pellets.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
pellets.code.repository (alpha) |  | STR_0D |  | URL of software repository
pellets.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
pellets.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
pellets.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
pellets.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
pellets.ids_properties.occurrence |  | INT_0D |  |
pellets.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pellets.time_slice (alpha) | [pellets.time_slice[:].time] | STRUCT_ARRAY |  | Description of the pellets launched at various time slices. The time of this structure corresponds to the full ablation of the pellet inside the plasma.
pellets.time_slice[:].pellet (alpha) | [1...N] | STRUCT_ARRAY |  | Set of pellets ablated in the plasma at a given time
pellets.time_slice[:].pellet[:].path_geometry (alpha) |  | STRUCTURE |  | Geometry of the pellet path in the vaccuum chamber
pellets.time_slice[:].pellet[:].path_geometry.first_point (alpha) |  | STRUCTURE |  | Position of the first point
pellets.time_slice[:].pellet[:].path_geometry.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
pellets.time_slice[:].pellet[:].path_geometry.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
pellets.time_slice[:].pellet[:].path_geometry.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
pellets.time_slice[:].pellet[:].path_geometry.second_point (alpha) |  | STRUCTURE |  | Position of the second point
pellets.time_slice[:].pellet[:].path_geometry.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
pellets.time_slice[:].pellet[:].path_geometry.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
pellets.time_slice[:].pellet[:].path_geometry.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
pellets.time_slice[:].pellet[:].path_profiles (alpha) |  | STRUCTURE |  | 1-D profiles of plasma and pellet along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.ablated_particles (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | - | Number of ablated particles (electrons) along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.ablation_rate (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | s^-1 | Ablation rate (electrons) along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.distance (alpha) | [1...N] | FLT_1D (uncertain) | m | Distance along the pellet path, with the origin taken at path_geometry/first_point. Used as the main coordinate for the path_profiles structure
pellets.time_slice[:].pellet[:].path_profiles.n_e (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | m^-3 | Electron density along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.position (alpha) |  | STRUCTURE |  | Position along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.position.phi (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.position.r] | FLT_1D (uncertain) | rad | Toroidal angle
pellets.time_slice[:].pellet[:].path_profiles.position.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
pellets.time_slice[:].pellet[:].path_profiles.position.z (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.position.r] | FLT_1D (uncertain) | m | Height
pellets.time_slice[:].pellet[:].path_profiles.psi (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | Wb | Poloidal flux along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.rho_tor_norm (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | - | Normalised toroidal coordinate along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.rho_tor_norm_drift (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | - | Difference to due ExB drifts between the ablation and the final deposition locations, in terms of the normalised toroidal flux coordinate
pellets.time_slice[:].pellet[:].path_profiles.t_e (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | eV | Electron temperature along the pellet path
pellets.time_slice[:].pellet[:].path_profiles.velocity (alpha) | [pellets.time_slice[:].pellet[:].path_profiles.distance] | FLT_1D (uncertain) | m.s^-1 | Pellet velocity along the pellet path
pellets.time_slice[:].pellet[:].shape (alpha) |  | STRUCTURE |  | Initial shape of a pellet at launch
pellets.time_slice[:].pellet[:].shape.size (alpha) | [1...N] | FLT_1D (uncertain) | m | Size of the pellet in the various dimensions, depending on the shape type. Spherical pellets: size(1) is the radius of the pellet. Cylindrical pellets: size(1) is the radius and size(2) is the height of the cylinder. Rectangular pellets: size(1) is the height, size(2) is the width and size(3) is the length
pellets.time_slice[:].pellet[:].shape.type (alpha) |  | STRUCTURE |  | Identifier structure for the shape type: 1-spherical; 2-cylindrical; 3-rectangular
pellets.time_slice[:].pellet[:].shape.type.description (alpha) |  | STR_0D |  | Verbose description
pellets.time_slice[:].pellet[:].shape.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
pellets.time_slice[:].pellet[:].shape.type.name (alpha) |  | STR_0D |  | Short string identifier
pellets.time_slice[:].pellet[:].species (alpha) | [1...N] | STRUCT_ARRAY |  | Set of species included in the pellet composition
pellets.time_slice[:].pellet[:].species[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
pellets.time_slice[:].pellet[:].species[:].density (alpha) |  | FLT_0D (uncertain) | - | Material density of the species in the pellet
pellets.time_slice[:].pellet[:].species[:].fraction (alpha) |  | FLT_0D (uncertain) | - | Fraction of the species atoms in the pellet
pellets.time_slice[:].pellet[:].species[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H, D, T, ...)
pellets.time_slice[:].pellet[:].species[:].sublimation_energy (alpha) |  | FLT_0D (uncertain) | eV | Sublimation energy per atom
pellets.time_slice[:].pellet[:].species[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
pellets.time_slice[:].pellet[:].velocity_initial (alpha) |  | FLT_0D (uncertain) | m.s^-1 | Initial velocity of the pellet as it enters the vaccum chamber
pellets.time_slice[:].time (alpha) |  | FLT_0D | s | Time

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
pf_active (alpha) |  |  |  | Description of the axisymmetric active poloidal field (PF) coils and supplies; includes the limits of these systems; includes the forces on them; does not include non-axisymmetric coil systems
pf_active.circuit (alpha) | [1...N] | STRUCT_ARRAY |  | Circuits, connecting multiple PF coils to multiple supplies, defining the current and voltage relationships in the system
pf_active.circuit[:].connections (alpha) | [1...N, 1...N] | INT_2D |  | Description of the supplies and coils connections (nodes) across the circuit. Nodes of the circuit are listed as the first dimension of the matrix. Supplies (listed first) and coils (listed second) SIDES are listed as the second dimension. Thus the second dimension has a size equal to 2*(N_supplies+N_coils). The (i,j) matrix elements are 1 if the j-th supply or coil side is connected to the i-th node, or 0 otherwise.
pf_active.circuit[:].current (alpha) |  | STRUCTURE |  | Current in the circuit
pf_active.circuit[:].current.data (alpha) | [pf_active.circuit[:].current.time] | FLT_1D (uncertain) | V | Current in the circuit
pf_active.circuit[:].current.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pf_active.circuit[:].identifier (alpha) |  | STR_0D |  | ID of the circuit
pf_active.circuit[:].name (alpha) |  | STR_0D |  | Name of the circuit
pf_active.circuit[:].type (alpha) |  | STR_0D |  | Type of the circuit
pf_active.circuit[:].voltage (alpha) |  | STRUCTURE |  | Voltage on the circuit
pf_active.circuit[:].voltage.data (alpha) | [pf_active.circuit[:].voltage.time] | FLT_1D (uncertain) | V | Voltage on the circuit
pf_active.circuit[:].voltage.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pf_active.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
pf_active.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
pf_active.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
pf_active.code.output_flag (alpha) | [pf_active.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
pf_active.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
pf_active.code.repository (alpha) |  | STR_0D |  | URL of software repository
pf_active.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
pf_active.coil (alpha) | [1...N] | STRUCT_ARRAY |  | Active PF coils
pf_active.coil[:].current (alpha) |  | STRUCTURE |  | Current in the coil
pf_active.coil[:].current.data (alpha) | [pf_active.coil[:].current.time] | FLT_1D (uncertain) | A | Current in the coil
pf_active.coil[:].current.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pf_active.coil[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Each PF coil is comprised of a number of cross-section elements described individually
pf_active.coil[:].element[:].area (alpha) |  | FLT_0D (uncertain) | m^2 | Cross-sectional areas of the element
pf_active.coil[:].element[:].geometry (alpha) |  | STRUCTURE |  | Cross-sectional shape of the element
pf_active.coil[:].element[:].geometry.geometry_type (alpha) |  | INT_0D |  | Type used to describe the element shape (1:'outline', 2:'rectangle', 3:'oblique')
pf_active.coil[:].element[:].geometry.oblique (alpha) |  | STRUCTURE |  | Trapezoidal description of the element
pf_active.coil[:].element[:].geometry.oblique.alpha (alpha) |  | FLT_0D (uncertain) | m | Inclination of first angle TBD
pf_active.coil[:].element[:].geometry.oblique.beta (alpha) |  | FLT_0D (uncertain) | m | Inclination of second angle TBD
pf_active.coil[:].element[:].geometry.oblique.length (alpha) |  | FLT_0D (uncertain) | m | Length
pf_active.coil[:].element[:].geometry.oblique.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
pf_active.coil[:].element[:].geometry.oblique.thickness (alpha) |  | FLT_0D (uncertain) | m | Thickness
pf_active.coil[:].element[:].geometry.oblique.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
pf_active.coil[:].element[:].geometry.outline (alpha) |  | STRUCTURE |  | Irregular outline of the element
pf_active.coil[:].element[:].geometry.outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
pf_active.coil[:].element[:].geometry.outline.z (alpha) | [pf_active.coil[:].element[:].geometry.outline.r] | FLT_1D (uncertain) | m | Height
pf_active.coil[:].element[:].geometry.rectangle (alpha) |  | STRUCTURE |  | Rectangular description of the element
pf_active.coil[:].element[:].geometry.rectangle.height (alpha) |  | FLT_0D (uncertain) | m | Vertical full height
pf_active.coil[:].element[:].geometry.rectangle.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
pf_active.coil[:].element[:].geometry.rectangle.width (alpha) |  | FLT_0D (uncertain) | m | Horizontal full width
pf_active.coil[:].element[:].geometry.rectangle.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
pf_active.coil[:].element[:].identifier (alpha) |  | STR_0D |  | Identifier of this element of this coil
pf_active.coil[:].element[:].name (alpha) |  | STR_0D |  | Name of this element of this coil
pf_active.coil[:].element[:].turns_with_sign (alpha) |  | INT_0D |  | Number of effective turns in the element for calculating magnetic fields of the coil; includes the sign of the number of turns
pf_active.coil[:].energy_limit_max (alpha) |  | FLT_0D (uncertain) | J | Maximum Energy to be dissipated in the coil
pf_active.coil[:].identifier (alpha) |  | STR_0D |  | Alphanumeric identifier of coils used for convenience
pf_active.coil[:].name (alpha) |  | STR_0D |  | Name of the coil
pf_active.coil[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | Coil resistance
pf_active.coil[:].voltage (alpha) |  | STRUCTURE |  | Voltage on the coil terminals
pf_active.coil[:].voltage.data (alpha) | [pf_active.coil[:].voltage.time] | FLT_1D (uncertain) | V | Voltage on the coil terminals
pf_active.coil[:].voltage.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pf_active.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
pf_active.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
pf_active.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
pf_active.ids_properties.occurrence |  | INT_0D |  |
pf_active.supply (alpha) | [1...N] | STRUCT_ARRAY |  | PF power supplies
pf_active.supply[:].current (alpha) |  | STRUCTURE |  | Current at the supply output, defined positive if it flows from point 1 to point 2 of the component in the pfcircuit description
pf_active.supply[:].current.data (alpha) | [pf_active.supply[:].current.time] | FLT_1D (uncertain) | A | Current at the supply output, defined positive if it flows from point 1 to point 2 of the component in the pfcircuit description
pf_active.supply[:].current.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pf_active.supply[:].current_limit_max (alpha) |  | FLT_0D (uncertain) | A | Maximum current in the supply
pf_active.supply[:].current_limit_min (alpha) |  | FLT_0D (uncertain) | A | Minimum current in the supply
pf_active.supply[:].current_limiter_gain (alpha) |  | FLT_0D (uncertain) | V | Gain to prevent overcurrent in a linear model of the supply
pf_active.supply[:].delay (alpha) |  | FLT_0D (uncertain) | s | Pure delay in the supply
pf_active.supply[:].energy_limit_max (alpha) |  | FLT_0D (uncertain) | J | Maximum energy to be dissipated in the supply during a pulse
pf_active.supply[:].filter_denominator (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Coefficients of the denominator, in increasing order : b0 + b1*s + ... + bm*s^m; used for a linear supply description
pf_active.supply[:].filter_numerator (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Coefficients of the numerator, in increasing order : a0 + a1*s + ... + an*s^n; used for a linear supply description
pf_active.supply[:].identifier (alpha) |  | STR_0D |  | Identifier of the supply
pf_active.supply[:].name (alpha) |  | STR_0D |  | Name of the PF supply
pf_active.supply[:].nonlinear_model (alpha) |  | STR_0D |  | Description of the nonlinear transfer function of the supply
pf_active.supply[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | Power supply internal resistance
pf_active.supply[:].type (alpha) |  | INT_0D |  | Type of the supply; TBD add free description of non-linear power supplies
pf_active.supply[:].voltage (alpha) |  | STRUCTURE |  | Voltage at the supply output
pf_active.supply[:].voltage.data (alpha) | [pf_active.supply[:].voltage.time] | FLT_1D (uncertain) | V | Voltage at the supply output
pf_active.supply[:].voltage.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pf_active.supply[:].voltage_limit_max (alpha) |  | FLT_0D (uncertain) | V | Maximum voltage from the supply
pf_active.supply[:].voltage_limit_min (alpha) |  | FLT_0D (uncertain) | V | Minimum voltage from the supply
pf_active.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pf_active.vertical_force (alpha) | [1...N] | STRUCT_ARRAY |  | Vertical forces on the axisymmetric PF coil system
pf_active.vertical_force[:].combination (alpha) | [1...N] | FLT_1D (uncertain) | - | Coils involved in the force combinations. Normally the vertical force would be the full set of coils, but in some cases, we want to have a difference in forces, such as a CS coil separation force. We therefore give each coil a force weight which we call the combination
pf_active.vertical_force[:].force (alpha) |  | STRUCTURE |  | Force
pf_active.vertical_force[:].force.data (alpha) | [pf_active.vertical_force[:].force.time] | FLT_1D (uncertain) | N | Force
pf_active.vertical_force[:].force.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pf_active.vertical_force[:].limit_max (alpha) |  | FLT_0D (uncertain) | N | Vertical force combination limit
pf_active.vertical_force[:].limit_min (alpha) |  | FLT_0D (uncertain) | N | Vertical force combination limit
pf_active.vertical_force[:].name (alpha) |  | STR_0D |  | Name of the force combination

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
pf_passive (alpha) |  |  |  | Description of the axisymmetric passive conductors, currents flowing in them
pf_passive.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
pf_passive.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
pf_passive.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
pf_passive.code.output_flag (alpha) | [pf_passive.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
pf_passive.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
pf_passive.code.repository (alpha) |  | STR_0D |  | URL of software repository
pf_passive.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
pf_passive.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
pf_passive.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
pf_passive.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
pf_passive.ids_properties.occurrence |  | INT_0D |  |
pf_passive.loop (alpha) | [1...N] | STRUCT_ARRAY |  | Passive axisymmetric conductor description in the form of non-connected loops; any connected loops are expressed as active coil circuits with no power supply attached.
pf_passive.loop[:].area (alpha) |  | FLT_0D (uncertain) | m^2 | Surface area of the passive loop
pf_passive.loop[:].current (alpha) | [pf_passive.time] | FLT_1D (uncertain) | A | Passive loop current
pf_passive.loop[:].geometry (alpha) |  | STRUCTURE |  | Shape of the passive loop
pf_passive.loop[:].geometry.geometry_type (alpha) |  | INT_0D |  | Type used to describe the element shape (1:'outline', 2:'rectangle', 3:'oblique')
pf_passive.loop[:].geometry.oblique (alpha) |  | STRUCTURE |  | Trapezoidal description of the element
pf_passive.loop[:].geometry.oblique.alpha (alpha) |  | FLT_0D (uncertain) | m | Inclination of first angle TBD
pf_passive.loop[:].geometry.oblique.beta (alpha) |  | FLT_0D (uncertain) | m | Inclination of second angle TBD
pf_passive.loop[:].geometry.oblique.length (alpha) |  | FLT_0D (uncertain) | m | Length
pf_passive.loop[:].geometry.oblique.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
pf_passive.loop[:].geometry.oblique.thickness (alpha) |  | FLT_0D (uncertain) | m | Thickness
pf_passive.loop[:].geometry.oblique.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
pf_passive.loop[:].geometry.outline (alpha) |  | STRUCTURE |  | Irregular outline of the element
pf_passive.loop[:].geometry.outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
pf_passive.loop[:].geometry.outline.z (alpha) | [pf_passive.loop[:].geometry.outline.r] | FLT_1D (uncertain) | m | Height
pf_passive.loop[:].geometry.rectangle (alpha) |  | STRUCTURE |  | Rectangular description of the element
pf_passive.loop[:].geometry.rectangle.height (alpha) |  | FLT_0D (uncertain) | m | Vertical full height
pf_passive.loop[:].geometry.rectangle.r (alpha) |  | FLT_0D (uncertain) | m | Geometric centre R
pf_passive.loop[:].geometry.rectangle.width (alpha) |  | FLT_0D (uncertain) | m | Horizontal full width
pf_passive.loop[:].geometry.rectangle.z (alpha) |  | FLT_0D (uncertain) | m | Geometric centre Z
pf_passive.loop[:].name (alpha) |  | STR_0D |  | Name of the loop
pf_passive.loop[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | Passive loop resistance
pf_passive.loop[:].resistivity (alpha) |  | FLT_0D (uncertain) | Ohm.m | Passive loop resistivity
pf_passive.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
pulse_schedule (alpha) |  |  |  | Description of Pulse Schedule, described by subsystems waveform references and an enveloppe aounrd them. The controllers, pulse schedule and SDN are defined separately
pulse_schedule.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
pulse_schedule.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
pulse_schedule.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
pulse_schedule.code.output_flag (alpha) | [pulse_schedule.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
pulse_schedule.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
pulse_schedule.code.repository (alpha) |  | STR_0D |  | URL of software repository
pulse_schedule.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
pulse_schedule.density_control (alpha) |  | STRUCTURE |  | Gas injection system and density control references
pulse_schedule.density_control.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.density_control.mode.data (alpha) | [pulse_schedule.density_control.mode.time] | INT_1D |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.density_control.mode.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.density_control.n_e_line (alpha) |  | STRUCTURE | m^-2 | Line integrated electron density
pulse_schedule.density_control.n_e_line.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.density_control.n_e_line.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.density_control.n_e_line.reference.data (alpha) | [pulse_schedule.density_control.n_e_line.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.density_control.n_e_line.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.density_control.n_e_line.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.density_control.n_e_line.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.density_control.n_h_over_n_d (alpha) |  | STRUCTURE | - | Average ratio of hydrogen over deuterium density
pulse_schedule.density_control.n_h_over_n_d.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.density_control.n_h_over_n_d.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.density_control.n_h_over_n_d.reference.data (alpha) | [pulse_schedule.density_control.n_h_over_n_d.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.density_control.n_h_over_n_d.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.density_control.n_h_over_n_d.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.density_control.n_h_over_n_d.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.density_control.n_t_over_n_d (alpha) |  | STRUCTURE | - | Average ratio of tritium over deuterium density
pulse_schedule.density_control.n_t_over_n_d.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.density_control.n_t_over_n_d.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.density_control.n_t_over_n_d.reference.data (alpha) | [pulse_schedule.density_control.n_t_over_n_d.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.density_control.n_t_over_n_d.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.density_control.n_t_over_n_d.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.density_control.n_t_over_n_d.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.density_control.valve (alpha) | [1...N] | STRUCT_ARRAY |  | Set of injection valves. Time-dependent
pulse_schedule.density_control.valve[:].flow_rate (alpha) |  | STRUCTURE | Pa.m^3.s^-1 | Flow rate of the valve
pulse_schedule.density_control.valve[:].flow_rate.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.density_control.valve[:].flow_rate.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.density_control.valve[:].flow_rate.reference.data (alpha) | [pulse_schedule.density_control.valve[:].flow_rate.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.density_control.valve[:].flow_rate.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.density_control.valve[:].flow_rate.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.density_control.valve[:].flow_rate.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.density_control.valve[:].species (alpha) | [1...N] | STRUCT_ARRAY |  | Species injected by the valve (may be more than one in case the valve injects a gas mixture)
pulse_schedule.density_control.valve[:].species[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
pulse_schedule.density_control.valve[:].species[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
pulse_schedule.density_control.valve[:].species[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
pulse_schedule.density_control.valve[:].species[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
pulse_schedule.density_control.valve[:].species[:].fraction (alpha) |  | INT_0D |  | Relative fraction of this species (in molecules) in the gas mixture
pulse_schedule.density_control.valve[:].species[:].label (alpha) |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
pulse_schedule.density_control.zeff (alpha) |  | STRUCTURE | - | Line average effective charge
pulse_schedule.density_control.zeff.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.density_control.zeff.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.density_control.zeff.reference.data (alpha) | [pulse_schedule.density_control.zeff.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.density_control.zeff.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.density_control.zeff.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.density_control.zeff.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ec (alpha) |  | STRUCTURE |  | Electron cyclotron heating and current drive system
pulse_schedule.ec.antenna (alpha) | [1...N] | STRUCT_ARRAY |  | Set of ECRH antennas
pulse_schedule.ec.antenna[:].deposition_rho_tor_norm (alpha) |  | STRUCTURE | - | Normalised toroidal flux coordinate at which the main deposition should occur
pulse_schedule.ec.antenna[:].deposition_rho_tor_norm.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ec.antenna[:].deposition_rho_tor_norm.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.ec.antenna[:].deposition_rho_tor_norm.reference.data (alpha) | [pulse_schedule.ec.antenna[:].deposition_rho_tor_norm.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.ec.antenna[:].deposition_rho_tor_norm.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.ec.antenna[:].deposition_rho_tor_norm.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ec.antenna[:].deposition_rho_tor_norm.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ec.antenna[:].frequency (alpha) |  | STRUCTURE | Hz | Frequency
pulse_schedule.ec.antenna[:].frequency.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ec.antenna[:].frequency.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.ec.antenna[:].frequency.reference.data (alpha) | [pulse_schedule.ec.antenna[:].frequency.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.ec.antenna[:].frequency.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.ec.antenna[:].frequency.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ec.antenna[:].frequency.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ec.antenna[:].launching_angle_pol (alpha) |  | STRUCTURE | rad | Poloidal launching angle between the horizontal plane and the poloidal component of the nominal beam centerline. tan(angle_pol)=-k_z/k_R. Positive means wave launched downwards, negative means wave launched upwards
pulse_schedule.ec.antenna[:].launching_angle_pol.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ec.antenna[:].launching_angle_pol.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.ec.antenna[:].launching_angle_pol.reference.data (alpha) | [pulse_schedule.ec.antenna[:].launching_angle_pol.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.ec.antenna[:].launching_angle_pol.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.ec.antenna[:].launching_angle_pol.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ec.antenna[:].launching_angle_pol.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ec.antenna[:].launching_angle_tor (alpha) |  | STRUCTURE | rad | Toroidal launching angle between the poloidal plane and the nominal beam centerline. sin(angle_tor)=k_phi. Positive sign means the waves is injected anti-clockwise when viewed from above.
pulse_schedule.ec.antenna[:].launching_angle_tor.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ec.antenna[:].launching_angle_tor.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.ec.antenna[:].launching_angle_tor.reference.data (alpha) | [pulse_schedule.ec.antenna[:].launching_angle_tor.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.ec.antenna[:].launching_angle_tor.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.ec.antenna[:].launching_angle_tor.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ec.antenna[:].launching_angle_tor.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ec.antenna[:].phase (alpha) |  | STRUCTURE | rad | Phase
pulse_schedule.ec.antenna[:].phase.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ec.antenna[:].phase.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.ec.antenna[:].phase.reference.data (alpha) | [pulse_schedule.ec.antenna[:].phase.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.ec.antenna[:].phase.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.ec.antenna[:].phase.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ec.antenna[:].phase.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ec.antenna[:].power (alpha) |  | STRUCTURE | W | Power
pulse_schedule.ec.antenna[:].power.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ec.antenna[:].power.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.ec.antenna[:].power.reference.data (alpha) | [pulse_schedule.ec.antenna[:].power.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.ec.antenna[:].power.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.ec.antenna[:].power.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ec.antenna[:].power.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ec.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.ec.mode.data (alpha) | [pulse_schedule.ec.mode.time] | INT_1D |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.ec.mode.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.flux_control (alpha) |  | STRUCTURE |  | Magnetic flux control references
pulse_schedule.flux_control.beta_normal (alpha) |  | STRUCTURE | - | Normalised toroidal beta, defined as 100 * beta_tor * a[m] * B0 [T] / ip [MA]
pulse_schedule.flux_control.beta_normal.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.flux_control.beta_normal.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.flux_control.beta_normal.reference.data (alpha) | [pulse_schedule.flux_control.beta_normal.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.flux_control.beta_normal.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.flux_control.beta_normal.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.flux_control.beta_normal.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.flux_control.i_plasma (alpha) |  | STRUCTURE | A | Plasma current
pulse_schedule.flux_control.i_plasma.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.flux_control.i_plasma.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.flux_control.i_plasma.reference.data (alpha) | [pulse_schedule.flux_control.i_plasma.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.flux_control.i_plasma.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.flux_control.i_plasma.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.flux_control.i_plasma.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.flux_control.li_3 (alpha) |  | STRUCTURE | - | Internal inductance
pulse_schedule.flux_control.li_3.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.flux_control.li_3.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.flux_control.li_3.reference.data (alpha) | [pulse_schedule.flux_control.li_3.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.flux_control.li_3.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.flux_control.li_3.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.flux_control.li_3.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.flux_control.loop_voltage (alpha) |  | STRUCTURE | V | Loop voltage
pulse_schedule.flux_control.loop_voltage.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.flux_control.loop_voltage.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.flux_control.loop_voltage.reference.data (alpha) | [pulse_schedule.flux_control.loop_voltage.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.flux_control.loop_voltage.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.flux_control.loop_voltage.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.flux_control.loop_voltage.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.flux_control.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.flux_control.mode.data (alpha) | [pulse_schedule.flux_control.mode.time] | INT_1D |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.flux_control.mode.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.ic (alpha) |  | STRUCTURE |  | Ion cyclotron heating and current drive system
pulse_schedule.ic.antenna (alpha) | [1...N] | STRUCT_ARRAY |  | Set of ICRH antennas
pulse_schedule.ic.antenna[:].frequency (alpha) |  | STRUCTURE | Hz | Frequency
pulse_schedule.ic.antenna[:].frequency.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ic.antenna[:].frequency.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.ic.antenna[:].frequency.reference.data (alpha) | [pulse_schedule.ic.antenna[:].frequency.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.ic.antenna[:].frequency.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.ic.antenna[:].frequency.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ic.antenna[:].frequency.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ic.antenna[:].phase (alpha) |  | STRUCTURE | rad | Phase
pulse_schedule.ic.antenna[:].phase.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ic.antenna[:].phase.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.ic.antenna[:].phase.reference.data (alpha) | [pulse_schedule.ic.antenna[:].phase.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.ic.antenna[:].phase.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.ic.antenna[:].phase.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ic.antenna[:].phase.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ic.antenna[:].power (alpha) |  | STRUCTURE | W | Power
pulse_schedule.ic.antenna[:].power.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.ic.antenna[:].power.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.ic.antenna[:].power.reference.data (alpha) | [pulse_schedule.ic.antenna[:].power.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.ic.antenna[:].power.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.ic.antenna[:].power.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.ic.antenna[:].power.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.ic.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.ic.mode.data (alpha) | [pulse_schedule.ic.mode.time] | INT_1D |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.ic.mode.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
pulse_schedule.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
pulse_schedule.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
pulse_schedule.ids_properties.occurrence |  | INT_0D |  |
pulse_schedule.lh (alpha) |  | STRUCTURE |  | Lower Hybrid heating and current drive system
pulse_schedule.lh.antenna (alpha) | [1...N] | STRUCT_ARRAY |  | Set of LH antennas
pulse_schedule.lh.antenna[:].frequency (alpha) |  | STRUCTURE | Hz | Frequency
pulse_schedule.lh.antenna[:].frequency.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.lh.antenna[:].frequency.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.lh.antenna[:].frequency.reference.data (alpha) | [pulse_schedule.lh.antenna[:].frequency.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.lh.antenna[:].frequency.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.lh.antenna[:].frequency.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.lh.antenna[:].frequency.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.lh.antenna[:].n_parallel (alpha) |  | STRUCTURE | - | Main parallel refractive index of the injected wave power spectrum
pulse_schedule.lh.antenna[:].n_parallel.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.lh.antenna[:].n_parallel.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.lh.antenna[:].n_parallel.reference.data (alpha) | [pulse_schedule.lh.antenna[:].n_parallel.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.lh.antenna[:].n_parallel.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.lh.antenna[:].n_parallel.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.lh.antenna[:].n_parallel.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.lh.antenna[:].phase (alpha) |  | STRUCTURE | rad | Phasing between neighbour waveguides (in the toroidal direction)
pulse_schedule.lh.antenna[:].phase.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.lh.antenna[:].phase.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.lh.antenna[:].phase.reference.data (alpha) | [pulse_schedule.lh.antenna[:].phase.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.lh.antenna[:].phase.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.lh.antenna[:].phase.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.lh.antenna[:].phase.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.lh.antenna[:].power (alpha) |  | STRUCTURE | W | Power
pulse_schedule.lh.antenna[:].power.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.lh.antenna[:].power.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.lh.antenna[:].power.reference.data (alpha) | [pulse_schedule.lh.antenna[:].power.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.lh.antenna[:].power.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.lh.antenna[:].power.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.lh.antenna[:].power.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.lh.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.lh.mode.data (alpha) | [pulse_schedule.lh.mode.time] | INT_1D |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.lh.mode.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.nbi (alpha) |  | STRUCTURE |  | Neutral beam heating and current drive system
pulse_schedule.nbi.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.nbi.mode.data (alpha) | [pulse_schedule.nbi.mode.time] | INT_1D |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.nbi.mode.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.nbi.unit (alpha) | [1...N] | STRUCT_ARRAY |  | Set of NBI units
pulse_schedule.nbi.unit[:].energy (alpha) |  | STRUCTURE | eV | Full energy of the injected species (acceleration of a single atom)
pulse_schedule.nbi.unit[:].energy.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.nbi.unit[:].energy.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.nbi.unit[:].energy.reference.data (alpha) | [pulse_schedule.nbi.unit[:].energy.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.nbi.unit[:].energy.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.nbi.unit[:].energy.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.nbi.unit[:].energy.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.nbi.unit[:].power (alpha) |  | STRUCTURE | W | Power
pulse_schedule.nbi.unit[:].power.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.nbi.unit[:].power.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.nbi.unit[:].power.reference.data (alpha) | [pulse_schedule.nbi.unit[:].power.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.nbi.unit[:].power.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.nbi.unit[:].power.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.nbi.unit[:].power.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.nbi.unit[:].species (alpha) | [1...N] | STRUCT_ARRAY |  | Species injected by the NBI unit (may be more than one in case the unit injects a gas mixture)
pulse_schedule.nbi.unit[:].species[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
pulse_schedule.nbi.unit[:].species[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
pulse_schedule.nbi.unit[:].species[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
pulse_schedule.nbi.unit[:].species[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
pulse_schedule.nbi.unit[:].species[:].fraction (alpha) |  | INT_0D |  | Relative fraction of this species (in molecules) in the gas mixture
pulse_schedule.nbi.unit[:].species[:].label (alpha) |  | STR_0D |  | String identifying neutral (e.g. H, D, T, He, C, ...)
pulse_schedule.position_control (alpha) |  | STRUCTURE |  | Plasma position and shape control references
pulse_schedule.position_control.active_limiter_point (alpha) |  | STRUCTURE |  | RZ position of the active limiter point (point of the plasma boundary in contact with the limiter)
pulse_schedule.position_control.active_limiter_point.r (alpha) |  | STRUCTURE | m | Major radius
pulse_schedule.position_control.active_limiter_point.r.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.active_limiter_point.r.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.active_limiter_point.r.reference.data (alpha) | [pulse_schedule.position_control.active_limiter_point.r.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.active_limiter_point.r.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.active_limiter_point.r.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.active_limiter_point.r.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.active_limiter_point.z (alpha) |  | STRUCTURE | m | Height
pulse_schedule.position_control.active_limiter_point.z.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.active_limiter_point.z.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.active_limiter_point.z.reference.data (alpha) | [pulse_schedule.position_control.active_limiter_point.z.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.active_limiter_point.z.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.active_limiter_point.z.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.active_limiter_point.z.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.boundary_outline (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (R,Z) points defining the outline of the plasma boundary
pulse_schedule.position_control.boundary_outline[:].r (alpha) |  | STRUCTURE | m | Major radius
pulse_schedule.position_control.boundary_outline[:].r.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.boundary_outline[:].r.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.boundary_outline[:].r.reference.data (alpha) | [pulse_schedule.position_control.boundary_outline[:].r.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.boundary_outline[:].r.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.boundary_outline[:].r.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.boundary_outline[:].r.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.boundary_outline[:].z (alpha) |  | STRUCTURE | m | Height
pulse_schedule.position_control.boundary_outline[:].z.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.boundary_outline[:].z.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.boundary_outline[:].z.reference.data (alpha) | [pulse_schedule.position_control.boundary_outline[:].z.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.boundary_outline[:].z.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.boundary_outline[:].z.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.boundary_outline[:].z.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.elongation (alpha) |  | STRUCTURE | - | Elongation of the plasma boundary
pulse_schedule.position_control.elongation.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.elongation.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.elongation.reference.data (alpha) | [pulse_schedule.position_control.elongation.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.elongation.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.elongation.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.elongation.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.elongation_lower (alpha) |  | STRUCTURE | - | Elongation (lower half w.r.t. geometric axis) of the plasma boundary
pulse_schedule.position_control.elongation_lower.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.elongation_lower.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.elongation_lower.reference.data (alpha) | [pulse_schedule.position_control.elongation_lower.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.elongation_lower.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.elongation_lower.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.elongation_lower.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.elongation_upper (alpha) |  | STRUCTURE | - | Elongation (upper half w.r.t. geometric axis) of the plasma boundary
pulse_schedule.position_control.elongation_upper.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.elongation_upper.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.elongation_upper.reference.data (alpha) | [pulse_schedule.position_control.elongation_upper.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.elongation_upper.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.elongation_upper.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.elongation_upper.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.gap (alpha) | [1...N] | STRUCT_ARRAY |  | Set of gaps, defined by a reference point and a direction.
pulse_schedule.position_control.gap[:].angle (alpha) |  | FLT_0D (uncertain) | rad | Angle between the direction in which the gap is measured (in the poloidal cross-section) and the horizontal axis.
pulse_schedule.position_control.gap[:].r (alpha) |  | FLT_0D (uncertain) | m | Major radius of the reference point
pulse_schedule.position_control.gap[:].value (alpha) |  | STRUCTURE | m | Value of the gap, i.e. distance between the reference point and the separatrix along the gap direction
pulse_schedule.position_control.gap[:].value.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.gap[:].value.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.gap[:].value.reference.data (alpha) | [pulse_schedule.position_control.gap[:].value.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.gap[:].value.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.gap[:].value.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.gap[:].value.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.gap[:].z (alpha) |  | FLT_0D (uncertain) | m | Height of the reference point
pulse_schedule.position_control.geometric_axis (alpha) |  | STRUCTURE |  | RZ position of the geometric axis (defined as (Rmin+Rmax) / 2 and (Zmin+Zmax) / 2 of the boundary)
pulse_schedule.position_control.geometric_axis.r (alpha) |  | STRUCTURE | m | Major radius
pulse_schedule.position_control.geometric_axis.r.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.geometric_axis.r.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.geometric_axis.r.reference.data (alpha) | [pulse_schedule.position_control.geometric_axis.r.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.geometric_axis.r.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.geometric_axis.r.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.geometric_axis.r.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.geometric_axis.z (alpha) |  | STRUCTURE | m | Height
pulse_schedule.position_control.geometric_axis.z.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.geometric_axis.z.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.geometric_axis.z.reference.data (alpha) | [pulse_schedule.position_control.geometric_axis.z.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.geometric_axis.z.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.geometric_axis.z.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.geometric_axis.z.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.magnetic_axis (alpha) |  | STRUCTURE |  | Magnetic axis position
pulse_schedule.position_control.magnetic_axis.r (alpha) |  | STRUCTURE | m | Major radius
pulse_schedule.position_control.magnetic_axis.r.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.magnetic_axis.r.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.magnetic_axis.r.reference.data (alpha) | [pulse_schedule.position_control.magnetic_axis.r.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.magnetic_axis.r.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.magnetic_axis.r.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.magnetic_axis.r.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.magnetic_axis.z (alpha) |  | STRUCTURE | m | Height
pulse_schedule.position_control.magnetic_axis.z.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.magnetic_axis.z.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.magnetic_axis.z.reference.data (alpha) | [pulse_schedule.position_control.magnetic_axis.z.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.magnetic_axis.z.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.magnetic_axis.z.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.magnetic_axis.z.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.minor_radius (alpha) |  | STRUCTURE | m | Minor radius of the plasma boundary (defined as (Rmax-Rmin) / 2 of the boundary)
pulse_schedule.position_control.minor_radius.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.minor_radius.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.minor_radius.reference.data (alpha) | [pulse_schedule.position_control.minor_radius.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.minor_radius.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.minor_radius.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.minor_radius.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.position_control.mode.data (alpha) | [pulse_schedule.position_control.mode.time] | INT_1D |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.position_control.mode.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.strike_point (alpha) | [1...N] | STRUCT_ARRAY |  | Array of strike points, for each of them the RZ position is given
pulse_schedule.position_control.strike_point[:].r (alpha) |  | STRUCTURE | m | Major radius
pulse_schedule.position_control.strike_point[:].r.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.strike_point[:].r.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.strike_point[:].r.reference.data (alpha) | [pulse_schedule.position_control.strike_point[:].r.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.strike_point[:].r.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.strike_point[:].r.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.strike_point[:].r.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.strike_point[:].z (alpha) |  | STRUCTURE | m | Height
pulse_schedule.position_control.strike_point[:].z.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.strike_point[:].z.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.strike_point[:].z.reference.data (alpha) | [pulse_schedule.position_control.strike_point[:].z.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.strike_point[:].z.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.strike_point[:].z.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.strike_point[:].z.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.triangularity (alpha) |  | STRUCTURE | - | Triangularity of the plasma boundary
pulse_schedule.position_control.triangularity.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.triangularity.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.triangularity.reference.data (alpha) | [pulse_schedule.position_control.triangularity.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.triangularity.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.triangularity.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.triangularity.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.triangularity_lower (alpha) |  | STRUCTURE | - | Lower triangularity of the plasma boundary
pulse_schedule.position_control.triangularity_lower.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.triangularity_lower.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.triangularity_lower.reference.data (alpha) | [pulse_schedule.position_control.triangularity_lower.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.triangularity_lower.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.triangularity_lower.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.triangularity_lower.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.triangularity_upper (alpha) |  | STRUCTURE | - | Upper triangularity of the plasma boundary
pulse_schedule.position_control.triangularity_upper.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.triangularity_upper.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.triangularity_upper.reference.data (alpha) | [pulse_schedule.position_control.triangularity_upper.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.triangularity_upper.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.triangularity_upper.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.triangularity_upper.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.x_point (alpha) | [1...N] | STRUCT_ARRAY |  | Array of X-points, for each of them the RZ position is given
pulse_schedule.position_control.x_point[:].r (alpha) |  | STRUCTURE | m | Major radius
pulse_schedule.position_control.x_point[:].r.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.x_point[:].r.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.x_point[:].r.reference.data (alpha) | [pulse_schedule.position_control.x_point[:].r.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.x_point[:].r.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.x_point[:].r.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.x_point[:].r.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.position_control.x_point[:].z (alpha) |  | STRUCTURE | m | Height
pulse_schedule.position_control.x_point[:].z.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.position_control.x_point[:].z.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.position_control.x_point[:].z.reference.data (alpha) | [pulse_schedule.position_control.x_point[:].z.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.position_control.x_point[:].z.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.position_control.x_point[:].z.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.position_control.x_point[:].z.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.tf (alpha) |  | STRUCTURE |  | Toroidal field references
pulse_schedule.tf.b_field_tor_vacuum_r (alpha) |  | STRUCTURE | T.m | Vacuum field times major radius in the toroidal field magnet. Positive sign means anti-clockwise when viewed from above
pulse_schedule.tf.b_field_tor_vacuum_r.envelope_type (alpha) |  | INT_0D |  | Envelope type: 0:relative; 1: absolute; refers to the envelope bounds which are given by the reference/data_error_upper and reference/data_error_lower nodes
pulse_schedule.tf.b_field_tor_vacuum_r.reference (alpha) |  | STRUCTURE |  | Reference waveform
pulse_schedule.tf.b_field_tor_vacuum_r.reference.data (alpha) | [pulse_schedule.tf.b_field_tor_vacuum_r.reference.time] | FLT_1D (uncertain) | mixed | Reference waveform
pulse_schedule.tf.b_field_tor_vacuum_r.reference.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.tf.b_field_tor_vacuum_r.reference_name (alpha) |  | STR_0D |  | Reference name (e.g. in the native pulse schedule system of the device)
pulse_schedule.tf.b_field_tor_vacuum_r.reference_type (alpha) |  | INT_0D |  | Reference type: 0:relative; 1: absolute; refers to the reference/data node
pulse_schedule.tf.mode (alpha) |  | STRUCTURE |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.tf.mode.data (alpha) | [pulse_schedule.tf.mode.time] | INT_1D |  | Control mode (operation mode and/or settings used by the controller)
pulse_schedule.tf.mode.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
pulse_schedule.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
sawteeth (alpha) |  |  |  | Description of sawtooth events. This IDS must be used in homogeneous_time = 1 mode
sawteeth.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
sawteeth.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
sawteeth.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
sawteeth.code.output_flag (alpha) | [sawteeth.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
sawteeth.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
sawteeth.code.repository (alpha) |  | STR_0D |  | URL of software repository
sawteeth.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
sawteeth.crash_trigger (alpha) | [sawteeth.time] | INT_1D |  | Flag indicating whether a crash condition has been satisfied : 0 = no crash. N(>0) = crash triggered due to condition N as follows. 1: crash triggered by the ideal kink criterion; 2: crash triggered by the ideal kink criterion including kinetic effects from fast particles; 31: crash triggered by the resistive kink criterion (meeting necessary conditions for reconnection); 32: crash triggered by the resistive kink criterion (resistive kink mode is unstable). The distinction between 31 and 32 only indicates whether (31) or (32) was the last criterion to be satisfied
sawteeth.diagnostics (alpha) |  | STRUCTURE |  | Detailed information about the sawtooth characteristics
sawteeth.diagnostics.magnetic_shear_q1 (alpha) | [sawteeth.time] | FLT_1D (uncertain) | - | Magnetic shear at surface q = 1, defined as rho_tor/q . dq/drho_tor
sawteeth.diagnostics.previous_crash_time (alpha) | [sawteeth.time] | FLT_1D (uncertain) | s | Time at which the previous sawtooth crash occured
sawteeth.diagnostics.previous_crash_trigger (alpha) | [sawteeth.time] | INT_1D |  | Previous crash trigger. Flag indicating whether a crash condition has been satisfied : 0 = no crash. N(>0) = crash triggered due to condition N
sawteeth.diagnostics.previous_period (alpha) | [sawteeth.time] | FLT_1D (uncertain) | s | Previous sawtooth period
sawteeth.diagnostics.rho_tor_norm_inversion (alpha) | [sawteeth.time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate at inversion radius
sawteeth.diagnostics.rho_tor_norm_mixing (alpha) | [sawteeth.time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate at mixing radius
sawteeth.diagnostics.rho_tor_norm_q1 (alpha) | [sawteeth.time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate at surface q = 1
sawteeth.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
sawteeth.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
sawteeth.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
sawteeth.ids_properties.occurrence |  | INT_0D |  |
sawteeth.profiles_1d (alpha) | [sawteeth.profiles_1d[:].time] | STRUCT_ARRAY |  | Core profiles after sawtooth crash for various time slices
sawteeth.profiles_1d[:].conductivity_parallel (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | ohm^-1.m^-1 | Parallel conductivity
sawteeth.profiles_1d[:].e_field_parallel (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Parallel electric field = average(E.B) / B0, where Core_Profiles/Vacuum_Toroidal_Field/ B0
sawteeth.profiles_1d[:].grid (alpha) |  | STRUCTURE |  | Radial grid
sawteeth.profiles_1d[:].grid.area (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
sawteeth.profiles_1d[:].grid.psi (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
sawteeth.profiles_1d[:].grid.rho_tor (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
sawteeth.profiles_1d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
sawteeth.profiles_1d[:].grid.volume (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
sawteeth.profiles_1d[:].j_bootstrap (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Bootstrap current density = average(J_Bootstrap.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
sawteeth.profiles_1d[:].j_non_inductive (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Non-inductive (includes bootstrap) parallel current density = average(jni.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
sawteeth.profiles_1d[:].j_ohmic (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Ohmic parallel current density = average(J_Ohmic.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
sawteeth.profiles_1d[:].j_tor (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Total toroidal current density = average(J_Tor/R) / average(1/R)
sawteeth.profiles_1d[:].j_total (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A/m^2 | Total parallel current density = average(jtot.B) / B0, where B0 = Core_Profiles/Vacuum_Toroidal_Field/ B0
sawteeth.profiles_1d[:].magnetic_shear (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
sawteeth.profiles_1d[:].momentum_tor (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | kg.m/s | Total plasma toroidal momentum, summed over ion species and electrons
sawteeth.profiles_1d[:].n_e (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Electron density (thermal+non-thermal)
sawteeth.profiles_1d[:].n_e_fast (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) electrons
sawteeth.profiles_1d[:].n_i_total_over_n_e (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Ratio of total ion density (sum over species and charge states) over electron density. (thermal+non-thermal)
sawteeth.profiles_1d[:].p_e (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Electron pressure
sawteeth.profiles_1d[:].p_e_fast_parallel (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) electron parallel pressure
sawteeth.profiles_1d[:].p_e_fast_perpendicular (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) electron perpendicular pressure
sawteeth.profiles_1d[:].p_i_total (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total ion pressure (sum over the ion species)
sawteeth.profiles_1d[:].p_i_total_fast_parallel (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) total ion (sum over the ion species) parallel pressure
sawteeth.profiles_1d[:].p_i_total_fast_perpendicular (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) total ion (sum over the ion species) perpendicular pressure
sawteeth.profiles_1d[:].phi (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Toroidal flux
sawteeth.profiles_1d[:].pressure_parallel (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total parallel pressure (electrons+ions, thermal+non-thermal)
sawteeth.profiles_1d[:].pressure_perpendicular (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total perpendicular pressure (electrons+ions, thermal+non-thermal)
sawteeth.profiles_1d[:].pressure_thermal (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Thermal pressure (electrons+ions)
sawteeth.profiles_1d[:].psi_star_post_crash (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Psi* = psi - phi, after the sawtooth crash
sawteeth.profiles_1d[:].psi_star_pre_crash (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Psi* = psi - phi, just before the sawtooth crash
sawteeth.profiles_1d[:].q (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Safety factor
sawteeth.profiles_1d[:].t_e (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Electron temperature
sawteeth.profiles_1d[:].t_i_average (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Ion temperature (averaged on charge states and ion species)
sawteeth.profiles_1d[:].time (alpha) |  | FLT_0D | s | Time
sawteeth.profiles_1d[:].zeff (alpha) | [sawteeth.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Effective charge
sawteeth.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
sawteeth.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition)
sawteeth.vacuum_toroidal_field.b0 (alpha) | [sawteeth.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewed from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
sawteeth.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
sdn (alpha) |  |  |  | Description of the Synchronous Data Network parameters and the signals on it
sdn.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
sdn.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
sdn.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
sdn.code.output_flag (alpha) | [sdn.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
sdn.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
sdn.code.repository (alpha) |  | STR_0D |  | URL of software repository
sdn.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
sdn.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
sdn.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
sdn.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
sdn.ids_properties.occurrence |  | INT_0D |  |
sdn.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
sdn.topic (alpha) | [1...N] | STRUCT_ARRAY |  | List of topics. SDN signals are grouped by topic
sdn.topic[:].name (alpha) |  | STR_0D |  | Topic name
sdn.topic[:].signal (alpha) | [1...N] | STRUCT_ARRAY |  | List of signals which can be allocated to the SDN
sdn.topic[:].signal[:].allocated_position (alpha) |  | INT_0D |  | Allocation of signal to a position in the SDN (1..N); this will be implementation specific
sdn.topic[:].signal[:].definition (alpha) |  | STR_0D |  | Signal definition
sdn.topic[:].signal[:].name (alpha) |  | STR_0D |  | Signal name
sdn.topic[:].signal[:].quality (alpha) |  | STRUCTURE |  | Indicator of the quality of the signal. Following ITER PCS documentation (https://user.iter.org/?uid=354SJ3&action=get_document), possible values are: 1 - GOOD (the nominal state); 2 - INVALID (data no usable); 3 - DATA INTEGRITY ERROR (e.g. out of bounds with respect to expectations, calibration error,...)
sdn.topic[:].signal[:].quality.data (alpha) | [sdn.topic[:].signal[:].quality.time] | INT_1D |  | Indicator of the quality of the signal. Following ITER PCS documentation (https://user.iter.org/?uid=354SJ3&action=get_document), possible values are: 1 - GOOD (the nominal state); 2 - INVALID (data no usable); 3 - DATA INTEGRITY ERROR (e.g. out of bounds with respect to expectations, calibration error,...)
sdn.topic[:].signal[:].quality.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
sdn.topic[:].signal[:].value (alpha) |  | STRUCTURE |  | Signal value
sdn.topic[:].signal[:].value.data (alpha) | [sdn.topic[:].signal[:].value.time] | FLT_1D (uncertain) | mixed | Signal value
sdn.topic[:].signal[:].value.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
spectrometer_visible (alpha) |  |  |  | Spectrometer in visible light range diagnostic
spectrometer_visible.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (lines-of-sight)
spectrometer_visible.channel[:].filter (alpha) |  | STRUCTURE |  | Quantities measured by the channel if connected to a filter spectrometer
spectrometer_visible.channel[:].filter.calibrated_line_integrals (alpha) |  | STRUCTURE |  | Calibrated line gross areas integrals
spectrometer_visible.channel[:].filter.calibrated_line_integrals.data (alpha) | [spectrometer_visible.channel[:].filter.calibrated_lines, spectrometer_visible.channel[:].filter.calibrated_line_integrals.time] | FLT_2D (uncertain) | m^-2.s^-1.sr^-1 | Calibrated line gross areas integrals
spectrometer_visible.channel[:].filter.calibrated_line_integrals.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
spectrometer_visible.channel[:].filter.calibrated_lines (alpha) | [1...N] | FLT_1D (uncertain) | m | Central wavelength of the calibrated lines
spectrometer_visible.channel[:].filter.exposure_time (alpha) |  | FLT_0D (uncertain) | s | Exposure time
spectrometer_visible.channel[:].filter.line_intensities (alpha) |  | STRUCTURE |  | Line gross integral intensities
spectrometer_visible.channel[:].filter.line_intensities.data (alpha) | [spectrometer_visible.channel[:].filter.raw_lines, spectrometer_visible.channel[:].filter.line_intensities.time] | FLT_2D (uncertain) | m^-2.s^-1.sr^-1 | Line gross integral intensities
spectrometer_visible.channel[:].filter.line_intensities.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
spectrometer_visible.channel[:].filter.line_radiances (alpha) |  | STRUCTURE |  | Calibrated, background subtracted line integrals
spectrometer_visible.channel[:].filter.line_radiances.data (alpha) | [spectrometer_visible.channel[:].filter.processed_lines, spectrometer_visible.channel[:].filter.line_radiances.time] | FLT_2D (uncertain) | m^-2.s^-1.sr^-1 | Calibrated, background subtracted line integrals
spectrometer_visible.channel[:].filter.line_radiances.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
spectrometer_visible.channel[:].filter.processed_lines (alpha) | [1...N] | FLT_1D (uncertain) | m | Central wavelength of the processed lines
spectrometer_visible.channel[:].filter.radiance_calibration (alpha) |  | FLT_0D (uncertain) | m^-2.sr^-1 | Radiance calibration
spectrometer_visible.channel[:].filter.radiance_calibration_date (alpha) |  | STR_0D |  | Date of the radiance calibration (yyyy_mm_dd)
spectrometer_visible.channel[:].filter.raw_lines (alpha) | [1...N] | FLT_1D (uncertain) | m | Central wavelength of the raw lines
spectrometer_visible.channel[:].grating (alpha) |  | STRUCTURE |  | Quantities measured by the channel if connected to a grating spectrometer
spectrometer_visible.channel[:].grating.exposure_time (alpha) |  | FLT_0D (uncertain) | s | Exposure time
spectrometer_visible.channel[:].grating.intensity_spectra (alpha) |  | STRUCTURE |  | Intensity spectra (not calibrated)
spectrometer_visible.channel[:].grating.intensity_spectra.data (alpha) | [spectrometer_visible.channel[:].grating.wavelengths, spectrometer_visible.channel[:].grating.intensity_spectra.time] | FLT_2D (uncertain) | s^-1 | Intensity spectra (not calibrated)
spectrometer_visible.channel[:].grating.intensity_spectra.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
spectrometer_visible.channel[:].grating.line_radiances (alpha) |  | STRUCTURE |  | Calibrated, background subtracted line integrals
spectrometer_visible.channel[:].grating.line_radiances.data (alpha) | [spectrometer_visible.channel[:].grating.processed_lines, spectrometer_visible.channel[:].grating.line_radiances.time] | FLT_2D (uncertain) | m^-2.s^-1.sr^-1 | Calibrated, background subtracted line integrals
spectrometer_visible.channel[:].grating.line_radiances.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
spectrometer_visible.channel[:].grating.processed_lines (alpha) | [1...N] | FLT_1D (uncertain) | m | Central wavelength of the processed lines
spectrometer_visible.channel[:].grating.radiance_calibration (alpha) | [spectrometer_visible.channel[:].grating.wavelengths] | FLT_1D (uncertain) | m^-2.sr^-1 | Radiance calibration
spectrometer_visible.channel[:].grating.radiance_calibration_date (alpha) |  | STR_0D |  | Date of the radiance calibration (yyyy_mm_dd)
spectrometer_visible.channel[:].grating.radiance_spectra (alpha) |  | STRUCTURE |  | Calibrated spectra
spectrometer_visible.channel[:].grating.radiance_spectra.data (alpha) | [spectrometer_visible.channel[:].grating.wavelengths, spectrometer_visible.channel[:].grating.radiance_spectra.time] | FLT_2D (uncertain) | m^-2.s^-1.sr^-1 | Calibrated spectra
spectrometer_visible.channel[:].grating.radiance_spectra.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
spectrometer_visible.channel[:].grating.wavelength_calibration_date (alpha) |  | STR_0D |  | Date of the wavelength calibration (yyyy_mm_dd)
spectrometer_visible.channel[:].grating.wavelengths (alpha) | [1...N] | FLT_1D (uncertain) | m | Measured wavelengths
spectrometer_visible.channel[:].line_of_sight (alpha) |  | STRUCTURE |  | Description of the line of sight of the channel, given by 2 points
spectrometer_visible.channel[:].line_of_sight.first_point (alpha) |  | STRUCTURE |  | Position of the first point
spectrometer_visible.channel[:].line_of_sight.first_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
spectrometer_visible.channel[:].line_of_sight.first_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_visible.channel[:].line_of_sight.first_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_visible.channel[:].line_of_sight.second_point (alpha) |  | STRUCTURE |  | Position of the second point
spectrometer_visible.channel[:].line_of_sight.second_point.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
spectrometer_visible.channel[:].line_of_sight.second_point.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
spectrometer_visible.channel[:].line_of_sight.second_point.z (alpha) |  | FLT_0D (uncertain) | m | Height
spectrometer_visible.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
spectrometer_visible.channel[:].spot_diameter (alpha) |  | FLT_0D (uncertain) | m | Spot diameter
spectrometer_visible.channel[:].type (alpha) |  | STRUCTURE |  | Type of spectrometer the channel is connected to (index=1: grating, 2: filter)
spectrometer_visible.channel[:].type.description (alpha) |  | STR_0D |  | Verbose description
spectrometer_visible.channel[:].type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
spectrometer_visible.channel[:].type.name (alpha) |  | STR_0D |  | Short string identifier
spectrometer_visible.channel[:].validity (alpha) |  | INT_0D |  | Indicator of the validity of the channel for the whole acquisition period (0 means valid, negative values mean non-valid)
spectrometer_visible.channel[:].validity_timed (alpha) |  | STRUCTURE |  | Indicator of the validity of the channel as a function of time (0 means valid, negative values mean non-valid)
spectrometer_visible.channel[:].validity_timed.data (alpha) | [spectrometer_visible.channel[:].validity_timed.time] | INT_1D |  | Indicator of the validity of the channel as a function of time (0 means valid, negative values mean non-valid)
spectrometer_visible.channel[:].validity_timed.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
spectrometer_visible.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
spectrometer_visible.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
spectrometer_visible.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
spectrometer_visible.code.output_flag (alpha) | [spectrometer_visible.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
spectrometer_visible.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
spectrometer_visible.code.repository (alpha) |  | STR_0D |  | URL of software repository
spectrometer_visible.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
spectrometer_visible.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
spectrometer_visible.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
spectrometer_visible.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
spectrometer_visible.ids_properties.occurrence |  | INT_0D |  |
spectrometer_visible.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
summary (alpha) |  |  |  | Summary of physics quantities from a simulation or an experiment. Dynamic quantities are either taken at given time slices (indicated in the "time" vector) or time-averaged over an interval (in such case the "time_width" of the interval is indicated and the "time" vector represents the end of each time interval).
summary.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
summary.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
summary.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
summary.code.output_flag (alpha) | [summary.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
summary.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
summary.code.repository (alpha) |  | STR_0D |  | URL of software repository
summary.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
summary.disruption (alpha) |  | STRUCTURE |  | Disruption characteristics, if the pulse is terminated by a disruption
summary.disruption.mitigation_valve (alpha) |  | STRUCTURE |  | Flag indicating whether any disruption mitigation valve has been used (1) or none (0)
summary.disruption.mitigation_valve.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.disruption.mitigation_valve.value (alpha) |  | INT_0D | ? | Value
summary.disruption.time (alpha) |  | STRUCTURE | s | Time of the disruption
summary.disruption.time.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.disruption.time.value (alpha) |  | FLT_0D (uncertain) | s | Value
summary.disruption.time_half_ip (alpha) |  | STRUCTURE | s | Time at which the plasma current has fallen to half of the initial current at the start of the disruption, relative to the time of the disruption
summary.disruption.time_half_ip.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.disruption.time_half_ip.value (alpha) |  | FLT_0D (uncertain) | s | Value
summary.disruption.time_radiated_power_max (alpha) |  | STRUCTURE | s | Time of maximum radiated power, relative to the time of the disruption
summary.disruption.time_radiated_power_max.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.disruption.time_radiated_power_max.value (alpha) |  | FLT_0D (uncertain) | s | Value
summary.disruption.vertical_displacement (alpha) |  | STRUCTURE | s | Direction of the plasma vertical displacement just before the disruption 1 (upwards) / 0 (no displacement)/ -1 (downwards)
summary.disruption.vertical_displacement.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.disruption.vertical_displacement.value (alpha) |  | INT_0D | s | Value
summary.fusion (alpha) |  | STRUCTURE |  | Fusion reactions
summary.fusion.current (alpha) |  | STRUCTURE | A | Parallel current driven by this fusion reactions
summary.fusion.current.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.current.value (alpha) | [summary.time] | FLT_1D (uncertain) | A | Value
summary.fusion.neutron_fluxes (alpha) |  | STRUCTURE |  | Neutron fluxes from various reactions
summary.fusion.neutron_fluxes.dd (alpha) |  | STRUCTURE |  | Neutron fluxes from DD reactions
summary.fusion.neutron_fluxes.dd.beam_beam (alpha) |  | STRUCTURE | Hz | Neutron flux coming from NBI beam self reactions
summary.fusion.neutron_fluxes.dd.beam_beam.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dd.beam_beam.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.dd.beam_thermal (alpha) |  | STRUCTURE | Hz | Neutron flux coming from NBI beam - plasma reactions
summary.fusion.neutron_fluxes.dd.beam_thermal.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dd.beam_thermal.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.dd.thermal (alpha) |  | STRUCTURE | Hz | Neutron flux coming from thermal plasma
summary.fusion.neutron_fluxes.dd.thermal.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dd.thermal.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.dd.total (alpha) |  | STRUCTURE | Hz | Total neutron flux coming from this reaction
summary.fusion.neutron_fluxes.dd.total.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dd.total.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.dt (alpha) |  | STRUCTURE |  | Neutron fluxes from DT reactions
summary.fusion.neutron_fluxes.dt.beam_beam (alpha) |  | STRUCTURE | Hz | Neutron flux coming from NBI beam self reactions
summary.fusion.neutron_fluxes.dt.beam_beam.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dt.beam_beam.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.dt.beam_thermal (alpha) |  | STRUCTURE | Hz | Neutron flux coming from NBI beam - plasma reactions
summary.fusion.neutron_fluxes.dt.beam_thermal.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dt.beam_thermal.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.dt.thermal (alpha) |  | STRUCTURE | Hz | Neutron flux coming from thermal plasma
summary.fusion.neutron_fluxes.dt.thermal.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dt.thermal.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.dt.total (alpha) |  | STRUCTURE | Hz | Total neutron flux coming from this reaction
summary.fusion.neutron_fluxes.dt.total.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.dt.total.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.thermal (alpha) |  | STRUCTURE | Hz | Neutron flux from all plasma thermal reactions
summary.fusion.neutron_fluxes.thermal.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.thermal.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.total (alpha) |  | STRUCTURE | Hz | Total neutron flux from all reactions
summary.fusion.neutron_fluxes.total.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.total.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.tt (alpha) |  | STRUCTURE |  | Neutron fluxes from TT reactions
summary.fusion.neutron_fluxes.tt.beam_beam (alpha) |  | STRUCTURE | Hz | Neutron flux coming from NBI beam self reactions
summary.fusion.neutron_fluxes.tt.beam_beam.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.tt.beam_beam.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.tt.beam_thermal (alpha) |  | STRUCTURE | Hz | Neutron flux coming from NBI beam - plasma reactions
summary.fusion.neutron_fluxes.tt.beam_thermal.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.tt.beam_thermal.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.tt.thermal (alpha) |  | STRUCTURE | Hz | Neutron flux coming from thermal plasma
summary.fusion.neutron_fluxes.tt.thermal.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.tt.thermal.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.neutron_fluxes.tt.total (alpha) |  | STRUCTURE | Hz | Total neutron flux coming from this reaction
summary.fusion.neutron_fluxes.tt.total.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.neutron_fluxes.tt.total.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.fusion.power (alpha) |  | STRUCTURE | W | Power coupled to the plasma by fusion reactions
summary.fusion.power.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.fusion.power.value (alpha) | [summary.time] | FLT_1D (uncertain) | W | Value
summary.global_quantities (alpha) |  | STRUCTURE |  | Various global quantities derived from the profiles
summary.global_quantities.b0 (alpha) |  | STRUCTURE | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewed from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
summary.global_quantities.b0.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.b0.value (alpha) | [summary.time] | FLT_1D (uncertain) | T | Value
summary.global_quantities.beta_pol (alpha) |  | STRUCTURE | - | Poloidal beta. Defined as betap = 4 int(p dV) / [R_0 * mu_0 * Ip^2]
summary.global_quantities.beta_pol.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.beta_pol.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.beta_tor (alpha) |  | STRUCTURE | - | Toroidal beta, defined as the volume-averaged total perpendicular pressure divided by (B0^2/(2*mu0)), i.e. beta_toroidal = 2 mu0 int(p dV) / V / B0^2
summary.global_quantities.beta_tor.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.beta_tor.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.beta_tor_norm (alpha) |  | STRUCTURE | - | Normalised toroidal beta, defined as 100 * beta_tor * a[m] * B0 [T] / ip [MA]
summary.global_quantities.beta_tor_norm.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.beta_tor_norm.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.current_alignment (alpha) |  | STRUCTURE | A | Figure of merit of the alignment of the current profile sources, defined in the following reference: http://iopscience.iop.org/article/10.1088/0029-5515/43/7/318
summary.global_quantities.current_alignment.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.current_alignment.value (alpha) | [summary.time] | FLT_1D (uncertain) | A | Value
summary.global_quantities.current_bootstrap (alpha) |  | STRUCTURE | A | Bootstrap parallel current
summary.global_quantities.current_bootstrap.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.current_bootstrap.value (alpha) | [summary.time] | FLT_1D (uncertain) | A | Value
summary.global_quantities.current_non_inductive (alpha) |  | STRUCTURE | A | Total non-inductive parallel current
summary.global_quantities.current_non_inductive.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.current_non_inductive.value (alpha) | [summary.time] | FLT_1D (uncertain) | A | Value
summary.global_quantities.current_ohm (alpha) |  | STRUCTURE | A | Ohmic parallel current
summary.global_quantities.current_ohm.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.current_ohm.value (alpha) | [summary.time] | FLT_1D (uncertain) | A | Value
summary.global_quantities.energy_b_field_pol (alpha) |  | STRUCTURE | J | Thermal plasma energy content = 1/(2.mu0) * integral over the plasma volume of b_field_pol^2
summary.global_quantities.energy_b_field_pol.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.energy_b_field_pol.value (alpha) | [summary.time] | FLT_1D (uncertain) | J | Value
summary.global_quantities.energy_diamagnetic (alpha) |  | STRUCTURE | J | Plasma energy content = 3/2 * integral over the plasma volume of the total perpendicular pressure
summary.global_quantities.energy_diamagnetic.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.energy_diamagnetic.value (alpha) | [summary.time] | FLT_1D (uncertain) | J | Value
summary.global_quantities.energy_thermal (alpha) |  | STRUCTURE | J | Thermal plasma energy content = 3/2 * integral over the plasma volume of the thermal pressure
summary.global_quantities.energy_thermal.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.energy_thermal.value (alpha) | [summary.time] | FLT_1D (uncertain) | J | Value
summary.global_quantities.energy_total (alpha) |  | STRUCTURE | J | Plasma energy content = 3/2 * integral over the plasma volume of the total kinetic pressure
summary.global_quantities.energy_total.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.energy_total.value (alpha) | [summary.time] | FLT_1D (uncertain) | J | Value
summary.global_quantities.h_98 (alpha) |  | STRUCTURE | - | Energy confinement time enhancement factor over the IPB98(y,2) scaling
summary.global_quantities.h_98.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.h_98.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.h_mode (alpha) |  | STRUCTURE |  | H-mode flag: 0 when the plasma is in L-mode and 1 when in H-mode
summary.global_quantities.h_mode.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.h_mode.value (alpha) | [summary.time] | INT_1D |  | Value
summary.global_quantities.ip (alpha) |  | STRUCTURE | A | Total plasma current
summary.global_quantities.ip.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.ip.value (alpha) | [summary.time] | FLT_1D (uncertain) | A | Value
summary.global_quantities.li (alpha) |  | STRUCTURE | - | Internal inductance. The li_3 definition is used, i.e. li_3 = 2/R0/mu0^2/Ip^2 * int(Bp^2 dV).
summary.global_quantities.li.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.li.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.global_quantities.r0 (alpha) |  | STRUCTURE | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)
summary.global_quantities.r0.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.r0.value (alpha) |  | FLT_0D (uncertain) | m | Value
summary.global_quantities.resistance (alpha) |  | STRUCTURE | ohm | Plasma electric resistance
summary.global_quantities.resistance.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.resistance.value (alpha) | [summary.time] | FLT_1D (uncertain) | ohm | Value
summary.global_quantities.tau_energy (alpha) |  | STRUCTURE | s | Energy confinement time
summary.global_quantities.tau_energy.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.tau_energy.value (alpha) | [summary.time] | FLT_1D (uncertain) | s | Value
summary.global_quantities.tau_helium (alpha) |  | STRUCTURE | s | Helium confinement time
summary.global_quantities.tau_helium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.tau_helium.value (alpha) | [summary.time] | FLT_1D (uncertain) | s | Value
summary.global_quantities.tau_resistive (alpha) |  | STRUCTURE | s | Current diffusion characteristic time
summary.global_quantities.tau_resistive.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.tau_resistive.value (alpha) | [summary.time] | FLT_1D (uncertain) | s | Value
summary.global_quantities.v_loop (alpha) |  | STRUCTURE | V | LCFS loop voltage
summary.global_quantities.v_loop.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.v_loop.value (alpha) | [summary.time] | FLT_1D (uncertain) | V | Value
summary.global_quantities.volume (alpha) |  | STRUCTURE | m^3 | Volume of the confined plasma
summary.global_quantities.volume.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.global_quantities.volume.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^3 | Value
summary.heating_current_drive (alpha) |  | STRUCTURE |  | Heating and current drive parameters
summary.heating_current_drive.ec (alpha) | [1...N] | STRUCT_ARRAY |  | Set of ECRH/ECCD launchers
summary.heating_current_drive.ec[:].angle_pol (alpha) |  | STRUCTURE | rad | Poloidal angle of ECRH at resonance
summary.heating_current_drive.ec[:].angle_pol.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].angle_pol.value (alpha) | [summary.time] | FLT_1D (uncertain) | rad | Value
summary.heating_current_drive.ec[:].angle_tor (alpha) |  | STRUCTURE | rad | Toroidal angle of ECRH at resonance
summary.heating_current_drive.ec[:].angle_tor.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].angle_tor.value (alpha) | [summary.time] | FLT_1D (uncertain) | rad | Value
summary.heating_current_drive.ec[:].current (alpha) |  | STRUCTURE | A | Parallel current driven by EC waves
summary.heating_current_drive.ec[:].current.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].current.value (alpha) | [summary.time] | FLT_1D (uncertain) | A | Value
summary.heating_current_drive.ec[:].energy_fast (alpha) |  | STRUCTURE | J | Fast particle energy content driven by EC waves
summary.heating_current_drive.ec[:].energy_fast.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].energy_fast.value (alpha) | [summary.time] | FLT_1D (uncertain) | J | Value
summary.heating_current_drive.ec[:].frequency (alpha) |  | STRUCTURE | Hz | ECRH frequency
summary.heating_current_drive.ec[:].frequency.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].frequency.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.heating_current_drive.ec[:].harmonic (alpha) |  | STRUCTURE |  | Harmonic number of the absorbed ECRH waves
summary.heating_current_drive.ec[:].harmonic.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].harmonic.value (alpha) | [summary.time] | INT_1D |  | Value
summary.heating_current_drive.ec[:].polarisation (alpha) |  | STRUCTURE |  | Polarisation of the ECRH waves (0 = O mode, 1 = X mode)
summary.heating_current_drive.ec[:].polarisation.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].polarisation.value (alpha) | [summary.time] | INT_1D |  | Value
summary.heating_current_drive.ec[:].position (alpha) |  | STRUCTURE | - | Position of the maximum of the ECRH power deposition, in rho_tor_norm
summary.heating_current_drive.ec[:].position.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].position.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.heating_current_drive.ec[:].power (alpha) |  | STRUCTURE | W | Electron cyclotron heating power coupled to the plasma
summary.heating_current_drive.ec[:].power.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ec[:].power.value (alpha) | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.ic (alpha) | [1...N] | STRUCT_ARRAY |  | Set of ICRH launchers
summary.heating_current_drive.ic[:].current (alpha) |  | STRUCTURE | A | Parallel current driven by IC waves
summary.heating_current_drive.ic[:].current.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].current.value (alpha) | [summary.time] | FLT_1D (uncertain) | A | Value
summary.heating_current_drive.ic[:].e_field_plus_minus_ratio (alpha) |  | STRUCTURE | - | Average E+/E- power ratio of IC waves
summary.heating_current_drive.ic[:].e_field_plus_minus_ratio.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].e_field_plus_minus_ratio.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.heating_current_drive.ic[:].energy_fast (alpha) |  | STRUCTURE | J | Fast particle energy content driven by IC waves
summary.heating_current_drive.ic[:].energy_fast.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].energy_fast.value (alpha) | [summary.time] | FLT_1D (uncertain) | J | Value
summary.heating_current_drive.ic[:].frequency (alpha) |  | STRUCTURE | Hz | ICRH frequency
summary.heating_current_drive.ic[:].frequency.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].frequency.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.heating_current_drive.ic[:].harmonic (alpha) |  | STRUCTURE |  | Harmonic number of the absorbed ICRH waves
summary.heating_current_drive.ic[:].harmonic.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].harmonic.value (alpha) | [summary.time] | INT_1D |  | Value
summary.heating_current_drive.ic[:].k_perpendicular (alpha) |  | STRUCTURE | m^-1 | Main perpendicular wave number of IC waves
summary.heating_current_drive.ic[:].k_perpendicular.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].k_perpendicular.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-1 | Value
summary.heating_current_drive.ic[:].n_tor (alpha) |  | STRUCTURE |  | Main toroidal mode number of IC waves
summary.heating_current_drive.ic[:].n_tor.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].n_tor.value (alpha) | [summary.time] | INT_1D |  | Value
summary.heating_current_drive.ic[:].phase (alpha) |  | STRUCTURE | rad | Phase between straps
summary.heating_current_drive.ic[:].phase.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].phase.value (alpha) | [summary.time] | FLT_1D (uncertain) | rad | Value
summary.heating_current_drive.ic[:].position (alpha) |  | STRUCTURE | - | Position of the maximum of the ICRH power deposition, in rho_tor_norm
summary.heating_current_drive.ic[:].position.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].position.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.heating_current_drive.ic[:].power (alpha) |  | STRUCTURE | W | IC heating power coupled to the plasma
summary.heating_current_drive.ic[:].power.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.ic[:].power.value (alpha) | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.lh (alpha) | [1...N] | STRUCT_ARRAY |  | Set of LHCD launchers
summary.heating_current_drive.lh[:].current (alpha) |  | STRUCTURE | A | Parallel current driven by LH waves
summary.heating_current_drive.lh[:].current.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.lh[:].current.value (alpha) | [summary.time] | FLT_1D (uncertain) | A | Value
summary.heating_current_drive.lh[:].energy_fast (alpha) |  | STRUCTURE | J | Fast particle energy content driven by LH waves
summary.heating_current_drive.lh[:].energy_fast.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.lh[:].energy_fast.value (alpha) | [summary.time] | FLT_1D (uncertain) | J | Value
summary.heating_current_drive.lh[:].frequency (alpha) |  | STRUCTURE | Hz | LH wave frequency
summary.heating_current_drive.lh[:].frequency.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.lh[:].frequency.value (alpha) | [summary.time] | FLT_1D (uncertain) | Hz | Value
summary.heating_current_drive.lh[:].n_parallel (alpha) |  | STRUCTURE | - | Main parallel refractive index of LH waves at launch
summary.heating_current_drive.lh[:].n_parallel.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.lh[:].n_parallel.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.heating_current_drive.lh[:].position (alpha) |  | STRUCTURE | - | Position of the maximum of the LH power deposition, in rho_tor_norm
summary.heating_current_drive.lh[:].position.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.lh[:].position.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.heating_current_drive.lh[:].power (alpha) |  | STRUCTURE | W | LH heating power coupled to the plasma
summary.heating_current_drive.lh[:].power.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.lh[:].power.value (alpha) | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.nbi (alpha) | [1...N] | STRUCT_ARRAY |  | Set of NBI units
summary.heating_current_drive.nbi[:].angle (alpha) |  | STRUCTURE | rad | Angle of inclination between a beamlet at the centre of the injection unit surface and the horiontal plane
summary.heating_current_drive.nbi[:].angle.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].angle.value (alpha) |  | FLT_0D (uncertain) | rad | Value
summary.heating_current_drive.nbi[:].beam_current_fraction (alpha) |  | STRUCTURE | - | Fractions of beam current distributed among the different energies, the first index corresponds to the fast neutrals energy (1:full, 2: half, 3: one third)
summary.heating_current_drive.nbi[:].beam_current_fraction.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].beam_current_fraction.value (alpha) | [1...3, summary.time] | FLT_2D (uncertain) | - | Value
summary.heating_current_drive.nbi[:].beam_power_fraction (alpha) |  | STRUCTURE | - | Fractions of beam power distributed among the different energies, the first index corresponds to the fast neutrals energy (1:full, 2: half, 3: one third)
summary.heating_current_drive.nbi[:].beam_power_fraction.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].beam_power_fraction.value (alpha) | [1...3, summary.time] | FLT_2D (uncertain) | - | Value
summary.heating_current_drive.nbi[:].current (alpha) |  | STRUCTURE | A | Parallel current driven by this NBI unit
summary.heating_current_drive.nbi[:].current.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].current.value (alpha) | [summary.time] | FLT_1D (uncertain) | A | Value
summary.heating_current_drive.nbi[:].direction (alpha) |  | STRUCTURE |  | Direction of the beam seen from above the torus: -1 = clockwise; 1 = counter clockwise
summary.heating_current_drive.nbi[:].direction.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].direction.value (alpha) |  | INT_0D | ? | Value
summary.heating_current_drive.nbi[:].energy (alpha) |  | STRUCTURE | eV | Full energy of the injected species (acceleration of a single atom)
summary.heating_current_drive.nbi[:].energy.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].energy.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.heating_current_drive.nbi[:].position (alpha) |  | STRUCTURE |  | R, Z, Phi position of the NBI unit centre
summary.heating_current_drive.nbi[:].position.phi (alpha) |  | STRUCTURE | rad | Toroidal angle
summary.heating_current_drive.nbi[:].position.phi.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].position.phi.value (alpha) |  | FLT_0D (uncertain) | rad | Value
summary.heating_current_drive.nbi[:].position.r (alpha) |  | STRUCTURE | m | Major radius
summary.heating_current_drive.nbi[:].position.r.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].position.r.value (alpha) |  | FLT_0D (uncertain) | m | Value
summary.heating_current_drive.nbi[:].position.z (alpha) |  | STRUCTURE | m | Height
summary.heating_current_drive.nbi[:].position.z.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].position.z.value (alpha) |  | FLT_0D (uncertain) | m | Value
summary.heating_current_drive.nbi[:].power (alpha) |  | STRUCTURE | W | NBI power coupled to the plasma by this unit
summary.heating_current_drive.nbi[:].power.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].power.value (alpha) | [summary.time] | FLT_1D (uncertain) | W | Value
summary.heating_current_drive.nbi[:].species (alpha) |  | STRUCTURE | Atomic Mass Unit | Injected species
summary.heating_current_drive.nbi[:].species.a (alpha) |  | STRUCTURE | Atomic Mass Unit | Mass of atom
summary.heating_current_drive.nbi[:].species.a.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].species.a.value (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Value
summary.heating_current_drive.nbi[:].species.label (alpha) |  | STRUCTURE |  | String identifying the species (e.g. H, D, T, ...)
summary.heating_current_drive.nbi[:].species.label.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].species.label.value (alpha) |  | STR_0D |  | Value
summary.heating_current_drive.nbi[:].species.z_n (alpha) |  | STRUCTURE | Elementary Charge Unit | Nuclear charge
summary.heating_current_drive.nbi[:].species.z_n.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].species.z_n.value (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Value
summary.heating_current_drive.nbi[:].tangency_radius (alpha) |  | STRUCTURE | m | Tangency radius (major radius where the central line of a NBI unit is tangent to a circle around the torus)
summary.heating_current_drive.nbi[:].tangency_radius.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.heating_current_drive.nbi[:].tangency_radius.value (alpha) |  | FLT_0D (uncertain) | m | Value
summary.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
summary.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
summary.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
summary.ids_properties.occurrence |  | INT_0D |  |
summary.line_average (alpha) |  | STRUCTURE |  | Line average plasma parameters
summary.line_average.n_e (alpha) |  | STRUCTURE | m^-3 | Electron density
summary.line_average.n_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i (alpha) |  | STRUCTURE | m^-3 | Ion density per species
summary.line_average.n_i.argon (alpha) |  | STRUCTURE |  | Argon
summary.line_average.n_i.argon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.argon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.berylium (alpha) |  | STRUCTURE |  | Berylium
summary.line_average.n_i.berylium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.berylium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.carbon (alpha) |  | STRUCTURE |  | Carbon
summary.line_average.n_i.carbon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.carbon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.deuterium (alpha) |  | STRUCTURE |  | Deuterium
summary.line_average.n_i.deuterium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.deuterium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.helium_3 (alpha) |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.line_average.n_i.helium_3.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.helium_3.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.helium_4 (alpha) |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.line_average.n_i.helium_4.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.helium_4.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.hydrogen (alpha) |  | STRUCTURE |  | Hydrogen
summary.line_average.n_i.hydrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.hydrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.lithium (alpha) |  | STRUCTURE |  | Lithium
summary.line_average.n_i.lithium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.lithium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.neon (alpha) |  | STRUCTURE |  | Neon
summary.line_average.n_i.neon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.neon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.nitrogen (alpha) |  | STRUCTURE |  | Nitrogen
summary.line_average.n_i.nitrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.nitrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.oxygen (alpha) |  | STRUCTURE |  | Oxygen
summary.line_average.n_i.oxygen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.oxygen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.tritium (alpha) |  | STRUCTURE |  | Tritium
summary.line_average.n_i.tritium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.tritium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.tungsten (alpha) |  | STRUCTURE |  | Tungsten
summary.line_average.n_i.tungsten.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.tungsten.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i.xenon (alpha) |  | STRUCTURE |  | Xenon
summary.line_average.n_i.xenon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i.xenon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.n_i_total (alpha) |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.line_average.n_i_total.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.n_i_total.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.line_average.t_e (alpha) |  | STRUCTURE | eV | Electron temperature
summary.line_average.t_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.t_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.line_average.t_i_average (alpha) |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.line_average.t_i_average.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.t_i_average.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.line_average.zeff (alpha) |  | STRUCTURE | - | Effective charge
summary.line_average.zeff.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.line_average.zeff.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local (alpha) |  | STRUCTURE |  | Plasma parameter values at different locations
summary.local.divertor_plate (alpha) | [1...N] | STRUCT_ARRAY |  | Parameters at a divertor plate. RAJOUTER NAME DANS LA STRUCTURE dESSOUS
summary.local.divertor_plate[:].flux_expansion (alpha) |  | STRUCTURE | - | Flux expansion
summary.local.divertor_plate[:].flux_expansion.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].flux_expansion.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.divertor_plate[:].n_e (alpha) |  | STRUCTURE | m^-3 | Electron density
summary.local.divertor_plate[:].n_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i (alpha) |  | STRUCTURE | m^-3 | Ion density per species
summary.local.divertor_plate[:].n_i.argon (alpha) |  | STRUCTURE |  | Argon
summary.local.divertor_plate[:].n_i.argon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.argon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.berylium (alpha) |  | STRUCTURE |  | Berylium
summary.local.divertor_plate[:].n_i.berylium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.berylium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.carbon (alpha) |  | STRUCTURE |  | Carbon
summary.local.divertor_plate[:].n_i.carbon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.carbon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.deuterium (alpha) |  | STRUCTURE |  | Deuterium
summary.local.divertor_plate[:].n_i.deuterium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.deuterium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.helium_3 (alpha) |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.divertor_plate[:].n_i.helium_3.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.helium_3.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.helium_4 (alpha) |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.divertor_plate[:].n_i.helium_4.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.helium_4.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.hydrogen (alpha) |  | STRUCTURE |  | Hydrogen
summary.local.divertor_plate[:].n_i.hydrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.hydrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.lithium (alpha) |  | STRUCTURE |  | Lithium
summary.local.divertor_plate[:].n_i.lithium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.lithium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.neon (alpha) |  | STRUCTURE |  | Neon
summary.local.divertor_plate[:].n_i.neon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.neon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.nitrogen (alpha) |  | STRUCTURE |  | Nitrogen
summary.local.divertor_plate[:].n_i.nitrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.nitrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.oxygen (alpha) |  | STRUCTURE |  | Oxygen
summary.local.divertor_plate[:].n_i.oxygen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.oxygen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.tritium (alpha) |  | STRUCTURE |  | Tritium
summary.local.divertor_plate[:].n_i.tritium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.tritium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.tungsten (alpha) |  | STRUCTURE |  | Tungsten
summary.local.divertor_plate[:].n_i.tungsten.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.tungsten.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i.xenon (alpha) |  | STRUCTURE |  | Xenon
summary.local.divertor_plate[:].n_i.xenon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i.xenon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].n_i_total (alpha) |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.local.divertor_plate[:].n_i_total.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].n_i_total.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.divertor_plate[:].t_e (alpha) |  | STRUCTURE | eV | Electron temperature
summary.local.divertor_plate[:].t_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].t_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.divertor_plate[:].t_i_average (alpha) |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.local.divertor_plate[:].t_i_average.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].t_i_average.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.divertor_plate[:].zeff (alpha) |  | STRUCTURE | - | Effective charge
summary.local.divertor_plate[:].zeff.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.divertor_plate[:].zeff.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.edge (alpha) |  | STRUCTURE |  | Parameters at last closed flux surface
summary.local.edge.magnetic_shear (alpha) |  | STRUCTURE | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
summary.local.edge.magnetic_shear.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.magnetic_shear.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.edge.momentum_tor (alpha) |  | STRUCTURE | kg.m.s^-1 | Total plasma toroidal momentum, summed over ion species and electrons
summary.local.edge.momentum_tor.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.momentum_tor.value (alpha) | [summary.time] | FLT_1D (uncertain) | kg.m.s^-1 | Value
summary.local.edge.n_e (alpha) |  | STRUCTURE | m^-3 | Electron density
summary.local.edge.n_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.n_i (alpha) |  | STRUCTURE | m^-3 | Ion density per species
summary.local.edge.n_i.argon (alpha) |  | STRUCTURE |  | Argon
summary.local.edge.n_i.argon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_i.argon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.n_i.berylium (alpha) |  | STRUCTURE |  | Berylium
summary.local.edge.n_i.berylium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_i.berylium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.n_i.carbon (alpha) |  | STRUCTURE |  | Carbon
summary.local.edge.n_i.carbon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_i.carbon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.n_i.deuterium (alpha) |  | STRUCTURE |  | Deuterium
summary.local.edge.n_i.deuterium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_i.deuterium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.n_i.helium_3 (alpha) |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.edge.n_i.helium_3.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_i.helium_3.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.n_i.helium_4 (alpha) |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.edge.n_i.helium_4.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_i.helium_4.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.n_i.hydrogen (alpha) |  | STRUCTURE |  | Hydrogen
summary.local.edge.n_i.hydrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_i.hydrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.n_i.lithium (alpha) |  | STRUCTURE |  | Lithium
summary.local.edge.n_i.lithium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_i.lithium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.n_i.neon (alpha) |  | STRUCTURE |  | Neon
summary.local.edge.n_i.neon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_i.neon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.n_i.nitrogen (alpha) |  | STRUCTURE |  | Nitrogen
summary.local.edge.n_i.nitrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_i.nitrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.n_i.oxygen (alpha) |  | STRUCTURE |  | Oxygen
summary.local.edge.n_i.oxygen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_i.oxygen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.n_i.tritium (alpha) |  | STRUCTURE |  | Tritium
summary.local.edge.n_i.tritium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_i.tritium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.n_i.tungsten (alpha) |  | STRUCTURE |  | Tungsten
summary.local.edge.n_i.tungsten.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_i.tungsten.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.n_i.xenon (alpha) |  | STRUCTURE |  | Xenon
summary.local.edge.n_i.xenon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_i.xenon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.n_i_total (alpha) |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.local.edge.n_i_total.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.n_i_total.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.edge.position (alpha) |  | STRUCTURE |  | Radial position at which physics quantities are evaluated
summary.local.edge.position.psi (alpha) | [summary.time] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
summary.local.edge.position.rho_tor (alpha) | [summary.time] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under global_quantities/b0
summary.local.edge.position.rho_tor_norm (alpha) | [summary.time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
summary.local.edge.q (alpha) |  | STRUCTURE | - | Safety factor
summary.local.edge.q.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.q.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.edge.t_e (alpha) |  | STRUCTURE | eV | Electron temperature
summary.local.edge.t_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.t_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.edge.t_i_average (alpha) |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.local.edge.t_i_average.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.t_i_average.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.edge.velocity_tor (alpha) |  | STRUCTURE | m.s^-1 | Ion toroidal rotation velocity, per species
summary.local.edge.velocity_tor.argon (alpha) |  | STRUCTURE |  | Argon
summary.local.edge.velocity_tor.argon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.velocity_tor.argon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.edge.velocity_tor.berylium (alpha) |  | STRUCTURE |  | Berylium
summary.local.edge.velocity_tor.berylium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.velocity_tor.berylium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.edge.velocity_tor.carbon (alpha) |  | STRUCTURE |  | Carbon
summary.local.edge.velocity_tor.carbon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.velocity_tor.carbon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.edge.velocity_tor.deuterium (alpha) |  | STRUCTURE |  | Deuterium
summary.local.edge.velocity_tor.deuterium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.velocity_tor.deuterium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.edge.velocity_tor.helium_3 (alpha) |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.edge.velocity_tor.helium_3.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.velocity_tor.helium_3.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.edge.velocity_tor.helium_4 (alpha) |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.edge.velocity_tor.helium_4.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.velocity_tor.helium_4.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.edge.velocity_tor.hydrogen (alpha) |  | STRUCTURE |  | Hydrogen
summary.local.edge.velocity_tor.hydrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.velocity_tor.hydrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.edge.velocity_tor.lithium (alpha) |  | STRUCTURE |  | Lithium
summary.local.edge.velocity_tor.lithium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.velocity_tor.lithium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.edge.velocity_tor.neon (alpha) |  | STRUCTURE |  | Neon
summary.local.edge.velocity_tor.neon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.velocity_tor.neon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.edge.velocity_tor.nitrogen (alpha) |  | STRUCTURE |  | Nitrogen
summary.local.edge.velocity_tor.nitrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.velocity_tor.nitrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.edge.velocity_tor.oxygen (alpha) |  | STRUCTURE |  | Oxygen
summary.local.edge.velocity_tor.oxygen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.velocity_tor.oxygen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.edge.velocity_tor.tritium (alpha) |  | STRUCTURE |  | Tritium
summary.local.edge.velocity_tor.tritium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.velocity_tor.tritium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.edge.velocity_tor.tungsten (alpha) |  | STRUCTURE |  | Tungsten
summary.local.edge.velocity_tor.tungsten.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.velocity_tor.tungsten.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.edge.velocity_tor.xenon (alpha) |  | STRUCTURE |  | Xenon
summary.local.edge.velocity_tor.xenon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.velocity_tor.xenon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.edge.zeff (alpha) |  | STRUCTURE | - | Effective charge
summary.local.edge.zeff.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.edge.zeff.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.itb (alpha) |  | STRUCTURE |  | Parameters at internal transport barrier
summary.local.itb.magnetic_shear (alpha) |  | STRUCTURE | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
summary.local.itb.magnetic_shear.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.magnetic_shear.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.itb.momentum_tor (alpha) |  | STRUCTURE | kg.m.s^-1 | Total plasma toroidal momentum, summed over ion species and electrons
summary.local.itb.momentum_tor.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.momentum_tor.value (alpha) | [summary.time] | FLT_1D (uncertain) | kg.m.s^-1 | Value
summary.local.itb.n_e (alpha) |  | STRUCTURE | m^-3 | Electron density
summary.local.itb.n_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i (alpha) |  | STRUCTURE | m^-3 | Ion density per species
summary.local.itb.n_i.argon (alpha) |  | STRUCTURE |  | Argon
summary.local.itb.n_i.argon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.argon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.berylium (alpha) |  | STRUCTURE |  | Berylium
summary.local.itb.n_i.berylium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.berylium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.carbon (alpha) |  | STRUCTURE |  | Carbon
summary.local.itb.n_i.carbon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.carbon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.deuterium (alpha) |  | STRUCTURE |  | Deuterium
summary.local.itb.n_i.deuterium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.deuterium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.helium_3 (alpha) |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.itb.n_i.helium_3.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.helium_3.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.helium_4 (alpha) |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.itb.n_i.helium_4.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.helium_4.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.hydrogen (alpha) |  | STRUCTURE |  | Hydrogen
summary.local.itb.n_i.hydrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.hydrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.lithium (alpha) |  | STRUCTURE |  | Lithium
summary.local.itb.n_i.lithium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.lithium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.neon (alpha) |  | STRUCTURE |  | Neon
summary.local.itb.n_i.neon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.neon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.nitrogen (alpha) |  | STRUCTURE |  | Nitrogen
summary.local.itb.n_i.nitrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.nitrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.oxygen (alpha) |  | STRUCTURE |  | Oxygen
summary.local.itb.n_i.oxygen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.oxygen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.tritium (alpha) |  | STRUCTURE |  | Tritium
summary.local.itb.n_i.tritium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.tritium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.tungsten (alpha) |  | STRUCTURE |  | Tungsten
summary.local.itb.n_i.tungsten.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.tungsten.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i.xenon (alpha) |  | STRUCTURE |  | Xenon
summary.local.itb.n_i.xenon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i.xenon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.n_i_total (alpha) |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.local.itb.n_i_total.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.n_i_total.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.itb.position (alpha) |  | STRUCTURE |  | Radial position at which physics quantities are evaluated
summary.local.itb.position.psi (alpha) | [summary.time] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
summary.local.itb.position.rho_tor (alpha) | [summary.time] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under global_quantities/b0
summary.local.itb.position.rho_tor_norm (alpha) | [summary.time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
summary.local.itb.q (alpha) |  | STRUCTURE | - | Safety factor
summary.local.itb.q.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.q.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.itb.t_e (alpha) |  | STRUCTURE | eV | Electron temperature
summary.local.itb.t_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.t_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.itb.t_i_average (alpha) |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.local.itb.t_i_average.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.t_i_average.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.itb.velocity_tor (alpha) |  | STRUCTURE | m.s^-1 | Ion toroidal rotation velocity, per species
summary.local.itb.velocity_tor.argon (alpha) |  | STRUCTURE |  | Argon
summary.local.itb.velocity_tor.argon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.argon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.berylium (alpha) |  | STRUCTURE |  | Berylium
summary.local.itb.velocity_tor.berylium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.berylium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.carbon (alpha) |  | STRUCTURE |  | Carbon
summary.local.itb.velocity_tor.carbon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.carbon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.deuterium (alpha) |  | STRUCTURE |  | Deuterium
summary.local.itb.velocity_tor.deuterium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.deuterium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.helium_3 (alpha) |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.itb.velocity_tor.helium_3.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.helium_3.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.helium_4 (alpha) |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.itb.velocity_tor.helium_4.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.helium_4.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.hydrogen (alpha) |  | STRUCTURE |  | Hydrogen
summary.local.itb.velocity_tor.hydrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.hydrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.lithium (alpha) |  | STRUCTURE |  | Lithium
summary.local.itb.velocity_tor.lithium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.lithium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.neon (alpha) |  | STRUCTURE |  | Neon
summary.local.itb.velocity_tor.neon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.neon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.nitrogen (alpha) |  | STRUCTURE |  | Nitrogen
summary.local.itb.velocity_tor.nitrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.nitrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.oxygen (alpha) |  | STRUCTURE |  | Oxygen
summary.local.itb.velocity_tor.oxygen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.oxygen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.tritium (alpha) |  | STRUCTURE |  | Tritium
summary.local.itb.velocity_tor.tritium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.tritium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.tungsten (alpha) |  | STRUCTURE |  | Tungsten
summary.local.itb.velocity_tor.tungsten.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.tungsten.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.velocity_tor.xenon (alpha) |  | STRUCTURE |  | Xenon
summary.local.itb.velocity_tor.xenon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.velocity_tor.xenon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.itb.zeff (alpha) |  | STRUCTURE | - | Effective charge
summary.local.itb.zeff.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.itb.zeff.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.limiter (alpha) |  | STRUCTURE |  | Parameters at the limiter
summary.local.limiter.flux_expansion (alpha) |  | STRUCTURE | - | Flux expansion
summary.local.limiter.flux_expansion.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.flux_expansion.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.limiter.n_e (alpha) |  | STRUCTURE | m^-3 | Electron density
summary.local.limiter.n_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i (alpha) |  | STRUCTURE | m^-3 | Ion density per species
summary.local.limiter.n_i.argon (alpha) |  | STRUCTURE |  | Argon
summary.local.limiter.n_i.argon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.argon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.berylium (alpha) |  | STRUCTURE |  | Berylium
summary.local.limiter.n_i.berylium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.berylium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.carbon (alpha) |  | STRUCTURE |  | Carbon
summary.local.limiter.n_i.carbon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.carbon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.deuterium (alpha) |  | STRUCTURE |  | Deuterium
summary.local.limiter.n_i.deuterium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.deuterium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.helium_3 (alpha) |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.limiter.n_i.helium_3.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.helium_3.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.helium_4 (alpha) |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.limiter.n_i.helium_4.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.helium_4.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.hydrogen (alpha) |  | STRUCTURE |  | Hydrogen
summary.local.limiter.n_i.hydrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.hydrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.lithium (alpha) |  | STRUCTURE |  | Lithium
summary.local.limiter.n_i.lithium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.lithium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.neon (alpha) |  | STRUCTURE |  | Neon
summary.local.limiter.n_i.neon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.neon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.nitrogen (alpha) |  | STRUCTURE |  | Nitrogen
summary.local.limiter.n_i.nitrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.nitrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.oxygen (alpha) |  | STRUCTURE |  | Oxygen
summary.local.limiter.n_i.oxygen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.oxygen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.tritium (alpha) |  | STRUCTURE |  | Tritium
summary.local.limiter.n_i.tritium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.tritium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.tungsten (alpha) |  | STRUCTURE |  | Tungsten
summary.local.limiter.n_i.tungsten.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.tungsten.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i.xenon (alpha) |  | STRUCTURE |  | Xenon
summary.local.limiter.n_i.xenon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i.xenon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.n_i_total (alpha) |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.local.limiter.n_i_total.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.n_i_total.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.limiter.t_e (alpha) |  | STRUCTURE | eV | Electron temperature
summary.local.limiter.t_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.t_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.limiter.t_i_average (alpha) |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.local.limiter.t_i_average.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.t_i_average.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.limiter.zeff (alpha) |  | STRUCTURE | - | Effective charge
summary.local.limiter.zeff.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.limiter.zeff.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.magnetic_axis (alpha) |  | STRUCTURE |  | Parameters at magnetic axis
summary.local.magnetic_axis.magnetic_shear (alpha) |  | STRUCTURE | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
summary.local.magnetic_axis.magnetic_shear.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.magnetic_shear.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.magnetic_axis.momentum_tor (alpha) |  | STRUCTURE | kg.m.s^-1 | Total plasma toroidal momentum, summed over ion species and electrons
summary.local.magnetic_axis.momentum_tor.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.momentum_tor.value (alpha) | [summary.time] | FLT_1D (uncertain) | kg.m.s^-1 | Value
summary.local.magnetic_axis.n_e (alpha) |  | STRUCTURE | m^-3 | Electron density
summary.local.magnetic_axis.n_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i (alpha) |  | STRUCTURE | m^-3 | Ion density per species
summary.local.magnetic_axis.n_i.argon (alpha) |  | STRUCTURE |  | Argon
summary.local.magnetic_axis.n_i.argon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.argon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.berylium (alpha) |  | STRUCTURE |  | Berylium
summary.local.magnetic_axis.n_i.berylium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.berylium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.carbon (alpha) |  | STRUCTURE |  | Carbon
summary.local.magnetic_axis.n_i.carbon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.carbon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.deuterium (alpha) |  | STRUCTURE |  | Deuterium
summary.local.magnetic_axis.n_i.deuterium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.deuterium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.helium_3 (alpha) |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.magnetic_axis.n_i.helium_3.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.helium_3.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.helium_4 (alpha) |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.magnetic_axis.n_i.helium_4.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.helium_4.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.hydrogen (alpha) |  | STRUCTURE |  | Hydrogen
summary.local.magnetic_axis.n_i.hydrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.hydrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.lithium (alpha) |  | STRUCTURE |  | Lithium
summary.local.magnetic_axis.n_i.lithium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.lithium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.neon (alpha) |  | STRUCTURE |  | Neon
summary.local.magnetic_axis.n_i.neon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.neon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.nitrogen (alpha) |  | STRUCTURE |  | Nitrogen
summary.local.magnetic_axis.n_i.nitrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.nitrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.oxygen (alpha) |  | STRUCTURE |  | Oxygen
summary.local.magnetic_axis.n_i.oxygen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.oxygen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.tritium (alpha) |  | STRUCTURE |  | Tritium
summary.local.magnetic_axis.n_i.tritium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.tritium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.tungsten (alpha) |  | STRUCTURE |  | Tungsten
summary.local.magnetic_axis.n_i.tungsten.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.tungsten.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i.xenon (alpha) |  | STRUCTURE |  | Xenon
summary.local.magnetic_axis.n_i.xenon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i.xenon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.n_i_total (alpha) |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.local.magnetic_axis.n_i_total.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.n_i_total.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.magnetic_axis.position (alpha) |  | STRUCTURE |  | Radial position at which physics quantities are evaluated
summary.local.magnetic_axis.position.psi (alpha) | [summary.time] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
summary.local.magnetic_axis.position.r (alpha) | [summary.time] | FLT_1D (uncertain) | m | Major radius
summary.local.magnetic_axis.position.rho_tor (alpha) | [summary.time] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under global_quantities/b0
summary.local.magnetic_axis.position.rho_tor_norm (alpha) | [summary.time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
summary.local.magnetic_axis.position.z (alpha) | [summary.time] | FLT_1D (uncertain) | m | Height
summary.local.magnetic_axis.q (alpha) |  | STRUCTURE | - | Safety factor
summary.local.magnetic_axis.q.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.q.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.magnetic_axis.t_e (alpha) |  | STRUCTURE | eV | Electron temperature
summary.local.magnetic_axis.t_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.t_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.magnetic_axis.t_i_average (alpha) |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.local.magnetic_axis.t_i_average.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.t_i_average.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.magnetic_axis.velocity_tor (alpha) |  | STRUCTURE | m.s^-1 | Ion toroidal rotation velocity, per species
summary.local.magnetic_axis.velocity_tor.argon (alpha) |  | STRUCTURE |  | Argon
summary.local.magnetic_axis.velocity_tor.argon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.argon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.berylium (alpha) |  | STRUCTURE |  | Berylium
summary.local.magnetic_axis.velocity_tor.berylium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.berylium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.carbon (alpha) |  | STRUCTURE |  | Carbon
summary.local.magnetic_axis.velocity_tor.carbon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.carbon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.deuterium (alpha) |  | STRUCTURE |  | Deuterium
summary.local.magnetic_axis.velocity_tor.deuterium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.deuterium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.helium_3 (alpha) |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.magnetic_axis.velocity_tor.helium_3.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.helium_3.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.helium_4 (alpha) |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.magnetic_axis.velocity_tor.helium_4.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.helium_4.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.hydrogen (alpha) |  | STRUCTURE |  | Hydrogen
summary.local.magnetic_axis.velocity_tor.hydrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.hydrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.lithium (alpha) |  | STRUCTURE |  | Lithium
summary.local.magnetic_axis.velocity_tor.lithium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.lithium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.neon (alpha) |  | STRUCTURE |  | Neon
summary.local.magnetic_axis.velocity_tor.neon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.neon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.nitrogen (alpha) |  | STRUCTURE |  | Nitrogen
summary.local.magnetic_axis.velocity_tor.nitrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.nitrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.oxygen (alpha) |  | STRUCTURE |  | Oxygen
summary.local.magnetic_axis.velocity_tor.oxygen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.oxygen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.tritium (alpha) |  | STRUCTURE |  | Tritium
summary.local.magnetic_axis.velocity_tor.tritium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.tritium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.tungsten (alpha) |  | STRUCTURE |  | Tungsten
summary.local.magnetic_axis.velocity_tor.tungsten.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.tungsten.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.velocity_tor.xenon (alpha) |  | STRUCTURE |  | Xenon
summary.local.magnetic_axis.velocity_tor.xenon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.velocity_tor.xenon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.magnetic_axis.zeff (alpha) |  | STRUCTURE | - | Effective charge
summary.local.magnetic_axis.zeff.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.magnetic_axis.zeff.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.pedestal (alpha) |  | STRUCTURE |  | Parameters at pedestal top
summary.local.pedestal.magnetic_shear (alpha) |  | STRUCTURE | - | Magnetic shear, defined as rho_tor/q . dq/drho_tor
summary.local.pedestal.magnetic_shear.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.magnetic_shear.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.pedestal.momentum_tor (alpha) |  | STRUCTURE | kg.m.s^-1 | Total plasma toroidal momentum, summed over ion species and electrons
summary.local.pedestal.momentum_tor.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.momentum_tor.value (alpha) | [summary.time] | FLT_1D (uncertain) | kg.m.s^-1 | Value
summary.local.pedestal.n_e (alpha) |  | STRUCTURE | m^-3 | Electron density
summary.local.pedestal.n_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i (alpha) |  | STRUCTURE | m^-3 | Ion density per species
summary.local.pedestal.n_i.argon (alpha) |  | STRUCTURE |  | Argon
summary.local.pedestal.n_i.argon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.argon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.berylium (alpha) |  | STRUCTURE |  | Berylium
summary.local.pedestal.n_i.berylium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.berylium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.carbon (alpha) |  | STRUCTURE |  | Carbon
summary.local.pedestal.n_i.carbon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.carbon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.deuterium (alpha) |  | STRUCTURE |  | Deuterium
summary.local.pedestal.n_i.deuterium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.deuterium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.helium_3 (alpha) |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.pedestal.n_i.helium_3.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.helium_3.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.helium_4 (alpha) |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.pedestal.n_i.helium_4.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.helium_4.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.hydrogen (alpha) |  | STRUCTURE |  | Hydrogen
summary.local.pedestal.n_i.hydrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.hydrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.lithium (alpha) |  | STRUCTURE |  | Lithium
summary.local.pedestal.n_i.lithium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.lithium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.neon (alpha) |  | STRUCTURE |  | Neon
summary.local.pedestal.n_i.neon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.neon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.nitrogen (alpha) |  | STRUCTURE |  | Nitrogen
summary.local.pedestal.n_i.nitrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.nitrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.oxygen (alpha) |  | STRUCTURE |  | Oxygen
summary.local.pedestal.n_i.oxygen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.oxygen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.tritium (alpha) |  | STRUCTURE |  | Tritium
summary.local.pedestal.n_i.tritium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.tritium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.tungsten (alpha) |  | STRUCTURE |  | Tungsten
summary.local.pedestal.n_i.tungsten.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.tungsten.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i.xenon (alpha) |  | STRUCTURE |  | Xenon
summary.local.pedestal.n_i.xenon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i.xenon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.n_i_total (alpha) |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.local.pedestal.n_i_total.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.n_i_total.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.local.pedestal.position (alpha) |  | STRUCTURE |  | Radial position at which physics quantities are evaluated
summary.local.pedestal.position.psi (alpha) | [summary.time] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
summary.local.pedestal.position.rho_tor (alpha) | [summary.time] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under global_quantities/b0
summary.local.pedestal.position.rho_tor_norm (alpha) | [summary.time] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
summary.local.pedestal.q (alpha) |  | STRUCTURE | - | Safety factor
summary.local.pedestal.q.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.q.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.local.pedestal.t_e (alpha) |  | STRUCTURE | eV | Electron temperature
summary.local.pedestal.t_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.t_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.pedestal.t_i_average (alpha) |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.local.pedestal.t_i_average.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.t_i_average.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.local.pedestal.velocity_tor (alpha) |  | STRUCTURE | m.s^-1 | Ion toroidal rotation velocity, per species
summary.local.pedestal.velocity_tor.argon (alpha) |  | STRUCTURE |  | Argon
summary.local.pedestal.velocity_tor.argon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.argon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.berylium (alpha) |  | STRUCTURE |  | Berylium
summary.local.pedestal.velocity_tor.berylium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.berylium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.carbon (alpha) |  | STRUCTURE |  | Carbon
summary.local.pedestal.velocity_tor.carbon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.carbon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.deuterium (alpha) |  | STRUCTURE |  | Deuterium
summary.local.pedestal.velocity_tor.deuterium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.deuterium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.helium_3 (alpha) |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.local.pedestal.velocity_tor.helium_3.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.helium_3.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.helium_4 (alpha) |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.local.pedestal.velocity_tor.helium_4.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.helium_4.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.hydrogen (alpha) |  | STRUCTURE |  | Hydrogen
summary.local.pedestal.velocity_tor.hydrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.hydrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.lithium (alpha) |  | STRUCTURE |  | Lithium
summary.local.pedestal.velocity_tor.lithium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.lithium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.neon (alpha) |  | STRUCTURE |  | Neon
summary.local.pedestal.velocity_tor.neon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.neon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.nitrogen (alpha) |  | STRUCTURE |  | Nitrogen
summary.local.pedestal.velocity_tor.nitrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.nitrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.oxygen (alpha) |  | STRUCTURE |  | Oxygen
summary.local.pedestal.velocity_tor.oxygen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.oxygen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.tritium (alpha) |  | STRUCTURE |  | Tritium
summary.local.pedestal.velocity_tor.tritium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.tritium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.tungsten (alpha) |  | STRUCTURE |  | Tungsten
summary.local.pedestal.velocity_tor.tungsten.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.tungsten.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.velocity_tor.xenon (alpha) |  | STRUCTURE |  | Xenon
summary.local.pedestal.velocity_tor.xenon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.velocity_tor.xenon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m.s^-1 | Value
summary.local.pedestal.zeff (alpha) |  | STRUCTURE | - | Effective charge
summary.local.pedestal.zeff.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.local.pedestal.zeff.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.runaways (alpha) |  | STRUCTURE |  | Runaway electrons
summary.runaways.current (alpha) |  | STRUCTURE | A | Parallel current driven by the runaway electrons
summary.runaways.current.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.runaways.current.value (alpha) | [summary.time] | FLT_1D (uncertain) | A | Value
summary.runaways.particles (alpha) |  | STRUCTURE | - | Number of runaway electrons
summary.runaways.particles.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.runaways.particles.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value
summary.scrape_off_layer (alpha) |  | STRUCTURE |  | Scrape-Off-Layer (SOL) characteristics
summary.scrape_off_layer.heat_flux_e_decay_length (alpha) |  | STRUCTURE | m | Electron heat flux radial decay length inv(grad qe/qe)
summary.scrape_off_layer.heat_flux_e_decay_length.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.heat_flux_e_decay_length.value (alpha) | [summary.time] | FLT_1D (uncertain) | m | Value
summary.scrape_off_layer.heat_flux_i_decay_length (alpha) |  | STRUCTURE | m | Ion heat flux radial decay length inv(grad qi/qi)
summary.scrape_off_layer.heat_flux_i_decay_length.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.heat_flux_i_decay_length.value (alpha) | [summary.time] | FLT_1D (uncertain) | m | Value
summary.scrape_off_layer.n_e_decay_length (alpha) |  | STRUCTURE | m | Electron density radial decay length inv(grad ne/ne)
summary.scrape_off_layer.n_e_decay_length.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.n_e_decay_length.value (alpha) | [summary.time] | FLT_1D (uncertain) | m | Value
summary.scrape_off_layer.n_i_total_decay_length (alpha) |  | STRUCTURE | m | Ion density radial decay length inv(grad ni/ni)
summary.scrape_off_layer.n_i_total_decay_length.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.n_i_total_decay_length.value (alpha) | [summary.time] | FLT_1D (uncertain) | m | Value
summary.scrape_off_layer.power_radiated (alpha) |  | STRUCTURE | W | Power radiated from the SOL
summary.scrape_off_layer.power_radiated.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.power_radiated.value (alpha) | [summary.time] | FLT_1D (uncertain) | W | Value
summary.scrape_off_layer.pressure_neutral (alpha) |  | STRUCTURE | Pa | Neutral pressure in the SOL
summary.scrape_off_layer.pressure_neutral.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.pressure_neutral.value (alpha) | [summary.time] | FLT_1D (uncertain) | Pa | Value
summary.scrape_off_layer.t_e_decay_length (alpha) |  | STRUCTURE | m | Electron temperature radial decay length inv(grad Te/Te)
summary.scrape_off_layer.t_e_decay_length.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.t_e_decay_length.value (alpha) | [summary.time] | FLT_1D (uncertain) | m | Value
summary.scrape_off_layer.t_i_average_decay_length (alpha) |  | STRUCTURE | m | Ion temperature (average over ion species) radial decay length inv(grad Ti/Ti)
summary.scrape_off_layer.t_i_average_decay_length.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.scrape_off_layer.t_i_average_decay_length.value (alpha) | [summary.time] | FLT_1D (uncertain) | m | Value
summary.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
summary.time_width (alpha) | [summary.time] | FLT_1D (uncertain) | s | In case the time-dependent quantities of this IDS are averaged over a time interval, this node is the width of this time interval (empty otherwise). By convention, the time interval starts at time-time_width and ends at time.
summary.volume_average (alpha) |  | STRUCTURE |  | Volume average plasma parameters
summary.volume_average.n_e (alpha) |  | STRUCTURE | m^-3 | Electron density
summary.volume_average.n_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i (alpha) |  | STRUCTURE | m^-3 | Ion density per species
summary.volume_average.n_i.argon (alpha) |  | STRUCTURE |  | Argon
summary.volume_average.n_i.argon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.argon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.berylium (alpha) |  | STRUCTURE |  | Berylium
summary.volume_average.n_i.berylium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.berylium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.carbon (alpha) |  | STRUCTURE |  | Carbon
summary.volume_average.n_i.carbon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.carbon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.deuterium (alpha) |  | STRUCTURE |  | Deuterium
summary.volume_average.n_i.deuterium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.deuterium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.helium_3 (alpha) |  | STRUCTURE |  | Helium isotope with 3 nucleons
summary.volume_average.n_i.helium_3.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.helium_3.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.helium_4 (alpha) |  | STRUCTURE |  | Helium isotope with 4 nucleons
summary.volume_average.n_i.helium_4.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.helium_4.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.hydrogen (alpha) |  | STRUCTURE |  | Hydrogen
summary.volume_average.n_i.hydrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.hydrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.lithium (alpha) |  | STRUCTURE |  | Lithium
summary.volume_average.n_i.lithium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.lithium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.neon (alpha) |  | STRUCTURE |  | Neon
summary.volume_average.n_i.neon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.neon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.nitrogen (alpha) |  | STRUCTURE |  | Nitrogen
summary.volume_average.n_i.nitrogen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.nitrogen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.oxygen (alpha) |  | STRUCTURE |  | Oxygen
summary.volume_average.n_i.oxygen.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.oxygen.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.tritium (alpha) |  | STRUCTURE |  | Tritium
summary.volume_average.n_i.tritium.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.tritium.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.tungsten (alpha) |  | STRUCTURE |  | Tungsten
summary.volume_average.n_i.tungsten.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.tungsten.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i.xenon (alpha) |  | STRUCTURE |  | Xenon
summary.volume_average.n_i.xenon.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i.xenon.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.n_i_total (alpha) |  | STRUCTURE | m^-3 | Total ion density (sum over species)
summary.volume_average.n_i_total.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.n_i_total.value (alpha) | [summary.time] | FLT_1D (uncertain) | m^-3 | Value
summary.volume_average.t_e (alpha) |  | STRUCTURE | eV | Electron temperature
summary.volume_average.t_e.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.t_e.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.volume_average.t_i_average (alpha) |  | STRUCTURE | eV | Ion temperature (average over ion species)
summary.volume_average.t_i_average.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.t_i_average.value (alpha) | [summary.time] | FLT_1D (uncertain) | eV | Value
summary.volume_average.zeff (alpha) |  | STRUCTURE | - | Effective charge
summary.volume_average.zeff.source (alpha) |  | STR_0D |  | Source of the data (any comment describing the origin of the data : code, path to diagnostic signals, processing method, ...)
summary.volume_average.zeff.value (alpha) | [summary.time] | FLT_1D (uncertain) | - | Value

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
temporary (alpha) |  |  |  | Storage of undeclared data model components
temporary.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
temporary.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
temporary.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
temporary.code.output_flag (alpha) | [temporary.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
temporary.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
temporary.code.repository (alpha) |  | STR_0D |  | URL of software repository
temporary.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
temporary.constant_float0d (alpha) | [1...N] | STRUCT_ARRAY | mixed | Constant 0D float
temporary.constant_float0d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_float0d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_float0d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.constant_float0d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_float0d[:].value (alpha) |  | FLT_0D (uncertain) | - | Value
temporary.constant_float1d (alpha) | [1...N] | STRUCT_ARRAY | mixed | Constant 1D float
temporary.constant_float1d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_float1d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_float1d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.constant_float1d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_float1d[:].value (alpha) | [1...N] | FLT_1D (uncertain) | - | Value
temporary.constant_float2d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 2D float
temporary.constant_float2d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_float2d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_float2d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.constant_float2d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_float2d[:].value (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | Value
temporary.constant_float3d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 3D float
temporary.constant_float3d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_float3d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_float3d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.constant_float3d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_float3d[:].value (alpha) | [1...N, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Value
temporary.constant_float4d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 4D float
temporary.constant_float4d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_float4d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_float4d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.constant_float4d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_float4d[:].value (alpha) | [1...N, 1...N, 1...N, 1...N] | FLT_4D (uncertain) | mixed | Value
temporary.constant_float5d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 5D float
temporary.constant_float5d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_float5d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_float5d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.constant_float5d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_float5d[:].value (alpha) | [1...N, 1...N, 1...N, 1...N, 1...N] | FLT_5D (uncertain) | mixed | Value
temporary.constant_float6d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 6D float
temporary.constant_float6d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_float6d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_float6d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.constant_float6d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_float6d[:].value (alpha) | [1...N, 1...N, 1...N, 1...N, 1...N, 1...N] | FLT_6D (uncertain) | mixed | Value
temporary.constant_integer0d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 0D integer
temporary.constant_integer0d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_integer0d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_integer0d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.constant_integer0d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_integer0d[:].value (alpha) |  | INT_0D |  | Value
temporary.constant_integer1d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 1D integer
temporary.constant_integer1d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_integer1d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_integer1d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.constant_integer1d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_integer1d[:].value (alpha) | [1...N] | INT_1D |  | Value
temporary.constant_integer2d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 2D integer
temporary.constant_integer2d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_integer2d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_integer2d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.constant_integer2d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_integer2d[:].value (alpha) | [1...N, 1...N] | INT_2D | mixed | Value
temporary.constant_integer3d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 3D integer
temporary.constant_integer3d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_integer3d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_integer3d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.constant_integer3d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_integer3d[:].value (alpha) | [1...N, 1...N, 1...N] | INT_3D | mixed | Value
temporary.constant_string0d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 0D string
temporary.constant_string0d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_string0d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_string0d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.constant_string0d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_string0d[:].value (alpha) |  | STR_0D |  | Value
temporary.constant_string1d (alpha) | [1...N] | STRUCT_ARRAY |  | Constant 1D string
temporary.constant_string1d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.constant_string1d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.constant_string1d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.constant_string1d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.constant_string1d[:].value (alpha) | [1...N] | STR_1D |  | Value
temporary.dynamic_float1d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 1D float
temporary.dynamic_float1d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_float1d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_float1d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.dynamic_float1d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_float1d[:].value (alpha) |  | STRUCTURE |  | Value
temporary.dynamic_float1d[:].value.data (alpha) | [temporary.dynamic_float1d[:].value.time] | FLT_1D (uncertain) | mixed | Value
temporary.dynamic_float1d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
temporary.dynamic_float2d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 2D float
temporary.dynamic_float2d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_float2d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_float2d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.dynamic_float2d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_float2d[:].value (alpha) |  | STRUCTURE |  | Value
temporary.dynamic_float2d[:].value.data (alpha) | [1...N, temporary.dynamic_float2d[:].value.time] | FLT_2D (uncertain) | mixed | Value
temporary.dynamic_float2d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
temporary.dynamic_float3d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 3D float
temporary.dynamic_float3d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_float3d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_float3d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.dynamic_float3d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_float3d[:].value (alpha) |  | STRUCTURE |  | Value
temporary.dynamic_float3d[:].value.data (alpha) | [1...N, 1...N, temporary.dynamic_float3d[:].value.time] | FLT_3D (uncertain) | mixed | Value
temporary.dynamic_float3d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
temporary.dynamic_float4d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 4D float
temporary.dynamic_float4d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_float4d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_float4d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.dynamic_float4d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_float4d[:].value (alpha) |  | STRUCTURE |  | Value
temporary.dynamic_float4d[:].value.data (alpha) | [1...N, 1...N, 1...N, temporary.dynamic_float4d[:].value.time] | FLT_4D (uncertain) | mixed | Value
temporary.dynamic_float4d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
temporary.dynamic_float5d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 5D float
temporary.dynamic_float5d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_float5d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_float5d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.dynamic_float5d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_float5d[:].value (alpha) |  | STRUCTURE |  | Value
temporary.dynamic_float5d[:].value.data (alpha) | [1...N, 1...N, 1...N, 1...N, temporary.dynamic_float5d[:].value.time] | FLT_5D (uncertain) | mixed | Value
temporary.dynamic_float5d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
temporary.dynamic_float6d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 6D float
temporary.dynamic_float6d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_float6d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_float6d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.dynamic_float6d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_float6d[:].value (alpha) |  | STRUCTURE |  | Value
temporary.dynamic_float6d[:].value.data (alpha) | [1...N, 1...N, 1...N, 1...N, 1...N, temporary.dynamic_float6d[:].value.time] | FLT_6D (uncertain) | mixed | Value
temporary.dynamic_float6d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
temporary.dynamic_integer1d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 1D integer
temporary.dynamic_integer1d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_integer1d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_integer1d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.dynamic_integer1d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_integer1d[:].value (alpha) |  | STRUCTURE |  | Value
temporary.dynamic_integer1d[:].value.data (alpha) | [temporary.dynamic_integer1d[:].value.time] | INT_1D | mixed | Value
temporary.dynamic_integer1d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
temporary.dynamic_integer2d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 2D integer
temporary.dynamic_integer2d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_integer2d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_integer2d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.dynamic_integer2d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_integer2d[:].value (alpha) |  | STRUCTURE |  | Value
temporary.dynamic_integer2d[:].value.data (alpha) | [1...N, temporary.dynamic_integer2d[:].value.time] | INT_2D | mixed | Value
temporary.dynamic_integer2d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
temporary.dynamic_integer3d (alpha) | [1...N] | STRUCT_ARRAY |  | Dynamic 3D integer
temporary.dynamic_integer3d[:].identifier (alpha) |  | STRUCTURE |  | Description of the quantity using the standard identifier structure
temporary.dynamic_integer3d[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
temporary.dynamic_integer3d[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
temporary.dynamic_integer3d[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
temporary.dynamic_integer3d[:].value (alpha) |  | STRUCTURE |  | Value
temporary.dynamic_integer3d[:].value.data (alpha) | [1...N, 1...N, temporary.dynamic_integer3d[:].value.time] | INT_3D | mixed | Value
temporary.dynamic_integer3d[:].value.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
temporary.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
temporary.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
temporary.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
temporary.ids_properties.occurrence |  | INT_0D |  |
temporary.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
tf (alpha) |  |  |  | Toroidal field coils
tf.b_field_tor_vacuum_r (alpha) |  | STRUCTURE |  | Vacuum field times major radius in the toroidal field magnet. Positive sign means anti-clockwise when viewed from above
tf.b_field_tor_vacuum_r.data (alpha) | [tf.b_field_tor_vacuum_r.time] | FLT_1D (uncertain) | T.m | Vacuum field times major radius in the toroidal field magnet. Positive sign means anti-clockwise when viewed from above
tf.b_field_tor_vacuum_r.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
tf.coil (alpha) | [1...N] | STRUCT_ARRAY |  | Set of coils around the tokamak
tf.coil[:].conductor (alpha) | [1...N] | STRUCT_ARRAY |  | Set of conductors inside the coil. The structure can be used with size 1 for a simplified description as a single conductor. A conductor is composed of several elements, serially connected, i.e. transporting the same current.
tf.coil[:].conductor[:].cross_section (alpha) |  | STRUCTURE |  | The cross-section perpendicular to the TF conductor contour is described by a series of contour points, given by their relative position with respect to the start point of the first element. This cross-section is assumed constant for all elements.
tf.coil[:].conductor[:].cross_section.delta_phi (alpha) | [tf.coil[:].conductor[:].cross_section.delta_r] | FLT_1D (uncertain) | rad | Toroidal angles (relative to a reference point)
tf.coil[:].conductor[:].cross_section.delta_r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radii (relative to a reference point)
tf.coil[:].conductor[:].cross_section.delta_z (alpha) | [tf.coil[:].conductor[:].cross_section.delta_r] | FLT_1D (uncertain) | m | Heights (relative to a reference point)
tf.coil[:].conductor[:].current (alpha) |  | STRUCTURE |  | Current in the conductor
tf.coil[:].conductor[:].current.data (alpha) | [tf.coil[:].conductor[:].current.time] | FLT_1D (uncertain) | A | Current in the conductor
tf.coil[:].conductor[:].current.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
tf.coil[:].conductor[:].elements (alpha) |  | STRUCTURE |  | Set of geometrical elements (line segments and/or arcs of a circle) describing the contour of the TF conductor centre
tf.coil[:].conductor[:].elements.centres (alpha) |  | STRUCTURE |  | Position of the centre of the arc of a circle of every element (meaningful only if type/index = 2 or 3, fill with default/empty value otherwise)
tf.coil[:].conductor[:].elements.centres.phi (alpha) | [tf.coil[:].conductor[:].elements.centres.r] | FLT_1D (uncertain) | rad | Toroidal angle
tf.coil[:].conductor[:].elements.centres.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
tf.coil[:].conductor[:].elements.centres.z (alpha) | [tf.coil[:].conductor[:].elements.centres.r] | FLT_1D (uncertain) | m | Height
tf.coil[:].conductor[:].elements.end_points (alpha) |  | STRUCTURE |  | Position of the end point of every element. Meaningful only if type/index = 1 or 2, fill with default/empty value otherwise
tf.coil[:].conductor[:].elements.end_points.phi (alpha) | [tf.coil[:].conductor[:].elements.end_points.r] | FLT_1D (uncertain) | rad | Toroidal angle
tf.coil[:].conductor[:].elements.end_points.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
tf.coil[:].conductor[:].elements.end_points.z (alpha) | [tf.coil[:].conductor[:].elements.end_points.r] | FLT_1D (uncertain) | m | Height
tf.coil[:].conductor[:].elements.intermediate_points (alpha) |  | STRUCTURE |  | Position of an intermediate point along the arc of circle, for every element, providing the orientation of the element (must define with the corresponding start point an aperture angle strictly inferior to PI). Meaningful only if type/index = 2, fill with default/empty value otherwise
tf.coil[:].conductor[:].elements.intermediate_points.phi (alpha) | [tf.coil[:].conductor[:].elements.intermediate_points.r] | FLT_1D (uncertain) | rad | Toroidal angle
tf.coil[:].conductor[:].elements.intermediate_points.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
tf.coil[:].conductor[:].elements.intermediate_points.z (alpha) | [tf.coil[:].conductor[:].elements.intermediate_points.r] | FLT_1D (uncertain) | m | Height
tf.coil[:].conductor[:].elements.names (alpha) | [1...N] | STR_1D |  | Name or description of every element
tf.coil[:].conductor[:].elements.start_points (alpha) |  | STRUCTURE |  | Position of the start point of every element
tf.coil[:].conductor[:].elements.start_points.phi (alpha) | [tf.coil[:].conductor[:].elements.start_points.r] | FLT_1D (uncertain) | rad | Toroidal angle
tf.coil[:].conductor[:].elements.start_points.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
tf.coil[:].conductor[:].elements.start_points.z (alpha) | [tf.coil[:].conductor[:].elements.start_points.r] | FLT_1D (uncertain) | m | Height
tf.coil[:].conductor[:].elements.types (alpha) | [tf.coil[:].conductor[:].elements.names] | INT_1D |  | Type of every element: 1: line segment, its ends are given by the start and end points; index = 2: arc of a circle; index = 3: full circle
tf.coil[:].conductor[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | conductor resistance
tf.coil[:].conductor[:].voltage (alpha) |  | STRUCTURE |  | Voltage on the conductor terminals
tf.coil[:].conductor[:].voltage.data (alpha) | [tf.coil[:].conductor[:].voltage.time] | FLT_1D (uncertain) | V | Voltage on the conductor terminals
tf.coil[:].conductor[:].voltage.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
tf.coil[:].current (alpha) |  | STRUCTURE |  | Current in the coil
tf.coil[:].current.data (alpha) | [tf.coil[:].current.time] | FLT_1D (uncertain) | A | Current in the coil
tf.coil[:].current.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
tf.coil[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | Coil resistance
tf.coil[:].turns (alpha) |  | FLT_0D (uncertain) | - | Number of total turns in a toroidal field coil. May be a fraction when describing the coil connections.
tf.coil[:].voltage (alpha) |  | STRUCTURE |  | Voltage on the coil terminals
tf.coil[:].voltage.data (alpha) | [tf.coil[:].voltage.time] | FLT_1D (uncertain) | V | Voltage on the coil terminals
tf.coil[:].voltage.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
tf.coils_n (alpha) |  | INT_0D |  | Number of coils around the torus, in case is_periodic = 1
tf.field_map (alpha) | [tf.field_map[:].time] | STRUCT_ARRAY |  | Map of the vacuum field at various time slices, represented using the generic grid description
tf.field_map[:].a_field_r (alpha) | [1...N] | STRUCT_ARRAY | T.m | R component of the vacuum vector potential, given on various grid subsets
tf.field_map[:].a_field_r[:].coefficients (alpha) | [tf.field_map[:].a_field_r[:].values, 1...N] | FLT_2D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
tf.field_map[:].a_field_r[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
tf.field_map[:].a_field_r[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
tf.field_map[:].a_field_r[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T.m | One scalar value is provided per element in the grid subset.
tf.field_map[:].a_field_tor (alpha) | [1...N] | STRUCT_ARRAY | T.m | Toroidal component of the vacuum vector potential, given on various grid subsets
tf.field_map[:].a_field_tor[:].coefficients (alpha) | [tf.field_map[:].a_field_tor[:].values, 1...N] | FLT_2D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
tf.field_map[:].a_field_tor[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
tf.field_map[:].a_field_tor[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
tf.field_map[:].a_field_tor[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T.m | One scalar value is provided per element in the grid subset.
tf.field_map[:].a_field_z (alpha) | [1...N] | STRUCT_ARRAY | T.m | Z component of the vacuum vector potential, given on various grid subsets
tf.field_map[:].a_field_z[:].coefficients (alpha) | [tf.field_map[:].a_field_z[:].values, 1...N] | FLT_2D (uncertain) | T.m | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
tf.field_map[:].a_field_z[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
tf.field_map[:].a_field_z[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
tf.field_map[:].a_field_z[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T.m | One scalar value is provided per element in the grid subset.
tf.field_map[:].b_field_r (alpha) | [1...N] | STRUCT_ARRAY | T | R component of the vacuum magnetic field, given on various grid subsets
tf.field_map[:].b_field_r[:].coefficients (alpha) | [tf.field_map[:].b_field_r[:].values, 1...N] | FLT_2D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
tf.field_map[:].b_field_r[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
tf.field_map[:].b_field_r[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
tf.field_map[:].b_field_r[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T | One scalar value is provided per element in the grid subset.
tf.field_map[:].b_field_tor (alpha) | [1...N] | STRUCT_ARRAY | T | Toroidal component of the vacuum magnetic field, given on various grid subsets
tf.field_map[:].b_field_tor[:].coefficients (alpha) | [tf.field_map[:].b_field_tor[:].values, 1...N] | FLT_2D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
tf.field_map[:].b_field_tor[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
tf.field_map[:].b_field_tor[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
tf.field_map[:].b_field_tor[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T | One scalar value is provided per element in the grid subset.
tf.field_map[:].b_field_z (alpha) | [1...N] | STRUCT_ARRAY | T | Z component of the vacuum magnetic field, given on various grid subsets
tf.field_map[:].b_field_z[:].coefficients (alpha) | [tf.field_map[:].b_field_z[:].values, 1...N] | FLT_2D (uncertain) | T | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
tf.field_map[:].b_field_z[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
tf.field_map[:].b_field_z[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
tf.field_map[:].b_field_z[:].values (alpha) | [1...N] | FLT_1D (uncertain) | T | One scalar value is provided per element in the grid subset.
tf.field_map[:].grid (alpha) |  | STRUCTURE |  | Grid description
tf.field_map[:].grid.grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
tf.field_map[:].grid.grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
tf.field_map[:].grid.grid_subset[:].base[:].jacobian (alpha) | [tf.field_map[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
tf.field_map[:].grid.grid_subset[:].base[:].tensor_contravariant (alpha) | [tf.field_map[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
tf.field_map[:].grid.grid_subset[:].base[:].tensor_covariant (alpha) | [tf.field_map[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
tf.field_map[:].grid.grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
tf.field_map[:].grid.grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
tf.field_map[:].grid.grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
tf.field_map[:].grid.grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
tf.field_map[:].grid.grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
tf.field_map[:].grid.grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
tf.field_map[:].grid.grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier
tf.field_map[:].grid.grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
tf.field_map[:].grid.grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
tf.field_map[:].grid.grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
tf.field_map[:].grid.grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
tf.field_map[:].grid.grid_subset[:].metric.jacobian (alpha) | [tf.field_map[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
tf.field_map[:].grid.grid_subset[:].metric.tensor_contravariant (alpha) | [tf.field_map[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
tf.field_map[:].grid.grid_subset[:].metric.tensor_covariant (alpha) | [tf.field_map[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
tf.field_map[:].grid.identifier (alpha) |  | STRUCTURE |  | Grid identifier
tf.field_map[:].grid.identifier.description (alpha) |  | STR_0D |  | Verbose description
tf.field_map[:].grid.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
tf.field_map[:].grid.identifier.name (alpha) |  | STR_0D |  | Short string identifier
tf.field_map[:].grid.space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
tf.field_map[:].grid.space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therfore defines the dimension of the space. The meaning of these predefined integer constants can be found in the documentation of the grid service library
tf.field_map[:].grid.space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
tf.field_map[:].grid.space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
tf.field_map[:].grid.space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
tf.field_map[:].grid.space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
tf.field_map[:].grid.space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
tf.field_map[:].grid.space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
tf.field_map[:].grid.space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
tf.field_map[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
tf.field_map[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
tf.field_map[:].grid.space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
tf.field_map[:].grid.space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
tf.field_map[:].grid.space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
tf.field_map[:].time (alpha) |  | FLT_0D | s | Time
tf.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
tf.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
tf.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
tf.ids_properties.occurrence |  | INT_0D |  |
tf.is_periodic (alpha) |  | INT_0D |  | Flag indicating whether coils are described one by one in the coil() structure (flag=0) or whether the coil structure represents only coils having different characteristics (flag = 1, n_coils must be filled in that case). In the latter case, the coil() sequence is repeated periodically around the torus.
tf.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
thomson_scattering (alpha) |  |  |  | Thomson scattering diagnostic
thomson_scattering.channel (alpha) | [1...N] | STRUCT_ARRAY |  | Set of channels (lines-of-sight)
thomson_scattering.channel[:].identifier (alpha) |  | STR_0D |  | ID of the channel
thomson_scattering.channel[:].n_e (alpha) |  | STRUCTURE |  | Electron density
thomson_scattering.channel[:].n_e.data (alpha) | [thomson_scattering.channel[:].n_e.time] | FLT_1D (uncertain) | m^-3 | Electron density
thomson_scattering.channel[:].n_e.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
thomson_scattering.channel[:].name (alpha) |  | STR_0D |  | Name of the channel
thomson_scattering.channel[:].position (alpha) |  | STRUCTURE |  | Position of the measurements (intersection between laser beam and line of sight)
thomson_scattering.channel[:].position.phi (alpha) |  | FLT_0D (uncertain) | rad | Toroidal angle
thomson_scattering.channel[:].position.r (alpha) |  | FLT_0D (uncertain) | m | Major radius
thomson_scattering.channel[:].position.z (alpha) |  | FLT_0D (uncertain) | m | Height
thomson_scattering.channel[:].t_e (alpha) |  | STRUCTURE |  | Electron temperature
thomson_scattering.channel[:].t_e.data (alpha) | [thomson_scattering.channel[:].t_e.time] | FLT_1D (uncertain) | eV | Electron temperature
thomson_scattering.channel[:].t_e.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
thomson_scattering.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
thomson_scattering.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
thomson_scattering.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
thomson_scattering.code.output_flag (alpha) | [thomson_scattering.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
thomson_scattering.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
thomson_scattering.code.repository (alpha) |  | STR_0D |  | URL of software repository
thomson_scattering.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
thomson_scattering.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
thomson_scattering.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
thomson_scattering.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
thomson_scattering.ids_properties.occurrence |  | INT_0D |  |
thomson_scattering.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
transport_solver_numerics (alpha) |  |  |  | Numerical quantities used by transport solvers and convergence details
transport_solver_numerics.boundary_conditions_1d (alpha) | [transport_solver_numerics.boundary_conditions_1d[:].time] | STRUCT_ARRAY |  | Boundary conditions of the radial transport equations for various time slices. To be removed when the profiles_1d structure is finalized.
transport_solver_numerics.boundary_conditions_1d[:].current (alpha) |  | STRUCTURE |  | Boundary condition for the current diffusion equation.
transport_solver_numerics.boundary_conditions_1d[:].current.identifier (alpha) | [transport_solver_numerics.grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: poloidal flux; 2: ip; 3: loop voltage; 4: undefined; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].current.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].current.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_1d[:].current.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].current.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].current.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
transport_solver_numerics.boundary_conditions_1d[:].electrons.energy (alpha) | [transport_solver_numerics.boundary_conditions_1d[:].grid.rho_tor_norm] | STRUCTURE | W.m^-3 | Boundary condition for the electron energy equation (temperature if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].electrons.energy.identifier (alpha) | [transport_solver_numerics.boundary_conditions_1d[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].electrons.energy.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].electrons.energy.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_1d[:].electrons.energy.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].electrons.energy.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].electrons.energy.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].electrons.particles (alpha) | [transport_solver_numerics.boundary_conditions_1d[:].grid.rho_tor_norm] | STRUCTURE | m^-3.s^-1 | Boundary condition for the electron density equation (density if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].electrons.particles.identifier (alpha) | [transport_solver_numerics.boundary_conditions_1d[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].electrons.particles.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].electrons.particles.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_1d[:].electrons.particles.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].electrons.particles.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].electrons.particles.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].energy_ion_total (alpha) | [transport_solver_numerics.grid.rho_tor_norm] | STRUCTURE | W.m^-3 | Boundary condition for the ion total (sum over ion species) energy equation (temperature if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].energy_ion_total.identifier (alpha) | [transport_solver_numerics.grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].energy_ion_total.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].energy_ion_total.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_1d[:].energy_ion_total.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].energy_ion_total.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].energy_ion_total.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
transport_solver_numerics.boundary_conditions_1d[:].ion[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
transport_solver_numerics.boundary_conditions_1d[:].ion[:].energy (alpha) | [transport_solver_numerics.boundary_conditions_1d[:].grid.rho_tor_norm] | STRUCTURE | W.m^-3 | Boundary condition for the ion energy equation (temperature if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].energy.identifier (alpha) | [transport_solver_numerics.boundary_conditions_1d[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].ion[:].energy.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].ion[:].energy.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].energy.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].ion[:].energy.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].energy.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
transport_solver_numerics.boundary_conditions_1d[:].ion[:].particles (alpha) | [transport_solver_numerics.boundary_conditions_1d[:].grid.rho_tor_norm] | STRUCTURE | m^-3.s^-1 | Boundary condition for the ion density equation (density if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].particles.identifier (alpha) | [transport_solver_numerics.boundary_conditions_1d[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].ion[:].particles.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].ion[:].particles.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].particles.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].ion[:].particles.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].particles.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].energy (alpha) | [transport_solver_numerics.boundary_conditions_1d[:].ion[:].grid.rho_tor_norm] | STRUCTURE | W.m^-3 | Boundary condition for the charge state energy equation (temperature if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].energy.identifier (alpha) | [transport_solver_numerics.boundary_conditions_1d[:].ion[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].energy.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].energy.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].energy.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].energy.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].energy.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].is_neutral (alpha) |  | INT_0D |  | Flag specifying if this state corresponds to a neutral (1) or not (0)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].neutral_type (alpha) |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].neutral_type.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].particles (alpha) | [transport_solver_numerics.boundary_conditions_1d[:].ion[:].grid.rho_tor_norm] | STRUCTURE | m^-3.s^-1 | Boundary condition for the charge state density equation (density if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].particles.identifier (alpha) | [transport_solver_numerics.boundary_conditions_1d[:].ion[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].particles.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].particles.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].particles.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].particles.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].particles.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
transport_solver_numerics.boundary_conditions_1d[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
transport_solver_numerics.boundary_conditions_1d[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
transport_solver_numerics.boundary_conditions_1d[:].ion[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
transport_solver_numerics.boundary_conditions_1d[:].momentum_tor (alpha) | [transport_solver_numerics.grid.rho_tor_norm] | STRUCTURE | kg.m.s^-1 | Boundary condition for the total plasma toroidal momentum equation (summed over ion species and electrons) (momentum if ID = 1)
transport_solver_numerics.boundary_conditions_1d[:].momentum_tor.identifier (alpha) | [transport_solver_numerics.grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.boundary_conditions_1d[:].momentum_tor.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_1d[:].momentum_tor.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_1d[:].momentum_tor.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_1d[:].momentum_tor.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.boundary_conditions_1d[:].momentum_tor.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.boundary_conditions_1d[:].time (alpha) |  | FLT_0D | s | Time
transport_solver_numerics.boundary_conditions_ggd (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].time] | STRUCT_ARRAY |  | Boundary conditions of the transport equations, provided on the GGD, for various time slices
transport_solver_numerics.boundary_conditions_ggd[:].current (alpha) | [1...N] | STRUCT_ARRAY |  | Boundary condition for the current diffusion equation, on various grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].current[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
transport_solver_numerics.boundary_conditions_ggd[:].current[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
transport_solver_numerics.boundary_conditions_ggd[:].current[:].identifier (alpha) | [transport_solver_numerics.grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. List of options TBD.
transport_solver_numerics.boundary_conditions_ggd[:].current[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].current[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_ggd[:].current[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].current[:].values (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | List of vector components, one list per element in the grid subset. First dimenstion: element index. Second dimension: vector component index (for ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3)
transport_solver_numerics.boundary_conditions_ggd[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Boundary condition for the electron energy equation (temperature if ID = 1), on various grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy[:].identifier (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. List of options TBD.
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].electrons.energy[:].values (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | List of vector components, one list per element in the grid subset. First dimenstion: element index. Second dimension: vector component index (for ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3)
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles (alpha) | [1...N] | STRUCT_ARRAY | m^-3.s^-1 | Boundary condition for the electron density equation (density if ID = 1), on various grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles[:].identifier (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. List of options TBD.
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].electrons.particles[:].values (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | List of vector components, one list per element in the grid subset. First dimenstion: element index. Second dimension: vector component index (for ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3)
transport_solver_numerics.boundary_conditions_ggd[:].grid (alpha) |  | STRUCTURE |  | Grid description
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].base[:].jacobian (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].base[:].tensor_contravariant (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].base[:].tensor_covariant (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].metric.jacobian (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].metric.tensor_contravariant (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].metric.tensor_covariant (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
transport_solver_numerics.boundary_conditions_ggd[:].grid.identifier (alpha) |  | STRUCTURE |  | Grid identifier
transport_solver_numerics.boundary_conditions_ggd[:].grid.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].grid.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_ggd[:].grid.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].grid.space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therfore defines the dimension of the space. The meaning of these predefined integer constants can be found in the documentation of the grid service library
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
transport_solver_numerics.boundary_conditions_ggd[:].grid.space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
transport_solver_numerics.boundary_conditions_ggd[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Boundary condition for the ion energy equation (temperature if ID = 1), on various grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy[:].identifier (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. List of options TBD.
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].energy[:].values (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | List of vector components, one list per element in the grid subset. First dimenstion: element index. Second dimension: vector component index (for ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles (alpha) | [1...N] | STRUCT_ARRAY | m^-3.s^-1 | Boundary condition for the ion density equation (density if ID = 1), on various grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles[:].identifier (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. List of options TBD.
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].particles[:].values (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | List of vector components, one list per element in the grid subset. First dimenstion: element index. Second dimension: vector component index (for ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy (alpha) | [1...N] | STRUCT_ARRAY | W.m^-3 | Boundary condition for the charge state energy equation (temperature if ID = 1), on various grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy[:].identifier (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].ion[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. List of options TBD.
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].energy[:].values (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | List of vector components, one list per element in the grid subset. First dimenstion: element index. Second dimension: vector component index (for ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].is_neutral (alpha) |  | INT_0D |  | Flag specifying if this state corresponds to a neutral (1) or not (0)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].neutral_type (alpha) |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].neutral_type.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles (alpha) | [1...N] | STRUCT_ARRAY | m^-3.s^-1 | Boundary condition for the charge state density equation (density if ID = 1), on various grid subsets
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles[:].identifier (alpha) | [transport_solver_numerics.boundary_conditions_ggd[:].ion[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. List of options TBD.
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].particles[:].values (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | mixed | List of vector components, one list per element in the grid subset. First dimenstion: element index. Second dimension: vector component index (for ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
transport_solver_numerics.boundary_conditions_ggd[:].ion[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
transport_solver_numerics.boundary_conditions_ggd[:].time (alpha) |  | FLT_0D | s | Time
transport_solver_numerics.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
transport_solver_numerics.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
transport_solver_numerics.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
transport_solver_numerics.code.output_flag (alpha) | [transport_solver_numerics.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
transport_solver_numerics.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
transport_solver_numerics.code.repository (alpha) |  | STR_0D |  | URL of software repository
transport_solver_numerics.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
transport_solver_numerics.convergence (alpha) |  | STRUCTURE |  | Convergence details
transport_solver_numerics.convergence.equations (alpha) | [transport_solver_numerics.convergence.equations[:].time] | STRUCT_ARRAY |  | Convergence details of the transport equations, for various time slices
transport_solver_numerics.convergence.equations[:].current (alpha) |  | STRUCTURE |  | Convergence details of the current diffusion equation
transport_solver_numerics.convergence.equations[:].current.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
transport_solver_numerics.convergence.equations[:].electrons.energy (alpha) | [transport_solver_numerics.convergence.equations[:].grid.rho_tor_norm] | STRUCTURE | W.m^-3 | Convergence details of the electron energy equation
transport_solver_numerics.convergence.equations[:].electrons.energy.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].electrons.particles (alpha) | [transport_solver_numerics.convergence.equations[:].grid.rho_tor_norm] | STRUCTURE | m^-3.s^-1 | Convergence details of the electron density equation
transport_solver_numerics.convergence.equations[:].electrons.particles.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].energy_ion_total (alpha) | [transport_solver_numerics.convergence.grid.rho_tor_norm] | STRUCTURE | W.m^-3 | Convergence details of the ion total (sum over ion species) energy equation
transport_solver_numerics.convergence.equations[:].energy_ion_total.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
transport_solver_numerics.convergence.equations[:].ion[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
transport_solver_numerics.convergence.equations[:].ion[:].energy (alpha) | [transport_solver_numerics.convergence.equations[:].grid.rho_tor_norm] | STRUCTURE | W.m^-3 | Convergence details of the ion energy equation
transport_solver_numerics.convergence.equations[:].ion[:].energy.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].ion[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
transport_solver_numerics.convergence.equations[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
transport_solver_numerics.convergence.equations[:].ion[:].particles (alpha) | [transport_solver_numerics.convergence.equations[:].grid.rho_tor_norm] | STRUCTURE | m^-3.s^-1 | Convergence details of the ion density equation
transport_solver_numerics.convergence.equations[:].ion[:].particles.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].ion[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Convergence details of the related to the different states transport equations
transport_solver_numerics.convergence.equations[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
transport_solver_numerics.convergence.equations[:].ion[:].state[:].energy (alpha) | [transport_solver_numerics.convergence.equations[:].ion[:].grid.rho_tor_norm] | STRUCTURE | W.m^-3 | Convergence details of the charge state energy equation
transport_solver_numerics.convergence.equations[:].ion[:].state[:].energy.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].ion[:].state[:].is_neutral (alpha) |  | INT_0D |  | Flag specifying if this state corresponds to a neutral (1) or not (0)
transport_solver_numerics.convergence.equations[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
transport_solver_numerics.convergence.equations[:].ion[:].state[:].neutral_type (alpha) |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
transport_solver_numerics.convergence.equations[:].ion[:].state[:].neutral_type.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.convergence.equations[:].ion[:].state[:].neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.convergence.equations[:].ion[:].state[:].neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.convergence.equations[:].ion[:].state[:].particles (alpha) | [transport_solver_numerics.convergence.equations[:].ion[:].grid.rho_tor_norm] | STRUCTURE | m^-3.s^-1 | Convergence details of the charge state density equation
transport_solver_numerics.convergence.equations[:].ion[:].state[:].particles.iterations_n (alpha) |  | INT_0D |  | Number of iterations carried out in the convergence loop
transport_solver_numerics.convergence.equations[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
transport_solver_numerics.convergence.equations[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
transport_solver_numerics.convergence.equations[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
transport_solver_numerics.convergence.equations[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
transport_solver_numerics.convergence.equations[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
transport_solver_numerics.convergence.equations[:].ion[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
transport_solver_numerics.convergence.equations[:].time (alpha) |  | FLT_0D | s | Time
transport_solver_numerics.convergence.time_step (alpha) |  | STRUCTURE |  | Internal time step used by the transport solver (assuming all transport equations are solved with the same time step)
transport_solver_numerics.convergence.time_step.data (alpha) | [transport_solver_numerics.convergence.time_step.time] | FLT_1D (uncertain) | s | Internal time step used by the transport solver (assuming all transport equations are solved with the same time step)
transport_solver_numerics.convergence.time_step.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
transport_solver_numerics.derivatives_1d (alpha) | [transport_solver_numerics.derivatives_1d[:].time] | STRUCT_ARRAY |  | Radial profiles derivatives for various time slices. To be removed when the profiles_1d structure is finalized.
transport_solver_numerics.derivatives_1d[:].d2_drho_tor_norm2 (alpha) |  | STRUCTURE |  | Second derivatives of total ion quantities with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].d2_drho_tor_norm2.n_i_total_over_n_e (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Ratio of total ion density (sum over species and charge states) over electron density. (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].d2_drho_tor_norm2.pressure_ion_total (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total thermal ion pressure
transport_solver_numerics.derivatives_1d[:].d2psi_drho_tor2 (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb.m^-2 | Second derivative of the poloidal flux profile with respect to the toroidal flux coordinate
transport_solver_numerics.derivatives_1d[:].d_drho_tor_norm (alpha) |  | STRUCTURE |  | Derivatives of total ion quantities with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].d_drho_tor_norm.n_i_total_over_n_e (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Ratio of total ion density (sum over species and charge states) over electron density. (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].d_drho_tor_norm.pressure_ion_total (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total thermal ion pressure
transport_solver_numerics.derivatives_1d[:].d_dt (alpha) |  | STRUCTURE |  | Derivatives of total ion quantities with respect to time
transport_solver_numerics.derivatives_1d[:].d_dt.n_i_total_over_n_e (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | - | Ratio of total ion density (sum over species and charge states) over electron density. (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].d_dt.pressure_ion_total (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Total thermal ion pressure
transport_solver_numerics.derivatives_1d[:].d_dvolume_drho_tor_dt (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Partial derivative with respect to time of the derivative of the volume with respect to the toroidal flux coordinate
transport_solver_numerics.derivatives_1d[:].dpsi_drho_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb.m^-1 | Derivative of the poloidal flux profile with respect to the toroidal flux coordinate
transport_solver_numerics.derivatives_1d[:].dpsi_dt (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V | Derivative of the poloidal flux profile with respect to time
transport_solver_numerics.derivatives_1d[:].dpsi_dt_cphi (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V | Derivative of the poloidal flux profile with respect to time, at constant toroidal flux
transport_solver_numerics.derivatives_1d[:].dpsi_dt_crho_tor_norm (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V | Derivative of the poloidal flux profile with respect to time, at constant normalised toroidal flux coordinate
transport_solver_numerics.derivatives_1d[:].drho_tor_dt (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Partial derivative of the toroidal flux coordinate profile with respect to time
transport_solver_numerics.derivatives_1d[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2 (alpha) |  | STRUCTURE |  | Second derivatives with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
transport_solver_numerics.derivatives_1d[:].electrons.d2_drho_tor_norm2.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm (alpha) |  | STRUCTURE |  | Derivatives with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
transport_solver_numerics.derivatives_1d[:].electrons.d_drho_tor_norm.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
transport_solver_numerics.derivatives_1d[:].electrons.d_dt (alpha) |  | STRUCTURE |  | Derivatives with respect to time
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
transport_solver_numerics.derivatives_1d[:].electrons.d_dt.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
transport_solver_numerics.derivatives_1d[:].grid (alpha) |  | STRUCTURE |  | Radial grid
transport_solver_numerics.derivatives_1d[:].grid.area (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
transport_solver_numerics.derivatives_1d[:].grid.psi (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
transport_solver_numerics.derivatives_1d[:].grid.rho_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
transport_solver_numerics.derivatives_1d[:].grid.volume (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
transport_solver_numerics.derivatives_1d[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
transport_solver_numerics.derivatives_1d[:].ion[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2 (alpha) |  | STRUCTURE |  | Second derivatives with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d2_drho_tor_norm2.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm (alpha) |  | STRUCTURE |  | Derivatives with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_drho_tor_norm.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt (alpha) |  | STRUCTURE |  | Derivatives with respect to time
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal) (sum over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles (sum over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].d_dt.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity (average over charge states when multiple charge states are considered)
transport_solver_numerics.derivatives_1d[:].ion[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
transport_solver_numerics.derivatives_1d[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
transport_solver_numerics.derivatives_1d[:].ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2 (alpha) |  | STRUCTURE |  | Second derivatives with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d2_drho_tor_norm2.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm (alpha) |  | STRUCTURE |  | Derivatives with respect to the normalised toroidal flux
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_drho_tor_norm.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt (alpha) |  | STRUCTURE |  | Derivatives with respect to time
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.density (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density (thermal+non-thermal)
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.density_fast (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^-3 | Density of fast (non-thermal) particles
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.pressure (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.pressure_fast_parallel (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) parallel pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.pressure_fast_perpendicular (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Pa | Fast (non-thermal) perpendicular pressure
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.temperature (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | eV | Temperature
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.velocity_pol (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Poloidal velocity
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].d_dt.velocity_tor (alpha) | [transport_solver_numerics.derivatives_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Toroidal velocity
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].is_neutral (alpha) |  | INT_0D |  | Flag specifying if this state corresponds to a neutral (1) or not (0)
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].neutral_type (alpha) |  | STRUCTURE |  | Neutral type (if the considered state is a neutral), in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].neutral_type.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle
transport_solver_numerics.derivatives_1d[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
transport_solver_numerics.derivatives_1d[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed)
transport_solver_numerics.derivatives_1d[:].ion[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
transport_solver_numerics.derivatives_1d[:].time (alpha) |  | FLT_0D | s | Time
transport_solver_numerics.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
transport_solver_numerics.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
transport_solver_numerics.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
transport_solver_numerics.ids_properties.occurrence |  | INT_0D |  |
transport_solver_numerics.primary_coordinate (alpha) |  | STRUCTURE |  | Primary coordinate system with which the transport equations are solved. For a 1D transport solver: index = 1 means rho_tor_norm; 2 = rho_tor.
transport_solver_numerics.primary_coordinate.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.primary_coordinate.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.primary_coordinate.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d (alpha) | [transport_solver_numerics.profiles_1d[:].time] | STRUCT_ARRAY |  | Numerics related to 1D radial profiles, for various time slices
transport_solver_numerics.profiles_1d[:].current (alpha) |  | STRUCTURE |  | Quantities related to the current diffusion equation
transport_solver_numerics.profiles_1d[:].current.boundary_condition (alpha) |  | STRUCTURE |  | Boundary condition for the current diffusion equation
transport_solver_numerics.profiles_1d[:].current.boundary_condition.identifier (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: poloidal flux; 2: ip; 3: loop voltage; 4: undefined; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.profiles_1d[:].current.boundary_condition.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].current.boundary_condition.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].current.boundary_condition.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].current.boundary_condition.rho_tor (alpha) |  | FLT_0D (uncertain) | m | Position, in toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].current.boundary_condition.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].current.boundary_condition.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 3, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.profiles_1d[:].current.derivatives (alpha) |  | STRUCTURE |  | Derivatives of the primary quantity
transport_solver_numerics.profiles_1d[:].current.derivatives.d2_drho_tor2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].current.derivatives.d2_drho_tor_norm2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].current.derivatives.d_drho_tor (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].current.derivatives.d_drho_tor_norm (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].current.derivatives.d_dt (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Time derivative
transport_solver_numerics.profiles_1d[:].current.derivatives.d_dt_cphi (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to time, at constant toroidal flux
transport_solver_numerics.profiles_1d[:].current.derivatives.d_dt_crho_tor_norm (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to time, at constant normalised toroidal flux coordinate
transport_solver_numerics.profiles_1d[:].current.primary_quantity (alpha) |  | STRUCTURE |  | Identifier for the primary quantity of the current transport equation: index=0-psi; 1-q; 2-parallel current density
transport_solver_numerics.profiles_1d[:].current.primary_quantity.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].current.primary_quantity.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].current.primary_quantity.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].d_dvolume_drho_tor_dt (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2.s^-1 | Partial derivative with respect to time of the derivative of the volume with respect to the toroidal flux coordinate
transport_solver_numerics.profiles_1d[:].drho_tor_dt (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m.s^-1 | Partial derivative of the toroidal flux coordinate profile with respect to time
transport_solver_numerics.profiles_1d[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electron transport equations
transport_solver_numerics.profiles_1d[:].electrons.energy (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | STRUCTURE | W.m^-3 | Numerics for the electron energy equation
transport_solver_numerics.profiles_1d[:].electrons.energy.boundary_condition (alpha) |  | STRUCTURE |  | Boundary condition (field y designates temperature)
transport_solver_numerics.profiles_1d[:].electrons.energy.boundary_condition.identifier (alpha) | [transport_solver_numerics.profiles_1d[:].electrons.grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.profiles_1d[:].electrons.energy.boundary_condition.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].electrons.energy.boundary_condition.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].electrons.energy.boundary_condition.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].electrons.energy.boundary_condition.rho_tor (alpha) |  | FLT_0D (uncertain) | m | Position, in toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].electrons.energy.boundary_condition.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].electrons.energy.boundary_condition.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.profiles_1d[:].electrons.energy.derivatives (alpha) |  | STRUCTURE |  | Derivatives of the primary quantity
transport_solver_numerics.profiles_1d[:].electrons.energy.derivatives.d2_drho_tor2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].electrons.energy.derivatives.d2_drho_tor_norm2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].electrons.energy.derivatives.d_drho_tor (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].electrons.energy.derivatives.d_drho_tor_norm (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].electrons.energy.derivatives.d_dt (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Time derivative
transport_solver_numerics.profiles_1d[:].electrons.energy.primary_quantity (alpha) |  | STRUCTURE |  | Identifier for the primary quantity of the transport equation (pressure for index = 0, temperature for index=1)
transport_solver_numerics.profiles_1d[:].electrons.energy.primary_quantity.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].electrons.energy.primary_quantity.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].electrons.energy.primary_quantity.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].electrons.particles (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | STRUCTURE | m^-3.s^-1 | Numerics for the electron density equation
transport_solver_numerics.profiles_1d[:].electrons.particles.boundary_condition (alpha) |  | STRUCTURE |  | Boundary condition (field y designates density)
transport_solver_numerics.profiles_1d[:].electrons.particles.boundary_condition.identifier (alpha) | [transport_solver_numerics.profiles_1d[:].electrons.grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.profiles_1d[:].electrons.particles.boundary_condition.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].electrons.particles.boundary_condition.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].electrons.particles.boundary_condition.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].electrons.particles.boundary_condition.rho_tor (alpha) |  | FLT_0D (uncertain) | m | Position, in toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].electrons.particles.boundary_condition.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].electrons.particles.boundary_condition.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.profiles_1d[:].electrons.particles.derivatives (alpha) |  | STRUCTURE |  | Derivatives of the primary quantity
transport_solver_numerics.profiles_1d[:].electrons.particles.derivatives.d2_drho_tor2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].electrons.particles.derivatives.d2_drho_tor_norm2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].electrons.particles.derivatives.d_drho_tor (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].electrons.particles.derivatives.d_drho_tor_norm (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].electrons.particles.derivatives.d_dt (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Time derivative
transport_solver_numerics.profiles_1d[:].electrons.particles.primary_quantity (alpha) |  | STRUCTURE |  | Identifier for the primary quantity of the transport equation (density for index=1)
transport_solver_numerics.profiles_1d[:].electrons.particles.primary_quantity.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].electrons.particles.primary_quantity.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].electrons.particles.primary_quantity.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].energy_ion_total (alpha) | [transport_solver_numerics.grid.rho_tor_norm] | STRUCTURE | W.m^-3 | Numerics for the total ion energy equation
transport_solver_numerics.profiles_1d[:].energy_ion_total.boundary_condition (alpha) |  | STRUCTURE |  | Boundary condition (field y designates temperature)
transport_solver_numerics.profiles_1d[:].energy_ion_total.boundary_condition.identifier (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.profiles_1d[:].energy_ion_total.boundary_condition.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].energy_ion_total.boundary_condition.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].energy_ion_total.boundary_condition.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].energy_ion_total.boundary_condition.rho_tor (alpha) |  | FLT_0D (uncertain) | m | Position, in toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].energy_ion_total.boundary_condition.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].energy_ion_total.boundary_condition.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.profiles_1d[:].energy_ion_total.derivatives (alpha) |  | STRUCTURE |  | Derivatives of the primary quantity
transport_solver_numerics.profiles_1d[:].energy_ion_total.derivatives.d2_drho_tor2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].energy_ion_total.derivatives.d2_drho_tor_norm2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].energy_ion_total.derivatives.d_drho_tor (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].energy_ion_total.derivatives.d_drho_tor_norm (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].energy_ion_total.derivatives.d_dt (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Time derivative
transport_solver_numerics.profiles_1d[:].energy_ion_total.primary_quantity (alpha) |  | STRUCTURE |  | Identifier for the primary quantity of the transport equation (pressure for index = 0, temperature for index=1)
transport_solver_numerics.profiles_1d[:].energy_ion_total.primary_quantity.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].energy_ion_total.primary_quantity.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].energy_ion_total.primary_quantity.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].grid (alpha) |  | STRUCTURE |  | Radial grid
transport_solver_numerics.profiles_1d[:].grid.area (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
transport_solver_numerics.profiles_1d[:].grid.psi (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
transport_solver_numerics.profiles_1d[:].grid.rho_tor (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
transport_solver_numerics.profiles_1d[:].grid.volume (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
transport_solver_numerics.profiles_1d[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
transport_solver_numerics.profiles_1d[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
transport_solver_numerics.profiles_1d[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
transport_solver_numerics.profiles_1d[:].ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
transport_solver_numerics.profiles_1d[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
transport_solver_numerics.profiles_1d[:].ion[:].energy (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | STRUCTURE | W.m^-3 | Numerics for the ion energy equation
transport_solver_numerics.profiles_1d[:].ion[:].energy.boundary_condition (alpha) |  | STRUCTURE |  | Boundary condition (field y designates temperature)
transport_solver_numerics.profiles_1d[:].ion[:].energy.boundary_condition.identifier (alpha) | [transport_solver_numerics.profiles_1d[:].ion[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.profiles_1d[:].ion[:].energy.boundary_condition.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].ion[:].energy.boundary_condition.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].ion[:].energy.boundary_condition.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].ion[:].energy.boundary_condition.rho_tor (alpha) |  | FLT_0D (uncertain) | m | Position, in toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].ion[:].energy.boundary_condition.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].ion[:].energy.boundary_condition.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.profiles_1d[:].ion[:].energy.derivatives (alpha) |  | STRUCTURE |  | Derivatives of the primary quantity
transport_solver_numerics.profiles_1d[:].ion[:].energy.derivatives.d2_drho_tor2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].energy.derivatives.d2_drho_tor_norm2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].energy.derivatives.d_drho_tor (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].energy.derivatives.d_drho_tor_norm (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].energy.derivatives.d_dt (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Time derivative
transport_solver_numerics.profiles_1d[:].ion[:].energy.primary_quantity (alpha) |  | STRUCTURE |  | Identifier for the primary quantity of the transport equation (pressure for index = 0, temperature for index=1)
transport_solver_numerics.profiles_1d[:].ion[:].energy.primary_quantity.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].ion[:].energy.primary_quantity.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].ion[:].energy.primary_quantity.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].ion[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
transport_solver_numerics.profiles_1d[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
transport_solver_numerics.profiles_1d[:].ion[:].neutral_index (alpha) |  | INT_0D |  | Index of the corresponding neutral species in the ../../neutral array
transport_solver_numerics.profiles_1d[:].ion[:].particles (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | STRUCTURE | m^-3.s^-1 | Numerics for the ion density equation
transport_solver_numerics.profiles_1d[:].ion[:].particles.boundary_condition (alpha) |  | STRUCTURE |  | Boundary condition (field y designates density)
transport_solver_numerics.profiles_1d[:].ion[:].particles.boundary_condition.identifier (alpha) | [transport_solver_numerics.profiles_1d[:].ion[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.profiles_1d[:].ion[:].particles.boundary_condition.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].ion[:].particles.boundary_condition.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].ion[:].particles.boundary_condition.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].ion[:].particles.boundary_condition.rho_tor (alpha) |  | FLT_0D (uncertain) | m | Position, in toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].ion[:].particles.boundary_condition.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].ion[:].particles.boundary_condition.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.profiles_1d[:].ion[:].particles.derivatives (alpha) |  | STRUCTURE |  | Derivatives of the primary quantity
transport_solver_numerics.profiles_1d[:].ion[:].particles.derivatives.d2_drho_tor2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].particles.derivatives.d2_drho_tor_norm2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].particles.derivatives.d_drho_tor (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].particles.derivatives.d_drho_tor_norm (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].particles.derivatives.d_dt (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Time derivative
transport_solver_numerics.profiles_1d[:].ion[:].particles.primary_quantity (alpha) |  | STRUCTURE |  | Identifier for the primary quantity of the transport equation (density for index=1)
transport_solver_numerics.profiles_1d[:].ion[:].particles.primary_quantity.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].ion[:].particles.primary_quantity.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].ion[:].particles.primary_quantity.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].ion[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
transport_solver_numerics.profiles_1d[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy (alpha) | [transport_solver_numerics.profiles_1d[:].ion[:].grid.rho_tor_norm] | STRUCTURE | W.m^-3 | Numerics for the state energy equation
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.boundary_condition (alpha) |  | STRUCTURE |  | Boundary condition (field y designates temperature)
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.boundary_condition.identifier (alpha) | [transport_solver_numerics.profiles_1d[:].ion[:].state[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.boundary_condition.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.boundary_condition.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.boundary_condition.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.boundary_condition.rho_tor (alpha) |  | FLT_0D (uncertain) | m | Position, in toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.boundary_condition.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.boundary_condition.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.derivatives (alpha) |  | STRUCTURE |  | Derivatives of the primary quantity
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.derivatives.d2_drho_tor2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.derivatives.d2_drho_tor_norm2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.derivatives.d_drho_tor (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.derivatives.d_drho_tor_norm (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.derivatives.d_dt (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Time derivative
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.primary_quantity (alpha) |  | STRUCTURE |  | Identifier for the primary quantity of the transport equation (pressure for index = 0, temperature for index=1)
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.primary_quantity.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.primary_quantity.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].ion[:].state[:].energy.primary_quantity.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].ion[:].state[:].ionisation_potential (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Cumulative and average ionisation potential to reach a given bundle. Defined as sum (x_z* (sum of Epot from z'=0 to z-1)), where Epot is the ionisation potential of ion Xz_+, and x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
transport_solver_numerics.profiles_1d[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles (alpha) | [transport_solver_numerics.profiles_1d[:].ion[:].grid.rho_tor_norm] | STRUCTURE | m^-3.s^-1 | Numerics for the state density equation
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.boundary_condition (alpha) |  | STRUCTURE |  | Boundary condition (field y designates density)
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.boundary_condition.identifier (alpha) | [transport_solver_numerics.profiles_1d[:].ion[:].state[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.boundary_condition.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.boundary_condition.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.boundary_condition.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.boundary_condition.rho_tor (alpha) |  | FLT_0D (uncertain) | m | Position, in toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.boundary_condition.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.boundary_condition.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.derivatives (alpha) |  | STRUCTURE |  | Derivatives of the primary quantity
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.derivatives.d2_drho_tor2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.derivatives.d2_drho_tor_norm2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.derivatives.d_drho_tor (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.derivatives.d_drho_tor_norm (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.derivatives.d_dt (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Time derivative
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.primary_quantity (alpha) |  | STRUCTURE |  | Identifier for the primary quantity of the transport equation (density for index=1)
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.primary_quantity.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.primary_quantity.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].ion[:].state[:].particles.primary_quantity.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
transport_solver_numerics.profiles_1d[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
transport_solver_numerics.profiles_1d[:].ion[:].state[:].z_average (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Average Z of the charge state bundle (equal to z_min if no bundle), = sum (Z*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
transport_solver_numerics.profiles_1d[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
transport_solver_numerics.profiles_1d[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle
transport_solver_numerics.profiles_1d[:].ion[:].state[:].z_square_average (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Average Z square of the charge state bundle (equal to z_min if no bundle), = sum (Z^2*x_z) where x_z is the relative concentration of a given charge state in the bundle, i.e. sum(x_z) = 1 over the bundle.
transport_solver_numerics.profiles_1d[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed), volume averaged over plasma radius
transport_solver_numerics.profiles_1d[:].momentum_tor (alpha) | [transport_solver_numerics.grid.rho_tor_norm] | STRUCTURE | W.m^-3 | Numerics for the total plasma toroidal momentum equation (summed over ion species and electrons)
transport_solver_numerics.profiles_1d[:].momentum_tor.boundary_condition (alpha) |  | STRUCTURE |  | Boundary condition (field y designates toroidal momentum)
transport_solver_numerics.profiles_1d[:].momentum_tor.boundary_condition.identifier (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.profiles_1d[:].momentum_tor.boundary_condition.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].momentum_tor.boundary_condition.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].momentum_tor.boundary_condition.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].momentum_tor.boundary_condition.rho_tor (alpha) |  | FLT_0D (uncertain) | m | Position, in toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].momentum_tor.boundary_condition.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].momentum_tor.boundary_condition.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.profiles_1d[:].momentum_tor.derivatives (alpha) |  | STRUCTURE |  | Derivatives of the primary quantity
transport_solver_numerics.profiles_1d[:].momentum_tor.derivatives.d2_drho_tor2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].momentum_tor.derivatives.d2_drho_tor_norm2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].momentum_tor.derivatives.d_drho_tor (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].momentum_tor.derivatives.d_drho_tor_norm (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].momentum_tor.derivatives.d_dt (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Time derivative
transport_solver_numerics.profiles_1d[:].momentum_tor.primary_quantity (alpha) |  | STRUCTURE |  | Identifier for the primary quantity of the transport equation (toroidal momentum for index=1)
transport_solver_numerics.profiles_1d[:].momentum_tor.primary_quantity.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].momentum_tor.primary_quantity.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].momentum_tor.primary_quantity.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].neutral (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different neutral species
transport_solver_numerics.profiles_1d[:].neutral[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
transport_solver_numerics.profiles_1d[:].neutral[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
transport_solver_numerics.profiles_1d[:].neutral[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
transport_solver_numerics.profiles_1d[:].neutral[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
transport_solver_numerics.profiles_1d[:].neutral[:].energy (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | STRUCTURE | W.m^-3 | Numerics for the neutral energy equation
transport_solver_numerics.profiles_1d[:].neutral[:].energy.boundary_condition (alpha) |  | STRUCTURE |  | Boundary condition (field y designates temperature)
transport_solver_numerics.profiles_1d[:].neutral[:].energy.boundary_condition.identifier (alpha) | [transport_solver_numerics.profiles_1d[:].neutral[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.profiles_1d[:].neutral[:].energy.boundary_condition.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].neutral[:].energy.boundary_condition.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].neutral[:].energy.boundary_condition.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].neutral[:].energy.boundary_condition.rho_tor (alpha) |  | FLT_0D (uncertain) | m | Position, in toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].neutral[:].energy.boundary_condition.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].neutral[:].energy.boundary_condition.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.profiles_1d[:].neutral[:].energy.derivatives (alpha) |  | STRUCTURE |  | Derivatives of the primary quantity
transport_solver_numerics.profiles_1d[:].neutral[:].energy.derivatives.d2_drho_tor2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].energy.derivatives.d2_drho_tor_norm2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].energy.derivatives.d_drho_tor (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].energy.derivatives.d_drho_tor_norm (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].energy.derivatives.d_dt (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Time derivative
transport_solver_numerics.profiles_1d[:].neutral[:].energy.primary_quantity (alpha) |  | STRUCTURE |  | Identifier for the primary quantity of the transport equation (pressure for index = 0, temperature for index=1)
transport_solver_numerics.profiles_1d[:].neutral[:].energy.primary_quantity.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].neutral[:].energy.primary_quantity.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].neutral[:].energy.primary_quantity.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].neutral[:].ion_index (alpha) |  | INT_0D |  | Index of the corresponding ion species in the ../../ion array
transport_solver_numerics.profiles_1d[:].neutral[:].label (alpha) |  | STR_0D |  | String identifying ion (e.g. H+, D+, T+, He+2, C+, ...)
transport_solver_numerics.profiles_1d[:].neutral[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple states calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
transport_solver_numerics.profiles_1d[:].neutral[:].particles (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | STRUCTURE | m^-3.s^-1 | Numerics for the neutral density equation
transport_solver_numerics.profiles_1d[:].neutral[:].particles.boundary_condition (alpha) |  | STRUCTURE |  | Boundary condition (field y designates density)
transport_solver_numerics.profiles_1d[:].neutral[:].particles.boundary_condition.identifier (alpha) | [transport_solver_numerics.profiles_1d[:].neutral[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.profiles_1d[:].neutral[:].particles.boundary_condition.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].neutral[:].particles.boundary_condition.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].neutral[:].particles.boundary_condition.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].neutral[:].particles.boundary_condition.rho_tor (alpha) |  | FLT_0D (uncertain) | m | Position, in toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].neutral[:].particles.boundary_condition.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].neutral[:].particles.boundary_condition.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.profiles_1d[:].neutral[:].particles.derivatives (alpha) |  | STRUCTURE |  | Derivatives of the primary quantity
transport_solver_numerics.profiles_1d[:].neutral[:].particles.derivatives.d2_drho_tor2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].particles.derivatives.d2_drho_tor_norm2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].particles.derivatives.d_drho_tor (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].particles.derivatives.d_drho_tor_norm (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].particles.derivatives.d_dt (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Time derivative
transport_solver_numerics.profiles_1d[:].neutral[:].particles.primary_quantity (alpha) |  | STRUCTURE |  | Identifier for the primary quantity of the transport equation (density for index=1)
transport_solver_numerics.profiles_1d[:].neutral[:].particles.primary_quantity.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].neutral[:].particles.primary_quantity.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].neutral[:].particles.primary_quantity.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].neutral[:].state (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different states of the species (ionisation, energy, excitation, ...)
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy (alpha) | [transport_solver_numerics.profiles_1d[:].neutral[:].grid.rho_tor_norm] | STRUCTURE | W.m^-3 | Numerics for the state energy equation
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.boundary_condition (alpha) |  | STRUCTURE |  | Boundary condition (field y designates temperature)
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.boundary_condition.identifier (alpha) | [transport_solver_numerics.profiles_1d[:].neutral[:].state[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.boundary_condition.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.boundary_condition.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.boundary_condition.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.boundary_condition.rho_tor (alpha) |  | FLT_0D (uncertain) | m | Position, in toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.boundary_condition.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.boundary_condition.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.derivatives (alpha) |  | STRUCTURE |  | Derivatives of the primary quantity
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.derivatives.d2_drho_tor2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.derivatives.d2_drho_tor_norm2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.derivatives.d_drho_tor (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.derivatives.d_drho_tor_norm (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.derivatives.d_dt (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Time derivative
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.primary_quantity (alpha) |  | STRUCTURE |  | Identifier for the primary quantity of the transport equation (pressure for index = 0, temperature for index=1)
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.primary_quantity.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.primary_quantity.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].energy.primary_quantity.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].label (alpha) |  | STR_0D |  | String identifying state
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].neutral_type (alpha) |  | STRUCTURE |  | Neutral type, in terms of energy. ID =1: cold; 2: thermal; 3: fast; 4: NBI
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].neutral_type.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].neutral_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].neutral_type.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles (alpha) | [transport_solver_numerics.profiles_1d[:].neutral[:].grid.rho_tor_norm] | STRUCTURE | m^-3.s^-1 | Numerics for the state density equation
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.boundary_condition (alpha) |  | STRUCTURE |  | Boundary condition (field y designates density)
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.boundary_condition.identifier (alpha) | [transport_solver_numerics.profiles_1d[:].neutral[:].state[:].grid.rho_tor_norm] | STRUCTURE | eV | Identifier of the boundary condition type. ID = 1: value of the field y; 2: radial derivative of the field (-dy/drho_tor); 3: scale length of the field y/(-dy/drho_tor); 4: flux; 5: generic boundary condition y expressed as a1y'+a2y=a3. 6: equation not solved;
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.boundary_condition.identifier.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.boundary_condition.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.boundary_condition.identifier.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.boundary_condition.rho_tor (alpha) |  | FLT_0D (uncertain) | m | Position, in toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.boundary_condition.rho_tor_norm (alpha) |  | FLT_0D (uncertain) | - | Position, in normalised toroidal flux, at which the boundary condition is imposed. Outside this position, the value of the data are considered to be prescribed.
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.boundary_condition.value (alpha) | [1...3] | FLT_1D (uncertain) | mixed | Value of the boundary condition. For ID = 1 to 4, only the first position in the vector is used. For ID = 5, all three positions are used, meaning respectively a1, a2, a3.
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.derivatives (alpha) |  | STRUCTURE |  | Derivatives of the primary quantity
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.derivatives.d2_drho_tor2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.derivatives.d2_drho_tor_norm2 (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Second derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.derivatives.d_drho_tor (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.derivatives.d_drho_tor_norm (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Derivative with respect to the normalised toroidal flux
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.derivatives.d_dt (alpha) | [transport_solver_numerics.profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | mixed | Time derivative
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.primary_quantity (alpha) |  | STRUCTURE |  | Identifier for the primary quantity of the transport equation (density for index=1)
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.primary_quantity.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.primary_quantity.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].particles.primary_quantity.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
transport_solver_numerics.profiles_1d[:].neutral[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
transport_solver_numerics.profiles_1d[:].time (alpha) |  | FLT_0D | s | Time
transport_solver_numerics.restart_files (alpha) | [transport_solver_numerics.restart_files[:].time] | STRUCT_ARRAY |  | Set of code-specific restart files for a given time slice. These files are managed by a physical application to ensure its restart during long simulations
transport_solver_numerics.restart_files[:].descriptions (alpha) | [transport_solver_numerics.restart_files[:].names] | STR_1D |  | Descriptions of the restart files
transport_solver_numerics.restart_files[:].names (alpha) | [1...N] | STR_1D |  | Names of the restart files
transport_solver_numerics.restart_files[:].time (alpha) |  | FLT_0D | s | Time
transport_solver_numerics.solver (alpha) |  | STRUCTURE |  | Solver identifier
transport_solver_numerics.solver.description (alpha) |  | STR_0D |  | Verbose description
transport_solver_numerics.solver.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
transport_solver_numerics.solver.name (alpha) |  | STR_0D |  | Short string identifier
transport_solver_numerics.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
transport_solver_numerics.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition and in the normalization of current densities)
transport_solver_numerics.vacuum_toroidal_field.b0 (alpha) | [transport_solver_numerics.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewed from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
transport_solver_numerics.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
wall (alpha) |  |  |  | Description of the torus wall and its interaction with the plasma
wall.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
wall.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
wall.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
wall.code.output_flag (alpha) | [wall.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
wall.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
wall.code.repository (alpha) |  | STR_0D |  | URL of software repository
wall.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
wall.description_2d (alpha) | [1...N] | STRUCT_ARRAY |  | Set of 2D wall descriptions, for each type of possible physics or engineering configurations necessary (gas tight vs wall with ports and holes, coarse vs fine representation, single contour limiter, disjoint gapped plasma facing components, ...).
wall.description_2d[:].limiter (alpha) |  | STRUCTURE |  | Description of the immobile limiting surface(s) or plasma facing components for defining the Last Closed Flux Surface.
wall.description_2d[:].limiter.type (alpha) |  | STRUCTURE |  | Type of the limiter description. index = 0 for the official single contour limiter and 1 for the official disjoint PFC structure like first wall. Additional representations needed on a code-by-code basis follow same incremental pair tagging starting on flag=2
wall.description_2d[:].limiter.type.description (alpha) |  | STR_0D |  | Verbose description
wall.description_2d[:].limiter.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
wall.description_2d[:].limiter.type.name (alpha) |  | STR_0D |  | Short string identifier
wall.description_2d[:].limiter.unit (alpha) | [1...N] | STRUCT_ARRAY |  | Set of limiter units
wall.description_2d[:].limiter.unit[:].closed (alpha) |  | INT_0D |  | Flag identifying whether the contour is closed (1) or open (0)
wall.description_2d[:].limiter.unit[:].name (alpha) |  | STR_0D |  | Name of the limiter unit
wall.description_2d[:].limiter.unit[:].outline (alpha) |  | STRUCTURE |  | Irregular outline of the limiting surface. Do NOT repeat the first point for closed contours
wall.description_2d[:].limiter.unit[:].outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
wall.description_2d[:].limiter.unit[:].outline.z (alpha) | [wall.description_2d[:].limiter.unit[:].outline.r] | FLT_1D (uncertain) | m | Height
wall.description_2d[:].limiter.unit[:].resistivity (alpha) |  | FLT_0D (uncertain) | ohm.m | Resistivity of the limiter unit
wall.description_2d[:].type (alpha) |  | STRUCTURE |  | Type of the description. index = 0 for equilibrium codes (single closed limiter and vessel); 1 for gas-tight walls (disjoint PFCs with inner vessel as last limiter_unit; no vessel structure); 2 for free boundary codes (disjoint PFCs and vessel)
wall.description_2d[:].type.description (alpha) |  | STR_0D |  | Verbose description
wall.description_2d[:].type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
wall.description_2d[:].type.name (alpha) |  | STR_0D |  | Short string identifier
wall.description_2d[:].vessel (alpha) |  | STRUCTURE |  | Mechanical structure of the vacuum vessel. The vessel is described as a set of nested layers with given physics properties; Two representations are admitted for each vessel unit : annular (two contours) or block elements.
wall.description_2d[:].vessel.type (alpha) |  | STRUCTURE |  | Type of the vessel description. index = 0 for the official single/multiple annular vessel and 1 for the official block element representation for each vessel unit. Additional representations needed on a code-by-code basis follow same incremental pair tagging starting on flag=2
wall.description_2d[:].vessel.type.description (alpha) |  | STR_0D |  | Verbose description
wall.description_2d[:].vessel.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
wall.description_2d[:].vessel.type.name (alpha) |  | STR_0D |  | Short string identifier
wall.description_2d[:].vessel.unit (alpha) | [1...N] | STRUCT_ARRAY |  | Set of vessel units
wall.description_2d[:].vessel.unit[:].annular (alpha) |  | STRUCTURE |  | Annular representation of a vessel layer by two contours, inner and outer
wall.description_2d[:].vessel.unit[:].annular.outline_inner (alpha) |  | STRUCTURE |  | Inner vessel outline. Do NOT repeat the first point for closed contours
wall.description_2d[:].vessel.unit[:].annular.outline_inner.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
wall.description_2d[:].vessel.unit[:].annular.outline_inner.z (alpha) | [wall.description_2d[:].vessel.unit[:].annular.outline_inner.r] | FLT_1D (uncertain) | m | Height
wall.description_2d[:].vessel.unit[:].annular.outline_outer (alpha) |  | STRUCTURE |  | Outer vessel outline. Do NOT repeat the first point for closed contours
wall.description_2d[:].vessel.unit[:].annular.outline_outer.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
wall.description_2d[:].vessel.unit[:].annular.outline_outer.z (alpha) | [wall.description_2d[:].vessel.unit[:].annular.outline_outer.r] | FLT_1D (uncertain) | m | Height
wall.description_2d[:].vessel.unit[:].annular.resistivity (alpha) |  | FLT_0D (uncertain) | ohm.m | Resistivity of the vessel unit
wall.description_2d[:].vessel.unit[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of block elements
wall.description_2d[:].vessel.unit[:].element[:].j_tor (alpha) |  | STRUCTURE |  | Toroidal current induced in this block element
wall.description_2d[:].vessel.unit[:].element[:].j_tor.data (alpha) | [wall.description_2d[:].vessel.unit[:].element[:].j_tor.time] | FLT_1D (uncertain) | A | Toroidal current induced in this block element
wall.description_2d[:].vessel.unit[:].element[:].j_tor.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
wall.description_2d[:].vessel.unit[:].element[:].name (alpha) |  | STR_0D |  | Name of the block element
wall.description_2d[:].vessel.unit[:].element[:].outline (alpha) |  | STRUCTURE |  | Outline of the block element. Do NOT repeat the first point for closed contours
wall.description_2d[:].vessel.unit[:].element[:].outline.r (alpha) | [1...N] | FLT_1D (uncertain) | m | Major radius
wall.description_2d[:].vessel.unit[:].element[:].outline.z (alpha) | [wall.description_2d[:].vessel.unit[:].element[:].outline.r] | FLT_1D (uncertain) | m | Height
wall.description_2d[:].vessel.unit[:].element[:].resistance (alpha) |  | FLT_0D (uncertain) | Ohm | Resistance of the block element
wall.description_2d[:].vessel.unit[:].element[:].resistivity (alpha) |  | FLT_0D (uncertain) | ohm.m | Resistivity of the block element
wall.description_2d[:].vessel.unit[:].name (alpha) |  | STR_0D |  | Name of the vessel unit
wall.global_quantities (alpha) |  | STRUCTURE |  | Simple 0D description of plasma-wall interaction
wall.global_quantities.electrons (alpha) |  | STRUCTURE |  | Quantities related to electrons
wall.global_quantities.electrons.gas_puff (alpha) | [wall.time] | FLT_1D (uncertain) | s^-1 | Gas puff rate (in equivalent electrons)
wall.global_quantities.electrons.particle_flux_from_plasma (alpha) | [wall.time] | FLT_1D (uncertain) | s^-1 | Particle flux from the plasma (in equivalent electrons)
wall.global_quantities.electrons.particle_flux_from_wall (alpha) | [1...3, wall.time] | FLT_2D (uncertain) | s^-1 | Particle flux from the wall corresponding to the conversion into various neutral types (first dimension: 1: cold; 2: thermal; 3: fast), in equivalent electrons
wall.global_quantities.electrons.pumping_speed (alpha) | [wall.time] | FLT_1D (uncertain) | s^-1 | Pumped particle flux (in equivalent electrons)
wall.global_quantities.neutral (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the various neutral species
wall.global_quantities.neutral[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
wall.global_quantities.neutral[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
wall.global_quantities.neutral[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
wall.global_quantities.neutral[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
wall.global_quantities.neutral[:].gas_puff (alpha) | [wall.time] | FLT_1D (uncertain) | s^-1 | Gas puff rate for that species
wall.global_quantities.neutral[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H, D, CD4, ...)
wall.global_quantities.neutral[:].particle_flux_from_plasma (alpha) | [wall.time] | FLT_1D (uncertain) | s^-1 | Particle flux from the plasma for that species
wall.global_quantities.neutral[:].particle_flux_from_wall (alpha) | [1...3, wall.time] | FLT_2D (uncertain) | s^-1 | Particle flux from the wall corresponding to the conversion into various neutral types (first dimension: 1: cold; 2: thermal; 3: fast)
wall.global_quantities.neutral[:].pumping_speed (alpha) | [wall.time] | FLT_1D (uncertain) | s^-1 | Pumped particle flux for that species
wall.global_quantities.neutral[:].recycling_energy_coefficient (alpha) | [1...3, wall.time] | FLT_2D (uncertain) | - | Energy recycling coefficient corresponding to the conversion into various neutral types (first dimension: 1: cold; 2: thermal; 3: fast)
wall.global_quantities.neutral[:].recycling_particles_coefficient (alpha) | [1...3, wall.time] | FLT_2D (uncertain) | - | Particle recycling coefficient corresponding to the conversion into various neutral types (first dimension: 1: cold; 2: thermal; 3: fast)
wall.global_quantities.neutral[:].sputtering_chemical_coefficient (alpha) | [1...3, wall.time] | FLT_2D (uncertain) | - | Effective coefficient of chemical sputtering for various neutral types (first dimension: 1: cold; 2: thermal; 3: fast)
wall.global_quantities.neutral[:].sputtering_physical_coefficient (alpha) | [1...3, wall.time] | FLT_2D (uncertain) | - | Effective coefficient of physical sputtering for various neutral types (first dimension: 1: cold; 2: thermal; 3: fast)
wall.global_quantities.neutral[:].wall_inventory (alpha) | [wall.time] | FLT_1D (uncertain) | - | Wall inventory, i.e. cumulated exchange of neutral species between plasma and wall from t = 0, positive if a species has gone to the wall, for that species
wall.global_quantities.power_from_plasma (alpha) | [wall.time] | FLT_1D (uncertain) | W | Power flowing from the plasma to the wall
wall.global_quantities.power_to_cooling (alpha) | [wall.time] | FLT_1D (uncertain) | W | Power to cooling systems
wall.global_quantities.temperature (alpha) | [wall.time] | FLT_1D (uncertain) | K | Wall temperature
wall.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
wall.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
wall.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
wall.ids_properties.occurrence |  | INT_0D |  |
wall.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]

Path | Dimensions | Type | Units | Description
--- | --- | --- | --- | ---
waves (alpha) |  |  |  | RF wave propagation and deposition
waves.code (alpha) |  | STRUCTURE |  | Generic decription of the code-specific parameters for the code that has produced this IDS
waves.code.commit (alpha) |  | STR_0D |  | Unique commit reference of software
waves.code.name (alpha) |  | STR_0D |  | Name of software generating IDS
waves.code.output_flag (alpha) | [waves.time] | INT_1D |  | Output flag : 0 means the run is successful, other values mean some difficulty has been encountered, the exact meaning is then code specific. Negative values mean the result shall not be used.
waves.code.parameters (alpha) |  | STR_0D |  | List of the code specific parameters in XML format
waves.code.repository (alpha) |  | STR_0D |  | URL of software repository
waves.code.version (alpha) |  | STR_0D |  | Unique version (tag) of software
waves.coherent_wave (alpha) | [1...N] | STRUCT_ARRAY |  | Wave description for each frequency
waves.coherent_wave[:].beam_tracing (alpha) | [waves.coherent_wave[:].beam_tracing[:].time] | STRUCT_ARRAY |  | Beam tracing calculations, for various time slices
waves.coherent_wave[:].beam_tracing[:].beam (alpha) | [1...N] | STRUCT_ARRAY |  | Set of rays/beams describing the wave propagation
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field (alpha) |  | STRUCTURE |  | Electric field polarization of the ray/beam along its path
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.minus (alpha) |  | STRUCTURE | V.m^-1 | Right hand polarised electric field component
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.minus.imaginary (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | V.m^-1 | Imaginary part
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.minus.real (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | V.m^-1 | Real part
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.parallel (alpha) |  | STRUCTURE | V.m^-1 | Parallel to magnetic field polarised electric field component
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.parallel.imaginary (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | V.m^-1 | Imaginary part
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.parallel.real (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | V.m^-1 | Real part
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.plus (alpha) |  | STRUCTURE | V.m^-1 | Left hand polarised electric field component
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.plus.imaginary (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | V.m^-1 | Imaginary part
waves.coherent_wave[:].beam_tracing[:].beam[:].e_field.plus.real (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | V.m^-1 | Real part
waves.coherent_wave[:].beam_tracing[:].beam[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
waves.coherent_wave[:].beam_tracing[:].beam[:].electrons.power (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | W | Power absorbed along the beam by the species
waves.coherent_wave[:].beam_tracing[:].beam[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].power (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | W | Power absorbed along the beam by the species
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state[:].power (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | W | Power absorbed along the beam by the species
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
waves.coherent_wave[:].beam_tracing[:].beam[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
waves.coherent_wave[:].beam_tracing[:].beam[:].length (alpha) | [1...N] | FLT_1D (uncertain) | m | Ray/beam curvilinear length
waves.coherent_wave[:].beam_tracing[:].beam[:].position (alpha) |  | STRUCTURE |  | Position of the ray/beam along its path
waves.coherent_wave[:].beam_tracing[:].beam[:].position.phi (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | rad | Toroidal angle
waves.coherent_wave[:].beam_tracing[:].beam[:].position.psi (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | Wb | Poloidal flux
waves.coherent_wave[:].beam_tracing[:].beam[:].position.r (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | m | Major radius
waves.coherent_wave[:].beam_tracing[:].beam[:].position.theta (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | rad | Poloidal angle
waves.coherent_wave[:].beam_tracing[:].beam[:].position.z (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | m | Height
waves.coherent_wave[:].beam_tracing[:].beam[:].power_flow_norm (alpha) |  | STRUCTURE |  | Normalised power flow
waves.coherent_wave[:].beam_tracing[:].beam[:].power_flow_norm.parallel (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | - | Normalized power flow in the direction parallel to the magnetic field
waves.coherent_wave[:].beam_tracing[:].beam[:].power_flow_norm.perpendicular (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | - | Normalized power flow in the direction perpendicular to the magnetic field
waves.coherent_wave[:].beam_tracing[:].beam[:].power_initial (alpha) |  | FLT_0D (uncertain) | W | Initial power in the ray/beam
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector (alpha) |  | STRUCTURE |  | Wave vector of the ray/beam along its path
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector.k_r (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | m^-1 | Wave vector component in the major radius direction
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector.k_tor (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | m^-1 | Wave vector component in the toroidal direction
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector.k_z (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | m^-1 | Wave vector component in the vertical direction
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector.n_parallel (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | - | Parallel refractive index
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector.n_perpendicular (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | FLT_1D (uncertain) | - | Perpendicular refractive index
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector.n_tor (alpha) | [waves.coherent_wave[:].beam_tracing[:].beam[:].length] | INT_1D |  | Toroidal wave number, contains a single value if varying_ntor = 1 to avoid useless repetition constant values
waves.coherent_wave[:].beam_tracing[:].beam[:].wave_vector.varying_n_tor (alpha) |  | INT_0D |  | Flag telling whether n_tor is constant along the ray path (0) or varying (1)
waves.coherent_wave[:].beam_tracing[:].time (alpha) |  | FLT_0D | s | Time
waves.coherent_wave[:].full_wave (alpha) | [waves.coherent_wave[:].full_wave[:].time] | STRUCT_ARRAY |  | Solution by a full wave code, given on a generic grid description, for various time slices
waves.coherent_wave[:].full_wave[:].b_field (alpha) |  | STRUCTURE |  | Components of the wave magnetic field
waves.coherent_wave[:].full_wave[:].b_field.bi_normal (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Magnitude of perpendicular (to the static magnetic field) wave magnetic field tangent to a flux surface, given on various grid subsets
waves.coherent_wave[:].full_wave[:].b_field.bi_normal[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].b_field.bi_normal[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].b_field.bi_normal[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].b_field.bi_normal[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].b_field.bi_normal[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].b_field.normal (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Magnitude of wave magnetic field normal to a flux surface, given on various grid subsets
waves.coherent_wave[:].full_wave[:].b_field.normal[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].b_field.normal[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].b_field.normal[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].b_field.normal[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].b_field.normal[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].b_field.parallel (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Parallel (to the static magnetic field) component of the wave magnetic field, given on various grid subsets
waves.coherent_wave[:].full_wave[:].b_field.parallel[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].b_field.parallel[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].b_field.parallel[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].b_field.parallel[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].b_field.parallel[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].e_field (alpha) |  | STRUCTURE |  | Components of the wave electric field
waves.coherent_wave[:].full_wave[:].e_field.bi_normal (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Magnitude of perpendicular (to the static magnetic field) wave electric field tangent to a flux surface, given on various grid subsets
waves.coherent_wave[:].full_wave[:].e_field.bi_normal[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].e_field.bi_normal[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].e_field.bi_normal[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].e_field.bi_normal[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].e_field.bi_normal[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].e_field.minus (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Right hand circularly polarised component of the perpendicular (to the static magnetic field) electric field, given on various grid subsets
waves.coherent_wave[:].full_wave[:].e_field.minus[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].e_field.minus[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].e_field.minus[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].e_field.minus[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].e_field.minus[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].e_field.normal (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Magnitude of wave electric field normal to a flux surface, given on various grid subsets
waves.coherent_wave[:].full_wave[:].e_field.normal[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].e_field.normal[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].e_field.normal[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].e_field.normal[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].e_field.normal[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].e_field.parallel (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Parallel (to the static magnetic field) component of electric field, given on various grid subsets
waves.coherent_wave[:].full_wave[:].e_field.parallel[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].e_field.parallel[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].e_field.parallel[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].e_field.parallel[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].e_field.parallel[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].e_field.plus (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Left hand circularly polarised component of the perpendicular (to the static magnetic field) electric field, given on various grid subsets
waves.coherent_wave[:].full_wave[:].e_field.plus[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].e_field.plus[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].e_field.plus[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].e_field.plus[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].e_field.plus[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].grid (alpha) |  | STRUCTURE |  | Grid description
waves.coherent_wave[:].full_wave[:].grid.grid_subset (alpha) | [1...N] | STRUCT_ARRAY |  | Grid subsets
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].base (alpha) | [1...N] | STRUCT_ARRAY |  | Set of bases for the grid subset. For each base, the structure describes the projection of the base vectors on the canonical frame of the grid.
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].base[:].jacobian (alpha) | [waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].base[:].tensor_contravariant (alpha) | [waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].base[:].tensor_covariant (alpha) | [waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].dimension (alpha) |  | INT_0D |  | Space dimension of the grid subset elements. This must be equal to the sum of the dimensions of the individual objects forming the element.
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | Set of elements defining the grid subset. An element is defined by a combination of objects from potentially all spaces
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects defining the element
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element[:].object[:].dimension (alpha) |  | INT_0D |  | Dimension of the object
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element[:].object[:].index (alpha) |  | INT_0D |  | Object index
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element[:].object[:].space (alpha) |  | INT_0D |  | Index of the space from which that object is taken
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].identifier (alpha) |  | STRUCTURE |  | Grid subset identifier
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].identifier.description (alpha) |  | STR_0D |  | Verbose description
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].identifier.name (alpha) |  | STR_0D |  | Short string identifier
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].metric (alpha) |  | STRUCTURE |  | Metric of the canonical frame onto Cartesian coordinates
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].metric.jacobian (alpha) | [waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element] | FLT_1D (uncertain) | mixed | Metric Jacobian
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].metric.tensor_contravariant (alpha) | [waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Contravariant metric tensor, given on each element of the subgrid (first dimension)
waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].metric.tensor_covariant (alpha) | [waves.coherent_wave[:].full_wave[:].grid.grid_subset[:].element, 1...N, 1...N] | FLT_3D (uncertain) | mixed | Covariant metric tensor, given on each element of the subgrid (first dimension)
waves.coherent_wave[:].full_wave[:].grid.identifier (alpha) |  | STRUCTURE |  | Grid identifier
waves.coherent_wave[:].full_wave[:].grid.identifier.description (alpha) |  | STR_0D |  | Verbose description
waves.coherent_wave[:].full_wave[:].grid.identifier.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
waves.coherent_wave[:].full_wave[:].grid.identifier.name (alpha) |  | STR_0D |  | Short string identifier
waves.coherent_wave[:].full_wave[:].grid.space (alpha) | [1...N] | STRUCT_ARRAY |  | Set of grid spaces
waves.coherent_wave[:].full_wave[:].grid.space[:].coordinates_type (alpha) | [1...N] | INT_1D |  | Type of coordinates describing the physical space, for every coordinate of the space. The size of this node therfore defines the dimension of the space. The meaning of these predefined integer constants can be found in the documentation of the grid service library
waves.coherent_wave[:].full_wave[:].grid.space[:].geometry_type (alpha) |  | STRUCTURE |  | Type of space geometry (0: standard, 1:Fourier)
waves.coherent_wave[:].full_wave[:].grid.space[:].geometry_type.description (alpha) |  | STR_0D |  | Verbose description
waves.coherent_wave[:].full_wave[:].grid.space[:].geometry_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
waves.coherent_wave[:].full_wave[:].grid.space[:].geometry_type.name (alpha) |  | STR_0D |  | Short string identifier
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension (alpha) | [1...N] | STRUCT_ARRAY |  | Definition of the space objects for every dimension (from one to the dimension of the highest-dimensional objects). The index correspond to 1=nodes, 2=edges, 3=faces, 4=cells/volumes, .... For every index, a collection of objects of that dimension is described.
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension[:].object (alpha) | [1...N] | STRUCT_ARRAY |  | Set of objects for a given dimension
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension[:].object[:].boundary (alpha) | [1...N] | STRUCT_ARRAY |  | Set of (n-1)-dimensional objects defining the boundary of this n-dimensional object
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].index (alpha) |  | INT_0D |  | Index of this (n-1)-dimensional boundary object
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension[:].object[:].boundary[:].neighbours (alpha) | [1...N] | INT_1D |  | List of indices of the n-dimensional objects adjacent to the given n-dimensional object. An object can possibly have multiple neighbours on a boundary
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension[:].object[:].geometry (alpha) | [1...N] | FLT_1D (uncertain) | mixed | Geometry data associated with the object. Its dimension depends on the type of object, geometry and coordinate considered.
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension[:].object[:].measure (alpha) |  | FLT_0D (uncertain) | m^dimension | Measure of the space object, i.e. physical size (length for 1d, area for 2d, volume for 3d objects,...)
waves.coherent_wave[:].full_wave[:].grid.space[:].objects_per_dimension[:].object[:].nodes (alpha) | [1...N] | INT_1D |  | List of nodes forming this object (indices to objects_per_dimension(1)%object(:) in Fortran notation)
waves.coherent_wave[:].full_wave[:].k_perpendicular (alpha) | [1...N] | STRUCT_ARRAY | V.m^-1 | Perpendicular wave vector, given on various grid subsets
waves.coherent_wave[:].full_wave[:].k_perpendicular[:].coefficients (alpha) | [waves.coherent_wave[:].full_wave[:].k_perpendicular[:].values, 1...N] | FLT_2D (uncertain) | V.m^-1 | Interpolation coefficients, to be used for a high precision evaluation of the physical quantity with finite elements, provided per element in the grid subset (first dimension).
waves.coherent_wave[:].full_wave[:].k_perpendicular[:].grid_index (alpha) |  | INT_0D |  | Index of the grid used to represent this quantity
waves.coherent_wave[:].full_wave[:].k_perpendicular[:].grid_subset_index (alpha) |  | INT_0D |  | Index of the grid subset the data is provided on
waves.coherent_wave[:].full_wave[:].k_perpendicular[:].values (alpha) | [1...N] | FLT_1D (uncertain) | V.m^-1 | One scalar value is provided per element in the grid subset.
waves.coherent_wave[:].full_wave[:].time (alpha) |  | FLT_0D | s | Time
waves.coherent_wave[:].global_quantities (alpha) | [waves.coherent_wave[:].global_quantities[:].time] | STRUCT_ARRAY |  | Global quantities for various time slices
waves.coherent_wave[:].global_quantities[:].current_tor (alpha) |  | FLT_0D (uncertain) | A | Wave driven toroidal current from a stand alone calculation (not consistent with other sources)
waves.coherent_wave[:].global_quantities[:].current_tor_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | A | Wave driven toroidal current from a stand alone calculation (not consistent with other sources) per toroidal mode number
waves.coherent_wave[:].global_quantities[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
waves.coherent_wave[:].global_quantities[:].electrons.distribution_assumption (alpha) |  | INT_0D |  | Assumption on the distribution function used by the wave solver to calculate the power deposition on this species: 0 = Maxwellian (linear absorption); 1 = quasi-linear (F given by a distributions IDS).
waves.coherent_wave[:].global_quantities[:].electrons.power_fast (alpha) |  | FLT_0D (uncertain) | W | Wave power absorbed by the fast particle population
waves.coherent_wave[:].global_quantities[:].electrons.power_fast_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | W | Wave power absorbed by the fast particle population per toroidal mode number
waves.coherent_wave[:].global_quantities[:].electrons.power_thermal (alpha) |  | FLT_0D (uncertain) | W | Wave power absorbed by the thermal particle population
waves.coherent_wave[:].global_quantities[:].electrons.power_thermal_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | W | Wave power absorbed by the thermal particle population per toroidal mode number
waves.coherent_wave[:].global_quantities[:].frequency (alpha) |  | FLT_0D (uncertain) | Hz | Wave frequency
waves.coherent_wave[:].global_quantities[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
waves.coherent_wave[:].global_quantities[:].ion[:].distribution_assumption (alpha) |  | INT_0D |  | Assumption on the distribution function used by the wave solver to calculate the power deposition on this species: 0 = Maxwellian (linear absorption); 1 = quasi-linear (F given by a distributions IDS).
waves.coherent_wave[:].global_quantities[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
waves.coherent_wave[:].global_quantities[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
waves.coherent_wave[:].global_quantities[:].ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
waves.coherent_wave[:].global_quantities[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
waves.coherent_wave[:].global_quantities[:].ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
waves.coherent_wave[:].global_quantities[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
waves.coherent_wave[:].global_quantities[:].ion[:].power_fast (alpha) |  | FLT_0D (uncertain) | W | Wave power absorbed by the fast particle population
waves.coherent_wave[:].global_quantities[:].ion[:].power_fast_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | W | Wave power absorbed by the fast particle population per toroidal mode number
waves.coherent_wave[:].global_quantities[:].ion[:].power_thermal (alpha) |  | FLT_0D (uncertain) | W | Wave power absorbed by the thermal particle population
waves.coherent_wave[:].global_quantities[:].ion[:].power_thermal_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | W | Wave power absorbed by the thermal particle population per toroidal mode number
waves.coherent_wave[:].global_quantities[:].ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].power_fast (alpha) |  | FLT_0D (uncertain) | W | Wave power absorbed by the fast particle population
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].power_fast_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | W | Wave power absorbed by the fast particle population per toroidal mode number
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].power_thermal (alpha) |  | FLT_0D (uncertain) | W | Wave power absorbed by the thermal particle population
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].power_thermal_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | W | Wave power absorbed by the thermal particle population per toroidal mode number
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
waves.coherent_wave[:].global_quantities[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
waves.coherent_wave[:].global_quantities[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
waves.coherent_wave[:].global_quantities[:].n_tor (alpha) | [1...N] | INT_1D |  | Toroidal mode numbers
waves.coherent_wave[:].global_quantities[:].power (alpha) |  | FLT_0D (uncertain) | W | Total absorbed wave power
waves.coherent_wave[:].global_quantities[:].power_n_tor (alpha) | [waves.coherent_wave[:].global_quantities[:].n_tor] | FLT_1D (uncertain) | W | Absorbed wave power per toroidal mode number
waves.coherent_wave[:].global_quantities[:].time (alpha) |  | FLT_0D | s | Time
waves.coherent_wave[:].identifier (alpha) |  | STRUCTURE |  | Identifier of the coherent wave, in terms of the type and name of the antenna driving the wave and an index separating waves driven by the same antenna.
waves.coherent_wave[:].identifier.antenna_name (alpha) |  | STR_0D |  | Name of the antenna that launches this wave. Corresponds to the name specified in antennas/ec(i)/name, or antennas/ic(i)/name or antennas/lh(i)/name (depends of antenna/wave type) in the ANTENNAS IDS.
waves.coherent_wave[:].identifier.index_in_antenna (alpha) |  | INT_0D |  | Index of the wave (starts at 1), separating different waves generated from a single antenna.
waves.coherent_wave[:].identifier.type (alpha) |  | STRUCTURE |  | Wave/antenna type. index=1 for name=EC; index=2 for name=IC; index=3 for name=LH
waves.coherent_wave[:].identifier.type.description (alpha) |  | STR_0D |  | Verbose description
waves.coherent_wave[:].identifier.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
waves.coherent_wave[:].identifier.type.name (alpha) |  | STR_0D |  | Short string identifier
waves.coherent_wave[:].profiles_1d (alpha) | [waves.coherent_wave[:].profiles_1d[:].time] | STRUCT_ARRAY |  | Source radial profiles (flux surface averaged quantities) for various time slices
waves.coherent_wave[:].profiles_1d[:].current_parallel_density (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A.m^-2 | Flux surface averaged wave driven parallel current density = average(j.B) / B0, where B0 = vacuum_toroidal_field/b0.
waves.coherent_wave[:].profiles_1d[:].current_parallel_density_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | A.m^-2 | Flux surface averaged wave driven parallel current density, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].current_tor_inside (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | A | Wave driven toroidal current from a stand alone calculation (not consistent with other sources), inside a flux surface
waves.coherent_wave[:].profiles_1d[:].current_tor_inside_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | A | Wave driven toroidal current from a stand alone calculation (not consistent with other sources), inside a flux surface, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].n_tor] | STRUCT_ARRAY |  | Components of the electric field per toroidal mode number, averaged over the flux surface, where the averaged is weighted with the power deposition density, such that e_field = ave(e_field.power_density) / ave(power_density)
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].minus (alpha) |  | STRUCTURE | V.m^-1 | Right hand polarised electric field component for every flux surface
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].minus.amplitude (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Amplitude
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].minus.phase (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Phase
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].parallel (alpha) |  | STRUCTURE | V.m^-1 | Parallel electric field component for every flux surface
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].parallel.amplitude (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Amplitude
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].parallel.phase (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Phase
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].plus (alpha) |  | STRUCTURE | V.m^-1 | Left hand polarised electric field component for every flux surface
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].plus.amplitude (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Amplitude
waves.coherent_wave[:].profiles_1d[:].e_field_n_tor[:].plus.phase (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | V.m^-1 | Phase
waves.coherent_wave[:].profiles_1d[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
waves.coherent_wave[:].profiles_1d[:].electrons.power_density_fast (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the fast species
waves.coherent_wave[:].profiles_1d[:].electrons.power_density_fast_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the fast species, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].electrons.power_density_thermal (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the thermal species
waves.coherent_wave[:].profiles_1d[:].electrons.power_density_thermal_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the thermal species, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].electrons.power_inside_fast (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density)
waves.coherent_wave[:].profiles_1d[:].electrons.power_inside_fast_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density), per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].electrons.power_inside_thermal (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density)
waves.coherent_wave[:].profiles_1d[:].electrons.power_inside_thermal_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density), per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].grid (alpha) |  | STRUCTURE |  | Radial grid
waves.coherent_wave[:].profiles_1d[:].grid.area (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^2 | Cross-sectional area of the flux surface
waves.coherent_wave[:].profiles_1d[:].grid.psi (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | Wb | Poloidal magnetic flux
waves.coherent_wave[:].profiles_1d[:].grid.rho_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m | Toroidal flux coordinate. rho_tor = sqrt(b_flux_tor/(pi*b0)) ~ sqrt(pi*r^2*b0/(pi*b0)) ~ r [m]. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm (alpha) | [1...N] | FLT_1D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation, see time_slice/boundary/b_flux_pol_norm in the equilibrium IDS)
waves.coherent_wave[:].profiles_1d[:].grid.volume (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
waves.coherent_wave[:].profiles_1d[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
waves.coherent_wave[:].profiles_1d[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
waves.coherent_wave[:].profiles_1d[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
waves.coherent_wave[:].profiles_1d[:].ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
waves.coherent_wave[:].profiles_1d[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
waves.coherent_wave[:].profiles_1d[:].ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
waves.coherent_wave[:].profiles_1d[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
waves.coherent_wave[:].profiles_1d[:].ion[:].power_density_fast (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the fast species
waves.coherent_wave[:].profiles_1d[:].ion[:].power_density_fast_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the fast species, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].power_density_thermal (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the thermal species
waves.coherent_wave[:].profiles_1d[:].ion[:].power_density_thermal_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the thermal species, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].power_inside_fast (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density)
waves.coherent_wave[:].profiles_1d[:].ion[:].power_inside_fast_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density), per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].power_inside_thermal (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density)
waves.coherent_wave[:].profiles_1d[:].ion[:].power_inside_thermal_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density), per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_density_fast (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the fast species
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_density_fast_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the fast species, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_density_thermal (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the thermal species
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_density_thermal_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density on the thermal species, per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_inside_fast (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density)
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_inside_fast_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density), per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_inside_thermal (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density)
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].power_inside_thermal_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W | Absorbed wave power on thermal species inside a flux surface (cumulative volume integral of the absorbed power density), per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
waves.coherent_wave[:].profiles_1d[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
waves.coherent_wave[:].profiles_1d[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
waves.coherent_wave[:].profiles_1d[:].k_perpendicular (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | V.m^-1 | Perpendicular wave vector, averaged over the flux surface, where the averaged is weighted with the power deposition density, such that k_perpendicular = ave(k_perpendicular.power_density) / ave(power_density), for every flux surface and every toroidal number
waves.coherent_wave[:].profiles_1d[:].n_tor (alpha) | [1...N] | INT_1D |  | Toroidal mode numbers
waves.coherent_wave[:].profiles_1d[:].power_density (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W.m^-3 | Flux surface averaged total absorbed wave power density (electrons + ion + fast populations)
waves.coherent_wave[:].profiles_1d[:].power_density_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W.m^-3 | Flux surface averaged absorbed wave power density per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].power_inside (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm] | FLT_1D (uncertain) | W | Total absorbed wave power (electrons + ion + fast populations) inside a flux surface (cumulative volume integral of the absorbed power density)
waves.coherent_wave[:].profiles_1d[:].power_inside_n_tor (alpha) | [waves.coherent_wave[:].profiles_1d[:].grid.rho_tor_norm, waves.coherent_wave[:].profiles_1d[:].n_tor] | FLT_2D (uncertain) | W | Total absorbed wave power (electrons + ion + fast populations) inside a flux surface (cumulative volume integral of the absorbed power density), per toroidal mode number
waves.coherent_wave[:].profiles_1d[:].time (alpha) |  | FLT_0D | s | Time
waves.coherent_wave[:].profiles_2d (alpha) | [waves.coherent_wave[:].profiles_2d[:].time] | STRUCT_ARRAY |  | 2D profiles in poloidal cross-section, for various time slices
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor (alpha) | [waves.coherent_wave[:].profiles_2d[:].n_tor] | STRUCT_ARRAY |  | Components of the electric field per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].minus (alpha) |  | STRUCTURE | V.m^-1 | Right hand polarised electric field component
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].minus.amplitude (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | V.m^-1 | Amplitude
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].minus.phase (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | V.m^-1 | Phase
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].parallel (alpha) |  | STRUCTURE | V.m^-1 | Parallel electric field component
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].parallel.amplitude (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | V.m^-1 | Amplitude
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].parallel.phase (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | V.m^-1 | Phase
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].plus (alpha) |  | STRUCTURE | V.m^-1 | Left hand polarised electric field component
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].plus.amplitude (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | V.m^-1 | Amplitude
waves.coherent_wave[:].profiles_2d[:].e_field_n_tor[:].plus.phase (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | V.m^-1 | Phase
waves.coherent_wave[:].profiles_2d[:].electrons (alpha) |  | STRUCTURE |  | Quantities related to the electrons
waves.coherent_wave[:].profiles_2d[:].electrons.power_density_fast (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | W.m^-3 | Absorbed wave power density on the fast species
waves.coherent_wave[:].profiles_2d[:].electrons.power_density_fast_n_tor (alpha) | [1...N, 1...N, waves.coherent_wave[:].profiles_2d[:].n_tor] | FLT_3D (uncertain) | W.m^-3 | Absorbed wave power density on the fast species, per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].electrons.power_density_thermal (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | W.m^-3 | Absorbed wave power density on the thermal species
waves.coherent_wave[:].profiles_2d[:].electrons.power_density_thermal_n_tor (alpha) | [1...N, 1...N, waves.coherent_wave[:].profiles_2d[:].n_tor] | FLT_3D (uncertain) | W.m^-3 | Absorbed wave power density on the thermal species, per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].grid (alpha) |  | STRUCTURE |  | 2D grid in a poloidal cross-section
waves.coherent_wave[:].profiles_2d[:].grid.area (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | m^2 | Cross-sectional area of the flux surface
waves.coherent_wave[:].profiles_2d[:].grid.psi (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | Wb | Poloidal magnetic flux
waves.coherent_wave[:].profiles_2d[:].grid.r (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | m | Major radius
waves.coherent_wave[:].profiles_2d[:].grid.rho_tor (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | m | Toroidal flux coordinate. The toroidal field used in its definition is indicated under vacuum_toroidal_field/b0
waves.coherent_wave[:].profiles_2d[:].grid.rho_tor_norm (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | - | Normalised toroidal flux coordinate. The normalizing value for rho_tor_norm, is the toroidal flux coordinate at the equilibrium boundary (LCFS or 99.x % of the LCFS in case of a fixed boundary equilibium calculation)
waves.coherent_wave[:].profiles_2d[:].grid.theta_geometric (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | rad | Geometrical poloidal angle
waves.coherent_wave[:].profiles_2d[:].grid.theta_straight (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | rad | Straight field line poloidal angle
waves.coherent_wave[:].profiles_2d[:].grid.type (alpha) | [waves.coherent_wave[:].profiles_2d[:].grid.rho_tor_norm] | STRUCTURE | m^3 | Grid type: index=0: Rectangular grid in the (R,Z) coordinates; index=1: Rectangular grid in the (radial, theta_geometric) coordinates; index=2: Rectangular grid in the (radial, theta_straight) coordinates. index=3: unstructured grid.
waves.coherent_wave[:].profiles_2d[:].grid.type.description (alpha) |  | STR_0D |  | Verbose description
waves.coherent_wave[:].profiles_2d[:].grid.type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
waves.coherent_wave[:].profiles_2d[:].grid.type.name (alpha) |  | STR_0D |  | Short string identifier
waves.coherent_wave[:].profiles_2d[:].grid.volume (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | m^3 | Volume enclosed inside the magnetic surface
waves.coherent_wave[:].profiles_2d[:].grid.z (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | m | Height
waves.coherent_wave[:].profiles_2d[:].ion (alpha) | [1...N] | STRUCT_ARRAY |  | Quantities related to the different ion species
waves.coherent_wave[:].profiles_2d[:].ion[:].element (alpha) | [1...N] | STRUCT_ARRAY |  | List of elements forming the atom or molecule
waves.coherent_wave[:].profiles_2d[:].ion[:].element[:].a (alpha) |  | FLT_0D (uncertain) | Atomic Mass Unit | Mass of atom
waves.coherent_wave[:].profiles_2d[:].ion[:].element[:].multiplicity (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Multiplicity of the atom
waves.coherent_wave[:].profiles_2d[:].ion[:].element[:].z_n (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Nuclear charge
waves.coherent_wave[:].profiles_2d[:].ion[:].label (alpha) |  | STR_0D |  | String identifying the species (e.g. H+, D+, T+, He+2, C+, D2, DT, CD4, ...)
waves.coherent_wave[:].profiles_2d[:].ion[:].multiple_states_flag (alpha) |  | INT_0D |  | Multiple state calculation flag : 0-Only one state is considered; 1-Multiple states are considered and are described in the state structure
waves.coherent_wave[:].profiles_2d[:].ion[:].power_density_fast (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | W.m^-3 | Absorbed wave power density on the fast species
waves.coherent_wave[:].profiles_2d[:].ion[:].power_density_fast_n_tor (alpha) | [1...N, 1...N, waves.coherent_wave[:].profiles_2d[:].n_tor] | FLT_3D (uncertain) | W.m^-3 | Absorbed wave power density on the fast species, per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].ion[:].power_density_thermal (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | W.m^-3 | Absorbed wave power density on the thermal species
waves.coherent_wave[:].profiles_2d[:].ion[:].power_density_thermal_n_tor (alpha) | [1...N, 1...N, waves.coherent_wave[:].profiles_2d[:].n_tor] | FLT_3D (uncertain) | W.m^-3 | Absorbed wave power density on the thermal species, per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].ion[:].state (alpha) | [1...N_charge_states] | STRUCT_ARRAY |  | Collisional exchange with the various states of the ion species (ionisation, energy, excitation, ...)
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].electron_configuration (alpha) |  | STR_0D |  | Configuration of atomic orbitals of this state, e.g. 1s2-2s1
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].label (alpha) |  | STR_0D |  | String identifying charge state (e.g. C+, C+2 , C+3, C+4, C+5, C+6, ...)
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].power_density_fast (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | W.m^-3 | Absorbed wave power density on the fast species
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].power_density_fast_n_tor (alpha) | [1...N, 1...N, waves.coherent_wave[:].profiles_2d[:].n_tor] | FLT_3D (uncertain) | W.m^-3 | Absorbed wave power density on the fast species, per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].power_density_thermal (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | W.m^-3 | Absorbed wave power density on the thermal species
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].power_density_thermal_n_tor (alpha) | [1...N, 1...N, waves.coherent_wave[:].profiles_2d[:].n_tor] | FLT_3D (uncertain) | W.m^-3 | Absorbed wave power density on the thermal species, per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].vibrational_level (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Vibrational level (can be bundled)
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].vibrational_mode (alpha) |  | STR_0D |  | Vibrational mode of this state, e.g. "A_g". Need to define, or adopt a standard nomenclature.
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].z_max (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Maximum Z of the charge state bundle (equal to z_min if no bundle)
waves.coherent_wave[:].profiles_2d[:].ion[:].state[:].z_min (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Minimum Z of the charge state bundle (z_min = z_max = 0 for a neutral)
waves.coherent_wave[:].profiles_2d[:].ion[:].z_ion (alpha) |  | FLT_0D (uncertain) | Elementary Charge Unit | Ion charge (of the dominant ionisation state; lumped ions are allowed).
waves.coherent_wave[:].profiles_2d[:].n_tor (alpha) | [1...N] | INT_1D |  | Toroidal mode numbers
waves.coherent_wave[:].profiles_2d[:].power_density (alpha) | [1...N, 1...N] | FLT_2D (uncertain) | W.m^-3 | Total absorbed wave power density (electrons + ion + fast populations)
waves.coherent_wave[:].profiles_2d[:].power_density_n_tor (alpha) | [1...N, 1...N, waves.coherent_wave[:].profiles_2d[:].n_tor] | FLT_3D (uncertain) | W.m^-3 | Absorbed wave power density per toroidal mode number
waves.coherent_wave[:].profiles_2d[:].time (alpha) |  | FLT_0D | s | Time
waves.coherent_wave[:].wave_solver_type (alpha) |  | STRUCTURE |  | Type of wave deposition solver used for this wave. Index = 1 for beam/ray tracing; index = 2 for full wave
waves.coherent_wave[:].wave_solver_type.description (alpha) |  | STR_0D |  | Verbose description
waves.coherent_wave[:].wave_solver_type.index (alpha) |  | INT_0D |  | Integer identifier (enumeration index within a list)
waves.coherent_wave[:].wave_solver_type.name (alpha) |  | STR_0D |  | Short string identifier
waves.ids_properties (alpha) |  | STRUCTURE |  | Interface Data Structure properties. This element identifies the node above as an IDS
waves.ids_properties.comment (alpha) |  | STR_0D |  | Any comment describing the content of this IDS
waves.ids_properties.homogeneous_time (alpha) |  | INT_0D |  | 1 if the time of this IDS is homogeneous. In this case, the time values for this IDS are stored in ../time just below the root of this IDS. Otherwise, the time values are stored in the various time fields at lower levels in the tree.
waves.ids_properties.occurrence |  | INT_0D |  |
waves.magnetic_axis (alpha) |  | STRUCTURE |  | Magnetic axis position (used to define a poloidal angle for the 2D profiles)
waves.magnetic_axis.r (alpha) | [waves.time] | FLT_1D (uncertain) | m | Major radius
waves.magnetic_axis.z (alpha) | [waves.time] | FLT_1D (uncertain) | m | Height
waves.time (alpha) | [1...N] | FLT_1D_TYPE |  | Generic time [s]
waves.vacuum_toroidal_field (alpha) |  | STRUCTURE |  | Characteristics of the vacuum toroidal field (used in rho_tor definition)
waves.vacuum_toroidal_field.b0 (alpha) | [waves.time] | FLT_1D (uncertain) | T | Vacuum toroidal field at R0 [T]; Positive sign means anti-clockwise when viewed from above. The product R0B0 must be consistent with the b_tor_vacuum_r field of the tf IDS.
waves.vacuum_toroidal_field.r0 (alpha) |  | FLT_0D (uncertain) | m | Reference major radius where the vacuum toroidal magnetic field is given (usually a fixed position such as the middle of the vessel at the equatorial midplane)